'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var fs = _interopDefault(require('fs'));
var path = _interopDefault(require('path'));

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */

// HTTP Status Code
var HTTP_STATUS = {
  OK: '200',
  NOT_MODIFIED: '304'
};

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
  return typeof obj;
} : function (obj) {
  return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
};









var asyncToGenerator = function (fn) {
  return function () {
    var gen = fn.apply(this, arguments);
    return new Promise(function (resolve, reject) {
      function step(key, arg) {
        try {
          var info = gen[key](arg);
          var value = info.value;
        } catch (error) {
          reject(error);
          return;
        }

        if (info.done) {
          resolve(value);
        } else {
          return Promise.resolve(value).then(function (value) {
            step("next", value);
          }, function (err) {
            step("throw", err);
          });
        }
      }

      return step("next");
    });
  };
};

var classCallCheck = function (instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
};

var createClass = function () {
  function defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  return function (Constructor, protoProps, staticProps) {
    if (protoProps) defineProperties(Constructor.prototype, protoProps);
    if (staticProps) defineProperties(Constructor, staticProps);
    return Constructor;
  };
}();







var get$1 = function get$1(object, property, receiver) {
  if (object === null) object = Function.prototype;
  var desc = Object.getOwnPropertyDescriptor(object, property);

  if (desc === undefined) {
    var parent = Object.getPrototypeOf(object);

    if (parent === null) {
      return undefined;
    } else {
      return get$1(parent, property, receiver);
    }
  } else if ("value" in desc) {
    return desc.value;
  } else {
    var getter = desc.get;

    if (getter === undefined) {
      return undefined;
    }

    return getter.call(receiver);
  }
};

var inherits = function (subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      enumerable: false,
      writable: true,
      configurable: true
    }
  });
  if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
};











var possibleConstructorReturn = function (self, call) {
  if (!self) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return call && (typeof call === "object" || typeof call === "function") ? call : self;
};



var set$1 = function set$1(object, property, value, receiver) {
  var desc = Object.getOwnPropertyDescriptor(object, property);

  if (desc === undefined) {
    var parent = Object.getPrototypeOf(object);

    if (parent !== null) {
      set$1(parent, property, value, receiver);
    }
  } else if ("value" in desc && desc.writable) {
    desc.value = value;
  } else {
    var setter = desc.set;

    if (setter !== undefined) {
      setter.call(receiver, value);
    }
  }

  return value;
};















var toConsumableArray = function (arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  } else {
    return Array.from(arr);
  }
};

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */
var axios = require("axios");

/**
 * Isomorphic Http Promise Requests Class
 * 
 */

var Http = function () {
  function Http() {
    classCallCheck(this, Http);
  }

  createClass(Http, null, [{
    key: 'request',

    /**
     * Request
     * @param   {String}  method
     * @param   {String}  url
     * @param   {Object}  [data]
     * @return  {Promise}
     */
    value: function request(method, url, data, files, useMultipartFormData, showHeader) {
      if (typeof window !== 'undefined' && window.XMLHttpRequest) {
        return Http.xmlHttpRequest(method, url, data);
      }
      return Http.requestPromise(method, url, data, files, useMultipartFormData, showHeader);
    }

    /**
     * XmlHttpRequest request
     * @param   {String}  method
     * @param   {String}  url
     * @param   {Object}  [data]
     * @return  {Promise}
     */

  }, {
    key: 'xmlHttpRequest',
    value: function xmlHttpRequest(method, url, data) {
      return new Promise(function (resolve, reject) {
        var request = new window.XMLHttpRequest();
        request.open(method, url);
        request.onload = function () {
          try {
            var response = JSON.parse(request.response);

            if (request.status.toString() === HTTP_STATUS.OK) {
              resolve(response);
            } else {
              reject(new Error({
                body: response,
                status: request.status
              }));
            }
          } catch (e) {
            reject(new Error({
              body: request.responseText,
              status: request.status
            }));
          }
        };
        request.setRequestHeader('Content-Type', 'application/json');
        request.setRequestHeader('Accept', 'application/json');
        request.send(JSON.stringify(data));
      });
    }

    /**
     * Request Promise
     * @param   {String}  method The HTTP method name (e.g. 'GET').
     * @param   {String}  url A full URL string.
     * @param   {Object}  [data] A mapping of request parameters where a key
     *   is the parameter name and its value is a string or an object
     *   which can be JSON-encoded.
     * @param   {Object}  [files] An optional mapping of file names to ReadStream
     *   objects. These files will be attached to the request.
     * @param   {Boolean} [useMultipartFormData] An optional flag to call with
     *   multipart/form-data.
     * @return  {Promise}
     */

  }, {
    key: 'requestPromise',
    value: function requestPromise(method, url, data, files) {
      var useMultipartFormData = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
      var showHeader = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : false;

      var options = {
        method: method,
        url: url,
        baseURL: FacebookAdsApi.GRAPH,
        json: !useMultipartFormData,
        headers: { 'User-Agent': 'fbbizsdk-nodejs-v' + FacebookAdsApi.SDK_VERSION },
        data: Object,
        resolveWithFullResponse: showHeader
      };
      // Prevent null or undefined input
      // because it can be merged with the files argument later
      if (!data) {
        data = {};
      }

      options.data = data;

      // Handle file attachments if provided
      if (useMultipartFormData || files && Object.keys(files).length > 0) {
        // Use formData instead of body (required by the request-promise library)
        options.data = Object.assign(data, files);
        delete options.data;
      }

      return axios(options).catch(function (response) {
        throw response;
      });
    }
  }]);
  return Http;
}();

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */

// request-promise error types
function FacebookError(error) {
  this.name = 'FacebookError';
  this.message = error.message;
  this.stack = new Error().stack;
}
FacebookError.prototype = Object.create(Error.prototype);
FacebookError.prototype.constructor = FacebookError;

/**
 * Raised when an api request fails.
 */
var FacebookRequestError = function (_FacebookError) {
  inherits(FacebookRequestError, _FacebookError);

  /**
   * @param  {[Object}  response
   * @param  {String}   method
   * @param  {String}   url
   * @param  {Object}   data
   */
  function FacebookRequestError(response, method, url, data) {
    classCallCheck(this, FacebookRequestError);

    var errorResponse = constructErrorResponse(response);

    var _this = possibleConstructorReturn(this, (FacebookRequestError.__proto__ || Object.getPrototypeOf(FacebookRequestError)).call(this, errorResponse));

    _this.name = 'FacebookRequestError';
    _this.message = errorResponse.message;
    _this.status = errorResponse.status;
    _this.response = errorResponse.body;
    _this.headers = errorResponse.headers;
    _this.method = method;
    _this.url = url;
    if (data) {
      _this.data = data;
    }
    return _this;
  }

  return FacebookRequestError;
}(FacebookError);

/**
 * Error response has several structures depended on called APIs or errors.
 * This method contructs and formats the response into the same structure for
 * creating a FacebookRequestError object.
 */
function constructErrorResponse(response) {
  var body = void 0;
  var message = void 0;
  var status = void 0;
  var headers = void 0;

  // Batch request error contains code and body fields
  var isBatchResponse = response.code && response.body;

  if (isBatchResponse) {
    // Handle batch response
    body = typeof response.body === 'string' ? JSON.parse(response.body) : response.body;
    status = response.code;
    message = body.error.message;
    headers = response.headers;
  } else {
    // Handle single response
    if (response.response) {
      // The request was made and the server responded with a status code
      // that falls out of the range of 2xx
      body = response.response.data.error ? response.response.data.error : response.response.data;
      body = typeof body === 'string' ? JSON.parse(body) : body;
      message = body.message;
      status = response.response.status;
      headers = response.response.headers;
    } else if (response.request) {
      body = null;
      message = "The request was made but no response was received";
      status = null;
      headers = null;
    } else {
      body = null;
      message = "Something happened in setting up the request that triggered an Error";
      status = null;
      headers = null;
    }
  }

  return { body: body, message: message, status: status, headers: headers };
}

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * 
 * @format
 */
var CrashReporter = function () {
  function CrashReporter() {
    classCallCheck(this, CrashReporter);

    this._active = true;
  }

  createClass(CrashReporter, null, [{
    key: 'enable',
    value: function enable() {
      var _this = this;

      if (this._instance == undefined || this._instance == null) {
        this._instance = new this();
        process.on('uncaughtException', function (err) {
          if (_this._instance._active && err instanceof Error) {
            var params = privateMethods.parseParam(err);
            if (params != null) {
              console.log('CrashReporter: SDK crash detected!');
              privateMethods.processUncaughtException(err, params);
              return;
            }
          }
          console.log('CrashReporter: No SDK crash detected or crash reporter is disabled!');
          throw err;
        });
      }
    }
  }, {
    key: 'disable',
    value: function disable() {
      if (this._instance == undefined || this._instance == null) {
        return;
      }
      this._instance._active = false;
    }
  }]);
  return CrashReporter;
}();

var privateMethods = {
  processUncaughtException: function processUncaughtException(err, params) {
    FacebookAdsApi.getDefaultApi().getAppID().then(function (data) {
      if (data["data"] !== undefined && data['data']['app_id'] !== undefined) {
        var appID = data['data']['app_id'];

        console.log("active uncaughtException : " + appID);
        var url = [FacebookAdsApi.GRAPH, FacebookAdsApi.VERSION, appID, 'instruments'].join('/');

        Http.request('POST', url, params).then(function (response) {
          console.log('Successfully sent crash report.');
        }).catch(function (response) {
          console.log('Failed to send crash report.');
        }).then(function () {
          throw err;
        });
      }
    }).catch(function (error) {
      console.log("Not be able to find appID, fail to send report to server.");
      throw err;
    });
  },
  parseParam: function parseParam(err) {
    var stack = err.stack.split('\n');

    var params = {};

    if (stack.length == 0) {
      return null;
    }

    var fln = stack[0].split(':');
    params['reason'] = fln[0];
    params['callstack'] = stack;
    params['platform'] = process.version;

    for (var i = 0; i < stack.length; i++) {
      if (stack[i].includes('facebook-nodejs-business-sdk')) {
        return { 'bizsdk_crash_report': params };
      }
    }
    return null;
  }
};

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * 
 * @format
 */
/**
 * Facebook Ads API
 */

var FacebookAdsApi = function () {
  createClass(FacebookAdsApi, null, [{
    key: 'VERSION',
    get: function get() {
      return 'v21.0';
    }
  }, {
    key: 'SDK_VERSION',
    get: function get() {
      return '21.0.0';
    }
  }, {
    key: 'GRAPH',
    get: function get() {
      return 'https://graph.facebook.com';
    }
  }, {
    key: 'GRAPH_VIDEO',
    get: function get() {
      return 'https://graph-video.facebook.com';
    }

    /**
     * @param {String} accessToken
     * @param {String} [locale]
     */

  }]);

  function FacebookAdsApi(accessToken) {
    var locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'en_US';
    var crash_log = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
    classCallCheck(this, FacebookAdsApi);

    if (!accessToken) {
      throw new Error('Access token required');
    }
    this.accessToken = accessToken;
    this.locale = locale;
    this._debug = false;
    this._showHeader = false;
    if (crash_log) {
      CrashReporter.enable();
    }
  }

  /**
   * Instantiate an API and store it as the default
   * @param  {String} accessToken
   * @param  {String} [locale]
   * @return {FacebookAdsApi}
   */


  createClass(FacebookAdsApi, [{
    key: 'getAppID',
    value: function getAppID() {
      var url = [FacebookAdsApi.GRAPH, FacebookAdsApi.VERSION, 'debug_token'].join('/');

      var params = {};

      params['access_token'] = this.accessToken;
      params['input_token'] = this.accessToken;
      params['fields'] = 'app_id';
      url += '?' + FacebookAdsApi._encodeParams(params);

      return Http.request('GET', url, {}, {}, false);
    }
  }, {
    key: 'setDebug',
    value: function setDebug(flag) {
      this._debug = flag;
      return this;
    }
  }, {
    key: 'setShowHeader',
    value: function setShowHeader(flag) {
      this._showHeader = flag;
      return this;
    }

    /**
     * Http Request
     * @param  {String} method
     * @param  {String} path
     * @param  {Object} [params]
     * @param  {Object} [files]
     * @return {Promise}
     */

  }, {
    key: 'call',
    value: function call(method, path$$1) {
      var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var files = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};

      var _this = this;

      var useMultipartFormData = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
      var urlOverride = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : '';

      var url = void 0;
      var data = {};
      if (method === 'POST' || method === 'PUT') {
        data = params;
        params = {};
      }
      var domain = urlOverride || FacebookAdsApi.GRAPH;
      if (typeof path$$1 !== 'string' && !(path$$1 instanceof String)) {
        url = [domain, FacebookAdsApi.VERSION].concat(toConsumableArray(path$$1)).join('/');
        params['access_token'] = this.accessToken;
        url += '?' + FacebookAdsApi._encodeParams(params);
      } else {
        url = path$$1;
      }
      var strUrl = url;
      return Http.request(method, strUrl, data, files, useMultipartFormData, this._showHeader).then(function (response) {
        if (_this._showHeader) {
          response.data['headers'] = response.headers;
        }

        response = response.data;

        if (_this._debug) {
          console.log('200 ' + method + ' ' + url + ' ' + (Object.keys(data).length > 0 ? JSON.stringify(data) : ""));
          console.log('Response: ' + (response ? JSON.stringify(response) : ""));
        }
        return Promise.resolve(response);
      }).catch(function (response) {
        if (_this._debug && response.response) {
          console.log(response.response.status + ' ' + method + ' ' + url + '\n            ' + (Object.keys(data).length > 0 ? JSON.stringify(data) : ''));
        }
        throw new FacebookRequestError(response, method, url, data);
      });
    }
  }], [{
    key: 'init',
    value: function init(accessToken) {
      var locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'en_US';
      var crash_log = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      var api = new this(accessToken, locale, crash_log);
      this.setDefaultApi(api);
      return api;
    }
  }, {
    key: 'setDefaultApi',
    value: function setDefaultApi(api) {
      this._defaultApi = api;
    }
  }, {
    key: 'getDefaultApi',
    value: function getDefaultApi() {
      return this._defaultApi;
    }
  }, {
    key: '_encodeParams',
    value: function _encodeParams(params) {
      return Object.keys(params).map(function (key) {
        var param = params[key];
        if ((typeof param === 'undefined' ? 'undefined' : _typeof(param)) === 'object') {
          param = param ? JSON.stringify(param) : '';
        }
        return encodeURIComponent(key) + '=' + encodeURIComponent(param);
      }).join('&');
    }
  }]);
  return FacebookAdsApi;
}();

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Abstract Object
 * Manages object data fields and provides matching properties
 *
 * 
 * @format
 */
var AbstractObject = function () {
  createClass(AbstractObject, null, [{
    key: 'Fields',

    // This is a Flow workaround for setting `this[field]` in the set() function.
    get: function get() {
      return Object.freeze({});
    }
  }]);

  function AbstractObject() {
    var _this = this;

    classCallCheck(this, AbstractObject);

    this._data = {};
    if (this.constructor.Fields === undefined) {
      throw new Error('A "Fields" frozen object must be defined in the object class');
    }
    var fields = this.constructor.Fields;
    this._fields = Object.keys(fields);
    this._fields.forEach(function (field) {
      _this._defineProperty(field);
    });
  }

  /**
   * Define data getter and setter field
   * @param {String} field
   */


  createClass(AbstractObject, [{
    key: '_defineProperty',
    value: function _defineProperty(field) {
      var _this2 = this;

      Object.defineProperty(this, field, {
        get: function get() {
          return _this2._data[field];
        },
        set: function set(value) {
          _this2._data[field] = value;
        },
        enumerable: true
      });
    }

    /**
     * Set data field
     * @param {String} field
     * @param {Mixed} value
     * @return this
     */

  }, {
    key: 'set',
    value: function set(field, value) {
      if (this._fields.indexOf(field) < 0) {
        this._defineProperty(field);
      }
      this[field] = value;
      return this;
    }

    /**
     * Set multiple data fields
     * @param {Object} data
     * @return this
     */

  }, {
    key: 'setData',
    value: function setData(data) {
      var _this3 = this;

      Object.keys(data).forEach(function (key) {
        _this3.set(key, data[key]);
      });
      return this;
    }

    /**
     * Export object data
     * @return {Object}
     */

  }, {
    key: 'exportData',
    value: function exportData() {
      return this._data;
    }
  }]);
  return AbstractObject;
}();

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * 
 * @format
 */
var Utils = function () {
  function Utils() {
    classCallCheck(this, Utils);
  }

  createClass(Utils, null, [{
    key: 'normalizeEndpoint',
    value: function normalizeEndpoint(str) {
      return str.replace(/^\/|\/$/g, '');
    }
  }, {
    key: 'removePreceedingSlash',
    value: function removePreceedingSlash(str) {
      return str.length && str[0] === '/' ? str.slice(1) : str;
    }
  }]);
  return Utils;
}();

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * Cursor
 * Iterates over edge objects and controls pagination
 * 
 * @format
 */
var Cursor = function (_Array) {
  inherits(Cursor, _Array);

  /**
   * @param  {Object} sourceObject
   * @param  {Object} targetClass
   * @param  {Object} [params]
   * @param  {String} [endpoint]
   */
  function Cursor(sourceObject, targetClass, params, endpoint) {
    classCallCheck(this, Cursor);

    var _this = possibleConstructorReturn(this, (Cursor.__proto__ || Object.getPrototypeOf(Cursor)).call(this));

    var next = [sourceObject.getId()];
    if (endpoint) {
      next.push(Utils.normalizeEndpoint(endpoint));
    } else {
      throw new Error('No endpoint specified for the target edge.');
    }
    _this._api = sourceObject.getApi();
    _this._targetClass = targetClass;
    _this.paging = { next: next, params: params };

    _this.clear = function () {
      _this.length = 0;
    };

    _this.set = function (array) {
      _this.clear();
      _this.push.apply(_this, toConsumableArray(array));
    };

    _this.next = function () {
      if (!_this.hasNext()) {
        return Promise.reject(new RangeError('end of pagination'));
      }
      return _this._loadPage(_this.paging.next);
    };

    _this.hasNext = function () {
      return Boolean(_this.paging) && Boolean(_this.paging.next);
    };

    _this.previous = function () {
      if (!_this.hasPrevious()) {
        return Promise.reject(new RangeError('start of pagination'));
      }
      return _this._loadPage(_this.paging.previous);
    };

    _this.hasPrevious = function () {
      return Boolean(_this.paging) && Boolean(_this.paging.previous);
    };

    _this._loadPage = function (path$$1) {
      var promise = new Promise(function (resolve, reject) {
        _this._api.call('GET', path$$1, _this.paging.params).then(function (response) {
          var objects = _this._buildObjectsFromResponse(response);
          _this.set(objects);
          _this.paging = response.paging;
          _this.summary = response.summary;
          _this.headers = response.headers;
          resolve(_this);
        }).catch(reject);
      });

      return promise;
    };

    _this._buildObjectsFromResponse = function (response) {
      return response.data.map(function (item) {
        var That = _this._targetClass;
        if (That.name === 'AbstractObject') {
          var result = new That();
          result.setData(item);
          return result;
        }
        return new That(item && item.id ? item.id : null, item, undefined, _this._api);
      });
    };
    return _this;
  }

  return Cursor;
}(Array);

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @format
 * 
 */
/**
 * Abstract Crud Object
 * Facebook Object basic persistence functions
 * @extends AbstractObject
 * 
 */
var AbstractCrudObject = function (_AbstractObject) {
  inherits(AbstractCrudObject, _AbstractObject);

  /**
   * @param  {Object} data
   * @param  {String} parentId
   * @param  {FacebookAdApi} [api]
   */
  function AbstractCrudObject() {
    var id = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
    var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var parentId = arguments[2];
    var api = arguments[3];
    classCallCheck(this, AbstractCrudObject);

    var _this = possibleConstructorReturn(this, (AbstractCrudObject.__proto__ || Object.getPrototypeOf(AbstractCrudObject)).call(this));

    _this._parentId = parentId;
    _this._api = api || FacebookAdsApi.getDefaultApi();
    if (id) {
      data.id = id;
    }
    if (data) {
      get$1(AbstractCrudObject.prototype.__proto__ || Object.getPrototypeOf(AbstractCrudObject.prototype), 'setData', _this).call(_this, data);
    }
    return _this;
  }

  /**
   * Define data getter and setter recording changes
   * @param {String} field
   */


  createClass(AbstractCrudObject, [{
    key: '_defineProperty',
    value: function _defineProperty(field) {
      var _this2 = this;

      if (this._changes === undefined) {
        this._changes = {};
      }
      Object.defineProperty(this, field, {
        get: function get() {
          return _this2._data[field];
        },
        set: function set(value) {
          _this2._changes[field] = value;
          _this2._data[field] = value;
        },
        enumerable: true
      });
    }

    /**
     * Set object data as if it were read from the server. Wipes related changes
     * @param {Object} data
     * @return this
     */

  }, {
    key: 'setData',
    value: function setData(data) {
      var _this3 = this;

      get$1(AbstractCrudObject.prototype.__proto__ || Object.getPrototypeOf(AbstractCrudObject.prototype), 'setData', this).call(this, data);
      Object.keys(data).forEach(function (key) {
        delete _this3._changes[key];
      });
      return this;
    }

    /**
     * Export changed object data
     * @return {Object}
     */

  }, {
    key: 'exportData',
    value: function exportData() {
      return this._changes;
    }

    /**
     * Export object data
     * @return {Object}
     */

  }, {
    key: 'exportAllData',
    value: function exportAllData() {
      return this._data;
    }

    /**
     * Clear change history
     * @return this
     */

  }, {
    key: 'clearHistory',
    value: function clearHistory() {
      this._changes = {};
      return this;
    }

    /**
     * @throws {Error} if object has no id
     * @return {String}
     */

  }, {
    key: 'getId',
    value: function getId() {
      if (!this.id) {
        throw new Error(this.constructor.name + ' Id not defined');
      }
      return this.id;
    }

    /**
     * @throws {Error} if object has no parent id
     * @return {String}
     */

  }, {
    key: 'getParentId',
    value: function getParentId() {
      if (!this._parentId) {
        throw new Error(this.constructor.name + ' parentId not defined');
      }
      return this._parentId;
    }

    /**
     * @return {String}
     */

  }, {
    key: 'getNodePath',
    value: function getNodePath() {
      return this.getId();
    }

    /**
     * Return object API instance
     * @throws {Error} if object doesn't hold an API
     * @return {FacebookAdsApi}
     */

  }, {
    key: 'getApi',
    value: function getApi() {
      var api = this._api;
      if (!api) {
        throw new Error(this.constructor.name + ' does not yet have an\n        associated api object.\n Did you forget to\n        instantiate an API session with:\n        "FacebookAdsApi.init"?');
      }
      return api;
    }

    /**
     * Read object data
     * @param   {Array}   [fields]
     * @param   {Object}  [params]
     * @return  {Promise}
     */

  }, {
    key: 'read',
    value: function read(fields) {
      var _this4 = this;

      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      var api = this.getApi();
      var path$$1 = [this.getNodePath()];
      if (fields) {
        params['fields'] = fields.join(',');
      }
      return new Promise(function (resolve, reject) {
        api.call('GET', path$$1, params).then(function (data) {
          return resolve(_this4.setData(data));
        }).catch(reject);
      });
    }

    /**
     * Update object
     * @param   {Object}  [params]
     * @return  {Promise}
     */

  }, {
    key: 'update',
    value: function update() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      var api = this.getApi();
      var path$$1 = [this.getNodePath()];
      params = Object.assign(params, this.exportData());
      return new Promise(function (resolve, reject) {
        api.call('POST', path$$1, params).then(function (data) {
          return resolve(data);
        }).catch(reject);
      });
    }

    /**
     * Delete object
     * @param   {Object}  [params]
     * @return  {Promise}
     */

  }, {
    key: 'delete',
    value: function _delete() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      var api = this.getApi();
      var path$$1 = [this.getNodePath()];
      params = Object.assign(params, this.exportData());
      return new Promise(function (resolve, reject) {
        api.call('DELETE', path$$1, params).then(function (data) {
          return resolve(data);
        }).catch(reject);
      });
    }

    /**
     * Initialize Cursor to paginate on edges
     * @param  {Object}  targetClass
     * @param  {Array}   [fields]
     * @param  {Object}  [params]
     * @param  {Boolean} [fetchFirstPage]
     * @param  {String}  [endpoint]
     * @return {Cursor}
     */

  }, {
    key: 'getEdge',
    value: function getEdge(targetClass, fields) {
      var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var fetchFirstPage = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
      var endpoint = arguments[4];

      if (fields && fields.length > 0) {
        params['fields'] = fields.join(',');
      }
      var sourceObject = this;
      var cursor = new Cursor(sourceObject, targetClass, params, endpoint);
      if (fetchFirstPage) {
        return cursor.next();
      }
      return cursor;
    }

    /**
     * Create edge object
     * @param   {String}  [endpoint]
     * @param   {Array}  [fields]
     * @param   {Object}  [params]
     * @param   {Function} [targetClassConstructor]
     * @return  {Promise}
     */

  }, {
    key: 'createEdge',
    value: function createEdge(endpoint, fields) {
      var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

      var _this5 = this;

      var targetClassConstructor = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
      var pathOverride = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : null;

      if (fields && fields.length > 0) {
        params['fields'] = fields.join(',');
      }
      var api = this.getApi();
      var path$$1 = pathOverride != null ? pathOverride : [this.getNodePath(), Utils.removePreceedingSlash(endpoint)];
      params = Object.assign(params, this.exportData());
      return new Promise(function (resolve, reject) {
        api.call('POST', path$$1, params).then(function (data) {
          resolve(
          /* eslint new-cap: "off" */
          targetClassConstructor === null ? _this5.setData(data) : new targetClassConstructor(data.id, data));
        }).catch(reject);
      });
    }

    /**
     * Delete edge object
     * @param   {String}  [endpoint]
     * @param   {Object}  [params]
     * @return  {Promise}
     */

  }, {
    key: 'deleteEdge',
    value: function deleteEdge(endpoint) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      var api = this.getApi();
      var path$$1 = [this.getNodePath(), Utils.removePreceedingSlash(endpoint)];
      params = Object.assign(params, this.exportData());
      return new Promise(function (resolve, reject) {
        api.call('DELETE', path$$1, params).then(function (data) {
          return resolve(data);
        }).catch(reject);
      });
    }

    /**
     * Read Objects by Ids
     * @param  {Array}          ids
     * @param  {Array}          [fields]
     * @param  {Object}         [params]
     * @param  {FacebookAdsApi} [api]
     * @return {Promise}
     */

  }], [{
    key: 'getByIds',
    value: function getByIds(ids, fields) {
      var _this6 = this;

      var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
      var api = arguments[3];

      api = api || FacebookAdsApi.getDefaultApi();
      if (fields && fields.length > 0) {
        params['fields'] = fields.join(',');
      }
      params['ids'] = ids.join(',');
      return new Promise(function (resolve, reject) {
        return api.call('GET', [''], params).then(function (response) {
          var result = [];
          for (var id in response) {
            var data = response[id];
            var That = _this6;
            var object = new That(data);
            result.push(object);
          }
          resolve(result);
        }).catch(reject);
      });
    }
  }]);
  return AbstractCrudObject;
}(AbstractObject);

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * 
 * @format
 */
/**
 * Represents an API request
 */

var APIRequest = function () {

  /**
   * @param {string} nodeId The node id to perform the api call.
   * @param {string} method The HTTP method of the call.
   * @param {string} endpoint The edge of the api call.
   */
  function APIRequest(nodeId, method, endpoint) {
    classCallCheck(this, APIRequest);

    this._nodeId = nodeId;
    this._method = method;
    this._endpoint = endpoint.replace('/', '');
    this._path = [nodeId, this.endpoint];
    this._fields = [];
    this._fileParams = Object.create(null);
    this._params = Object.create(null);
    this._fileCounter = 0;
  }

  /**
   * Getter function for node ID
   * @return {string} Node ID
   */


  createClass(APIRequest, [{
    key: 'addFile',


    /**
     * @param {string} filePath Path to file attached to the request
     * @return {APIReqeust} APIRequest instance
     */
    value: function addFile(filePath) {
      var fileKey = 'source' + this._fileCounter;
      var stats = fs.lstatSync(filePath);

      if (!stats.isFile()) {
        throw Error('Cannot find file ' + filePath + '!');
      }

      this._fileParams[fileKey] = filePath;
      this._fileCounter += 1;

      return this;
    }

    /**
     * @param {string[]} filePaths Array of paths to files attached to the request
     * @return {APIRequest} APIRequest instance
     */

  }, {
    key: 'addFiles',
    value: function addFiles(filePaths) {
      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = filePaths[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var filePath = _step.value;

          this.addFile(filePath);
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }

      return this;
    }

    /**
     * @param {string} field Requested field
     * @return {APIReqeust} APIRequest instance
     */

  }, {
    key: 'addField',
    value: function addField(field) {
      if (!this._fields.includes(field)) {
        this._fields.push(field);
      }

      return this;
    }

    /**
     * @param {string[]} fields Array of requested fields
     * @return {APIRequest} APIRequest instance
     */

  }, {
    key: 'addFields',
    value: function addFields(fields) {
      var _iteratorNormalCompletion2 = true;
      var _didIteratorError2 = false;
      var _iteratorError2 = undefined;

      try {
        for (var _iterator2 = fields[Symbol.iterator](), _step2; !(_iteratorNormalCompletion2 = (_step2 = _iterator2.next()).done); _iteratorNormalCompletion2 = true) {
          var field = _step2.value;

          this.addField(field);
        }
      } catch (err) {
        _didIteratorError2 = true;
        _iteratorError2 = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion2 && _iterator2.return) {
            _iterator2.return();
          }
        } finally {
          if (_didIteratorError2) {
            throw _iteratorError2;
          }
        }
      }

      return this;
    }

    /**
     * @param {string} key Param key
     * @param {*} value Param value
     * @return {APIRequest} APIRequest instance
     */

  }, {
    key: 'addParam',
    value: function addParam(key, value) {
      this._params[key] = value;

      return this;
    }

    /**
     * @param {Object} params An object containing param keys and values
     * @return {APIRequest} APIRequest instance
     */

  }, {
    key: 'addParams',
    value: function addParams(params) {
      this._params = params;

      return this;
    }
  }, {
    key: 'nodeId',
    get: function get() {
      return this._nodeId;
    }

    /**
     * Getter function for HTTP method e.g. GET, POST
     * @return {string} HTTP method
     */

  }, {
    key: 'method',
    get: function get() {
      return this._method;
    }

    /**
     * Getter function for the edge of the API call
     * @return {string} Endpoint edge
     */

  }, {
    key: 'endpoint',
    get: function get() {
      return this._endpoint;
    }

    /**
     * Getter function for path tokens
     * @return {Array<string>} Array of path tokens
     */

  }, {
    key: 'path',
    get: function get() {
      return this._path;
    }

    /**
     * Getter function for requested fields
     * @return {Array<string>} Array of request fields
     */

  }, {
    key: 'fields',
    get: function get() {
      return this._fields;
    }

    /**
     * Getter function for API params
     * @return {Object} Object containing API Params
     */

  }, {
    key: 'params',
    get: function get() {
      // Deep cloning when object value is not a function
      return JSON.parse(JSON.stringify(this._params));
    }

    /**
     * Getter function for API fileparams
     * @return {Object} Object containing API fileParams
     */

  }, {
    key: 'fileParams',
    get: function get() {
      // Deep cloning when object value is not a function
      return JSON.parse(JSON.stringify(this._fileParams));
    }
  }]);
  return APIRequest;
}();

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * 
 * @format
 */

/**
 * Encapsulates an http response from Facebook's Graph API.
 */

var APIResponse = function () {
  function APIResponse(response, call) {
    classCallCheck(this, APIResponse);

    response.body = JSON.parse(response.body);
    this._body = response.body;
    this._httpStatus = response.code;
    this._headers = response.headers;
    this._call = call;
    this._response = response;
  }

  /**
   * @return {Object} The response body
   */


  createClass(APIResponse, [{
    key: 'body',
    get: function get() {
      return this._body;
    }
  }, {
    key: 'headers',
    get: function get() {
      return this._headers;
    }
  }, {
    key: 'etag',
    get: function get() {
      return this._headers['ETag'];
    }
  }, {
    key: 'status',
    get: function get() {
      return this._httpStatus;
    }
  }, {
    key: 'isSuccess',
    get: function get() {
      var body = this._body;

      if ('error' in body) {
        return false;
      } else if (Object.keys(body).length !== 0) {
        if ('success' in body) {
          return body['success'];
        }
        return !('Service Unavailable' in body);
      } else if (this._httpStatus === HTTP_STATUS.NOT_MODIFIED) {
        // ETag Hit
        return true;
      } else if (this._httpStatus === HTTP_STATUS.OK) {
        // HTTP OK
        return true;
      } else {
        // Something else
        return false;
      }
    }
  }, {
    key: 'error',
    get: function get() {
      if (this.isSuccess) {
        return null;
      }

      return new FacebookRequestError(this._response, this._call.method, this._call.relativeUrl, this._call.body);
    }
  }]);
  return APIResponse;
}();

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * 
 * @format
 */
/**
 * Facebook Ads API Batch
 */

var FacebookAdsApiBatch = function () {

  /**
   * @param {FacebookAdsApi} api
   * @param {Function} successCallback
   * @param {Function} failureCallback
   */
  function FacebookAdsApiBatch(api, successCallback, failureCallback) {
    classCallCheck(this, FacebookAdsApiBatch);

    this._api = api;
    this._files = [];
    this._batch = [];
    this._requests = [];
    this._successCallbacks = [];
    this._failureCallbacks = [];

    if (successCallback != null) {
      this._successCallbacks.push(successCallback);
    }

    if (failureCallback != null) {
      this._failureCallbacks.push(failureCallback);
    }
  }

  /**
   * Adds a call to the batch.
   * @param  {string} method The HTTP method name (e.g. 'GET').
   * @param  {string[]|string} relativePath An array of path tokens or
   *   a relative URL string. An array will be translated to a url as follows:
   *     <graph url>/<tuple[0]>/<tuple[1]>...
   *   It will be assumed that if the path is not a string, it will be iterable.
   * @param  {Object} [params] A mapping of request parameters
   *   where a key is the parameter name and its value is a string or an object
   *   which can be JSON-encoded.
   * @param {Object} [files] An optional mapping of file names to binary open
   *   file objects. These files will be attached to the request.
   * @param {Function} [successCallback] A callback function which will be
   *   called with the response of this call if the call succeeded.
   * @param {Function} [failureCallback] A callback function which will be
   *   called with the response of this call if the call failed.
   * @param {APIRequest} [request] The APIRequest object
   * @return {Object} An object describing the call
   */


  createClass(FacebookAdsApiBatch, [{
    key: 'add',
    value: function add(method, relativePath, params, files, successCallback, failureCallback, request) {
      // Construct a relaitveUrl from relateivePath by assuming that
      // relativePath can only be a string or an array of strings
      var relativeUrl = typeof relativePath === 'string' ? relativePath : relativePath.join('/');

      // Contruct key-value pairs from params for GET querystring or POST body
      if (params != null) {
        var keyVals = [];

        for (var key in params) {
          var value = params[key];
          if (_typeof(params[key]) === 'object' && !(params[key] instanceof Date)) {
            value = JSON.stringify(value);
          }
          keyVals.push(key + '=' + value);
        }

        if (method === 'GET') {
          relativeUrl += '?' + keyVals.join('&');
        } else {
          var body = keyVals.join('&');
        }

        if (params && params['name']) {
          var name = params['name'];
        }
      }

      // Handle attached files
      if (files != null) {
        var attachedFiles = Object.keys(files).join(',');
      }

      // A Call object that will be used in a batch request
      var call = {
        method: method,
        relative_url: relativeUrl,
        body: body,
        name: name,
        attachedFiles: attachedFiles
      };

      this._batch.push(call);
      this._files.push(files);
      this._successCallbacks.push(successCallback);
      this._failureCallbacks.push(failureCallback);
      if (request !== undefined) {
        this._requests.push(request);
      }

      return call;
    }

    /**
     * Interface to add a APIRequest to the batch.
     * @param  {APIRequest} request The APIRequest object to add
     * @param  {Function} [successCallback] A callback function which
     *   will be called with response of this call if the call succeeded.
     * @param  {Function} [failureCallback] A callback function which
     *   will be called with the FacebookResponse of this call if the call failed.
     * @return {Object} An object describing the call
     */

  }, {
    key: 'addRequest',
    value: function addRequest(request, successCallback, failureCallback) {
      var updatedParams = request.params;
      updatedParams['fields'] = request.fields.join();

      return this.add(request.method, request.path, updatedParams, request.fileParams, successCallback, failureCallback, request);
    }

    /**
     * Makes a batch call to the api associated with this object.
     * For each individual call response, calls the success or failure callback
     * function if they were specified.
     * Note: Does not explicitly raise exceptions. Individual exceptions won't
     * be thrown for each call that fails. The success and failure callback
     * functions corresponding to a call should handle its success or failure.
     * @return {FacebookAdsApiBatch|None} If some of the calls have failed,
     *   returns a new FacebookAdsApiBatch object with those calls.
     *   Otherwise, returns None.
     */

  }, {
    key: 'execute',
    value: function execute() {
      var _this = this;

      if (this._batch.length < 1) {
        return;
      }

      var method = 'POST';
      var path$$1 = []; // request to root domain for a batch request
      var params = {
        batch: this._batch
      };

      // Call to the batch endpoint (WIP)
      return this._api.call(method, path$$1, params).then(function (responses) {
        // Keep track of batch indices that need to retry
        var retryIndices = [];

        // Check each response
        for (var index = 0; index < responses.length; index++) {
          var response = responses[index];

          if (response != null) {
            var apiResponse = new APIResponse(response, _this._batch[index]);

            // Call the success callback if provided
            if (apiResponse.isSuccess) {
              if (_this._successCallbacks[index]) {
                _this._successCallbacks[index](apiResponse);
              }
            } else {
              // Call the failure callback if provided
              if (_this._failureCallbacks[index]) {
                _this._failureCallbacks[index](apiResponse);
              }
            }
          } else {
            // Do not get response, so, we keep track of the index to retry
            retryIndices.push(index);
          }
        }

        // Create and return new batch if we need to retry
        if (retryIndices.length > 0) {
          // Create a new batch from retry indices in the current batch
          var newBatch = new FacebookAdsApiBatch(_this._api);

          var _iteratorNormalCompletion = true;
          var _didIteratorError = false;
          var _iteratorError = undefined;

          try {
            for (var _iterator = retryIndices[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
              var _index = _step.value;

              newBatch._files.push(_this._files[_index]);
              newBatch._batch.push(_this._batch[_index]);
              newBatch._successCallbacks.push(_this._successCallbacks[_index]);
              newBatch._failureCallbacks.push(_this._failureCallbacks[_index]);
            }
          } catch (err) {
            _didIteratorError = true;
            _iteratorError = err;
          } finally {
            try {
              if (!_iteratorNormalCompletion && _iterator.return) {
                _iterator.return();
              }
            } finally {
              if (_didIteratorError) {
                throw _iteratorError;
              }
            }
          }

          return newBatch;
        }

        // No retry
        return null;
      }).catch(function (error) {
        throw error;
      });
    }
  }]);
  return FacebookAdsApiBatch;
}();

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoThumbnail
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoThumbnail = function (_AbstractCrudObject) {
  inherits(VideoThumbnail, _AbstractCrudObject);

  function VideoThumbnail() {
    classCallCheck(this, VideoThumbnail);
    return possibleConstructorReturn(this, (VideoThumbnail.__proto__ || Object.getPrototypeOf(VideoThumbnail)).apply(this, arguments));
  }

  createClass(VideoThumbnail, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        height: 'height',
        id: 'id',
        is_preferred: 'is_preferred',
        name: 'name',
        scale: 'scale',
        uri: 'uri',
        width: 'width'
      });
    }
  }]);
  return VideoThumbnail;
}(AbstractCrudObject);

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @format
 * 
 */
/**
 * Video uploader that can upload videos to adaccount
 **/

var VideoUploader = function () {
  function VideoUploader() {
    classCallCheck(this, VideoUploader);

    this._session = null;
  }

  /**
   * Upload the given video file.
   * @param {AdVideo} video The AdVideo object that will be uploaded
   * @param {Boolean} [waitForEncoding] Whether to wait until encoding
   *   is finished
   **/


  createClass(VideoUploader, [{
    key: 'upload',
    value: function upload(video, waitForEncoding) {
      // Check there is no existing session
      if (this._session) {
        throw Error('There is already an upload session for this video uploader');
      }

      // Initate an upload session
      this._session = new VideoUploadSession(video, waitForEncoding);
      var result = this._session.start();
      this._session = null;
      return result;
    }
  }]);
  return VideoUploader;
}();

var VideoUploadSession = function () {
  function VideoUploadSession(video) {
    var waitForEncoding = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    classCallCheck(this, VideoUploadSession);

    this._video = video;
    this._api = video.getApi();

    if (video.filepath) {
      this._filePath = video.filepath;
      this._slideshowSpec = null;
    } else if (video.slideshow_spec) {
      this._slideshowSpec = video.slideshow_spec;
      this._filePath = null;
    }

    this._accountId = video.getParentId();
    this._waitForEncoding = waitForEncoding;
    // Setup start request manager
    this._startRequestManager = new VideoUploadStartRequestManager(this._api);
    // Setup transfer request manager
    this._transferRequestManager = new VideoUploadTransferRequestManager(this._api);
    // Setup finish request manager
    this._finishRequestManager = new VideoUploadFinishRequestManager(this._api);
  }

  createClass(VideoUploadSession, [{
    key: 'start',
    value: function () {
      var _ref = asyncToGenerator(function* () {
        var videoId = void 0;

        // Run start request manager
        var startResponse = yield this._startRequestManager.sendRequest(this.getStartRequestContext());
        this._startOffset = parseInt(startResponse['start_offset']);
        this._endOffset = parseInt(startResponse['end_offset']);
        this._sessionId = startResponse['upload_session_id'];
        videoId = startResponse['video_id'];
        // Run transfer request manager
        yield this._transferRequestManager.sendRequest(this.getTransferRequestContext());
        // Run finish request manager
        var finishResponse = yield this._finishRequestManager.sendRequest(this.getFinishRequestContext());
        // Populate the video info
        var body = finishResponse;
        body.id = videoId;
        delete body.success;

        return body;
      });

      function start() {
        return _ref.apply(this, arguments);
      }

      return start;
    }()
  }, {
    key: 'getStartRequestContext',
    value: function getStartRequestContext() {
      var context = new VideoUploadRequestContext();

      if (this._filePath) {
        // Read file size
        context.fileSize = fs.statSync(this._filePath).size;
      }
      context.accountId = this._accountId;

      return context;
    }
  }, {
    key: 'getTransferRequestContext',
    value: function getTransferRequestContext() {
      var context = new VideoUploadRequestContext();

      context.sessionId = this._sessionId;
      context.startOffset = this._startOffset;
      context.endOffset = this._endOffset;

      if (this._filePath) {
        context.filePath = this._filePath;
      }
      if (this._slideshowSpec) {
        context.slideshowSpec = this._slideshowSpec;
      }
      context.accountId = this._accountId;

      return context;
    }
  }, {
    key: 'getFinishRequestContext',
    value: function getFinishRequestContext() {
      var context = new VideoUploadRequestContext();

      context.sessionId = this._sessionId;
      context.accountId = this._accountId;

      if (this._filePath) {
        context.fileName = path.basename(this._filePath);
      }

      return context;
    }
  }]);
  return VideoUploadSession;
}();

/**
 * Abstract class for request managers
 **/


var VideoUploadRequestManager = function () {
  function VideoUploadRequestManager(api) {
    classCallCheck(this, VideoUploadRequestManager);

    this._api = api;
  }

  createClass(VideoUploadRequestManager, [{
    key: 'sendRequest',
    value: function sendRequest(context) {
      throw new TypeError('Class extending VideoUploadRequestManager must implement ' + 'sendRequest method');
    }
  }, {
    key: 'getParamsFromContext',
    value: function getParamsFromContext(context) {
      throw new TypeError('Class extending VideoUploadRequestManager must implement ' + 'getParamsFromContext method');
    }
  }]);
  return VideoUploadRequestManager;
}();

var VideoUploadStartRequestManager = function (_VideoUploadRequestMa) {
  inherits(VideoUploadStartRequestManager, _VideoUploadRequestMa);

  function VideoUploadStartRequestManager() {
    classCallCheck(this, VideoUploadStartRequestManager);
    return possibleConstructorReturn(this, (VideoUploadStartRequestManager.__proto__ || Object.getPrototypeOf(VideoUploadStartRequestManager)).apply(this, arguments));
  }

  createClass(VideoUploadStartRequestManager, [{
    key: 'sendRequest',

    /**
     * Send start request with the given context
     **/
    value: function () {
      var _ref2 = asyncToGenerator(function* (context) {
        // Init a VideoUploadRequest and send the request
        var request = new VideoUploadRequest(this._api);
        request.setParams(this.getParamsFromContext(context));

        var response = yield request.send([context.accountId, 'advideos']);

        return response;
      });

      function sendRequest(_x2) {
        return _ref2.apply(this, arguments);
      }

      return sendRequest;
    }()
  }, {
    key: 'getParamsFromContext',
    value: function getParamsFromContext(context) {
      return {
        file_size: context.fileSize,
        upload_phase: 'start'
      };
    }
  }]);
  return VideoUploadStartRequestManager;
}(VideoUploadRequestManager);

var VideoUploadTransferRequestManager = function (_VideoUploadRequestMa2) {
  inherits(VideoUploadTransferRequestManager, _VideoUploadRequestMa2);

  function VideoUploadTransferRequestManager() {
    classCallCheck(this, VideoUploadTransferRequestManager);
    return possibleConstructorReturn(this, (VideoUploadTransferRequestManager.__proto__ || Object.getPrototypeOf(VideoUploadTransferRequestManager)).apply(this, arguments));
  }

  createClass(VideoUploadTransferRequestManager, [{
    key: 'sendRequest',


    /**
     * Send transfer request with the given context
     **/
    value: function () {
      var _ref3 = asyncToGenerator(function* (context) {
        // Init a VideoUploadRequest
        var request = new VideoUploadRequest(this._api);
        var start_offset = context.startOffset;
        var end_offset = context.endOffset;
        var filePath = context.filePath;
        var fileSize = fs.statSync(filePath).size;

        // Give a chance to retry every 10M, or at least twice
        var numRetry = Math.max(fileSize / (1024 * 1024 * 10), 2);
        var response = null;
        // While there are still more chunks to send
        var videoFileDescriptor = fs.openSync(filePath, 'r');
        while (start_offset !== end_offset) {
          context.startOffset = start_offset;
          context.endOffset = end_offset;
          var params = {
            upload_phase: 'transfer',
            start_offset: context.startOffset,
            upload_session_id: context.sessionId,
            video_file_chunk: context.videoFileChunk
          };
          request.setParams(params, {
            video_file_chunk: fs.createReadStream(context.filePath, {
              start: context.startOffset,
              end: context.endOffset - 1
            })
          });
          // Send the request
          try {
            response = yield request.send([context.accountId, 'advideos']);
            start_offset = parseInt(response['start_offset']);
            end_offset = parseInt(response['end_offset']);
          } catch (error) {
            if (numRetry > 0) {
              numRetry = Math.max(numRetry - 1, 0);
              continue;
            }
            fs.close(videoFileDescriptor, function (err) {});
            throw error;
          }
        }

        this._startOffset = start_offset;
        this._endOffset = end_offset;
        fs.close(videoFileDescriptor, function (err) {});

        return response;
      });

      function sendRequest(_x3) {
        return _ref3.apply(this, arguments);
      }

      return sendRequest;
    }()
  }]);
  return VideoUploadTransferRequestManager;
}(VideoUploadRequestManager);

var VideoUploadFinishRequestManager = function (_VideoUploadRequestMa3) {
  inherits(VideoUploadFinishRequestManager, _VideoUploadRequestMa3);

  function VideoUploadFinishRequestManager() {
    classCallCheck(this, VideoUploadFinishRequestManager);
    return possibleConstructorReturn(this, (VideoUploadFinishRequestManager.__proto__ || Object.getPrototypeOf(VideoUploadFinishRequestManager)).apply(this, arguments));
  }

  createClass(VideoUploadFinishRequestManager, [{
    key: 'sendRequest',

    /**
     * Send transfer request with the given context
     **/
    value: function () {
      var _ref4 = asyncToGenerator(function* (context) {
        // Init a VideoUploadRequest
        var request = new VideoUploadRequest(this._api);

        // Parse the context
        request.setParams(this.getParamsFromContext(context));

        // Sent the request
        var response = yield request.send([context.accountId, 'advideos']);

        return response;
      });

      function sendRequest(_x4) {
        return _ref4.apply(this, arguments);
      }

      return sendRequest;
    }()
  }, {
    key: 'getParamsFromContext',
    value: function getParamsFromContext(context) {
      return {
        upload_phase: 'finish',
        upload_session_id: context.sessionId,
        title: context.fileName
      };
    }
  }]);
  return VideoUploadFinishRequestManager;
}(VideoUploadRequestManager);

/**
 * Upload request context that contains the param data
 **/


var VideoUploadRequestContext = function () {
  function VideoUploadRequestContext() {
    classCallCheck(this, VideoUploadRequestContext);
  }

  createClass(VideoUploadRequestContext, [{
    key: 'accountId',
    get: function get() {
      return this._accountId;
    },
    set: function set(accountId) {
      this._accountId = accountId;
    }
  }, {
    key: 'fileName',
    get: function get() {
      return this._fileName;
    },
    set: function set(fileName) {
      this._fileName = fileName;
    }
  }, {
    key: 'filePath',
    get: function get() {
      return this._filePath;
    },
    set: function set(filePath) {
      this._filePath = filePath;
    }
  }, {
    key: 'fileSize',
    get: function get() {
      return this._fileSize;
    },
    set: function set(fileSize) {
      this._fileSize = fileSize;
    }
  }, {
    key: 'name',
    get: function get() {
      return this._name;
    },
    set: function set(name) {
      this._name = name;
    }
  }, {
    key: 'sessionId',
    get: function get() {
      return this._sessionId;
    },
    set: function set(sessionId) {
      this._sessionId = sessionId;
    }
  }, {
    key: 'startOffset',
    get: function get() {
      return this._startOffset;
    },
    set: function set(startOffset) {
      this._startOffset = startOffset;
    }
  }, {
    key: 'endOffset',
    get: function get() {
      return this._endOffset;
    },
    set: function set(endOffset) {
      this._endOffset = endOffset;
    }
  }, {
    key: 'slideshowSpec',
    get: function get() {
      return this._slideshowSpec;
    },
    set: function set(slideshowSpec) {
      this._slideshowSpec = slideshowSpec;
    }
  }, {
    key: 'videoFileChunk',
    get: function get() {
      return this._videoFileChunk;
    },
    set: function set(videoFileChunk) {
      this._videoFileChunk = videoFileChunk;
    }
  }]);
  return VideoUploadRequestContext;
}();

var VideoUploadRequest = function () {
  function VideoUploadRequest(api) {
    classCallCheck(this, VideoUploadRequest);

    this._params = null;
    this._files = null;
    this._api = api;
  }

  /**
   * Send the current request
   **/


  createClass(VideoUploadRequest, [{
    key: 'send',
    value: function send(path$$1) {
      var _this4 = this;

      return new Promise(function (resolve, reject) {
        _this4._api.call('POST', path$$1, _this4._params, _this4._files, true, // use multipart/form-data
        FacebookAdsApi.GRAPH_VIDEO // override graph.facebook.com
        ).then(function (response) {
          return resolve(JSON.parse(response));
        }).catch(function (error) {
          return reject(error);
        });
      });
    }
  }, {
    key: 'setParams',
    value: function setParams(params) {
      var files = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

      this._params = params;
      this._files = files;
    }
  }]);
  return VideoUploadRequest;
}();

function sleep(ms) {
  return new Promise(function (resolve) {
    return setTimeout(resolve, ms);
  });
}

var VideoEncodingStatusChecker = function () {
  function VideoEncodingStatusChecker() {
    classCallCheck(this, VideoEncodingStatusChecker);
  }

  createClass(VideoEncodingStatusChecker, null, [{
    key: 'waitUntilReady',
    value: function () {
      var _ref5 = asyncToGenerator(function* (api, videoId, interval, timeout) {
        var startTime = new Date().getTime();
        var status = null;

        while (true) {
          status = VideoEncodingStatusChecker.getStatus(api, videoId);
          status = status['video_status'];

          if (status !== 'processing') {
            break;
          }

          if (startTime + timeout <= new Date().getTime()) {
            throw Error('Video encoding timeout: ' + timeout);
          }

          yield sleep(interval);
        }

        if (status !== 'ready') {
          status = status == null ? '' : status;
          throw Error('Video encoding status ' + status);
        }
      });

      function waitUntilReady(_x6, _x7, _x8, _x9) {
        return _ref5.apply(this, arguments);
      }

      return waitUntilReady;
    }()
  }, {
    key: 'getStatus',
    value: function getStatus(api, videoId) {
      var result = api.call('GET', [videoId.toString()], { fields: 'status' });
      // $FlowFixMe
      return result['status'];
    }
  }]);
  return VideoEncodingStatusChecker;
}();

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 * 
 */

/**
 * AdVideo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */
var AdVideo = function (_AbstractCrudObject) {
  inherits(AdVideo, _AbstractCrudObject);

  function AdVideo() {
    classCallCheck(this, AdVideo);
    return possibleConstructorReturn(this, (AdVideo.__proto__ || Object.getPrototypeOf(AdVideo)).apply(this, arguments));
  }

  createClass(AdVideo, [{
    key: 'create',


    /**
     * Uploads filepath and creates the AdVideo object from it.
     * It requires 'filepath' property to be defined.
     **/
    value: function create(batch, failureHandler, successHandler) {
      var response = null;
      var spec = this.slideshow_spec;
      if (spec) {
        var request = new VideoUploadRequest(this.getApi());

        request.setParams({
          'slideshow_spec[images_urls]': JSON.stringify(spec['images_urls']),
          'slideshow_spec[duration_ms]': spec['duration_ms'],
          'slideshow_spec[transition_ms]': spec['transition_ms']
        });
        response = request.send([this.getParentId(), 'advideos']);
      } else if (this.filepath) {
        var videoUploader = new VideoUploader();

        response = videoUploader.upload(this, true);
      } else {
        throw Error('AdVideo requires a filepath or slideshow_spec to be defined.');
      }

      this.setData(response);

      return response;
    }
  }, {
    key: 'waitUntilEncodingReady',
    value: function waitUntilEncodingReady() {
      var interval = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 30;
      var timeout = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 600;

      if (!this.id) {
        throw Error('Invalid Video ID');
      }

      VideoEncodingStatusChecker.waitUntilReady(this.getApi(), parseInt(this.id), interval, timeout);
    }

    /**
     *  Returns all the thumbnails associated with the ad video
     */

  }, {
    key: 'getThumbnails',
    value: function getThumbnails(fields, params) {
      return this.getEdge(VideoThumbnail, fields, params, true, 'thumbnails');
    }
  }, {
    key: 'filepath',
    get: function get() {
      return this.filepath;
    }
  }, {
    key: 'slideshow_spec',
    get: function get() {
      return this.slideshow_spec;
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        filepath: 'filepath',
        id: 'id',
        slideshow_spec: 'slideshow_spec'
      });
    }
  }]);
  return AdVideo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ALMAdAccountInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ALMAdAccountInfo = function (_AbstractCrudObject) {
  inherits(ALMAdAccountInfo, _AbstractCrudObject);

  function ALMAdAccountInfo() {
    classCallCheck(this, ALMAdAccountInfo);
    return possibleConstructorReturn(this, (ALMAdAccountInfo.__proto__ || Object.getPrototypeOf(ALMAdAccountInfo)).apply(this, arguments));
  }

  createClass(ALMAdAccountInfo, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_id: 'ad_account_id',
        id: 'id',
        managed_by: 'managed_by',
        owned_by: 'owned_by',
        parent_advertiser_id: 'parent_advertiser_id',
        sub_vertical: 'sub_vertical',
        tag: 'tag',
        user_ids: 'user_ids',
        vertical: 'vertical'
      });
    }
  }]);
  return ALMAdAccountInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ALMEndAdvertiserInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ALMEndAdvertiserInfo = function (_AbstractCrudObject) {
  inherits(ALMEndAdvertiserInfo, _AbstractCrudObject);

  function ALMEndAdvertiserInfo() {
    classCallCheck(this, ALMEndAdvertiserInfo);
    return possibleConstructorReturn(this, (ALMEndAdvertiserInfo.__proto__ || Object.getPrototypeOf(ALMEndAdvertiserInfo)).apply(this, arguments));
  }

  createClass(ALMEndAdvertiserInfo, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        estimated_ad_budget: 'estimated_ad_budget',
        id: 'id',
        parent_advertiser_id: 'parent_advertiser_id',
        parent_advertiser_name: 'parent_advertiser_name',
        tag: 'tag'
      });
    }
  }]);
  return ALMEndAdvertiserInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ALMEvent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ALMEvent = function (_AbstractCrudObject) {
  inherits(ALMEvent, _AbstractCrudObject);

  function ALMEvent() {
    classCallCheck(this, ALMEvent);
    return possibleConstructorReturn(this, (ALMEvent.__proto__ || Object.getPrototypeOf(ALMEvent)).apply(this, arguments));
  }

  createClass(ALMEvent, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_ids: 'ad_account_ids',
        campaign_ids: 'campaign_ids',
        channel: 'channel',
        event: 'event',
        event_time: 'event_time',
        guidance: 'guidance',
        guidance_detail: 'guidance_detail',
        id: 'id',
        parent_advertiser_ids: 'parent_advertiser_ids',
        reseller_business_id: 'reseller_business_id',
        sub_channel: 'sub_channel',
        user_id: 'user_id'
      });
    }
  }]);
  return ALMEvent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ALMGuidance
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ALMGuidance = function (_AbstractCrudObject) {
  inherits(ALMGuidance, _AbstractCrudObject);

  function ALMGuidance() {
    classCallCheck(this, ALMGuidance);
    return possibleConstructorReturn(this, (ALMGuidance.__proto__ || Object.getPrototypeOf(ALMGuidance)).apply(this, arguments));
  }

  createClass(ALMGuidance, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_id: 'ad_account_id',
        guidances: 'guidances',
        parent_advertiser_id: 'parent_advertiser_id',
        parent_advertiser_name: 'parent_advertiser_name'
      });
    }
  }]);
  return ALMGuidance;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ALMGuidanceMetrics
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ALMGuidanceMetrics = function (_AbstractCrudObject) {
  inherits(ALMGuidanceMetrics, _AbstractCrudObject);

  function ALMGuidanceMetrics() {
    classCallCheck(this, ALMGuidanceMetrics);
    return possibleConstructorReturn(this, (ALMGuidanceMetrics.__proto__ || Object.getPrototypeOf(ALMGuidanceMetrics)).apply(this, arguments));
  }

  createClass(ALMGuidanceMetrics, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_id: 'ad_account_id',
        adopted_objects: 'adopted_objects',
        guidance_name: 'guidance_name',
        guidance_type: 'guidance_type',
        l28_adoption: 'l28_adoption',
        l28_available: 'l28_available',
        l28_click: 'l28_click',
        l28_conversion: 'l28_conversion',
        l28_impression: 'l28_impression',
        l28_pitch: 'l28_pitch',
        last_pitch_ds: 'last_pitch_ds',
        parent_advertiser_id: 'parent_advertiser_id',
        report_ds: 'report_ds'
      });
    }
  }]);
  return ALMGuidanceMetrics;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AMOneshopSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AMOneshopSettings = function (_AbstractCrudObject) {
  inherits(AMOneshopSettings, _AbstractCrudObject);

  function AMOneshopSettings() {
    classCallCheck(this, AMOneshopSettings);
    return possibleConstructorReturn(this, (AMOneshopSettings.__proto__ || Object.getPrototypeOf(AMOneshopSettings)).apply(this, arguments));
  }

  createClass(AMOneshopSettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return AMOneshopSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ANBlockedBICategory
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ANBlockedBICategory = function (_AbstractCrudObject) {
  inherits(ANBlockedBICategory, _AbstractCrudObject);

  function ANBlockedBICategory() {
    classCallCheck(this, ANBlockedBICategory);
    return possibleConstructorReturn(this, (ANBlockedBICategory.__proto__ || Object.getPrototypeOf(ANBlockedBICategory)).apply(this, arguments));
  }

  createClass(ANBlockedBICategory, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        key: 'key'
      });
    }
  }]);
  return ANBlockedBICategory;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AREffect
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AREffect = function (_AbstractCrudObject) {
  inherits(AREffect, _AbstractCrudObject);

  function AREffect() {
    classCallCheck(this, AREffect);
    return possibleConstructorReturn(this, (AREffect.__proto__ || Object.getPrototypeOf(AREffect)).apply(this, arguments));
  }

  createClass(AREffect, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        id: 'id',
        last_modified_time: 'last_modified_time',
        name: 'name',
        status: 'status',
        surfaces: 'surfaces'
      });
    }
  }]);
  return AREffect;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeInsights = function (_AbstractCrudObject) {
  inherits(AdCreativeInsights, _AbstractCrudObject);

  function AdCreativeInsights() {
    classCallCheck(this, AdCreativeInsights);
    return possibleConstructorReturn(this, (AdCreativeInsights.__proto__ || Object.getPrototypeOf(AdCreativeInsights)).apply(this, arguments));
  }

  createClass(AdCreativeInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        aesthetics: 'aesthetics'
      });
    }
  }]);
  return AdCreativeInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdPreview
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdPreview = function (_AbstractCrudObject) {
  inherits(AdPreview, _AbstractCrudObject);

  function AdPreview() {
    classCallCheck(this, AdPreview);
    return possibleConstructorReturn(this, (AdPreview.__proto__ || Object.getPrototypeOf(AdPreview)).apply(this, arguments));
  }

  createClass(AdPreview, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        body: 'body',
        transformation_spec: 'transformation_spec'
      });
    }
  }, {
    key: 'AdFormat',
    get: function get() {
      return Object.freeze({
        audience_network_instream_video: 'AUDIENCE_NETWORK_INSTREAM_VIDEO',
        audience_network_instream_video_mobile: 'AUDIENCE_NETWORK_INSTREAM_VIDEO_MOBILE',
        audience_network_outstream_video: 'AUDIENCE_NETWORK_OUTSTREAM_VIDEO',
        audience_network_rewarded_video: 'AUDIENCE_NETWORK_REWARDED_VIDEO',
        biz_disco_feed_mobile: 'BIZ_DISCO_FEED_MOBILE',
        desktop_feed_standard: 'DESKTOP_FEED_STANDARD',
        facebook_profile_feed_desktop: 'FACEBOOK_PROFILE_FEED_DESKTOP',
        facebook_profile_feed_mobile: 'FACEBOOK_PROFILE_FEED_MOBILE',
        facebook_profile_reels_mobile: 'FACEBOOK_PROFILE_REELS_MOBILE',
        facebook_reels_banner: 'FACEBOOK_REELS_BANNER',
        facebook_reels_banner_desktop: 'FACEBOOK_REELS_BANNER_DESKTOP',
        facebook_reels_mobile: 'FACEBOOK_REELS_MOBILE',
        facebook_reels_postloop: 'FACEBOOK_REELS_POSTLOOP',
        facebook_reels_sticker: 'FACEBOOK_REELS_STICKER',
        facebook_story_mobile: 'FACEBOOK_STORY_MOBILE',
        facebook_story_sticker_mobile: 'FACEBOOK_STORY_STICKER_MOBILE',
        instagram_explore_contextual: 'INSTAGRAM_EXPLORE_CONTEXTUAL',
        instagram_explore_grid_home: 'INSTAGRAM_EXPLORE_GRID_HOME',
        instagram_explore_immersive: 'INSTAGRAM_EXPLORE_IMMERSIVE',
        instagram_feed_web: 'INSTAGRAM_FEED_WEB',
        instagram_feed_web_m_site: 'INSTAGRAM_FEED_WEB_M_SITE',
        instagram_lead_gen_multi_submit_ads: 'INSTAGRAM_LEAD_GEN_MULTI_SUBMIT_ADS',
        instagram_profile_feed: 'INSTAGRAM_PROFILE_FEED',
        instagram_profile_reels: 'INSTAGRAM_PROFILE_REELS',
        instagram_reels: 'INSTAGRAM_REELS',
        instagram_reels_overlay: 'INSTAGRAM_REELS_OVERLAY',
        instagram_search_chain: 'INSTAGRAM_SEARCH_CHAIN',
        instagram_search_grid: 'INSTAGRAM_SEARCH_GRID',
        instagram_standard: 'INSTAGRAM_STANDARD',
        instagram_story: 'INSTAGRAM_STORY',
        instagram_story_effect_tray: 'INSTAGRAM_STORY_EFFECT_TRAY',
        instagram_story_web: 'INSTAGRAM_STORY_WEB',
        instagram_story_web_m_site: 'INSTAGRAM_STORY_WEB_M_SITE',
        instant_article_recirculation_ad: 'INSTANT_ARTICLE_RECIRCULATION_AD',
        instant_article_standard: 'INSTANT_ARTICLE_STANDARD',
        instream_banner_desktop: 'INSTREAM_BANNER_DESKTOP',
        instream_banner_fullscreen_mobile: 'INSTREAM_BANNER_FULLSCREEN_MOBILE',
        instream_banner_immersive_mobile: 'INSTREAM_BANNER_IMMERSIVE_MOBILE',
        instream_banner_mobile: 'INSTREAM_BANNER_MOBILE',
        instream_video_desktop: 'INSTREAM_VIDEO_DESKTOP',
        instream_video_fullscreen_ios: 'INSTREAM_VIDEO_FULLSCREEN_IOS',
        instream_video_fullscreen_mobile: 'INSTREAM_VIDEO_FULLSCREEN_MOBILE',
        instream_video_image: 'INSTREAM_VIDEO_IMAGE',
        instream_video_immersive_mobile: 'INSTREAM_VIDEO_IMMERSIVE_MOBILE',
        instream_video_mobile: 'INSTREAM_VIDEO_MOBILE',
        job_browser_desktop: 'JOB_BROWSER_DESKTOP',
        job_browser_mobile: 'JOB_BROWSER_MOBILE',
        marketplace_mobile: 'MARKETPLACE_MOBILE',
        messenger_mobile_inbox_media: 'MESSENGER_MOBILE_INBOX_MEDIA',
        messenger_mobile_story_media: 'MESSENGER_MOBILE_STORY_MEDIA',
        mobile_banner: 'MOBILE_BANNER',
        mobile_feed_basic: 'MOBILE_FEED_BASIC',
        mobile_feed_standard: 'MOBILE_FEED_STANDARD',
        mobile_fullwidth: 'MOBILE_FULLWIDTH',
        mobile_interstitial: 'MOBILE_INTERSTITIAL',
        mobile_medium_rectangle: 'MOBILE_MEDIUM_RECTANGLE',
        mobile_native: 'MOBILE_NATIVE',
        right_column_standard: 'RIGHT_COLUMN_STANDARD',
        suggested_video_desktop: 'SUGGESTED_VIDEO_DESKTOP',
        suggested_video_fullscreen_mobile: 'SUGGESTED_VIDEO_FULLSCREEN_MOBILE',
        suggested_video_immersive_mobile: 'SUGGESTED_VIDEO_IMMERSIVE_MOBILE',
        suggested_video_mobile: 'SUGGESTED_VIDEO_MOBILE',
        watch_feed_home: 'WATCH_FEED_HOME',
        watch_feed_mobile: 'WATCH_FEED_MOBILE'
      });
    }
  }, {
    key: 'CreativeFeature',
    get: function get() {
      return Object.freeze({
        product_metadata_automation: 'product_metadata_automation',
        profile_card: 'profile_card',
        standard_enhancements_catalog: 'standard_enhancements_catalog'
      });
    }
  }, {
    key: 'RenderType',
    get: function get() {
      return Object.freeze({
        fallback: 'FALLBACK'
      });
    }
  }]);
  return AdPreview;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreative
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreative = function (_AbstractCrudObject) {
  inherits(AdCreative, _AbstractCrudObject);

  function AdCreative() {
    classCallCheck(this, AdCreative);
    return possibleConstructorReturn(this, (AdCreative.__proto__ || Object.getPrototypeOf(AdCreative)).apply(this, arguments));
  }

  createClass(AdCreative, [{
    key: 'createAdLabel',
    value: function createAdLabel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adlabels', fields, params, AdCreative, pathOverride);
    }
  }, {
    key: 'getCreativeInsights',
    value: function getCreativeInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdCreativeInsights, fields, params, fetchFirstPage, '/creative_insights');
    }
  }, {
    key: 'getPreviews',
    value: function getPreviews(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdPreview, fields, params, fetchFirstPage, '/previews');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdCreative.prototype.__proto__ || Object.getPrototypeOf(AdCreative.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdCreative.prototype.__proto__ || Object.getPrototypeOf(AdCreative.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        actor_id: 'actor_id',
        adlabels: 'adlabels',
        applink_treatment: 'applink_treatment',
        asset_feed_spec: 'asset_feed_spec',
        authorization_category: 'authorization_category',
        auto_update: 'auto_update',
        body: 'body',
        branded_content: 'branded_content',
        branded_content_sponsor_page_id: 'branded_content_sponsor_page_id',
        bundle_folder_id: 'bundle_folder_id',
        call_to_action_type: 'call_to_action_type',
        categorization_criteria: 'categorization_criteria',
        category_media_source: 'category_media_source',
        collaborative_ads_lsb_image_bank_id: 'collaborative_ads_lsb_image_bank_id',
        contextual_multi_ads: 'contextual_multi_ads',
        creative_sourcing_spec: 'creative_sourcing_spec',
        degrees_of_freedom_spec: 'degrees_of_freedom_spec',
        destination_set_id: 'destination_set_id',
        dynamic_ad_voice: 'dynamic_ad_voice',
        effective_authorization_category: 'effective_authorization_category',
        effective_instagram_media_id: 'effective_instagram_media_id',
        effective_instagram_story_id: 'effective_instagram_story_id',
        effective_object_story_id: 'effective_object_story_id',
        enable_direct_install: 'enable_direct_install',
        enable_launch_instant_app: 'enable_launch_instant_app',
        facebook_branded_content: 'facebook_branded_content',
        id: 'id',
        image_crops: 'image_crops',
        image_hash: 'image_hash',
        image_url: 'image_url',
        instagram_actor_id: 'instagram_actor_id',
        instagram_branded_content: 'instagram_branded_content',
        instagram_permalink_url: 'instagram_permalink_url',
        instagram_story_id: 'instagram_story_id',
        instagram_user_id: 'instagram_user_id',
        interactive_components_spec: 'interactive_components_spec',
        link_deep_link_url: 'link_deep_link_url',
        link_destination_display_url: 'link_destination_display_url',
        link_og_id: 'link_og_id',
        link_url: 'link_url',
        messenger_sponsored_message: 'messenger_sponsored_message',
        name: 'name',
        object_id: 'object_id',
        object_store_url: 'object_store_url',
        object_story_id: 'object_story_id',
        object_story_spec: 'object_story_spec',
        object_type: 'object_type',
        object_url: 'object_url',
        omnichannel_link_spec: 'omnichannel_link_spec',
        page_welcome_message: 'page_welcome_message',
        photo_album_source_object_story_id: 'photo_album_source_object_story_id',
        place_page_set_id: 'place_page_set_id',
        platform_customizations: 'platform_customizations',
        playable_asset_id: 'playable_asset_id',
        portrait_customizations: 'portrait_customizations',
        product_set_id: 'product_set_id',
        recommender_settings: 'recommender_settings',
        source_instagram_media_id: 'source_instagram_media_id',
        status: 'status',
        template_url: 'template_url',
        template_url_spec: 'template_url_spec',
        thumbnail_id: 'thumbnail_id',
        thumbnail_url: 'thumbnail_url',
        title: 'title',
        url_tags: 'url_tags',
        use_page_actor_override: 'use_page_actor_override',
        video_id: 'video_id'
      });
    }
  }, {
    key: 'CallToActionType',
    get: function get() {
      return Object.freeze({
        add_to_cart: 'ADD_TO_CART',
        apply_now: 'APPLY_NOW',
        ask_about_services: 'ASK_ABOUT_SERVICES',
        ask_for_more_info: 'ASK_FOR_MORE_INFO',
        audio_call: 'AUDIO_CALL',
        book_a_consultation: 'BOOK_A_CONSULTATION',
        book_now: 'BOOK_NOW',
        book_travel: 'BOOK_TRAVEL',
        buy: 'BUY',
        buy_now: 'BUY_NOW',
        buy_tickets: 'BUY_TICKETS',
        buy_via_message: 'BUY_VIA_MESSAGE',
        call: 'CALL',
        call_me: 'CALL_ME',
        call_now: 'CALL_NOW',
        chat_with_us: 'CHAT_WITH_US',
        confirm: 'CONFIRM',
        contact: 'CONTACT',
        contact_us: 'CONTACT_US',
        donate: 'DONATE',
        donate_now: 'DONATE_NOW',
        download: 'DOWNLOAD',
        event_rsvp: 'EVENT_RSVP',
        find_a_group: 'FIND_A_GROUP',
        find_your_groups: 'FIND_YOUR_GROUPS',
        follow_news_storyline: 'FOLLOW_NEWS_STORYLINE',
        follow_page: 'FOLLOW_PAGE',
        follow_user: 'FOLLOW_USER',
        get_a_quote: 'GET_A_QUOTE',
        get_directions: 'GET_DIRECTIONS',
        get_offer: 'GET_OFFER',
        get_offer_view: 'GET_OFFER_VIEW',
        get_promotions: 'GET_PROMOTIONS',
        get_quote: 'GET_QUOTE',
        get_showtimes: 'GET_SHOWTIMES',
        get_started: 'GET_STARTED',
        inquire_now: 'INQUIRE_NOW',
        install_app: 'INSTALL_APP',
        install_mobile_app: 'INSTALL_MOBILE_APP',
        join_channel: 'JOIN_CHANNEL',
        learn_more: 'LEARN_MORE',
        like_page: 'LIKE_PAGE',
        listen_music: 'LISTEN_MUSIC',
        listen_now: 'LISTEN_NOW',
        make_an_appointment: 'MAKE_AN_APPOINTMENT',
        message_page: 'MESSAGE_PAGE',
        mobile_download: 'MOBILE_DOWNLOAD',
        no_button: 'NO_BUTTON',
        open_instant_app: 'OPEN_INSTANT_APP',
        open_link: 'OPEN_LINK',
        order_now: 'ORDER_NOW',
        pay_to_access: 'PAY_TO_ACCESS',
        play_game: 'PLAY_GAME',
        play_game_on_facebook: 'PLAY_GAME_ON_FACEBOOK',
        purchase_gift_cards: 'PURCHASE_GIFT_CARDS',
        raise_money: 'RAISE_MONEY',
        record_now: 'RECORD_NOW',
        refer_friends: 'REFER_FRIENDS',
        request_time: 'REQUEST_TIME',
        say_thanks: 'SAY_THANKS',
        see_more: 'SEE_MORE',
        sell_now: 'SELL_NOW',
        send_a_gift: 'SEND_A_GIFT',
        send_gift_money: 'SEND_GIFT_MONEY',
        send_updates: 'SEND_UPDATES',
        share: 'SHARE',
        shop_now: 'SHOP_NOW',
        sign_up: 'SIGN_UP',
        sotto_subscribe: 'SOTTO_SUBSCRIBE',
        start_order: 'START_ORDER',
        subscribe: 'SUBSCRIBE',
        swipe_up_product: 'SWIPE_UP_PRODUCT',
        swipe_up_shop: 'SWIPE_UP_SHOP',
        update_app: 'UPDATE_APP',
        use_app: 'USE_APP',
        use_mobile_app: 'USE_MOBILE_APP',
        video_annotation: 'VIDEO_ANNOTATION',
        video_call: 'VIDEO_CALL',
        view_channel: 'VIEW_CHANNEL',
        view_product: 'VIEW_PRODUCT',
        visit_pages_feed: 'VISIT_PAGES_FEED',
        watch_more: 'WATCH_MORE',
        watch_video: 'WATCH_VIDEO',
        whatsapp_message: 'WHATSAPP_MESSAGE',
        woodhenge_support: 'WOODHENGE_SUPPORT'
      });
    }
  }, {
    key: 'ObjectType',
    get: function get() {
      return Object.freeze({
        application: 'APPLICATION',
        domain: 'DOMAIN',
        event: 'EVENT',
        invalid: 'INVALID',
        offer: 'OFFER',
        page: 'PAGE',
        photo: 'PHOTO',
        post_deleted: 'POST_DELETED',
        privacy_check_fail: 'PRIVACY_CHECK_FAIL',
        share: 'SHARE',
        status: 'STATUS',
        store_item: 'STORE_ITEM',
        video: 'VIDEO'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        deleted: 'DELETED',
        in_process: 'IN_PROCESS',
        with_issues: 'WITH_ISSUES'
      });
    }
  }, {
    key: 'ApplinkTreatment',
    get: function get() {
      return Object.freeze({
        automatic: 'automatic',
        deeplink_with_appstore_fallback: 'deeplink_with_appstore_fallback',
        deeplink_with_web_fallback: 'deeplink_with_web_fallback',
        web_only: 'web_only'
      });
    }
  }, {
    key: 'AuthorizationCategory',
    get: function get() {
      return Object.freeze({
        none: 'NONE',
        political: 'POLITICAL',
        political_with_digitally_created_media: 'POLITICAL_WITH_DIGITALLY_CREATED_MEDIA'
      });
    }
  }, {
    key: 'CategorizationCriteria',
    get: function get() {
      return Object.freeze({
        brand: 'brand',
        category: 'category',
        product_type: 'product_type'
      });
    }
  }, {
    key: 'CategoryMediaSource',
    get: function get() {
      return Object.freeze({
        category: 'CATEGORY',
        mixed: 'MIXED',
        products_collage: 'PRODUCTS_COLLAGE',
        products_slideshow: 'PRODUCTS_SLIDESHOW'
      });
    }
  }, {
    key: 'DynamicAdVoice',
    get: function get() {
      return Object.freeze({
        dynamic: 'DYNAMIC',
        story_owner: 'STORY_OWNER'
      });
    }
  }, {
    key: 'Operator',
    get: function get() {
      return Object.freeze({
        all: 'ALL',
        any: 'ANY'
      });
    }
  }]);
  return AdCreative;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleHistory
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleHistory = function (_AbstractCrudObject) {
  inherits(AdRuleHistory, _AbstractCrudObject);

  function AdRuleHistory() {
    classCallCheck(this, AdRuleHistory);
    return possibleConstructorReturn(this, (AdRuleHistory.__proto__ || Object.getPrototypeOf(AdRuleHistory)).apply(this, arguments));
  }

  createClass(AdRuleHistory, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        evaluation_spec: 'evaluation_spec',
        exception_code: 'exception_code',
        exception_message: 'exception_message',
        execution_spec: 'execution_spec',
        is_manual: 'is_manual',
        results: 'results',
        schedule_spec: 'schedule_spec',
        timestamp: 'timestamp'
      });
    }
  }, {
    key: 'Action',
    get: function get() {
      return Object.freeze({
        budget_not_redistributed: 'BUDGET_NOT_REDISTRIBUTED',
        changed_bid: 'CHANGED_BID',
        changed_budget: 'CHANGED_BUDGET',
        consolidate_asc_fragmentation: 'CONSOLIDATE_ASC_FRAGMENTATION',
        convert_asc_cp_single_instance: 'CONVERT_ASC_CP_SINGLE_INSTANCE',
        email: 'EMAIL',
        enable_advantage_campaign_budget: 'ENABLE_ADVANTAGE_CAMPAIGN_BUDGET',
        enable_advantage_plus_creative: 'ENABLE_ADVANTAGE_PLUS_CREATIVE',
        enable_advantage_plus_placements: 'ENABLE_ADVANTAGE_PLUS_PLACEMENTS',
        enable_autoflow: 'ENABLE_AUTOFLOW',
        enable_gen_uncrop: 'ENABLE_GEN_UNCROP',
        enable_landing_page_views: 'ENABLE_LANDING_PAGE_VIEWS',
        enable_music: 'ENABLE_MUSIC',
        enable_reels_placements: 'ENABLE_REELS_PLACEMENTS',
        enable_semantic_based_audience_expansion: 'ENABLE_SEMANTIC_BASED_AUDIENCE_EXPANSION',
        enable_shops_ads: 'ENABLE_SHOPS_ADS',
        endpoint_pinged: 'ENDPOINT_PINGED',
        error: 'ERROR',
        facebook_notification_sent: 'FACEBOOK_NOTIFICATION_SENT',
        message_sent: 'MESSAGE_SENT',
        not_changed: 'NOT_CHANGED',
        paused: 'PAUSED',
        unpaused: 'UNPAUSED'
      });
    }
  }]);
  return AdRuleHistory;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRule = function (_AbstractCrudObject) {
  inherits(AdRule, _AbstractCrudObject);

  function AdRule() {
    classCallCheck(this, AdRule);
    return possibleConstructorReturn(this, (AdRule.__proto__ || Object.getPrototypeOf(AdRule)).apply(this, arguments));
  }

  createClass(AdRule, [{
    key: 'createExecute',
    value: function createExecute(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/execute', fields, params, null, pathOverride);
    }
  }, {
    key: 'getHistory',
    value: function getHistory(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdRuleHistory, fields, params, fetchFirstPage, '/history');
    }
  }, {
    key: 'createPreview',
    value: function createPreview(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/preview', fields, params, AdRule, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdRule.prototype.__proto__ || Object.getPrototypeOf(AdRule.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdRule.prototype.__proto__ || Object.getPrototypeOf(AdRule.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        created_by: 'created_by',
        created_time: 'created_time',
        disable_error_code: 'disable_error_code',
        evaluation_spec: 'evaluation_spec',
        execution_spec: 'execution_spec',
        id: 'id',
        name: 'name',
        schedule_spec: 'schedule_spec',
        status: 'status',
        updated_time: 'updated_time'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        deleted: 'DELETED',
        disabled: 'DISABLED',
        enabled: 'ENABLED',
        has_issues: 'HAS_ISSUES'
      });
    }
  }, {
    key: 'UiCreationSource',
    get: function get() {
      return Object.freeze({
        am_account_overview_recommendations: 'AM_ACCOUNT_OVERVIEW_RECOMMENDATIONS',
        am_activity_history_table: 'AM_ACTIVITY_HISTORY_TABLE',
        am_ad_object_name_card: 'AM_AD_OBJECT_NAME_CARD',
        am_amfe_l3_recommendation: 'AM_AMFE_L3_RECOMMENDATION',
        am_autoflow_guidance_card: 'AM_AUTOFLOW_GUIDANCE_CARD',
        am_auto_apply_widget: 'AM_AUTO_APPLY_WIDGET',
        am_editor_card: 'AM_EDITOR_CARD',
        am_info_card: 'AM_INFO_CARD',
        am_name_cell_dropdown: 'AM_NAME_CELL_DROPDOWN',
        am_optimization_tip_guidance_card: 'AM_OPTIMIZATION_TIP_GUIDANCE_CARD',
        am_performance_summary: 'AM_PERFORMANCE_SUMMARY',
        am_rule_landing_page_banner: 'AM_RULE_LANDING_PAGE_BANNER',
        am_syd_resolution_flow: 'AM_SYD_RESOLUTION_FLOW',
        am_syd_resolution_flow_modal: 'AM_SYD_RESOLUTION_FLOW_MODAL',
        am_table_delivery_column_popover: 'AM_TABLE_DELIVERY_COLUMN_POPOVER',
        am_table_toggle_popover: 'AM_TABLE_TOGGLE_POPOVER',
        am_toolbar_create_rule_dropdown: 'AM_TOOLBAR_CREATE_RULE_DROPDOWN',
        pe_campaign_structure_menu: 'PE_CAMPAIGN_STRUCTURE_MENU',
        pe_editor_card: 'PE_EDITOR_CARD',
        pe_info_card: 'PE_INFO_CARD',
        pe_toolbar_create_rule_dropdown: 'PE_TOOLBAR_CREATE_RULE_DROPDOWN',
        rules_management_page_action_dropdown: 'RULES_MANAGEMENT_PAGE_ACTION_DROPDOWN',
        rules_management_page_rule_group: 'RULES_MANAGEMENT_PAGE_RULE_GROUP',
        rules_management_page_rule_name: 'RULES_MANAGEMENT_PAGE_RULE_NAME',
        rules_management_page_top_nav: 'RULES_MANAGEMENT_PAGE_TOP_NAV',
        rules_view_active_rules_dialog: 'RULES_VIEW_ACTIVE_RULES_DIALOG',
        rule_creation_success_dialog: 'RULE_CREATION_SUCCESS_DIALOG',
        rule_syd_redirect: 'RULE_SYD_REDIRECT',
        rule_templates_dialog: 'RULE_TEMPLATES_DIALOG'
      });
    }
  }]);
  return AdRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsInsights = function (_AbstractCrudObject) {
  inherits(AdsInsights, _AbstractCrudObject);

  function AdsInsights() {
    classCallCheck(this, AdsInsights);
    return possibleConstructorReturn(this, (AdsInsights.__proto__ || Object.getPrototypeOf(AdsInsights)).apply(this, arguments));
  }

  createClass(AdsInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_currency: 'account_currency',
        account_id: 'account_id',
        account_name: 'account_name',
        action_values: 'action_values',
        actions: 'actions',
        ad_click_actions: 'ad_click_actions',
        ad_id: 'ad_id',
        ad_impression_actions: 'ad_impression_actions',
        ad_name: 'ad_name',
        adset_end: 'adset_end',
        adset_id: 'adset_id',
        adset_name: 'adset_name',
        adset_start: 'adset_start',
        age_targeting: 'age_targeting',
        attribution_setting: 'attribution_setting',
        auction_bid: 'auction_bid',
        auction_competitiveness: 'auction_competitiveness',
        auction_max_competitor_bid: 'auction_max_competitor_bid',
        average_purchases_conversion_value: 'average_purchases_conversion_value',
        buying_type: 'buying_type',
        campaign_id: 'campaign_id',
        campaign_name: 'campaign_name',
        canvas_avg_view_percent: 'canvas_avg_view_percent',
        canvas_avg_view_time: 'canvas_avg_view_time',
        catalog_segment_actions: 'catalog_segment_actions',
        catalog_segment_value: 'catalog_segment_value',
        catalog_segment_value_mobile_purchase_roas: 'catalog_segment_value_mobile_purchase_roas',
        catalog_segment_value_omni_purchase_roas: 'catalog_segment_value_omni_purchase_roas',
        catalog_segment_value_website_purchase_roas: 'catalog_segment_value_website_purchase_roas',
        clicks: 'clicks',
        conversion_rate_ranking: 'conversion_rate_ranking',
        conversion_values: 'conversion_values',
        conversions: 'conversions',
        converted_product_quantity: 'converted_product_quantity',
        converted_product_value: 'converted_product_value',
        cost_per_15_sec_video_view: 'cost_per_15_sec_video_view',
        cost_per_2_sec_continuous_video_view: 'cost_per_2_sec_continuous_video_view',
        cost_per_action_type: 'cost_per_action_type',
        cost_per_ad_click: 'cost_per_ad_click',
        cost_per_conversion: 'cost_per_conversion',
        cost_per_dda_countby_convs: 'cost_per_dda_countby_convs',
        cost_per_estimated_ad_recallers: 'cost_per_estimated_ad_recallers',
        cost_per_inline_link_click: 'cost_per_inline_link_click',
        cost_per_inline_post_engagement: 'cost_per_inline_post_engagement',
        cost_per_one_thousand_ad_impression: 'cost_per_one_thousand_ad_impression',
        cost_per_outbound_click: 'cost_per_outbound_click',
        cost_per_thruplay: 'cost_per_thruplay',
        cost_per_unique_action_type: 'cost_per_unique_action_type',
        cost_per_unique_click: 'cost_per_unique_click',
        cost_per_unique_conversion: 'cost_per_unique_conversion',
        cost_per_unique_inline_link_click: 'cost_per_unique_inline_link_click',
        cost_per_unique_outbound_click: 'cost_per_unique_outbound_click',
        cpc: 'cpc',
        cpm: 'cpm',
        cpp: 'cpp',
        created_time: 'created_time',
        creative_media_type: 'creative_media_type',
        ctr: 'ctr',
        date_start: 'date_start',
        date_stop: 'date_stop',
        dda_countby_convs: 'dda_countby_convs',
        dda_results: 'dda_results',
        engagement_rate_ranking: 'engagement_rate_ranking',
        estimated_ad_recall_rate: 'estimated_ad_recall_rate',
        estimated_ad_recall_rate_lower_bound: 'estimated_ad_recall_rate_lower_bound',
        estimated_ad_recall_rate_upper_bound: 'estimated_ad_recall_rate_upper_bound',
        estimated_ad_recallers: 'estimated_ad_recallers',
        estimated_ad_recallers_lower_bound: 'estimated_ad_recallers_lower_bound',
        estimated_ad_recallers_upper_bound: 'estimated_ad_recallers_upper_bound',
        frequency: 'frequency',
        full_view_impressions: 'full_view_impressions',
        full_view_reach: 'full_view_reach',
        gender_targeting: 'gender_targeting',
        impressions: 'impressions',
        inline_link_click_ctr: 'inline_link_click_ctr',
        inline_link_clicks: 'inline_link_clicks',
        inline_post_engagement: 'inline_post_engagement',
        instagram_upcoming_event_reminders_set: 'instagram_upcoming_event_reminders_set',
        instant_experience_clicks_to_open: 'instant_experience_clicks_to_open',
        instant_experience_clicks_to_start: 'instant_experience_clicks_to_start',
        instant_experience_outbound_clicks: 'instant_experience_outbound_clicks',
        interactive_component_tap: 'interactive_component_tap',
        labels: 'labels',
        location: 'location',
        marketing_messages_cost_per_delivered: 'marketing_messages_cost_per_delivered',
        marketing_messages_cost_per_link_btn_click: 'marketing_messages_cost_per_link_btn_click',
        marketing_messages_spend: 'marketing_messages_spend',
        marketing_messages_website_purchase_values: 'marketing_messages_website_purchase_values',
        mobile_app_purchase_roas: 'mobile_app_purchase_roas',
        objective: 'objective',
        onsite_conversion_messaging_detected_purchase_deduped: 'onsite_conversion_messaging_detected_purchase_deduped',
        optimization_goal: 'optimization_goal',
        outbound_clicks: 'outbound_clicks',
        outbound_clicks_ctr: 'outbound_clicks_ctr',
        place_page_name: 'place_page_name',
        purchase_roas: 'purchase_roas',
        qualifying_question_qualify_answer_rate: 'qualifying_question_qualify_answer_rate',
        quality_ranking: 'quality_ranking',
        reach: 'reach',
        shops_assisted_purchases: 'shops_assisted_purchases',
        social_spend: 'social_spend',
        spend: 'spend',
        total_postbacks: 'total_postbacks',
        total_postbacks_detailed: 'total_postbacks_detailed',
        total_postbacks_detailed_v4: 'total_postbacks_detailed_v4',
        unique_actions: 'unique_actions',
        unique_clicks: 'unique_clicks',
        unique_conversions: 'unique_conversions',
        unique_ctr: 'unique_ctr',
        unique_inline_link_click_ctr: 'unique_inline_link_click_ctr',
        unique_inline_link_clicks: 'unique_inline_link_clicks',
        unique_link_clicks_ctr: 'unique_link_clicks_ctr',
        unique_outbound_clicks: 'unique_outbound_clicks',
        unique_outbound_clicks_ctr: 'unique_outbound_clicks_ctr',
        unique_video_continuous_2_sec_watched_actions: 'unique_video_continuous_2_sec_watched_actions',
        unique_video_view_15_sec: 'unique_video_view_15_sec',
        updated_time: 'updated_time',
        video_15_sec_watched_actions: 'video_15_sec_watched_actions',
        video_30_sec_watched_actions: 'video_30_sec_watched_actions',
        video_avg_time_watched_actions: 'video_avg_time_watched_actions',
        video_continuous_2_sec_watched_actions: 'video_continuous_2_sec_watched_actions',
        video_p100_watched_actions: 'video_p100_watched_actions',
        video_p25_watched_actions: 'video_p25_watched_actions',
        video_p50_watched_actions: 'video_p50_watched_actions',
        video_p75_watched_actions: 'video_p75_watched_actions',
        video_p95_watched_actions: 'video_p95_watched_actions',
        video_play_actions: 'video_play_actions',
        video_play_curve_actions: 'video_play_curve_actions',
        video_play_retention_0_to_15s_actions: 'video_play_retention_0_to_15s_actions',
        video_play_retention_20_to_60s_actions: 'video_play_retention_20_to_60s_actions',
        video_play_retention_graph_actions: 'video_play_retention_graph_actions',
        video_thruplay_watched_actions: 'video_thruplay_watched_actions',
        video_time_watched_actions: 'video_time_watched_actions',
        website_ctr: 'website_ctr',
        website_purchase_roas: 'website_purchase_roas',
        wish_bid: 'wish_bid'
      });
    }
  }, {
    key: 'ActionAttributionWindows',
    get: function get() {
      return Object.freeze({
        value_1d_click: '1d_click',
        value_1d_ev: '1d_ev',
        value_1d_view: '1d_view',
        value_28d_click: '28d_click',
        value_28d_view: '28d_view',
        value_28d_view_all_conversions: '28d_view_all_conversions',
        value_28d_view_first_conversion: '28d_view_first_conversion',
        value_7d_click: '7d_click',
        value_7d_view: '7d_view',
        value_7d_view_all_conversions: '7d_view_all_conversions',
        value_7d_view_first_conversion: '7d_view_first_conversion',
        dda: 'dda',
        default: 'default',
        skan_click: 'skan_click',
        skan_view: 'skan_view'
      });
    }
  }, {
    key: 'ActionBreakdowns',
    get: function get() {
      return Object.freeze({
        action_canvas_component_name: 'action_canvas_component_name',
        action_carousel_card_id: 'action_carousel_card_id',
        action_carousel_card_name: 'action_carousel_card_name',
        action_destination: 'action_destination',
        action_device: 'action_device',
        action_reaction: 'action_reaction',
        action_target_id: 'action_target_id',
        action_type: 'action_type',
        action_video_sound: 'action_video_sound',
        action_video_type: 'action_video_type',
        conversion_destination: 'conversion_destination',
        matched_persona_id: 'matched_persona_id',
        matched_persona_name: 'matched_persona_name',
        signal_source_bucket: 'signal_source_bucket',
        standard_event_content_type: 'standard_event_content_type'
      });
    }
  }, {
    key: 'ActionReportTime',
    get: function get() {
      return Object.freeze({
        conversion: 'conversion',
        impression: 'impression',
        mixed: 'mixed'
      });
    }
  }, {
    key: 'Breakdowns',
    get: function get() {
      return Object.freeze({
        ad_format_asset: 'ad_format_asset',
        age: 'age',
        app_id: 'app_id',
        body_asset: 'body_asset',
        breakdown_reporting_ad_id: 'breakdown_reporting_ad_id',
        call_to_action_asset: 'call_to_action_asset',
        coarse_conversion_value: 'coarse_conversion_value',
        conversion_destination: 'conversion_destination',
        country: 'country',
        description_asset: 'description_asset',
        device_platform: 'device_platform',
        dma: 'dma',
        fidelity_type: 'fidelity_type',
        frequency_value: 'frequency_value',
        gender: 'gender',
        hourly_stats_aggregated_by_advertiser_time_zone: 'hourly_stats_aggregated_by_advertiser_time_zone',
        hourly_stats_aggregated_by_audience_time_zone: 'hourly_stats_aggregated_by_audience_time_zone',
        hsid: 'hsid',
        image_asset: 'image_asset',
        impression_device: 'impression_device',
        is_conversion_id_modeled: 'is_conversion_id_modeled',
        is_rendered_as_delayed_skip_ad: 'is_rendered_as_delayed_skip_ad',
        landing_destination: 'landing_destination',
        link_url_asset: 'link_url_asset',
        marketing_messages_btn_name: 'marketing_messages_btn_name',
        mdsa_landing_destination: 'mdsa_landing_destination',
        media_asset_url: 'media_asset_url',
        media_creator: 'media_creator',
        media_destination_url: 'media_destination_url',
        media_format: 'media_format',
        media_origin_url: 'media_origin_url',
        media_text_content: 'media_text_content',
        media_type: 'media_type',
        mmm: 'mmm',
        place_page_id: 'place_page_id',
        platform_position: 'platform_position',
        postback_sequence_index: 'postback_sequence_index',
        product_id: 'product_id',
        publisher_platform: 'publisher_platform',
        redownload: 'redownload',
        region: 'region',
        signal_source_bucket: 'signal_source_bucket',
        skan_campaign_id: 'skan_campaign_id',
        skan_conversion_id: 'skan_conversion_id',
        skan_version: 'skan_version',
        standard_event_content_type: 'standard_event_content_type',
        title_asset: 'title_asset',
        user_persona_id: 'user_persona_id',
        user_persona_name: 'user_persona_name',
        video_asset: 'video_asset'
      });
    }
  }, {
    key: 'DatePreset',
    get: function get() {
      return Object.freeze({
        data_maximum: 'data_maximum',
        last_14d: 'last_14d',
        last_28d: 'last_28d',
        last_30d: 'last_30d',
        last_3d: 'last_3d',
        last_7d: 'last_7d',
        last_90d: 'last_90d',
        last_month: 'last_month',
        last_quarter: 'last_quarter',
        last_week_mon_sun: 'last_week_mon_sun',
        last_week_sun_sat: 'last_week_sun_sat',
        last_year: 'last_year',
        maximum: 'maximum',
        this_month: 'this_month',
        this_quarter: 'this_quarter',
        this_week_mon_today: 'this_week_mon_today',
        this_week_sun_today: 'this_week_sun_today',
        this_year: 'this_year',
        today: 'today',
        yesterday: 'yesterday'
      });
    }
  }, {
    key: 'Level',
    get: function get() {
      return Object.freeze({
        account: 'account',
        ad: 'ad',
        adset: 'adset',
        campaign: 'campaign'
      });
    }
  }, {
    key: 'SummaryActionBreakdowns',
    get: function get() {
      return Object.freeze({
        action_canvas_component_name: 'action_canvas_component_name',
        action_carousel_card_id: 'action_carousel_card_id',
        action_carousel_card_name: 'action_carousel_card_name',
        action_destination: 'action_destination',
        action_device: 'action_device',
        action_reaction: 'action_reaction',
        action_target_id: 'action_target_id',
        action_type: 'action_type',
        action_video_sound: 'action_video_sound',
        action_video_type: 'action_video_type',
        conversion_destination: 'conversion_destination',
        matched_persona_id: 'matched_persona_id',
        matched_persona_name: 'matched_persona_name',
        signal_source_bucket: 'signal_source_bucket',
        standard_event_content_type: 'standard_event_content_type'
      });
    }
  }]);
  return AdsInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdReportRun
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdReportRun = function (_AbstractCrudObject) {
  inherits(AdReportRun, _AbstractCrudObject);
  createClass(AdReportRun, [{
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsInsights, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        async_percent_completion: 'async_percent_completion',
        async_status: 'async_status',
        date_start: 'date_start',
        date_stop: 'date_stop',
        emails: 'emails',
        friendly_name: 'friendly_name',
        id: 'id',
        is_bookmarked: 'is_bookmarked',
        is_running: 'is_running',
        schedule_id: 'schedule_id',
        time_completed: 'time_completed',
        time_ref: 'time_ref'
      });
    }
  }]);

  function AdReportRun() {
    var id = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
    var data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    var parentId = arguments[2];
    var api = arguments[3];
    classCallCheck(this, AdReportRun);

    var _this = possibleConstructorReturn(this, (AdReportRun.__proto__ || Object.getPrototypeOf(AdReportRun)).call(this));

    _this.id = data.report_run_id;
    return _this;
  }

  return AdReportRun;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Lead
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Lead = function (_AbstractCrudObject) {
  inherits(Lead, _AbstractCrudObject);

  function Lead() {
    classCallCheck(this, Lead);
    return possibleConstructorReturn(this, (Lead.__proto__ || Object.getPrototypeOf(Lead)).apply(this, arguments));
  }

  createClass(Lead, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Lead.prototype.__proto__ || Object.getPrototypeOf(Lead.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_id: 'ad_id',
        ad_name: 'ad_name',
        adset_id: 'adset_id',
        adset_name: 'adset_name',
        campaign_id: 'campaign_id',
        campaign_name: 'campaign_name',
        created_time: 'created_time',
        custom_disclaimer_responses: 'custom_disclaimer_responses',
        field_data: 'field_data',
        form_id: 'form_id',
        home_listing: 'home_listing',
        id: 'id',
        is_organic: 'is_organic',
        partner_name: 'partner_name',
        platform: 'platform',
        post: 'post',
        post_submission_check_result: 'post_submission_check_result',
        retailer_item_id: 'retailer_item_id',
        vehicle: 'vehicle'
      });
    }
  }]);
  return Lead;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingSentenceLine
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingSentenceLine = function (_AbstractCrudObject) {
  inherits(TargetingSentenceLine, _AbstractCrudObject);

  function TargetingSentenceLine() {
    classCallCheck(this, TargetingSentenceLine);
    return possibleConstructorReturn(this, (TargetingSentenceLine.__proto__ || Object.getPrototypeOf(TargetingSentenceLine)).apply(this, arguments));
  }

  createClass(TargetingSentenceLine, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        params: 'params',
        targetingsentencelines: 'targetingsentencelines'
      });
    }
  }]);
  return TargetingSentenceLine;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Ad
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Ad = function (_AbstractCrudObject) {
  inherits(Ad, _AbstractCrudObject);

  function Ad() {
    classCallCheck(this, Ad);
    return possibleConstructorReturn(this, (Ad.__proto__ || Object.getPrototypeOf(Ad)).apply(this, arguments));
  }

  createClass(Ad, [{
    key: 'getAdCreatives',
    value: function getAdCreatives(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdCreative, fields, params, fetchFirstPage, '/adcreatives');
    }
  }, {
    key: 'createAdLabel',
    value: function createAdLabel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adlabels', fields, params, Ad, pathOverride);
    }
  }, {
    key: 'getAdRulesGoverned',
    value: function getAdRulesGoverned(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdRule, fields, params, fetchFirstPage, '/adrules_governed');
    }
  }, {
    key: 'getCopies',
    value: function getCopies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Ad, fields, params, fetchFirstPage, '/copies');
    }
  }, {
    key: 'createCopy',
    value: function createCopy(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/copies', fields, params, Ad, pathOverride);
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsInsights, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'getInsightsAsync',
    value: function getInsightsAsync(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/insights', fields, params, AdReportRun, pathOverride);
    }
  }, {
    key: 'getLeads',
    value: function getLeads(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Lead, fields, params, fetchFirstPage, '/leads');
    }
  }, {
    key: 'getPreviews',
    value: function getPreviews(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdPreview, fields, params, fetchFirstPage, '/previews');
    }
  }, {
    key: 'getTargetingSentenceLines',
    value: function getTargetingSentenceLines(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(TargetingSentenceLine, fields, params, fetchFirstPage, '/targetingsentencelines');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Ad.prototype.__proto__ || Object.getPrototypeOf(Ad.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Ad.prototype.__proto__ || Object.getPrototypeOf(Ad.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        ad_active_time: 'ad_active_time',
        ad_review_feedback: 'ad_review_feedback',
        ad_schedule_end_time: 'ad_schedule_end_time',
        ad_schedule_start_time: 'ad_schedule_start_time',
        adlabels: 'adlabels',
        adset: 'adset',
        adset_id: 'adset_id',
        bid_amount: 'bid_amount',
        bid_info: 'bid_info',
        bid_type: 'bid_type',
        campaign: 'campaign',
        campaign_id: 'campaign_id',
        configured_status: 'configured_status',
        conversion_domain: 'conversion_domain',
        conversion_specs: 'conversion_specs',
        created_time: 'created_time',
        creative: 'creative',
        creative_asset_groups_spec: 'creative_asset_groups_spec',
        demolink_hash: 'demolink_hash',
        display_sequence: 'display_sequence',
        effective_status: 'effective_status',
        engagement_audience: 'engagement_audience',
        failed_delivery_checks: 'failed_delivery_checks',
        id: 'id',
        issues_info: 'issues_info',
        last_updated_by_app_id: 'last_updated_by_app_id',
        name: 'name',
        placement: 'placement',
        preview_shareable_link: 'preview_shareable_link',
        priority: 'priority',
        recommendations: 'recommendations',
        source_ad: 'source_ad',
        source_ad_id: 'source_ad_id',
        status: 'status',
        targeting: 'targeting',
        tracking_and_conversion_with_defaults: 'tracking_and_conversion_with_defaults',
        tracking_specs: 'tracking_specs',
        updated_time: 'updated_time'
      });
    }
  }, {
    key: 'BidType',
    get: function get() {
      return Object.freeze({
        absolute_ocpm: 'ABSOLUTE_OCPM',
        cpa: 'CPA',
        cpc: 'CPC',
        cpm: 'CPM',
        multi_premium: 'MULTI_PREMIUM'
      });
    }
  }, {
    key: 'ConfiguredStatus',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        archived: 'ARCHIVED',
        deleted: 'DELETED',
        paused: 'PAUSED'
      });
    }
  }, {
    key: 'EffectiveStatus',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        adset_paused: 'ADSET_PAUSED',
        archived: 'ARCHIVED',
        campaign_paused: 'CAMPAIGN_PAUSED',
        deleted: 'DELETED',
        disapproved: 'DISAPPROVED',
        in_process: 'IN_PROCESS',
        paused: 'PAUSED',
        pending_billing_info: 'PENDING_BILLING_INFO',
        pending_review: 'PENDING_REVIEW',
        preapproved: 'PREAPPROVED',
        with_issues: 'WITH_ISSUES'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        archived: 'ARCHIVED',
        deleted: 'DELETED',
        paused: 'PAUSED'
      });
    }
  }, {
    key: 'DatePreset',
    get: function get() {
      return Object.freeze({
        data_maximum: 'data_maximum',
        last_14d: 'last_14d',
        last_28d: 'last_28d',
        last_30d: 'last_30d',
        last_3d: 'last_3d',
        last_7d: 'last_7d',
        last_90d: 'last_90d',
        last_month: 'last_month',
        last_quarter: 'last_quarter',
        last_week_mon_sun: 'last_week_mon_sun',
        last_week_sun_sat: 'last_week_sun_sat',
        last_year: 'last_year',
        maximum: 'maximum',
        this_month: 'this_month',
        this_quarter: 'this_quarter',
        this_week_mon_today: 'this_week_mon_today',
        this_week_sun_today: 'this_week_sun_today',
        this_year: 'this_year',
        today: 'today',
        yesterday: 'yesterday'
      });
    }
  }, {
    key: 'ExecutionOptions',
    get: function get() {
      return Object.freeze({
        include_recommendations: 'include_recommendations',
        synchronous_ad_review: 'synchronous_ad_review',
        validate_only: 'validate_only'
      });
    }
  }, {
    key: 'Operator',
    get: function get() {
      return Object.freeze({
        all: 'ALL',
        any: 'ANY'
      });
    }
  }, {
    key: 'StatusOption',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        inherited_from_source: 'INHERITED_FROM_SOURCE',
        paused: 'PAUSED'
      });
    }
  }]);
  return Ad;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountBusinessConstraints
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountBusinessConstraints = function (_AbstractCrudObject) {
  inherits(AdAccountBusinessConstraints, _AbstractCrudObject);

  function AdAccountBusinessConstraints() {
    classCallCheck(this, AdAccountBusinessConstraints);
    return possibleConstructorReturn(this, (AdAccountBusinessConstraints.__proto__ || Object.getPrototypeOf(AdAccountBusinessConstraints)).apply(this, arguments));
  }

  createClass(AdAccountBusinessConstraints, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience_controls: 'audience_controls',
        campaigns_with_error: 'campaigns_with_error',
        placement_controls: 'placement_controls',
        status: 'status'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        application_in_progress: 'APPLICATION_IN_PROGRESS',
        with_campaign_error: 'WITH_CAMPAIGN_ERROR'
      });
    }
  }]);
  return AdAccountBusinessConstraints;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdActivity
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdActivity = function (_AbstractCrudObject) {
  inherits(AdActivity, _AbstractCrudObject);

  function AdActivity() {
    classCallCheck(this, AdActivity);
    return possibleConstructorReturn(this, (AdActivity.__proto__ || Object.getPrototypeOf(AdActivity)).apply(this, arguments));
  }

  createClass(AdActivity, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actor_id: 'actor_id',
        actor_name: 'actor_name',
        application_id: 'application_id',
        application_name: 'application_name',
        date_time_in_timezone: 'date_time_in_timezone',
        event_time: 'event_time',
        event_type: 'event_type',
        extra_data: 'extra_data',
        object_id: 'object_id',
        object_name: 'object_name',
        object_type: 'object_type',
        translated_event_type: 'translated_event_type'
      });
    }
  }, {
    key: 'EventType',
    get: function get() {
      return Object.freeze({
        account_spending_limit_reached: 'account_spending_limit_reached',
        ad_account_add_user_to_role: 'ad_account_add_user_to_role',
        ad_account_billing_charge: 'ad_account_billing_charge',
        ad_account_billing_charge_failed: 'ad_account_billing_charge_failed',
        ad_account_billing_chargeback: 'ad_account_billing_chargeback',
        ad_account_billing_chargeback_reversal: 'ad_account_billing_chargeback_reversal',
        ad_account_billing_decline: 'ad_account_billing_decline',
        ad_account_billing_refund: 'ad_account_billing_refund',
        ad_account_remove_spend_limit: 'ad_account_remove_spend_limit',
        ad_account_remove_user_from_role: 'ad_account_remove_user_from_role',
        ad_account_reset_spend_limit: 'ad_account_reset_spend_limit',
        ad_account_set_business_information: 'ad_account_set_business_information',
        ad_account_update_audience_type_url_parameter: 'ad_account_update_audience_type_url_parameter',
        ad_account_update_spend_limit: 'ad_account_update_spend_limit',
        ad_account_update_status: 'ad_account_update_status',
        ad_review_approved: 'ad_review_approved',
        ad_review_declined: 'ad_review_declined',
        adaccount_update_audience_segment: 'adaccount_update_audience_segment',
        add_funding_source: 'add_funding_source',
        add_images: 'add_images',
        billing_event: 'billing_event',
        campaign_ended: 'campaign_ended',
        campaign_spending_limit_reached: 'campaign_spending_limit_reached',
        conversion_event_updated: 'conversion_event_updated',
        create_ad: 'create_ad',
        create_ad_set: 'create_ad_set',
        create_audience: 'create_audience',
        create_campaign_group: 'create_campaign_group',
        create_campaign_legacy: 'create_campaign_legacy',
        delete_audience: 'delete_audience',
        delete_images: 'delete_images',
        di_ad_set_learning_stage_exit: 'di_ad_set_learning_stage_exit',
        edit_and_update_ad_creative: 'edit_and_update_ad_creative',
        edit_images: 'edit_images',
        first_delivery_event: 'first_delivery_event',
        funding_event_initiated: 'funding_event_initiated',
        funding_event_successful: 'funding_event_successful',
        lifetime_budget_spent: 'lifetime_budget_spent',
        merge_campaigns: 'merge_campaigns',
        receive_audience: 'receive_audience',
        remove_funding_source: 'remove_funding_source',
        remove_shared_audience: 'remove_shared_audience',
        share_audience: 'share_audience',
        unknown: 'unknown',
        unshare_audience: 'unshare_audience',
        update_ad_bid_info: 'update_ad_bid_info',
        update_ad_bid_type: 'update_ad_bid_type',
        update_ad_creative: 'update_ad_creative',
        update_ad_friendly_name: 'update_ad_friendly_name',
        update_ad_labels: 'update_ad_labels',
        update_ad_run_status: 'update_ad_run_status',
        update_ad_run_status_to_be_set_after_review: 'update_ad_run_status_to_be_set_after_review',
        update_ad_set_ad_keywords: 'update_ad_set_ad_keywords',
        update_ad_set_bid_adjustments: 'update_ad_set_bid_adjustments',
        update_ad_set_bid_strategy: 'update_ad_set_bid_strategy',
        update_ad_set_bidding: 'update_ad_set_bidding',
        update_ad_set_budget: 'update_ad_set_budget',
        update_ad_set_duration: 'update_ad_set_duration',
        update_ad_set_learning_stage_status: 'update_ad_set_learning_stage_status',
        update_ad_set_min_spend_target: 'update_ad_set_min_spend_target',
        update_ad_set_name: 'update_ad_set_name',
        update_ad_set_optimization_goal: 'update_ad_set_optimization_goal',
        update_ad_set_run_status: 'update_ad_set_run_status',
        update_ad_set_spend_cap: 'update_ad_set_spend_cap',
        update_ad_set_target_spec: 'update_ad_set_target_spec',
        update_ad_targets_spec: 'update_ad_targets_spec',
        update_adgroup_stop_delivery: 'update_adgroup_stop_delivery',
        update_audience: 'update_audience',
        update_campaign_ad_scheduling: 'update_campaign_ad_scheduling',
        update_campaign_budget: 'update_campaign_budget',
        update_campaign_budget_optimization_toggling_status: 'update_campaign_budget_optimization_toggling_status',
        update_campaign_budget_scheduling_state: 'update_campaign_budget_scheduling_state',
        update_campaign_conversion_goal: 'update_campaign_conversion_goal',
        update_campaign_delivery_destination: 'update_campaign_delivery_destination',
        update_campaign_delivery_type: 'update_campaign_delivery_type',
        update_campaign_group_ad_scheduling: 'update_campaign_group_ad_scheduling',
        update_campaign_group_budget_scheduling_state: 'update_campaign_group_budget_scheduling_state',
        update_campaign_group_delivery_type: 'update_campaign_group_delivery_type',
        update_campaign_group_high_demand_periods: 'update_campaign_group_high_demand_periods',
        update_campaign_group_spend_cap: 'update_campaign_group_spend_cap',
        update_campaign_high_demand_periods: 'update_campaign_high_demand_periods',
        update_campaign_name: 'update_campaign_name',
        update_campaign_run_status: 'update_campaign_run_status',
        update_campaign_schedule: 'update_campaign_schedule',
        update_campaign_value_adjustment_rule: 'update_campaign_value_adjustment_rule',
        update_delivery_type_cross_level_shift: 'update_delivery_type_cross_level_shift'
      });
    }
  }, {
    key: 'Category',
    get: function get() {
      return Object.freeze({
        account: 'ACCOUNT',
        ad: 'AD',
        ad_keywords: 'AD_KEYWORDS',
        ad_set: 'AD_SET',
        audience: 'AUDIENCE',
        bid: 'BID',
        budget: 'BUDGET',
        campaign: 'CAMPAIGN',
        date: 'DATE',
        status: 'STATUS',
        targeting: 'TARGETING'
      });
    }
  }, {
    key: 'DataSource',
    get: function get() {
      return Object.freeze({
        calypso: 'CALYPSO',
        tao: 'TAO',
        tao_ad_account: 'TAO_AD_ACCOUNT',
        tao_ad_status: 'TAO_AD_STATUS'
      });
    }
  }]);
  return AdActivity;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdPlacePageSet
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdPlacePageSet = function (_AbstractCrudObject) {
  inherits(AdPlacePageSet, _AbstractCrudObject);

  function AdPlacePageSet() {
    classCallCheck(this, AdPlacePageSet);
    return possibleConstructorReturn(this, (AdPlacePageSet.__proto__ || Object.getPrototypeOf(AdPlacePageSet)).apply(this, arguments));
  }

  createClass(AdPlacePageSet, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        id: 'id',
        location_types: 'location_types',
        name: 'name',
        pages_count: 'pages_count',
        parent_page: 'parent_page'
      });
    }
  }, {
    key: 'LocationTypes',
    get: function get() {
      return Object.freeze({
        home: 'home',
        recent: 'recent'
      });
    }
  }, {
    key: 'TargetedAreaType',
    get: function get() {
      return Object.freeze({
        custom_radius: 'CUSTOM_RADIUS',
        marketing_area: 'MARKETING_AREA',
        none: 'NONE'
      });
    }
  }]);
  return AdPlacePageSet;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdSavedKeywords
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdSavedKeywords = function (_AbstractCrudObject) {
  inherits(AdSavedKeywords, _AbstractCrudObject);

  function AdSavedKeywords() {
    classCallCheck(this, AdSavedKeywords);
    return possibleConstructorReturn(this, (AdSavedKeywords.__proto__ || Object.getPrototypeOf(AdSavedKeywords)).apply(this, arguments));
  }

  createClass(AdSavedKeywords, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account: 'account',
        id: 'id',
        keywords: 'keywords',
        name: 'name',
        run_status: 'run_status',
        time_created: 'time_created',
        time_updated: 'time_updated'
      });
    }
  }]);
  return AdSavedKeywords;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAsyncRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAsyncRequest = function (_AbstractCrudObject) {
  inherits(AdAsyncRequest, _AbstractCrudObject);

  function AdAsyncRequest() {
    classCallCheck(this, AdAsyncRequest);
    return possibleConstructorReturn(this, (AdAsyncRequest.__proto__ || Object.getPrototypeOf(AdAsyncRequest)).apply(this, arguments));
  }

  createClass(AdAsyncRequest, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdAsyncRequest.prototype.__proto__ || Object.getPrototypeOf(AdAsyncRequest.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        async_request_set: 'async_request_set',
        created_time: 'created_time',
        id: 'id',
        input: 'input',
        result: 'result',
        scope_object_id: 'scope_object_id',
        status: 'status',
        type: 'type',
        updated_time: 'updated_time'
      });
    }
  }, {
    key: 'Statuses',
    get: function get() {
      return Object.freeze({
        canceled: 'CANCELED',
        canceled_dependency: 'CANCELED_DEPENDENCY',
        error: 'ERROR',
        error_conflicts: 'ERROR_CONFLICTS',
        error_dependency: 'ERROR_DEPENDENCY',
        initial: 'INITIAL',
        in_progress: 'IN_PROGRESS',
        pending_dependency: 'PENDING_DEPENDENCY',
        process_by_ad_async_engine: 'PROCESS_BY_AD_ASYNC_ENGINE',
        process_by_event_processor: 'PROCESS_BY_EVENT_PROCESSOR',
        success: 'SUCCESS',
        user_canceled: 'USER_CANCELED',
        user_canceled_dependency: 'USER_CANCELED_DEPENDENCY'
      });
    }
  }]);
  return AdAsyncRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * HighDemandPeriod
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var HighDemandPeriod = function (_AbstractCrudObject) {
  inherits(HighDemandPeriod, _AbstractCrudObject);

  function HighDemandPeriod() {
    classCallCheck(this, HighDemandPeriod);
    return possibleConstructorReturn(this, (HighDemandPeriod.__proto__ || Object.getPrototypeOf(HighDemandPeriod)).apply(this, arguments));
  }

  createClass(HighDemandPeriod, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(HighDemandPeriod.prototype.__proto__ || Object.getPrototypeOf(HighDemandPeriod.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(HighDemandPeriod.prototype.__proto__ || Object.getPrototypeOf(HighDemandPeriod.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_object_id: 'ad_object_id',
        budget_value: 'budget_value',
        budget_value_type: 'budget_value_type',
        id: 'id',
        recurrence_type: 'recurrence_type',
        time_end: 'time_end',
        time_start: 'time_start',
        weekly_schedule: 'weekly_schedule'
      });
    }
  }, {
    key: 'BudgetValueType',
    get: function get() {
      return Object.freeze({
        absolute: 'ABSOLUTE',
        multiplier: 'MULTIPLIER'
      });
    }
  }]);
  return HighDemandPeriod;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignDeliveryEstimate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignDeliveryEstimate = function (_AbstractCrudObject) {
  inherits(AdCampaignDeliveryEstimate, _AbstractCrudObject);

  function AdCampaignDeliveryEstimate() {
    classCallCheck(this, AdCampaignDeliveryEstimate);
    return possibleConstructorReturn(this, (AdCampaignDeliveryEstimate.__proto__ || Object.getPrototypeOf(AdCampaignDeliveryEstimate)).apply(this, arguments));
  }

  createClass(AdCampaignDeliveryEstimate, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        daily_outcomes_curve: 'daily_outcomes_curve',
        estimate_dau: 'estimate_dau',
        estimate_mau_lower_bound: 'estimate_mau_lower_bound',
        estimate_mau_upper_bound: 'estimate_mau_upper_bound',
        estimate_ready: 'estimate_ready',
        targeting_optimization_types: 'targeting_optimization_types'
      });
    }
  }, {
    key: 'OptimizationGoal',
    get: function get() {
      return Object.freeze({
        ad_recall_lift: 'AD_RECALL_LIFT',
        app_installs: 'APP_INSTALLS',
        app_installs_and_offsite_conversions: 'APP_INSTALLS_AND_OFFSITE_CONVERSIONS',
        conversations: 'CONVERSATIONS',
        derived_events: 'DERIVED_EVENTS',
        engaged_users: 'ENGAGED_USERS',
        event_responses: 'EVENT_RESPONSES',
        impressions: 'IMPRESSIONS',
        in_app_value: 'IN_APP_VALUE',
        landing_page_views: 'LANDING_PAGE_VIEWS',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        meaningful_call_attempt: 'MEANINGFUL_CALL_ATTEMPT',
        messaging_appointment_conversion: 'MESSAGING_APPOINTMENT_CONVERSION',
        messaging_purchase_conversion: 'MESSAGING_PURCHASE_CONVERSION',
        none: 'NONE',
        offsite_conversions: 'OFFSITE_CONVERSIONS',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        profile_visit: 'PROFILE_VISIT',
        quality_call: 'QUALITY_CALL',
        quality_lead: 'QUALITY_LEAD',
        reach: 'REACH',
        reminders_set: 'REMINDERS_SET',
        subscribers: 'SUBSCRIBERS',
        thruplay: 'THRUPLAY',
        value: 'VALUE',
        visit_instagram_profile: 'VISIT_INSTAGRAM_PROFILE'
      });
    }
  }]);
  return AdCampaignDeliveryEstimate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MessageDeliveryEstimate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MessageDeliveryEstimate = function (_AbstractCrudObject) {
  inherits(MessageDeliveryEstimate, _AbstractCrudObject);

  function MessageDeliveryEstimate() {
    classCallCheck(this, MessageDeliveryEstimate);
    return possibleConstructorReturn(this, (MessageDeliveryEstimate.__proto__ || Object.getPrototypeOf(MessageDeliveryEstimate)).apply(this, arguments));
  }

  createClass(MessageDeliveryEstimate, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        estimate_cost: 'estimate_cost',
        estimate_cost_lower_bound: 'estimate_cost_lower_bound',
        estimate_cost_upper_bound: 'estimate_cost_upper_bound',
        estimate_coverage_lower_bound: 'estimate_coverage_lower_bound',
        estimate_coverage_upper_bound: 'estimate_coverage_upper_bound',
        estimate_delivery: 'estimate_delivery',
        estimate_delivery_lower_bound: 'estimate_delivery_lower_bound',
        estimate_delivery_upper_bound: 'estimate_delivery_upper_bound',
        estimate_status: 'estimate_status'
      });
    }
  }, {
    key: 'OptimizationGoal',
    get: function get() {
      return Object.freeze({
        ad_recall_lift: 'AD_RECALL_LIFT',
        app_installs: 'APP_INSTALLS',
        app_installs_and_offsite_conversions: 'APP_INSTALLS_AND_OFFSITE_CONVERSIONS',
        conversations: 'CONVERSATIONS',
        derived_events: 'DERIVED_EVENTS',
        engaged_users: 'ENGAGED_USERS',
        event_responses: 'EVENT_RESPONSES',
        impressions: 'IMPRESSIONS',
        in_app_value: 'IN_APP_VALUE',
        landing_page_views: 'LANDING_PAGE_VIEWS',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        meaningful_call_attempt: 'MEANINGFUL_CALL_ATTEMPT',
        messaging_appointment_conversion: 'MESSAGING_APPOINTMENT_CONVERSION',
        messaging_purchase_conversion: 'MESSAGING_PURCHASE_CONVERSION',
        none: 'NONE',
        offsite_conversions: 'OFFSITE_CONVERSIONS',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        profile_visit: 'PROFILE_VISIT',
        quality_call: 'QUALITY_CALL',
        quality_lead: 'QUALITY_LEAD',
        reach: 'REACH',
        reminders_set: 'REMINDERS_SET',
        subscribers: 'SUBSCRIBERS',
        thruplay: 'THRUPLAY',
        value: 'VALUE',
        visit_instagram_profile: 'VISIT_INSTAGRAM_PROFILE'
      });
    }
  }, {
    key: 'PacingType',
    get: function get() {
      return Object.freeze({
        day_parting: 'DAY_PARTING',
        disabled: 'DISABLED',
        no_pacing: 'NO_PACING',
        probabilistic_pacing: 'PROBABILISTIC_PACING',
        probabilistic_pacing_v2: 'PROBABILISTIC_PACING_V2',
        standard: 'STANDARD'
      });
    }
  }]);
  return MessageDeliveryEstimate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdSet
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdSet = function (_AbstractCrudObject) {
  inherits(AdSet, _AbstractCrudObject);

  function AdSet() {
    classCallCheck(this, AdSet);
    return possibleConstructorReturn(this, (AdSet.__proto__ || Object.getPrototypeOf(AdSet)).apply(this, arguments));
  }

  createClass(AdSet, [{
    key: 'getActivities',
    value: function getActivities(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdActivity, fields, params, fetchFirstPage, '/activities');
    }
  }, {
    key: 'getAdStudies',
    value: function getAdStudies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdStudy, fields, params, fetchFirstPage, '/ad_studies');
    }
  }, {
    key: 'getAdCreatives',
    value: function getAdCreatives(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdCreative, fields, params, fetchFirstPage, '/adcreatives');
    }
  }, {
    key: 'deleteAdLabels',
    value: function deleteAdLabels() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdSet.prototype.__proto__ || Object.getPrototypeOf(AdSet.prototype), 'deleteEdge', this).call(this, '/adlabels', params);
    }
  }, {
    key: 'createAdLabel',
    value: function createAdLabel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adlabels', fields, params, AdSet, pathOverride);
    }
  }, {
    key: 'getAdRulesGoverned',
    value: function getAdRulesGoverned(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdRule, fields, params, fetchFirstPage, '/adrules_governed');
    }
  }, {
    key: 'getAds',
    value: function getAds(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Ad, fields, params, fetchFirstPage, '/ads');
    }
  }, {
    key: 'getAsyncAdRequests',
    value: function getAsyncAdRequests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAsyncRequest, fields, params, fetchFirstPage, '/asyncadrequests');
    }
  }, {
    key: 'createBudgetSchedule',
    value: function createBudgetSchedule(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/budget_schedules', fields, params, HighDemandPeriod, pathOverride);
    }
  }, {
    key: 'getCopies',
    value: function getCopies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdSet, fields, params, fetchFirstPage, '/copies');
    }
  }, {
    key: 'createCopy',
    value: function createCopy(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/copies', fields, params, AdSet, pathOverride);
    }
  }, {
    key: 'getDeliveryEstimate',
    value: function getDeliveryEstimate(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdCampaignDeliveryEstimate, fields, params, fetchFirstPage, '/delivery_estimate');
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsInsights, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'getInsightsAsync',
    value: function getInsightsAsync(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/insights', fields, params, AdReportRun, pathOverride);
    }
  }, {
    key: 'getMessageDeliveryEstimate',
    value: function getMessageDeliveryEstimate(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MessageDeliveryEstimate, fields, params, fetchFirstPage, '/message_delivery_estimate');
    }
  }, {
    key: 'getTargetingSentenceLines',
    value: function getTargetingSentenceLines(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(TargetingSentenceLine, fields, params, fetchFirstPage, '/targetingsentencelines');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdSet.prototype.__proto__ || Object.getPrototypeOf(AdSet.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdSet.prototype.__proto__ || Object.getPrototypeOf(AdSet.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        adlabels: 'adlabels',
        adset_schedule: 'adset_schedule',
        asset_feed_id: 'asset_feed_id',
        attribution_spec: 'attribution_spec',
        bid_adjustments: 'bid_adjustments',
        bid_amount: 'bid_amount',
        bid_constraints: 'bid_constraints',
        bid_info: 'bid_info',
        bid_strategy: 'bid_strategy',
        billing_event: 'billing_event',
        brand_safety_config: 'brand_safety_config',
        budget_remaining: 'budget_remaining',
        campaign: 'campaign',
        campaign_active_time: 'campaign_active_time',
        campaign_attribution: 'campaign_attribution',
        campaign_id: 'campaign_id',
        configured_status: 'configured_status',
        created_time: 'created_time',
        creative_sequence: 'creative_sequence',
        daily_budget: 'daily_budget',
        daily_min_spend_target: 'daily_min_spend_target',
        daily_spend_cap: 'daily_spend_cap',
        destination_type: 'destination_type',
        dsa_beneficiary: 'dsa_beneficiary',
        dsa_payor: 'dsa_payor',
        effective_status: 'effective_status',
        end_time: 'end_time',
        existing_customer_budget_percentage: 'existing_customer_budget_percentage',
        frequency_control_specs: 'frequency_control_specs',
        full_funnel_exploration_mode: 'full_funnel_exploration_mode',
        id: 'id',
        instagram_actor_id: 'instagram_actor_id',
        is_budget_schedule_enabled: 'is_budget_schedule_enabled',
        is_dynamic_creative: 'is_dynamic_creative',
        issues_info: 'issues_info',
        learning_stage_info: 'learning_stage_info',
        lifetime_budget: 'lifetime_budget',
        lifetime_imps: 'lifetime_imps',
        lifetime_min_spend_target: 'lifetime_min_spend_target',
        lifetime_spend_cap: 'lifetime_spend_cap',
        max_budget_spend_percentage: 'max_budget_spend_percentage',
        min_budget_spend_percentage: 'min_budget_spend_percentage',
        multi_optimization_goal_weight: 'multi_optimization_goal_weight',
        name: 'name',
        optimization_goal: 'optimization_goal',
        optimization_sub_event: 'optimization_sub_event',
        pacing_type: 'pacing_type',
        promoted_object: 'promoted_object',
        recommendations: 'recommendations',
        recurring_budget_semantics: 'recurring_budget_semantics',
        regional_regulated_categories: 'regional_regulated_categories',
        regional_regulation_identities: 'regional_regulation_identities',
        review_feedback: 'review_feedback',
        rf_prediction_id: 'rf_prediction_id',
        source_adset: 'source_adset',
        source_adset_id: 'source_adset_id',
        start_time: 'start_time',
        status: 'status',
        targeting: 'targeting',
        targeting_optimization_types: 'targeting_optimization_types',
        time_based_ad_rotation_id_blocks: 'time_based_ad_rotation_id_blocks',
        time_based_ad_rotation_intervals: 'time_based_ad_rotation_intervals',
        updated_time: 'updated_time',
        use_new_app_click: 'use_new_app_click'
      });
    }
  }, {
    key: 'BidStrategy',
    get: function get() {
      return Object.freeze({
        cost_cap: 'COST_CAP',
        lowest_cost_without_cap: 'LOWEST_COST_WITHOUT_CAP',
        lowest_cost_with_bid_cap: 'LOWEST_COST_WITH_BID_CAP',
        lowest_cost_with_min_roas: 'LOWEST_COST_WITH_MIN_ROAS'
      });
    }
  }, {
    key: 'BillingEvent',
    get: function get() {
      return Object.freeze({
        app_installs: 'APP_INSTALLS',
        clicks: 'CLICKS',
        impressions: 'IMPRESSIONS',
        link_clicks: 'LINK_CLICKS',
        listing_interaction: 'LISTING_INTERACTION',
        none: 'NONE',
        offer_claims: 'OFFER_CLAIMS',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        purchase: 'PURCHASE',
        thruplay: 'THRUPLAY'
      });
    }
  }, {
    key: 'ConfiguredStatus',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        archived: 'ARCHIVED',
        deleted: 'DELETED',
        paused: 'PAUSED'
      });
    }
  }, {
    key: 'EffectiveStatus',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        archived: 'ARCHIVED',
        campaign_paused: 'CAMPAIGN_PAUSED',
        deleted: 'DELETED',
        in_process: 'IN_PROCESS',
        paused: 'PAUSED',
        with_issues: 'WITH_ISSUES'
      });
    }
  }, {
    key: 'OptimizationGoal',
    get: function get() {
      return Object.freeze({
        ad_recall_lift: 'AD_RECALL_LIFT',
        app_installs: 'APP_INSTALLS',
        app_installs_and_offsite_conversions: 'APP_INSTALLS_AND_OFFSITE_CONVERSIONS',
        conversations: 'CONVERSATIONS',
        derived_events: 'DERIVED_EVENTS',
        engaged_users: 'ENGAGED_USERS',
        event_responses: 'EVENT_RESPONSES',
        impressions: 'IMPRESSIONS',
        in_app_value: 'IN_APP_VALUE',
        landing_page_views: 'LANDING_PAGE_VIEWS',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        meaningful_call_attempt: 'MEANINGFUL_CALL_ATTEMPT',
        messaging_appointment_conversion: 'MESSAGING_APPOINTMENT_CONVERSION',
        messaging_purchase_conversion: 'MESSAGING_PURCHASE_CONVERSION',
        none: 'NONE',
        offsite_conversions: 'OFFSITE_CONVERSIONS',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        profile_visit: 'PROFILE_VISIT',
        quality_call: 'QUALITY_CALL',
        quality_lead: 'QUALITY_LEAD',
        reach: 'REACH',
        reminders_set: 'REMINDERS_SET',
        subscribers: 'SUBSCRIBERS',
        thruplay: 'THRUPLAY',
        value: 'VALUE',
        visit_instagram_profile: 'VISIT_INSTAGRAM_PROFILE'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        archived: 'ARCHIVED',
        deleted: 'DELETED',
        paused: 'PAUSED'
      });
    }
  }, {
    key: 'DatePreset',
    get: function get() {
      return Object.freeze({
        data_maximum: 'DATA_MAXIMUM',
        last_14d: 'LAST_14D',
        last_28d: 'LAST_28D',
        last_30d: 'LAST_30D',
        last_3d: 'LAST_3D',
        last_7d: 'LAST_7D',
        last_90d: 'LAST_90D',
        last_month: 'LAST_MONTH',
        last_quarter: 'LAST_QUARTER',
        last_week_mon_sun: 'LAST_WEEK_MON_SUN',
        last_week_sun_sat: 'LAST_WEEK_SUN_SAT',
        last_year: 'LAST_YEAR',
        maximum: 'MAXIMUM',
        this_month: 'THIS_MONTH',
        this_quarter: 'THIS_QUARTER',
        this_week_mon_today: 'THIS_WEEK_MON_TODAY',
        this_week_sun_today: 'THIS_WEEK_SUN_TODAY',
        this_year: 'THIS_YEAR',
        today: 'TODAY',
        yesterday: 'YESTERDAY'
      });
    }
  }, {
    key: 'DestinationType',
    get: function get() {
      return Object.freeze({
        app: 'APP',
        applinks_automatic: 'APPLINKS_AUTOMATIC',
        facebook: 'FACEBOOK',
        facebook_page: 'FACEBOOK_PAGE',
        instagram_direct: 'INSTAGRAM_DIRECT',
        instagram_profile: 'INSTAGRAM_PROFILE',
        instagram_profile_and_facebook_page: 'INSTAGRAM_PROFILE_AND_FACEBOOK_PAGE',
        messaging_instagram_direct_messenger: 'MESSAGING_INSTAGRAM_DIRECT_MESSENGER',
        messaging_instagram_direct_messenger_whatsapp: 'MESSAGING_INSTAGRAM_DIRECT_MESSENGER_WHATSAPP',
        messaging_instagram_direct_whatsapp: 'MESSAGING_INSTAGRAM_DIRECT_WHATSAPP',
        messaging_messenger_whatsapp: 'MESSAGING_MESSENGER_WHATSAPP',
        messenger: 'MESSENGER',
        on_ad: 'ON_AD',
        on_event: 'ON_EVENT',
        on_page: 'ON_PAGE',
        on_post: 'ON_POST',
        on_video: 'ON_VIDEO',
        shop_automatic: 'SHOP_AUTOMATIC',
        website: 'WEBSITE',
        whatsapp: 'WHATSAPP'
      });
    }
  }, {
    key: 'ExecutionOptions',
    get: function get() {
      return Object.freeze({
        include_recommendations: 'include_recommendations',
        validate_only: 'validate_only'
      });
    }
  }, {
    key: 'FullFunnelExplorationMode',
    get: function get() {
      return Object.freeze({
        extended_exploration: 'EXTENDED_EXPLORATION',
        limited_exploration: 'LIMITED_EXPLORATION',
        none_exploration: 'NONE_EXPLORATION'
      });
    }
  }, {
    key: 'MultiOptimizationGoalWeight',
    get: function get() {
      return Object.freeze({
        balanced: 'BALANCED',
        prefer_event: 'PREFER_EVENT',
        prefer_install: 'PREFER_INSTALL',
        undefined: 'UNDEFINED'
      });
    }
  }, {
    key: 'OptimizationSubEvent',
    get: function get() {
      return Object.freeze({
        none: 'NONE',
        travel_intent: 'TRAVEL_INTENT',
        travel_intent_bucket_01: 'TRAVEL_INTENT_BUCKET_01',
        travel_intent_bucket_02: 'TRAVEL_INTENT_BUCKET_02',
        travel_intent_bucket_03: 'TRAVEL_INTENT_BUCKET_03',
        travel_intent_bucket_04: 'TRAVEL_INTENT_BUCKET_04',
        travel_intent_bucket_05: 'TRAVEL_INTENT_BUCKET_05',
        travel_intent_no_destination_intent: 'TRAVEL_INTENT_NO_DESTINATION_INTENT',
        trip_consideration: 'TRIP_CONSIDERATION',
        video_sound_on: 'VIDEO_SOUND_ON'
      });
    }
  }, {
    key: 'RegionalRegulatedCategories',
    get: function get() {
      return Object.freeze({
        value_0: '0',
        value_1: '1',
        value_2: '2'
      });
    }
  }, {
    key: 'TuneForCategory',
    get: function get() {
      return Object.freeze({
        credit: 'CREDIT',
        employment: 'EMPLOYMENT',
        financial_products_services: 'FINANCIAL_PRODUCTS_SERVICES',
        housing: 'HOUSING',
        issues_elections_politics: 'ISSUES_ELECTIONS_POLITICS',
        none: 'NONE',
        online_gambling_and_gaming: 'ONLINE_GAMBLING_AND_GAMING'
      });
    }
  }, {
    key: 'Operator',
    get: function get() {
      return Object.freeze({
        all: 'ALL',
        any: 'ANY'
      });
    }
  }, {
    key: 'StatusOption',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        inherited_from_source: 'INHERITED_FROM_SOURCE',
        paused: 'PAUSED'
      });
    }
  }]);
  return AdSet;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Campaign
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Campaign = function (_AbstractCrudObject) {
  inherits(Campaign, _AbstractCrudObject);

  function Campaign() {
    classCallCheck(this, Campaign);
    return possibleConstructorReturn(this, (Campaign.__proto__ || Object.getPrototypeOf(Campaign)).apply(this, arguments));
  }

  createClass(Campaign, [{
    key: 'getAdStudies',
    value: function getAdStudies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdStudy, fields, params, fetchFirstPage, '/ad_studies');
    }
  }, {
    key: 'createAdLabel',
    value: function createAdLabel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adlabels', fields, params, Campaign, pathOverride);
    }
  }, {
    key: 'getAdRulesGoverned',
    value: function getAdRulesGoverned(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdRule, fields, params, fetchFirstPage, '/adrules_governed');
    }
  }, {
    key: 'getAds',
    value: function getAds(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Ad, fields, params, fetchFirstPage, '/ads');
    }
  }, {
    key: 'getAdSets',
    value: function getAdSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdSet, fields, params, fetchFirstPage, '/adsets');
    }
  }, {
    key: 'createBudgetSchedule',
    value: function createBudgetSchedule(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/budget_schedules', fields, params, HighDemandPeriod, pathOverride);
    }
  }, {
    key: 'getCopies',
    value: function getCopies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Campaign, fields, params, fetchFirstPage, '/copies');
    }
  }, {
    key: 'createCopy',
    value: function createCopy(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/copies', fields, params, Campaign, pathOverride);
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsInsights, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'getInsightsAsync',
    value: function getInsightsAsync(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/insights', fields, params, AdReportRun, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Campaign.prototype.__proto__ || Object.getPrototypeOf(Campaign.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Campaign.prototype.__proto__ || Object.getPrototypeOf(Campaign.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        adlabels: 'adlabels',
        bid_strategy: 'bid_strategy',
        boosted_object_id: 'boosted_object_id',
        brand_lift_studies: 'brand_lift_studies',
        budget_rebalance_flag: 'budget_rebalance_flag',
        budget_remaining: 'budget_remaining',
        buying_type: 'buying_type',
        campaign_group_active_time: 'campaign_group_active_time',
        can_create_brand_lift_study: 'can_create_brand_lift_study',
        can_use_spend_cap: 'can_use_spend_cap',
        configured_status: 'configured_status',
        created_time: 'created_time',
        daily_budget: 'daily_budget',
        effective_status: 'effective_status',
        has_secondary_skadnetwork_reporting: 'has_secondary_skadnetwork_reporting',
        id: 'id',
        is_budget_schedule_enabled: 'is_budget_schedule_enabled',
        is_skadnetwork_attribution: 'is_skadnetwork_attribution',
        issues_info: 'issues_info',
        last_budget_toggling_time: 'last_budget_toggling_time',
        lifetime_budget: 'lifetime_budget',
        name: 'name',
        objective: 'objective',
        pacing_type: 'pacing_type',
        primary_attribution: 'primary_attribution',
        promoted_object: 'promoted_object',
        recommendations: 'recommendations',
        smart_promotion_type: 'smart_promotion_type',
        source_campaign: 'source_campaign',
        source_campaign_id: 'source_campaign_id',
        source_recommendation_type: 'source_recommendation_type',
        special_ad_categories: 'special_ad_categories',
        special_ad_category: 'special_ad_category',
        special_ad_category_country: 'special_ad_category_country',
        spend_cap: 'spend_cap',
        start_time: 'start_time',
        status: 'status',
        stop_time: 'stop_time',
        topline_id: 'topline_id',
        updated_time: 'updated_time'
      });
    }
  }, {
    key: 'BidStrategy',
    get: function get() {
      return Object.freeze({
        cost_cap: 'COST_CAP',
        lowest_cost_without_cap: 'LOWEST_COST_WITHOUT_CAP',
        lowest_cost_with_bid_cap: 'LOWEST_COST_WITH_BID_CAP',
        lowest_cost_with_min_roas: 'LOWEST_COST_WITH_MIN_ROAS'
      });
    }
  }, {
    key: 'ConfiguredStatus',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        archived: 'ARCHIVED',
        deleted: 'DELETED',
        paused: 'PAUSED'
      });
    }
  }, {
    key: 'EffectiveStatus',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        archived: 'ARCHIVED',
        deleted: 'DELETED',
        in_process: 'IN_PROCESS',
        paused: 'PAUSED',
        with_issues: 'WITH_ISSUES'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        archived: 'ARCHIVED',
        deleted: 'DELETED',
        paused: 'PAUSED'
      });
    }
  }, {
    key: 'DatePreset',
    get: function get() {
      return Object.freeze({
        data_maximum: 'data_maximum',
        last_14d: 'last_14d',
        last_28d: 'last_28d',
        last_30d: 'last_30d',
        last_3d: 'last_3d',
        last_7d: 'last_7d',
        last_90d: 'last_90d',
        last_month: 'last_month',
        last_quarter: 'last_quarter',
        last_week_mon_sun: 'last_week_mon_sun',
        last_week_sun_sat: 'last_week_sun_sat',
        last_year: 'last_year',
        maximum: 'maximum',
        this_month: 'this_month',
        this_quarter: 'this_quarter',
        this_week_mon_today: 'this_week_mon_today',
        this_week_sun_today: 'this_week_sun_today',
        this_year: 'this_year',
        today: 'today',
        yesterday: 'yesterday'
      });
    }
  }, {
    key: 'ExecutionOptions',
    get: function get() {
      return Object.freeze({
        include_recommendations: 'include_recommendations',
        validate_only: 'validate_only'
      });
    }
  }, {
    key: 'Objective',
    get: function get() {
      return Object.freeze({
        app_installs: 'APP_INSTALLS',
        brand_awareness: 'BRAND_AWARENESS',
        conversions: 'CONVERSIONS',
        event_responses: 'EVENT_RESPONSES',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        local_awareness: 'LOCAL_AWARENESS',
        messages: 'MESSAGES',
        offer_claims: 'OFFER_CLAIMS',
        outcome_app_promotion: 'OUTCOME_APP_PROMOTION',
        outcome_awareness: 'OUTCOME_AWARENESS',
        outcome_engagement: 'OUTCOME_ENGAGEMENT',
        outcome_leads: 'OUTCOME_LEADS',
        outcome_sales: 'OUTCOME_SALES',
        outcome_traffic: 'OUTCOME_TRAFFIC',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        product_catalog_sales: 'PRODUCT_CATALOG_SALES',
        reach: 'REACH',
        store_visits: 'STORE_VISITS',
        video_views: 'VIDEO_VIEWS'
      });
    }
  }, {
    key: 'SmartPromotionType',
    get: function get() {
      return Object.freeze({
        guided_creation: 'GUIDED_CREATION',
        smart_app_promotion: 'SMART_APP_PROMOTION'
      });
    }
  }, {
    key: 'SpecialAdCategories',
    get: function get() {
      return Object.freeze({
        credit: 'CREDIT',
        employment: 'EMPLOYMENT',
        financial_products_services: 'FINANCIAL_PRODUCTS_SERVICES',
        housing: 'HOUSING',
        issues_elections_politics: 'ISSUES_ELECTIONS_POLITICS',
        none: 'NONE',
        online_gambling_and_gaming: 'ONLINE_GAMBLING_AND_GAMING'
      });
    }
  }, {
    key: 'SpecialAdCategoryCountry',
    get: function get() {
      return Object.freeze({
        ad: 'AD',
        ae: 'AE',
        af: 'AF',
        ag: 'AG',
        ai: 'AI',
        al: 'AL',
        am: 'AM',
        an: 'AN',
        ao: 'AO',
        aq: 'AQ',
        ar: 'AR',
        as: 'AS',
        at: 'AT',
        au: 'AU',
        aw: 'AW',
        ax: 'AX',
        az: 'AZ',
        ba: 'BA',
        bb: 'BB',
        bd: 'BD',
        be: 'BE',
        bf: 'BF',
        bg: 'BG',
        bh: 'BH',
        bi: 'BI',
        bj: 'BJ',
        bl: 'BL',
        bm: 'BM',
        bn: 'BN',
        bo: 'BO',
        bq: 'BQ',
        br: 'BR',
        bs: 'BS',
        bt: 'BT',
        bv: 'BV',
        bw: 'BW',
        by: 'BY',
        bz: 'BZ',
        ca: 'CA',
        cc: 'CC',
        cd: 'CD',
        cf: 'CF',
        cg: 'CG',
        ch: 'CH',
        ci: 'CI',
        ck: 'CK',
        cl: 'CL',
        cm: 'CM',
        cn: 'CN',
        co: 'CO',
        cr: 'CR',
        cu: 'CU',
        cv: 'CV',
        cw: 'CW',
        cx: 'CX',
        cy: 'CY',
        cz: 'CZ',
        de: 'DE',
        dj: 'DJ',
        dk: 'DK',
        dm: 'DM',
        do: 'DO',
        dz: 'DZ',
        ec: 'EC',
        ee: 'EE',
        eg: 'EG',
        eh: 'EH',
        er: 'ER',
        es: 'ES',
        et: 'ET',
        fi: 'FI',
        fj: 'FJ',
        fk: 'FK',
        fm: 'FM',
        fo: 'FO',
        fr: 'FR',
        ga: 'GA',
        gb: 'GB',
        gd: 'GD',
        ge: 'GE',
        gf: 'GF',
        gg: 'GG',
        gh: 'GH',
        gi: 'GI',
        gl: 'GL',
        gm: 'GM',
        gn: 'GN',
        gp: 'GP',
        gq: 'GQ',
        gr: 'GR',
        gs: 'GS',
        gt: 'GT',
        gu: 'GU',
        gw: 'GW',
        gy: 'GY',
        hk: 'HK',
        hm: 'HM',
        hn: 'HN',
        hr: 'HR',
        ht: 'HT',
        hu: 'HU',
        id: 'ID',
        ie: 'IE',
        il: 'IL',
        im: 'IM',
        in: 'IN',
        io: 'IO',
        iq: 'IQ',
        ir: 'IR',
        is: 'IS',
        it: 'IT',
        je: 'JE',
        jm: 'JM',
        jo: 'JO',
        jp: 'JP',
        ke: 'KE',
        kg: 'KG',
        kh: 'KH',
        ki: 'KI',
        km: 'KM',
        kn: 'KN',
        kp: 'KP',
        kr: 'KR',
        kw: 'KW',
        ky: 'KY',
        kz: 'KZ',
        la: 'LA',
        lb: 'LB',
        lc: 'LC',
        li: 'LI',
        lk: 'LK',
        lr: 'LR',
        ls: 'LS',
        lt: 'LT',
        lu: 'LU',
        lv: 'LV',
        ly: 'LY',
        ma: 'MA',
        mc: 'MC',
        md: 'MD',
        me: 'ME',
        mf: 'MF',
        mg: 'MG',
        mh: 'MH',
        mk: 'MK',
        ml: 'ML',
        mm: 'MM',
        mn: 'MN',
        mo: 'MO',
        mp: 'MP',
        mq: 'MQ',
        mr: 'MR',
        ms: 'MS',
        mt: 'MT',
        mu: 'MU',
        mv: 'MV',
        mw: 'MW',
        mx: 'MX',
        my: 'MY',
        mz: 'MZ',
        na: 'NA',
        nc: 'NC',
        ne: 'NE',
        nf: 'NF',
        ng: 'NG',
        ni: 'NI',
        nl: 'NL',
        no: 'NO',
        np: 'NP',
        nr: 'NR',
        nu: 'NU',
        nz: 'NZ',
        om: 'OM',
        pa: 'PA',
        pe: 'PE',
        pf: 'PF',
        pg: 'PG',
        ph: 'PH',
        pk: 'PK',
        pl: 'PL',
        pm: 'PM',
        pn: 'PN',
        pr: 'PR',
        ps: 'PS',
        pt: 'PT',
        pw: 'PW',
        py: 'PY',
        qa: 'QA',
        re: 'RE',
        ro: 'RO',
        rs: 'RS',
        ru: 'RU',
        rw: 'RW',
        sa: 'SA',
        sb: 'SB',
        sc: 'SC',
        sd: 'SD',
        se: 'SE',
        sg: 'SG',
        sh: 'SH',
        si: 'SI',
        sj: 'SJ',
        sk: 'SK',
        sl: 'SL',
        sm: 'SM',
        sn: 'SN',
        so: 'SO',
        sr: 'SR',
        ss: 'SS',
        st: 'ST',
        sv: 'SV',
        sx: 'SX',
        sy: 'SY',
        sz: 'SZ',
        tc: 'TC',
        td: 'TD',
        tf: 'TF',
        tg: 'TG',
        th: 'TH',
        tj: 'TJ',
        tk: 'TK',
        tl: 'TL',
        tm: 'TM',
        tn: 'TN',
        to: 'TO',
        tr: 'TR',
        tt: 'TT',
        tv: 'TV',
        tw: 'TW',
        tz: 'TZ',
        ua: 'UA',
        ug: 'UG',
        um: 'UM',
        us: 'US',
        uy: 'UY',
        uz: 'UZ',
        va: 'VA',
        vc: 'VC',
        ve: 'VE',
        vg: 'VG',
        vi: 'VI',
        vn: 'VN',
        vu: 'VU',
        wf: 'WF',
        ws: 'WS',
        xk: 'XK',
        ye: 'YE',
        yt: 'YT',
        za: 'ZA',
        zm: 'ZM',
        zw: 'ZW'
      });
    }
  }, {
    key: 'Operator',
    get: function get() {
      return Object.freeze({
        all: 'ALL',
        any: 'ANY'
      });
    }
  }, {
    key: 'SpecialAdCategory',
    get: function get() {
      return Object.freeze({
        credit: 'CREDIT',
        employment: 'EMPLOYMENT',
        financial_products_services: 'FINANCIAL_PRODUCTS_SERVICES',
        housing: 'HOUSING',
        issues_elections_politics: 'ISSUES_ELECTIONS_POLITICS',
        none: 'NONE',
        online_gambling_and_gaming: 'ONLINE_GAMBLING_AND_GAMING'
      });
    }
  }, {
    key: 'StatusOption',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        inherited_from_source: 'INHERITED_FROM_SOURCE',
        paused: 'PAUSED'
      });
    }
  }]);
  return Campaign;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdStudyCell
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdStudyCell = function (_AbstractCrudObject) {
  inherits(AdStudyCell, _AbstractCrudObject);

  function AdStudyCell() {
    classCallCheck(this, AdStudyCell);
    return possibleConstructorReturn(this, (AdStudyCell.__proto__ || Object.getPrototypeOf(AdStudyCell)).apply(this, arguments));
  }

  createClass(AdStudyCell, [{
    key: 'getAdAccounts',
    value: function getAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/adaccounts');
    }
  }, {
    key: 'getAdSets',
    value: function getAdSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdSet, fields, params, fetchFirstPage, '/adsets');
    }
  }, {
    key: 'getCampaigns',
    value: function getCampaigns(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Campaign, fields, params, fetchFirstPage, '/campaigns');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdStudyCell.prototype.__proto__ || Object.getPrototypeOf(AdStudyCell.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_entities_count: 'ad_entities_count',
        control_percentage: 'control_percentage',
        id: 'id',
        name: 'name',
        treatment_percentage: 'treatment_percentage'
      });
    }
  }, {
    key: 'CreationTemplate',
    get: function get() {
      return Object.freeze({
        automatic_placements: 'AUTOMATIC_PLACEMENTS',
        brand_awareness: 'BRAND_AWARENESS',
        facebook: 'FACEBOOK',
        facebook_audience_network: 'FACEBOOK_AUDIENCE_NETWORK',
        facebook_instagram: 'FACEBOOK_INSTAGRAM',
        facebook_news_feed: 'FACEBOOK_NEWS_FEED',
        facebook_news_feed_in_stream_video: 'FACEBOOK_NEWS_FEED_IN_STREAM_VIDEO',
        high_frequency: 'HIGH_FREQUENCY',
        instagram: 'INSTAGRAM',
        in_stream_video: 'IN_STREAM_VIDEO',
        low_frequency: 'LOW_FREQUENCY',
        medium_frequency: 'MEDIUM_FREQUENCY',
        mobile_optimized_video: 'MOBILE_OPTIMIZED_VIDEO',
        page_post_engagement: 'PAGE_POST_ENGAGEMENT',
        reach: 'REACH',
        tv_commercial: 'TV_COMMERCIAL',
        tv_facebook: 'TV_FACEBOOK',
        video_view_optimization: 'VIDEO_VIEW_OPTIMIZATION'
      });
    }
  }]);
  return AdStudyCell;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PrivateLiftStudyInstance
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PrivateLiftStudyInstance = function (_AbstractCrudObject) {
  inherits(PrivateLiftStudyInstance, _AbstractCrudObject);

  function PrivateLiftStudyInstance() {
    classCallCheck(this, PrivateLiftStudyInstance);
    return possibleConstructorReturn(this, (PrivateLiftStudyInstance.__proto__ || Object.getPrototypeOf(PrivateLiftStudyInstance)).apply(this, arguments));
  }

  createClass(PrivateLiftStudyInstance, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(PrivateLiftStudyInstance.prototype.__proto__ || Object.getPrototypeOf(PrivateLiftStudyInstance.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        breakdown_key: 'breakdown_key',
        created_time: 'created_time',
        feature_list: 'feature_list',
        id: 'id',
        issuer_certificate: 'issuer_certificate',
        latest_status_update_time: 'latest_status_update_time',
        run_id: 'run_id',
        server_hostnames: 'server_hostnames',
        server_ips: 'server_ips',
        status: 'status',
        tier: 'tier'
      });
    }
  }, {
    key: 'Operation',
    get: function get() {
      return Object.freeze({
        aggregate: 'AGGREGATE',
        cancel: 'CANCEL',
        compute: 'COMPUTE',
        id_match: 'ID_MATCH',
        next: 'NEXT',
        none: 'NONE'
      });
    }
  }]);
  return PrivateLiftStudyInstance;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdPlacement
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdPlacement = function (_AbstractCrudObject) {
  inherits(AdPlacement, _AbstractCrudObject);

  function AdPlacement() {
    classCallCheck(this, AdPlacement);
    return possibleConstructorReturn(this, (AdPlacement.__proto__ || Object.getPrototypeOf(AdPlacement)).apply(this, arguments));
  }

  createClass(AdPlacement, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        bundle_id: 'bundle_id',
        display_format: 'display_format',
        external_placement_id: 'external_placement_id',
        google_display_format: 'google_display_format',
        id: 'id',
        name: 'name',
        placement_group: 'placement_group',
        platform: 'platform',
        status: 'status'
      });
    }
  }]);
  return AdPlacement;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdNetworkAnalyticsSyncQueryResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdNetworkAnalyticsSyncQueryResult = function (_AbstractCrudObject) {
  inherits(AdNetworkAnalyticsSyncQueryResult, _AbstractCrudObject);

  function AdNetworkAnalyticsSyncQueryResult() {
    classCallCheck(this, AdNetworkAnalyticsSyncQueryResult);
    return possibleConstructorReturn(this, (AdNetworkAnalyticsSyncQueryResult.__proto__ || Object.getPrototypeOf(AdNetworkAnalyticsSyncQueryResult)).apply(this, arguments));
  }

  createClass(AdNetworkAnalyticsSyncQueryResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        omitted_results: 'omitted_results',
        query_id: 'query_id',
        results: 'results'
      });
    }
  }, {
    key: 'AggregationPeriod',
    get: function get() {
      return Object.freeze({
        day: 'DAY',
        total: 'TOTAL'
      });
    }
  }, {
    key: 'Breakdowns',
    get: function get() {
      return Object.freeze({
        ad_server_campaign_id: 'AD_SERVER_CAMPAIGN_ID',
        ad_space: 'AD_SPACE',
        age: 'AGE',
        app: 'APP',
        clicked_view_tag: 'CLICKED_VIEW_TAG',
        country: 'COUNTRY',
        deal: 'DEAL',
        deal_ad: 'DEAL_AD',
        deal_page: 'DEAL_PAGE',
        delivery_method: 'DELIVERY_METHOD',
        display_format: 'DISPLAY_FORMAT',
        fail_reason: 'FAIL_REASON',
        gender: 'GENDER',
        instant_article_id: 'INSTANT_ARTICLE_ID',
        instant_article_page_id: 'INSTANT_ARTICLE_PAGE_ID',
        is_deal_backfill: 'IS_DEAL_BACKFILL',
        placement: 'PLACEMENT',
        placement_name: 'PLACEMENT_NAME',
        platform: 'PLATFORM',
        property: 'PROPERTY',
        sdk_version: 'SDK_VERSION'
      });
    }
  }, {
    key: 'Metrics',
    get: function get() {
      return Object.freeze({
        fb_ad_network_bidding_bid_rate: 'FB_AD_NETWORK_BIDDING_BID_RATE',
        fb_ad_network_bidding_request: 'FB_AD_NETWORK_BIDDING_REQUEST',
        fb_ad_network_bidding_response: 'FB_AD_NETWORK_BIDDING_RESPONSE',
        fb_ad_network_bidding_revenue: 'FB_AD_NETWORK_BIDDING_REVENUE',
        fb_ad_network_bidding_win_rate: 'FB_AD_NETWORK_BIDDING_WIN_RATE',
        fb_ad_network_click: 'FB_AD_NETWORK_CLICK',
        fb_ad_network_cpm: 'FB_AD_NETWORK_CPM',
        fb_ad_network_ctr: 'FB_AD_NETWORK_CTR',
        fb_ad_network_filled_request: 'FB_AD_NETWORK_FILLED_REQUEST',
        fb_ad_network_fill_rate: 'FB_AD_NETWORK_FILL_RATE',
        fb_ad_network_imp: 'FB_AD_NETWORK_IMP',
        fb_ad_network_impression_rate: 'FB_AD_NETWORK_IMPRESSION_RATE',
        fb_ad_network_request: 'FB_AD_NETWORK_REQUEST',
        fb_ad_network_revenue: 'FB_AD_NETWORK_REVENUE',
        fb_ad_network_show_rate: 'FB_AD_NETWORK_SHOW_RATE',
        fb_ad_network_video_guarantee_revenue: 'FB_AD_NETWORK_VIDEO_GUARANTEE_REVENUE',
        fb_ad_network_video_mrc: 'FB_AD_NETWORK_VIDEO_MRC',
        fb_ad_network_video_mrc_rate: 'FB_AD_NETWORK_VIDEO_MRC_RATE',
        fb_ad_network_video_view: 'FB_AD_NETWORK_VIDEO_VIEW',
        fb_ad_network_video_view_rate: 'FB_AD_NETWORK_VIDEO_VIEW_RATE'
      });
    }
  }, {
    key: 'OrderingColumn',
    get: function get() {
      return Object.freeze({
        metric: 'METRIC',
        time: 'TIME',
        value: 'VALUE'
      });
    }
  }, {
    key: 'OrderingType',
    get: function get() {
      return Object.freeze({
        ascending: 'ASCENDING',
        descending: 'DESCENDING'
      });
    }
  }]);
  return AdNetworkAnalyticsSyncQueryResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdNetworkAnalyticsAsyncQueryResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdNetworkAnalyticsAsyncQueryResult = function (_AbstractCrudObject) {
  inherits(AdNetworkAnalyticsAsyncQueryResult, _AbstractCrudObject);

  function AdNetworkAnalyticsAsyncQueryResult() {
    classCallCheck(this, AdNetworkAnalyticsAsyncQueryResult);
    return possibleConstructorReturn(this, (AdNetworkAnalyticsAsyncQueryResult.__proto__ || Object.getPrototypeOf(AdNetworkAnalyticsAsyncQueryResult)).apply(this, arguments));
  }

  createClass(AdNetworkAnalyticsAsyncQueryResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        data: 'data',
        error: 'error',
        omitted_results: 'omitted_results',
        query_id: 'query_id',
        results: 'results',
        status: 'status'
      });
    }
  }]);
  return AdNetworkAnalyticsAsyncQueryResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProfilePictureSource
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProfilePictureSource = function (_AbstractCrudObject) {
  inherits(ProfilePictureSource, _AbstractCrudObject);

  function ProfilePictureSource() {
    classCallCheck(this, ProfilePictureSource);
    return possibleConstructorReturn(this, (ProfilePictureSource.__proto__ || Object.getPrototypeOf(ProfilePictureSource)).apply(this, arguments));
  }

  createClass(ProfilePictureSource, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        bottom: 'bottom',
        cache_key: 'cache_key',
        height: 'height',
        is_silhouette: 'is_silhouette',
        left: 'left',
        right: 'right',
        top: 'top',
        url: 'url',
        width: 'width'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        album: 'album',
        small: 'small',
        thumbnail: 'thumbnail'
      });
    }
  }]);
  return ProfilePictureSource;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Profile
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Profile = function (_AbstractCrudObject) {
  inherits(Profile, _AbstractCrudObject);

  function Profile() {
    classCallCheck(this, Profile);
    return possibleConstructorReturn(this, (Profile.__proto__ || Object.getPrototypeOf(Profile)).apply(this, arguments));
  }

  createClass(Profile, [{
    key: 'getPicture',
    value: function getPicture(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProfilePictureSource, fields, params, fetchFirstPage, '/picture');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_post: 'can_post',
        id: 'id',
        link: 'link',
        name: 'name',
        pic: 'pic',
        pic_crop: 'pic_crop',
        pic_large: 'pic_large',
        pic_small: 'pic_small',
        pic_square: 'pic_square',
        profile_type: 'profile_type',
        username: 'username'
      });
    }
  }, {
    key: 'ProfileType',
    get: function get() {
      return Object.freeze({
        application: 'application',
        event: 'event',
        group: 'group',
        page: 'page',
        user: 'user'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        angry: 'ANGRY',
        care: 'CARE',
        fire: 'FIRE',
        haha: 'HAHA',
        hundred: 'HUNDRED',
        like: 'LIKE',
        love: 'LOVE',
        none: 'NONE',
        pride: 'PRIDE',
        sad: 'SAD',
        thankful: 'THANKFUL',
        wow: 'WOW'
      });
    }
  }]);
  return Profile;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Comment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Comment = function (_AbstractCrudObject) {
  inherits(Comment, _AbstractCrudObject);

  function Comment() {
    classCallCheck(this, Comment);
    return possibleConstructorReturn(this, (Comment.__proto__ || Object.getPrototypeOf(Comment)).apply(this, arguments));
  }

  createClass(Comment, [{
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Comment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, Comment, pathOverride);
    }
  }, {
    key: 'deleteLikes',
    value: function deleteLikes() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Comment.prototype.__proto__ || Object.getPrototypeOf(Comment.prototype), 'deleteEdge', this).call(this, '/likes', params);
    }
  }, {
    key: 'getLikes',
    value: function getLikes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/likes');
    }
  }, {
    key: 'createLike',
    value: function createLike(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/likes', fields, params, Comment, pathOverride);
    }
  }, {
    key: 'getReactions',
    value: function getReactions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/reactions');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Comment.prototype.__proto__ || Object.getPrototypeOf(Comment.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Comment.prototype.__proto__ || Object.getPrototypeOf(Comment.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        admin_creator: 'admin_creator',
        application: 'application',
        attachment: 'attachment',
        can_comment: 'can_comment',
        can_hide: 'can_hide',
        can_like: 'can_like',
        can_remove: 'can_remove',
        can_reply_privately: 'can_reply_privately',
        comment_count: 'comment_count',
        created_time: 'created_time',
        from: 'from',
        id: 'id',
        is_hidden: 'is_hidden',
        is_private: 'is_private',
        like_count: 'like_count',
        live_broadcast_timestamp: 'live_broadcast_timestamp',
        message: 'message',
        message_tags: 'message_tags',
        object: 'object',
        parent: 'parent',
        permalink_url: 'permalink_url',
        private_reply_conversation: 'private_reply_conversation',
        user_likes: 'user_likes'
      });
    }
  }, {
    key: 'Order',
    get: function get() {
      return Object.freeze({
        chronological: 'chronological',
        reverse_chronological: 'reverse_chronological'
      });
    }
  }, {
    key: 'CommentPrivacyValue',
    get: function get() {
      return Object.freeze({
        declined_by_admin_assistant: 'DECLINED_BY_ADMIN_ASSISTANT',
        default_privacy: 'DEFAULT_PRIVACY',
        friends_and_post_owner: 'FRIENDS_AND_POST_OWNER',
        friends_only: 'FRIENDS_ONLY',
        graphql_multiple_value_hack_do_not_use: 'GRAPHQL_MULTIPLE_VALUE_HACK_DO_NOT_USE',
        owner_or_commenter: 'OWNER_OR_COMMENTER',
        pending_approval: 'PENDING_APPROVAL',
        removed_by_admin_assistant: 'REMOVED_BY_ADMIN_ASSISTANT',
        side_conversation: 'SIDE_CONVERSATION',
        side_conversation_and_post_owner: 'SIDE_CONVERSATION_AND_POST_OWNER',
        spotlight_tab: 'SPOTLIGHT_TAB'
      });
    }
  }, {
    key: 'Filter',
    get: function get() {
      return Object.freeze({
        stream: 'stream',
        toplevel: 'toplevel'
      });
    }
  }, {
    key: 'LiveFilter',
    get: function get() {
      return Object.freeze({
        filter_low_quality: 'filter_low_quality',
        no_filter: 'no_filter'
      });
    }
  }]);
  return Comment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InsightsResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InsightsResult = function (_AbstractCrudObject) {
  inherits(InsightsResult, _AbstractCrudObject);

  function InsightsResult() {
    classCallCheck(this, InsightsResult);
    return possibleConstructorReturn(this, (InsightsResult.__proto__ || Object.getPrototypeOf(InsightsResult)).apply(this, arguments));
  }

  createClass(InsightsResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        description_from_api_doc: 'description_from_api_doc',
        id: 'id',
        name: 'name',
        period: 'period',
        title: 'title',
        values: 'values'
      });
    }
  }, {
    key: 'Breakdown',
    get: function get() {
      return Object.freeze({
        action_type: 'action_type',
        follow_type: 'follow_type',
        story_navigation_action_type: 'story_navigation_action_type',
        surface_type: 'surface_type'
      });
    }
  }, {
    key: 'Metric',
    get: function get() {
      return Object.freeze({
        clips_replays_count: 'clips_replays_count',
        comments: 'comments',
        follows: 'follows',
        ig_reels_aggregated_all_plays_count: 'ig_reels_aggregated_all_plays_count',
        ig_reels_avg_watch_time: 'ig_reels_avg_watch_time',
        ig_reels_video_view_total_time: 'ig_reels_video_view_total_time',
        impressions: 'impressions',
        likes: 'likes',
        navigation: 'navigation',
        peak_concurrent_viewers: 'peak_concurrent_viewers',
        plays: 'plays',
        profile_activity: 'profile_activity',
        profile_visits: 'profile_visits',
        quotes: 'quotes',
        reach: 'reach',
        replies: 'replies',
        reposts: 'reposts',
        saved: 'saved',
        shares: 'shares',
        thread_replies: 'thread_replies',
        thread_shares: 'thread_shares',
        total_interactions: 'total_interactions',
        video_views: 'video_views',
        views: 'views'
      });
    }
  }, {
    key: 'Period',
    get: function get() {
      return Object.freeze({
        day: 'day',
        days_28: 'days_28',
        lifetime: 'lifetime',
        month: 'month',
        total_over_range: 'total_over_range',
        week: 'week'
      });
    }
  }, {
    key: 'DatePreset',
    get: function get() {
      return Object.freeze({
        data_maximum: 'data_maximum',
        last_14d: 'last_14d',
        last_28d: 'last_28d',
        last_30d: 'last_30d',
        last_3d: 'last_3d',
        last_7d: 'last_7d',
        last_90d: 'last_90d',
        last_month: 'last_month',
        last_quarter: 'last_quarter',
        last_week_mon_sun: 'last_week_mon_sun',
        last_week_sun_sat: 'last_week_sun_sat',
        last_year: 'last_year',
        maximum: 'maximum',
        this_month: 'this_month',
        this_quarter: 'this_quarter',
        this_week_mon_today: 'this_week_mon_today',
        this_week_sun_today: 'this_week_sun_today',
        this_year: 'this_year',
        today: 'today',
        yesterday: 'yesterday'
      });
    }
  }]);
  return InsightsResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PagePostExperiment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PagePostExperiment = function (_AbstractCrudObject) {
  inherits(PagePostExperiment, _AbstractCrudObject);

  function PagePostExperiment() {
    classCallCheck(this, PagePostExperiment);
    return possibleConstructorReturn(this, (PagePostExperiment.__proto__ || Object.getPrototypeOf(PagePostExperiment)).apply(this, arguments));
  }

  createClass(PagePostExperiment, [{
    key: 'getVideoInsights',
    value: function getVideoInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/video_insights');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(PagePostExperiment.prototype.__proto__ || Object.getPrototypeOf(PagePostExperiment.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        auto_resolve_settings: 'auto_resolve_settings',
        control_video_id: 'control_video_id',
        creation_time: 'creation_time',
        creator: 'creator',
        declared_winning_time: 'declared_winning_time',
        declared_winning_video_id: 'declared_winning_video_id',
        description: 'description',
        experiment_video_ids: 'experiment_video_ids',
        id: 'id',
        insight_snapshots: 'insight_snapshots',
        name: 'name',
        optimization_goal: 'optimization_goal',
        publish_status: 'publish_status',
        publish_time: 'publish_time',
        scheduled_experiment_timestamp: 'scheduled_experiment_timestamp',
        updated_time: 'updated_time'
      });
    }
  }, {
    key: 'OptimizationGoal',
    get: function get() {
      return Object.freeze({
        auto_resolve_to_control: 'AUTO_RESOLVE_TO_CONTROL',
        avg_time_watched: 'AVG_TIME_WATCHED',
        comments: 'COMMENTS',
        impressions: 'IMPRESSIONS',
        impressions_unique: 'IMPRESSIONS_UNIQUE',
        link_clicks: 'LINK_CLICKS',
        other: 'OTHER',
        reactions: 'REACTIONS',
        reels_plays: 'REELS_PLAYS',
        shares: 'SHARES',
        video_views_60s: 'VIDEO_VIEWS_60S'
      });
    }
  }]);
  return PagePostExperiment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * RTBDynamicPost
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var RTBDynamicPost = function (_AbstractCrudObject) {
  inherits(RTBDynamicPost, _AbstractCrudObject);

  function RTBDynamicPost() {
    classCallCheck(this, RTBDynamicPost);
    return possibleConstructorReturn(this, (RTBDynamicPost.__proto__ || Object.getPrototypeOf(RTBDynamicPost)).apply(this, arguments));
  }

  createClass(RTBDynamicPost, [{
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Comment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'getLikes',
    value: function getLikes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/likes');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        child_attachments: 'child_attachments',
        created: 'created',
        description: 'description',
        id: 'id',
        image_url: 'image_url',
        link: 'link',
        message: 'message',
        owner_id: 'owner_id',
        place_id: 'place_id',
        product_id: 'product_id',
        title: 'title'
      });
    }
  }]);
  return RTBDynamicPost;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Post
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Post = function (_AbstractCrudObject) {
  inherits(Post, _AbstractCrudObject);

  function Post() {
    classCallCheck(this, Post);
    return possibleConstructorReturn(this, (Post.__proto__ || Object.getPrototypeOf(Post)).apply(this, arguments));
  }

  createClass(Post, [{
    key: 'getAttachments',
    value: function getAttachments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/attachments');
    }
  }, {
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Comment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, Comment, pathOverride);
    }
  }, {
    key: 'getDynamicPosts',
    value: function getDynamicPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(RTBDynamicPost, fields, params, fetchFirstPage, '/dynamic_posts');
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InsightsResult, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'deleteLikes',
    value: function deleteLikes() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Post.prototype.__proto__ || Object.getPrototypeOf(Post.prototype), 'deleteEdge', this).call(this, '/likes', params);
    }
  }, {
    key: 'createLike',
    value: function createLike(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/likes', fields, params, Post, pathOverride);
    }
  }, {
    key: 'getReactions',
    value: function getReactions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/reactions');
    }
  }, {
    key: 'getSharedPosts',
    value: function getSharedPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Post, fields, params, fetchFirstPage, '/sharedposts');
    }
  }, {
    key: 'getSponsorTags',
    value: function getSponsorTags(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/sponsor_tags');
    }
  }, {
    key: 'getTo',
    value: function getTo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/to');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Post.prototype.__proto__ || Object.getPrototypeOf(Post.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Post.prototype.__proto__ || Object.getPrototypeOf(Post.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actions: 'actions',
        admin_creator: 'admin_creator',
        allowed_advertising_objectives: 'allowed_advertising_objectives',
        application: 'application',
        backdated_time: 'backdated_time',
        call_to_action: 'call_to_action',
        can_reply_privately: 'can_reply_privately',
        caption: 'caption',
        child_attachments: 'child_attachments',
        comments_mirroring_domain: 'comments_mirroring_domain',
        coordinates: 'coordinates',
        created_time: 'created_time',
        description: 'description',
        event: 'event',
        expanded_height: 'expanded_height',
        expanded_width: 'expanded_width',
        feed_targeting: 'feed_targeting',
        from: 'from',
        full_picture: 'full_picture',
        height: 'height',
        icon: 'icon',
        id: 'id',
        instagram_eligibility: 'instagram_eligibility',
        is_app_share: 'is_app_share',
        is_eligible_for_promotion: 'is_eligible_for_promotion',
        is_expired: 'is_expired',
        is_hidden: 'is_hidden',
        is_inline_created: 'is_inline_created',
        is_instagram_eligible: 'is_instagram_eligible',
        is_popular: 'is_popular',
        is_published: 'is_published',
        is_spherical: 'is_spherical',
        link: 'link',
        message: 'message',
        message_tags: 'message_tags',
        multi_share_end_card: 'multi_share_end_card',
        multi_share_optimized: 'multi_share_optimized',
        name: 'name',
        object_id: 'object_id',
        parent_id: 'parent_id',
        permalink_url: 'permalink_url',
        picture: 'picture',
        place: 'place',
        privacy: 'privacy',
        promotable_id: 'promotable_id',
        promotion_status: 'promotion_status',
        properties: 'properties',
        scheduled_publish_time: 'scheduled_publish_time',
        shares: 'shares',
        source: 'source',
        status_type: 'status_type',
        story: 'story',
        story_tags: 'story_tags',
        subscribed: 'subscribed',
        target: 'target',
        targeting: 'targeting',
        timeline_visibility: 'timeline_visibility',
        type: 'type',
        updated_time: 'updated_time',
        via: 'via',
        video_buying_eligibility: 'video_buying_eligibility',
        width: 'width'
      });
    }
  }, {
    key: 'BackdatedTimeGranularity',
    get: function get() {
      return Object.freeze({
        day: 'day',
        hour: 'hour',
        min: 'min',
        month: 'month',
        none: 'none',
        year: 'year'
      });
    }
  }, {
    key: 'Formatting',
    get: function get() {
      return Object.freeze({
        markdown: 'MARKDOWN',
        plaintext: 'PLAINTEXT'
      });
    }
  }, {
    key: 'PlaceAttachmentSetting',
    get: function get() {
      return Object.freeze({
        value_1: '1',
        value_2: '2'
      });
    }
  }, {
    key: 'PostSurfacesBlacklist',
    get: function get() {
      return Object.freeze({
        value_1: '1',
        value_2: '2',
        value_3: '3',
        value_4: '4',
        value_5: '5'
      });
    }
  }, {
    key: 'PostingToRedspace',
    get: function get() {
      return Object.freeze({
        disabled: 'disabled',
        enabled: 'enabled'
      });
    }
  }, {
    key: 'TargetSurface',
    get: function get() {
      return Object.freeze({
        story: 'STORY',
        timeline: 'TIMELINE'
      });
    }
  }, {
    key: 'UnpublishedContentType',
    get: function get() {
      return Object.freeze({
        ads_post: 'ADS_POST',
        draft: 'DRAFT',
        inline_created: 'INLINE_CREATED',
        published: 'PUBLISHED',
        reviewable_branded_content: 'REVIEWABLE_BRANDED_CONTENT',
        scheduled: 'SCHEDULED',
        scheduled_recurring: 'SCHEDULED_RECURRING'
      });
    }
  }, {
    key: 'FeedStoryVisibility',
    get: function get() {
      return Object.freeze({
        hidden: 'hidden',
        visible: 'visible'
      });
    }
  }, {
    key: 'TimelineVisibility',
    get: function get() {
      return Object.freeze({
        forced_allow: 'forced_allow',
        hidden: 'hidden',
        normal: 'normal'
      });
    }
  }]);
  return Post;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PagePost
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PagePost = function (_AbstractCrudObject) {
  inherits(PagePost, _AbstractCrudObject);

  function PagePost() {
    classCallCheck(this, PagePost);
    return possibleConstructorReturn(this, (PagePost.__proto__ || Object.getPrototypeOf(PagePost)).apply(this, arguments));
  }

  createClass(PagePost, [{
    key: 'getAttachments',
    value: function getAttachments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/attachments');
    }
  }, {
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Comment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, Comment, pathOverride);
    }
  }, {
    key: 'getDynamicPosts',
    value: function getDynamicPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(RTBDynamicPost, fields, params, fetchFirstPage, '/dynamic_posts');
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InsightsResult, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'deleteLikes',
    value: function deleteLikes() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(PagePost.prototype.__proto__ || Object.getPrototypeOf(PagePost.prototype), 'deleteEdge', this).call(this, '/likes', params);
    }
  }, {
    key: 'getLikes',
    value: function getLikes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/likes');
    }
  }, {
    key: 'createLike',
    value: function createLike(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/likes', fields, params, PagePost, pathOverride);
    }
  }, {
    key: 'getReactions',
    value: function getReactions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/reactions');
    }
  }, {
    key: 'getSharedPosts',
    value: function getSharedPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Post, fields, params, fetchFirstPage, '/sharedposts');
    }
  }, {
    key: 'getSponsorTags',
    value: function getSponsorTags(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/sponsor_tags');
    }
  }, {
    key: 'getTo',
    value: function getTo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/to');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(PagePost.prototype.__proto__ || Object.getPrototypeOf(PagePost.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(PagePost.prototype.__proto__ || Object.getPrototypeOf(PagePost.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actions: 'actions',
        admin_creator: 'admin_creator',
        allowed_advertising_objectives: 'allowed_advertising_objectives',
        application: 'application',
        backdated_time: 'backdated_time',
        call_to_action: 'call_to_action',
        can_reply_privately: 'can_reply_privately',
        child_attachments: 'child_attachments',
        comments_mirroring_domain: 'comments_mirroring_domain',
        coordinates: 'coordinates',
        created_time: 'created_time',
        event: 'event',
        expanded_height: 'expanded_height',
        expanded_width: 'expanded_width',
        feed_targeting: 'feed_targeting',
        from: 'from',
        full_picture: 'full_picture',
        height: 'height',
        icon: 'icon',
        id: 'id',
        instagram_eligibility: 'instagram_eligibility',
        is_app_share: 'is_app_share',
        is_eligible_for_promotion: 'is_eligible_for_promotion',
        is_expired: 'is_expired',
        is_hidden: 'is_hidden',
        is_inline_created: 'is_inline_created',
        is_instagram_eligible: 'is_instagram_eligible',
        is_popular: 'is_popular',
        is_published: 'is_published',
        is_spherical: 'is_spherical',
        message: 'message',
        message_tags: 'message_tags',
        multi_share_end_card: 'multi_share_end_card',
        multi_share_optimized: 'multi_share_optimized',
        parent_id: 'parent_id',
        permalink_url: 'permalink_url',
        picture: 'picture',
        place: 'place',
        privacy: 'privacy',
        promotable_id: 'promotable_id',
        promotion_status: 'promotion_status',
        properties: 'properties',
        scheduled_publish_time: 'scheduled_publish_time',
        shares: 'shares',
        status_type: 'status_type',
        story: 'story',
        story_tags: 'story_tags',
        subscribed: 'subscribed',
        target: 'target',
        targeting: 'targeting',
        timeline_visibility: 'timeline_visibility',
        updated_time: 'updated_time',
        via: 'via',
        video_buying_eligibility: 'video_buying_eligibility',
        width: 'width'
      });
    }
  }, {
    key: 'With',
    get: function get() {
      return Object.freeze({
        location: 'LOCATION'
      });
    }
  }, {
    key: 'BackdatedTimeGranularity',
    get: function get() {
      return Object.freeze({
        day: 'day',
        hour: 'hour',
        min: 'min',
        month: 'month',
        none: 'none',
        year: 'year'
      });
    }
  }, {
    key: 'FeedStoryVisibility',
    get: function get() {
      return Object.freeze({
        hidden: 'hidden',
        visible: 'visible'
      });
    }
  }, {
    key: 'TimelineVisibility',
    get: function get() {
      return Object.freeze({
        forced_allow: 'forced_allow',
        hidden: 'hidden',
        normal: 'normal'
      });
    }
  }]);
  return PagePost;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ArAdsDataContainer
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ArAdsDataContainer = function (_AbstractCrudObject) {
  inherits(ArAdsDataContainer, _AbstractCrudObject);

  function ArAdsDataContainer() {
    classCallCheck(this, ArAdsDataContainer);
    return possibleConstructorReturn(this, (ArAdsDataContainer.__proto__ || Object.getPrototypeOf(ArAdsDataContainer)).apply(this, arguments));
  }

  createClass(ArAdsDataContainer, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        camera_facing_override: 'camera_facing_override',
        creation_time: 'creation_time',
        effect: 'effect',
        id: 'id',
        is_published: 'is_published',
        last_modified_time: 'last_modified_time',
        name: 'name'
      });
    }
  }]);
  return ArAdsDataContainer;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AssignedUser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AssignedUser = function (_AbstractCrudObject) {
  inherits(AssignedUser, _AbstractCrudObject);

  function AssignedUser() {
    classCallCheck(this, AssignedUser);
    return possibleConstructorReturn(this, (AssignedUser.__proto__ || Object.getPrototypeOf(AssignedUser)).apply(this, arguments));
  }

  createClass(AssignedUser, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        id: 'id',
        name: 'name',
        user_type: 'user_type'
      });
    }
  }]);
  return AssignedUser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessProject
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessProject = function (_AbstractCrudObject) {
  inherits(BusinessProject, _AbstractCrudObject);

  function BusinessProject() {
    classCallCheck(this, BusinessProject);
    return possibleConstructorReturn(this, (BusinessProject.__proto__ || Object.getPrototypeOf(BusinessProject)).apply(this, arguments));
  }

  createClass(BusinessProject, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        created_time: 'created_time',
        creator: 'creator',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return BusinessProject;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageCallToAction
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageCallToAction = function (_AbstractCrudObject) {
  inherits(PageCallToAction, _AbstractCrudObject);

  function PageCallToAction() {
    classCallCheck(this, PageCallToAction);
    return possibleConstructorReturn(this, (PageCallToAction.__proto__ || Object.getPrototypeOf(PageCallToAction)).apply(this, arguments));
  }

  createClass(PageCallToAction, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(PageCallToAction.prototype.__proto__ || Object.getPrototypeOf(PageCallToAction.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(PageCallToAction.prototype.__proto__ || Object.getPrototypeOf(PageCallToAction.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        android_app: 'android_app',
        android_deeplink: 'android_deeplink',
        android_destination_type: 'android_destination_type',
        android_package_name: 'android_package_name',
        android_url: 'android_url',
        created_time: 'created_time',
        email_address: 'email_address',
        from: 'from',
        id: 'id',
        intl_number_with_plus: 'intl_number_with_plus',
        iphone_app: 'iphone_app',
        iphone_deeplink: 'iphone_deeplink',
        iphone_destination_type: 'iphone_destination_type',
        iphone_url: 'iphone_url',
        status: 'status',
        type: 'type',
        updated_time: 'updated_time',
        web_destination_type: 'web_destination_type',
        web_url: 'web_url'
      });
    }
  }, {
    key: 'AndroidDestinationType',
    get: function get() {
      return Object.freeze({
        app_deeplink: 'APP_DEEPLINK',
        become_a_volunteer: 'BECOME_A_VOLUNTEER',
        email: 'EMAIL',
        facebook_app: 'FACEBOOK_APP',
        follow: 'FOLLOW',
        marketplace_inventory_page: 'MARKETPLACE_INVENTORY_PAGE',
        menu_on_facebook: 'MENU_ON_FACEBOOK',
        messenger: 'MESSENGER',
        mini_shop: 'MINI_SHOP',
        mobile_center: 'MOBILE_CENTER',
        none: 'NONE',
        phone_call: 'PHONE_CALL',
        shop_on_facebook: 'SHOP_ON_FACEBOOK',
        website: 'WEBSITE'
      });
    }
  }, {
    key: 'IphoneDestinationType',
    get: function get() {
      return Object.freeze({
        app_deeplink: 'APP_DEEPLINK',
        become_a_volunteer: 'BECOME_A_VOLUNTEER',
        email: 'EMAIL',
        facebook_app: 'FACEBOOK_APP',
        follow: 'FOLLOW',
        marketplace_inventory_page: 'MARKETPLACE_INVENTORY_PAGE',
        menu_on_facebook: 'MENU_ON_FACEBOOK',
        messenger: 'MESSENGER',
        mini_shop: 'MINI_SHOP',
        none: 'NONE',
        phone_call: 'PHONE_CALL',
        shop_on_facebook: 'SHOP_ON_FACEBOOK',
        website: 'WEBSITE'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        become_a_volunteer: 'BECOME_A_VOLUNTEER',
        book_appointment: 'BOOK_APPOINTMENT',
        book_now: 'BOOK_NOW',
        buy_tickets: 'BUY_TICKETS',
        call_now: 'CALL_NOW',
        charity_donate: 'CHARITY_DONATE',
        check_in: 'CHECK_IN',
        contact_us: 'CONTACT_US',
        donate_now: 'DONATE_NOW',
        email: 'EMAIL',
        follow_page: 'FOLLOW_PAGE',
        get_directions: 'GET_DIRECTIONS',
        get_offer: 'GET_OFFER',
        get_offer_view: 'GET_OFFER_VIEW',
        interested: 'INTERESTED',
        learn_more: 'LEARN_MORE',
        listen: 'LISTEN',
        local_dev_platform: 'LOCAL_DEV_PLATFORM',
        message: 'MESSAGE',
        mobile_center: 'MOBILE_CENTER',
        open_app: 'OPEN_APP',
        order_food: 'ORDER_FOOD',
        play_music: 'PLAY_MUSIC',
        play_now: 'PLAY_NOW',
        purchase_gift_cards: 'PURCHASE_GIFT_CARDS',
        request_appointment: 'REQUEST_APPOINTMENT',
        request_quote: 'REQUEST_QUOTE',
        shop_now: 'SHOP_NOW',
        shop_on_facebook: 'SHOP_ON_FACEBOOK',
        sign_up: 'SIGN_UP',
        view_inventory: 'VIEW_INVENTORY',
        view_menu: 'VIEW_MENU',
        view_shop: 'VIEW_SHOP',
        visit_group: 'VISIT_GROUP',
        watch_now: 'WATCH_NOW',
        woodhenge_support: 'WOODHENGE_SUPPORT'
      });
    }
  }, {
    key: 'WebDestinationType',
    get: function get() {
      return Object.freeze({
        become_a_volunteer: 'BECOME_A_VOLUNTEER',
        become_supporter: 'BECOME_SUPPORTER',
        email: 'EMAIL',
        follow: 'FOLLOW',
        messenger: 'MESSENGER',
        mobile_center: 'MOBILE_CENTER',
        none: 'NONE',
        shop_on_facebook: 'SHOP_ON_FACEBOOK',
        website: 'WEBSITE'
      });
    }
  }]);
  return PageCallToAction;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CanvasBodyElement
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CanvasBodyElement = function (_AbstractCrudObject) {
  inherits(CanvasBodyElement, _AbstractCrudObject);

  function CanvasBodyElement() {
    classCallCheck(this, CanvasBodyElement);
    return possibleConstructorReturn(this, (CanvasBodyElement.__proto__ || Object.getPrototypeOf(CanvasBodyElement)).apply(this, arguments));
  }

  createClass(CanvasBodyElement, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        element: 'element'
      });
    }
  }]);
  return CanvasBodyElement;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CanvasPreview
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CanvasPreview = function (_AbstractCrudObject) {
  inherits(CanvasPreview, _AbstractCrudObject);

  function CanvasPreview() {
    classCallCheck(this, CanvasPreview);
    return possibleConstructorReturn(this, (CanvasPreview.__proto__ || Object.getPrototypeOf(CanvasPreview)).apply(this, arguments));
  }

  createClass(CanvasPreview, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        body: 'body'
      });
    }
  }]);
  return CanvasPreview;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TextWithEntities
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TextWithEntities = function (_AbstractCrudObject) {
  inherits(TextWithEntities, _AbstractCrudObject);

  function TextWithEntities() {
    classCallCheck(this, TextWithEntities);
    return possibleConstructorReturn(this, (TextWithEntities.__proto__ || Object.getPrototypeOf(TextWithEntities)).apply(this, arguments));
  }

  createClass(TextWithEntities, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        text: 'text'
      });
    }
  }]);
  return TextWithEntities;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Canvas
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Canvas = function (_AbstractCrudObject) {
  inherits(Canvas, _AbstractCrudObject);

  function Canvas() {
    classCallCheck(this, Canvas);
    return possibleConstructorReturn(this, (Canvas.__proto__ || Object.getPrototypeOf(Canvas)).apply(this, arguments));
  }

  createClass(Canvas, [{
    key: 'getPreview',
    value: function getPreview(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CanvasPreview, fields, params, fetchFirstPage, '/preview');
    }
  }, {
    key: 'getPreviews',
    value: function getPreviews(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(TextWithEntities, fields, params, fetchFirstPage, '/previews');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Canvas.prototype.__proto__ || Object.getPrototypeOf(Canvas.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        background_color: 'background_color',
        body_elements: 'body_elements',
        business_id: 'business_id',
        canvas_link: 'canvas_link',
        collection_hero_image: 'collection_hero_image',
        collection_hero_video: 'collection_hero_video',
        collection_thumbnails: 'collection_thumbnails',
        dynamic_setting: 'dynamic_setting',
        element_payload: 'element_payload',
        elements: 'elements',
        fb_body_elements: 'fb_body_elements',
        id: 'id',
        is_hidden: 'is_hidden',
        is_published: 'is_published',
        last_editor: 'last_editor',
        linked_documents: 'linked_documents',
        name: 'name',
        owner: 'owner',
        property_list: 'property_list',
        source_template: 'source_template',
        store_url: 'store_url',
        style_list: 'style_list',
        tags: 'tags',
        ui_property_list: 'ui_property_list',
        unused_body_elements: 'unused_body_elements',
        update_time: 'update_time',
        use_retailer_item_ids: 'use_retailer_item_ids'
      });
    }
  }]);
  return Canvas;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ChatPlugin
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ChatPlugin = function (_AbstractCrudObject) {
  inherits(ChatPlugin, _AbstractCrudObject);

  function ChatPlugin() {
    classCallCheck(this, ChatPlugin);
    return possibleConstructorReturn(this, (ChatPlugin.__proto__ || Object.getPrototypeOf(ChatPlugin)).apply(this, arguments));
  }

  createClass(ChatPlugin, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        alignment: 'alignment',
        desktop_bottom_spacing: 'desktop_bottom_spacing',
        desktop_side_spacing: 'desktop_side_spacing',
        entry_point_icon: 'entry_point_icon',
        entry_point_label: 'entry_point_label',
        greeting_dialog_display: 'greeting_dialog_display',
        guest_chat_mode: 'guest_chat_mode',
        mobile_bottom_spacing: 'mobile_bottom_spacing',
        mobile_chat_display: 'mobile_chat_display',
        mobile_side_spacing: 'mobile_side_spacing',
        theme_color: 'theme_color',
        welcome_screen_greeting: 'welcome_screen_greeting'
      });
    }
  }]);
  return ChatPlugin;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CommerceOrder
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CommerceOrder = function (_AbstractCrudObject) {
  inherits(CommerceOrder, _AbstractCrudObject);

  function CommerceOrder() {
    classCallCheck(this, CommerceOrder);
    return possibleConstructorReturn(this, (CommerceOrder.__proto__ || Object.getPrototypeOf(CommerceOrder)).apply(this, arguments));
  }

  createClass(CommerceOrder, [{
    key: 'createAcknowledgeOrder',
    value: function createAcknowledgeOrder(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/acknowledge_order', fields, params, CommerceOrder, pathOverride);
    }
  }, {
    key: 'getCancellations',
    value: function getCancellations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/cancellations');
    }
  }, {
    key: 'createCancellation',
    value: function createCancellation(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/cancellations', fields, params, CommerceOrder, pathOverride);
    }
  }, {
    key: 'createItemUpdate',
    value: function createItemUpdate(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/item_updates', fields, params, CommerceOrder, pathOverride);
    }
  }, {
    key: 'getItems',
    value: function getItems(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/items');
    }
  }, {
    key: 'getPayments',
    value: function getPayments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/payments');
    }
  }, {
    key: 'getPromotionDetails',
    value: function getPromotionDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/promotion_details');
    }
  }, {
    key: 'getPromoTIOns',
    value: function getPromoTIOns(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/promotions');
    }
  }, {
    key: 'getRefunds',
    value: function getRefunds(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/refunds');
    }
  }, {
    key: 'createRefund',
    value: function createRefund(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/refunds', fields, params, CommerceOrder, pathOverride);
    }
  }, {
    key: 'getReturns',
    value: function getReturns(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/returns');
    }
  }, {
    key: 'createReturn',
    value: function createReturn(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/returns', fields, params, CommerceOrder, pathOverride);
    }
  }, {
    key: 'getShipments',
    value: function getShipments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/shipments');
    }
  }, {
    key: 'createShipment',
    value: function createShipment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/shipments', fields, params, CommerceOrder, pathOverride);
    }
  }, {
    key: 'createUpdateShipment',
    value: function createUpdateShipment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/update_shipment', fields, params, CommerceOrder, pathOverride);
    }
  }, {
    key: 'createUpdate',
    value: function createUpdate(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/updates', fields, params, CommerceOrder, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        buyer_details: 'buyer_details',
        channel: 'channel',
        contains_bopis_items: 'contains_bopis_items',
        created: 'created',
        estimated_payment_details: 'estimated_payment_details',
        id: 'id',
        is_group_buy: 'is_group_buy',
        is_test_order: 'is_test_order',
        last_updated: 'last_updated',
        merchant_order_id: 'merchant_order_id',
        order_status: 'order_status',
        pre_order_details: 'pre_order_details',
        selected_shipping_option: 'selected_shipping_option',
        ship_by_date: 'ship_by_date',
        shipping_address: 'shipping_address'
      });
    }
  }, {
    key: 'Filters',
    get: function get() {
      return Object.freeze({
        has_cancellations: 'HAS_CANCELLATIONS',
        has_fulfillments: 'HAS_FULFILLMENTS',
        has_refunds: 'HAS_REFUNDS',
        no_cancellations: 'NO_CANCELLATIONS',
        no_refunds: 'NO_REFUNDS',
        no_shipments: 'NO_SHIPMENTS'
      });
    }
  }, {
    key: 'State',
    get: function get() {
      return Object.freeze({
        completed: 'COMPLETED',
        created: 'CREATED',
        fb_processing: 'FB_PROCESSING',
        in_progress: 'IN_PROGRESS'
      });
    }
  }, {
    key: 'ReasonCode',
    get: function get() {
      return Object.freeze({
        buyers_remorse: 'BUYERS_REMORSE',
        damaged_goods: 'DAMAGED_GOODS',
        facebook_initiated: 'FACEBOOK_INITIATED',
        not_as_described: 'NOT_AS_DESCRIBED',
        quality_issue: 'QUALITY_ISSUE',
        refund_compromised: 'REFUND_COMPROMISED',
        refund_for_return: 'REFUND_FOR_RETURN',
        refund_reason_other: 'REFUND_REASON_OTHER',
        refund_sfi_fake: 'REFUND_SFI_FAKE',
        refund_sfi_real: 'REFUND_SFI_REAL',
        wrong_item: 'WRONG_ITEM'
      });
    }
  }]);
  return CommerceOrder;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CommercePayout
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CommercePayout = function (_AbstractCrudObject) {
  inherits(CommercePayout, _AbstractCrudObject);

  function CommercePayout() {
    classCallCheck(this, CommercePayout);
    return possibleConstructorReturn(this, (CommercePayout.__proto__ || Object.getPrototypeOf(CommercePayout)).apply(this, arguments));
  }

  createClass(CommercePayout, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount: 'amount',
        payout_date: 'payout_date',
        payout_reference_id: 'payout_reference_id',
        status: 'status',
        transfer_id: 'transfer_id'
      });
    }
  }]);
  return CommercePayout;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CommerceOrderTransactionDetail
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CommerceOrderTransactionDetail = function (_AbstractCrudObject) {
  inherits(CommerceOrderTransactionDetail, _AbstractCrudObject);

  function CommerceOrderTransactionDetail() {
    classCallCheck(this, CommerceOrderTransactionDetail);
    return possibleConstructorReturn(this, (CommerceOrderTransactionDetail.__proto__ || Object.getPrototypeOf(CommerceOrderTransactionDetail)).apply(this, arguments));
  }

  createClass(CommerceOrderTransactionDetail, [{
    key: 'getItems',
    value: function getItems(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/items');
    }
  }, {
    key: 'getTaxDetails',
    value: function getTaxDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/tax_details');
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        merchant_order_id: 'merchant_order_id',
        net_payment_amount: 'net_payment_amount',
        order_created: 'order_created',
        order_details: 'order_details',
        order_id: 'order_id',
        payout_reference_id: 'payout_reference_id',
        postal_code: 'postal_code',
        processing_fee: 'processing_fee',
        state: 'state',
        tax_rate: 'tax_rate',
        transaction_date: 'transaction_date',
        transaction_type: 'transaction_type',
        transfer_id: 'transfer_id',
        id: 'id'
      });
    }
  }]);
  return CommerceOrderTransactionDetail;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogItemChannelsToIntegrityStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogItemChannelsToIntegrityStatus = function (_AbstractCrudObject) {
  inherits(CatalogItemChannelsToIntegrityStatus, _AbstractCrudObject);

  function CatalogItemChannelsToIntegrityStatus() {
    classCallCheck(this, CatalogItemChannelsToIntegrityStatus);
    return possibleConstructorReturn(this, (CatalogItemChannelsToIntegrityStatus.__proto__ || Object.getPrototypeOf(CatalogItemChannelsToIntegrityStatus)).apply(this, arguments));
  }

  createClass(CatalogItemChannelsToIntegrityStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        channels: 'channels',
        rejection_information: 'rejection_information'
      });
    }
  }]);
  return CatalogItemChannelsToIntegrityStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OverrideDetails
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OverrideDetails = function (_AbstractCrudObject) {
  inherits(OverrideDetails, _AbstractCrudObject);

  function OverrideDetails() {
    classCallCheck(this, OverrideDetails);
    return possibleConstructorReturn(this, (OverrideDetails.__proto__ || Object.getPrototypeOf(OverrideDetails)).apply(this, arguments));
  }

  createClass(OverrideDetails, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        key: 'key',
        type: 'type',
        values: 'values'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        country: 'COUNTRY',
        language: 'LANGUAGE',
        language_and_country: 'LANGUAGE_AND_COUNTRY'
      });
    }
  }]);
  return OverrideDetails;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DynamicVideoMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DynamicVideoMetadata = function (_AbstractCrudObject) {
  inherits(DynamicVideoMetadata, _AbstractCrudObject);

  function DynamicVideoMetadata() {
    classCallCheck(this, DynamicVideoMetadata);
    return possibleConstructorReturn(this, (DynamicVideoMetadata.__proto__ || Object.getPrototypeOf(DynamicVideoMetadata)).apply(this, arguments));
  }

  createClass(DynamicVideoMetadata, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        tags: 'tags',
        url: 'url',
        video: 'video'
      });
    }
  }]);
  return DynamicVideoMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AutomotiveModel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AutomotiveModel = function (_AbstractCrudObject) {
  inherits(AutomotiveModel, _AbstractCrudObject);

  function AutomotiveModel() {
    classCallCheck(this, AutomotiveModel);
    return possibleConstructorReturn(this, (AutomotiveModel.__proto__ || Object.getPrototypeOf(AutomotiveModel)).apply(this, arguments));
  }

  createClass(AutomotiveModel, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'getVideosMetadata',
    value: function getVideosMetadata(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicVideoMetadata, fields, params, fetchFirstPage, '/videos_metadata');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        applinks: 'applinks',
        automotive_model_id: 'automotive_model_id',
        availability: 'availability',
        body_style: 'body_style',
        category_specific_fields: 'category_specific_fields',
        currency: 'currency',
        custom_label_0: 'custom_label_0',
        description: 'description',
        drivetrain: 'drivetrain',
        exterior_color: 'exterior_color',
        finance_description: 'finance_description',
        finance_type: 'finance_type',
        fuel_type: 'fuel_type',
        generation: 'generation',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        interior_color: 'interior_color',
        interior_upholstery: 'interior_upholstery',
        make: 'make',
        model: 'model',
        price: 'price',
        sanitized_images: 'sanitized_images',
        title: 'title',
        transmission: 'transmission',
        trim: 'trim',
        unit_price: 'unit_price',
        url: 'url',
        visibility: 'visibility',
        year: 'year'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }]);
  return AutomotiveModel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * StoreCatalogSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var StoreCatalogSettings = function (_AbstractCrudObject) {
  inherits(StoreCatalogSettings, _AbstractCrudObject);

  function StoreCatalogSettings() {
    classCallCheck(this, StoreCatalogSettings);
    return possibleConstructorReturn(this, (StoreCatalogSettings.__proto__ || Object.getPrototypeOf(StoreCatalogSettings)).apply(this, arguments));
  }

  createClass(StoreCatalogSettings, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(StoreCatalogSettings.prototype.__proto__ || Object.getPrototypeOf(StoreCatalogSettings.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        page: 'page'
      });
    }
  }]);
  return StoreCatalogSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogCategory
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogCategory = function (_AbstractCrudObject) {
  inherits(ProductCatalogCategory, _AbstractCrudObject);

  function ProductCatalogCategory() {
    classCallCheck(this, ProductCatalogCategory);
    return possibleConstructorReturn(this, (ProductCatalogCategory.__proto__ || Object.getPrototypeOf(ProductCatalogCategory)).apply(this, arguments));
  }

  createClass(ProductCatalogCategory, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        criteria_value: 'criteria_value',
        description: 'description',
        destination_uri: 'destination_uri',
        image_url: 'image_url',
        name: 'name',
        num_items: 'num_items',
        tokens: 'tokens'
      });
    }
  }, {
    key: 'CategorizationCriteria',
    get: function get() {
      return Object.freeze({
        brand: 'BRAND',
        category: 'CATEGORY',
        product_type: 'PRODUCT_TYPE'
      });
    }
  }]);
  return ProductCatalogCategory;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CheckBatchRequestStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CheckBatchRequestStatus = function (_AbstractCrudObject) {
  inherits(CheckBatchRequestStatus, _AbstractCrudObject);

  function CheckBatchRequestStatus() {
    classCallCheck(this, CheckBatchRequestStatus);
    return possibleConstructorReturn(this, (CheckBatchRequestStatus.__proto__ || Object.getPrototypeOf(CheckBatchRequestStatus)).apply(this, arguments));
  }

  createClass(CheckBatchRequestStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        errors: 'errors',
        errors_total_count: 'errors_total_count',
        handle: 'handle',
        ids_of_invalid_requests: 'ids_of_invalid_requests',
        status: 'status',
        warnings: 'warnings',
        warnings_total_count: 'warnings_total_count'
      });
    }
  }, {
    key: 'ErrorPriority',
    get: function get() {
      return Object.freeze({
        high: 'HIGH',
        low: 'LOW',
        medium: 'MEDIUM'
      });
    }
  }]);
  return CheckBatchRequestStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductImage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductImage = function (_AbstractCrudObject) {
  inherits(ProductImage, _AbstractCrudObject);

  function ProductImage() {
    classCallCheck(this, ProductImage);
    return possibleConstructorReturn(this, (ProductImage.__proto__ || Object.getPrototypeOf(ProductImage)).apply(this, arguments));
  }

  createClass(ProductImage, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        height: 'height',
        id: 'id',
        image_url: 'image_url',
        width: 'width'
      });
    }
  }]);
  return ProductImage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CPASLsbImageBank
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CPASLsbImageBank = function (_AbstractCrudObject) {
  inherits(CPASLsbImageBank, _AbstractCrudObject);

  function CPASLsbImageBank() {
    classCallCheck(this, CPASLsbImageBank);
    return possibleConstructorReturn(this, (CPASLsbImageBank.__proto__ || Object.getPrototypeOf(CPASLsbImageBank)).apply(this, arguments));
  }

  createClass(CPASLsbImageBank, [{
    key: 'getBackupImages',
    value: function getBackupImages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductImage, fields, params, fetchFirstPage, '/backup_images');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(CPASLsbImageBank.prototype.__proto__ || Object.getPrototypeOf(CPASLsbImageBank.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_group_id: 'ad_group_id',
        catalog_segment_proxy_id: 'catalog_segment_proxy_id',
        id: 'id'
      });
    }
  }]);
  return CPASLsbImageBank;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CollaborativeAdsShareSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CollaborativeAdsShareSettings = function (_AbstractCrudObject) {
  inherits(CollaborativeAdsShareSettings, _AbstractCrudObject);

  function CollaborativeAdsShareSettings() {
    classCallCheck(this, CollaborativeAdsShareSettings);
    return possibleConstructorReturn(this, (CollaborativeAdsShareSettings.__proto__ || Object.getPrototypeOf(CollaborativeAdsShareSettings)).apply(this, arguments));
  }

  createClass(CollaborativeAdsShareSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        agency_business: 'agency_business',
        id: 'id',
        product_catalog_proxy_id: 'product_catalog_proxy_id',
        utm_campaign: 'utm_campaign',
        utm_medium: 'utm_medium',
        utm_source: 'utm_source'
      });
    }
  }]);
  return CollaborativeAdsShareSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CreatorAssetCreative
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CreatorAssetCreative = function (_AbstractCrudObject) {
  inherits(CreatorAssetCreative, _AbstractCrudObject);

  function CreatorAssetCreative() {
    classCallCheck(this, CreatorAssetCreative);
    return possibleConstructorReturn(this, (CreatorAssetCreative.__proto__ || Object.getPrototypeOf(CreatorAssetCreative)).apply(this, arguments));
  }

  createClass(CreatorAssetCreative, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        image_url: 'image_url',
        moderation_status: 'moderation_status',
        product_item_retailer_id: 'product_item_retailer_id',
        product_url: 'product_url',
        retailer_id: 'retailer_id',
        video_url: 'video_url'
      });
    }
  }, {
    key: 'ModerationStatus',
    get: function get() {
      return Object.freeze({
        archived: 'ARCHIVED',
        eligible: 'ELIGIBLE',
        expired: 'EXPIRED',
        ineligible: 'INELIGIBLE',
        in_review: 'IN_REVIEW',
        paused: 'PAUSED',
        unknown: 'UNKNOWN'
      });
    }
  }]);
  return CreatorAssetCreative;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogDataSource
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogDataSource = function (_AbstractCrudObject) {
  inherits(ProductCatalogDataSource, _AbstractCrudObject);

  function ProductCatalogDataSource() {
    classCallCheck(this, ProductCatalogDataSource);
    return possibleConstructorReturn(this, (ProductCatalogDataSource.__proto__ || Object.getPrototypeOf(ProductCatalogDataSource)).apply(this, arguments));
  }

  createClass(ProductCatalogDataSource, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        id: 'id',
        ingestion_source_type: 'ingestion_source_type',
        name: 'name',
        upload_type: 'upload_type'
      });
    }
  }, {
    key: 'IngestionSourceType',
    get: function get() {
      return Object.freeze({
        all: 'ALL',
        primary: 'PRIMARY',
        supplementary: 'SUPPLEMENTARY'
      });
    }
  }]);
  return ProductCatalogDataSource;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Destination
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Destination = function (_AbstractCrudObject) {
  inherits(Destination, _AbstractCrudObject);

  function Destination() {
    classCallCheck(this, Destination);
    return possibleConstructorReturn(this, (Destination.__proto__ || Object.getPrototypeOf(Destination)).apply(this, arguments));
  }

  createClass(Destination, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'getVideosMetadata',
    value: function getVideosMetadata(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicVideoMetadata, fields, params, fetchFirstPage, '/videos_metadata');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        address: 'address',
        applinks: 'applinks',
        category_specific_fields: 'category_specific_fields',
        currency: 'currency',
        description: 'description',
        destination_id: 'destination_id',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        name: 'name',
        price: 'price',
        price_change: 'price_change',
        sanitized_images: 'sanitized_images',
        tags: 'tags',
        types: 'types',
        unit_price: 'unit_price',
        url: 'url',
        visibility: 'visibility'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }]);
  return Destination;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogDiagnosticGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogDiagnosticGroup = function (_AbstractCrudObject) {
  inherits(ProductCatalogDiagnosticGroup, _AbstractCrudObject);

  function ProductCatalogDiagnosticGroup() {
    classCallCheck(this, ProductCatalogDiagnosticGroup);
    return possibleConstructorReturn(this, (ProductCatalogDiagnosticGroup.__proto__ || Object.getPrototypeOf(ProductCatalogDiagnosticGroup)).apply(this, arguments));
  }

  createClass(ProductCatalogDiagnosticGroup, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        affected_channels: 'affected_channels',
        affected_entity: 'affected_entity',
        affected_features: 'affected_features',
        diagnostics: 'diagnostics',
        error_code: 'error_code',
        number_of_affected_entities: 'number_of_affected_entities',
        number_of_affected_items: 'number_of_affected_items',
        severity: 'severity',
        subtitle: 'subtitle',
        title: 'title',
        type: 'type'
      });
    }
  }, {
    key: 'AffectedEntity',
    get: function get() {
      return Object.freeze({
        product_catalog: 'product_catalog',
        product_event: 'product_event',
        product_item: 'product_item',
        product_set: 'product_set'
      });
    }
  }, {
    key: 'AffectedFeatures',
    get: function get() {
      return Object.freeze({
        augmented_reality: 'augmented_reality',
        checkout: 'checkout'
      });
    }
  }, {
    key: 'Severity',
    get: function get() {
      return Object.freeze({
        must_fix: 'MUST_FIX',
        opportunity: 'OPPORTUNITY'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        ar_visibility_issues: 'AR_VISIBILITY_ISSUES',
        attributes_invalid: 'ATTRIBUTES_INVALID',
        attributes_missing: 'ATTRIBUTES_MISSING',
        category: 'CATEGORY',
        checkout: 'CHECKOUT',
        da_visibility_issues: 'DA_VISIBILITY_ISSUES',
        event_source_issues: 'EVENT_SOURCE_ISSUES',
        image_quality: 'IMAGE_QUALITY',
        low_quality_title_and_description: 'LOW_QUALITY_TITLE_AND_DESCRIPTION',
        policy_violation: 'POLICY_VIOLATION',
        shops_visibility_issues: 'SHOPS_VISIBILITY_ISSUES'
      });
    }
  }, {
    key: 'AffectedChannels',
    get: function get() {
      return Object.freeze({
        b2c_marketplace: 'b2c_marketplace',
        c2c_marketplace: 'c2c_marketplace',
        da: 'da',
        daily_deals: 'daily_deals',
        daily_deals_legacy: 'daily_deals_legacy',
        ig_product_tagging: 'ig_product_tagging',
        marketplace: 'marketplace',
        marketplace_ads_deprecated: 'marketplace_ads_deprecated',
        marketplace_shops: 'marketplace_shops',
        mini_shops: 'mini_shops',
        offline_conversions: 'offline_conversions',
        shops: 'shops',
        universal_checkout: 'universal_checkout',
        whatsapp: 'whatsapp'
      });
    }
  }, {
    key: 'AffectedEntities',
    get: function get() {
      return Object.freeze({
        product_catalog: 'product_catalog',
        product_event: 'product_event',
        product_item: 'product_item',
        product_set: 'product_set'
      });
    }
  }, {
    key: 'Severities',
    get: function get() {
      return Object.freeze({
        must_fix: 'MUST_FIX',
        opportunity: 'OPPORTUNITY'
      });
    }
  }, {
    key: 'Types',
    get: function get() {
      return Object.freeze({
        ar_visibility_issues: 'AR_VISIBILITY_ISSUES',
        attributes_invalid: 'ATTRIBUTES_INVALID',
        attributes_missing: 'ATTRIBUTES_MISSING',
        category: 'CATEGORY',
        checkout: 'CHECKOUT',
        da_visibility_issues: 'DA_VISIBILITY_ISSUES',
        event_source_issues: 'EVENT_SOURCE_ISSUES',
        image_quality: 'IMAGE_QUALITY',
        low_quality_title_and_description: 'LOW_QUALITY_TITLE_AND_DESCRIPTION',
        policy_violation: 'POLICY_VIOLATION',
        shops_visibility_issues: 'SHOPS_VISIBILITY_ISSUES'
      });
    }
  }]);
  return ProductCatalogDiagnosticGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductEventStat
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductEventStat = function (_AbstractCrudObject) {
  inherits(ProductEventStat, _AbstractCrudObject);

  function ProductEventStat() {
    classCallCheck(this, ProductEventStat);
    return possibleConstructorReturn(this, (ProductEventStat.__proto__ || Object.getPrototypeOf(ProductEventStat)).apply(this, arguments));
  }

  createClass(ProductEventStat, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        date_start: 'date_start',
        date_stop: 'date_stop',
        device_type: 'device_type',
        event: 'event',
        event_source: 'event_source',
        total_content_ids_matched_other_catalogs: 'total_content_ids_matched_other_catalogs',
        total_matched_content_ids: 'total_matched_content_ids',
        total_unmatched_content_ids: 'total_unmatched_content_ids',
        unique_content_ids_matched_other_catalogs: 'unique_content_ids_matched_other_catalogs',
        unique_matched_content_ids: 'unique_matched_content_ids',
        unique_unmatched_content_ids: 'unique_unmatched_content_ids'
      });
    }
  }, {
    key: 'DeviceType',
    get: function get() {
      return Object.freeze({
        desktop: 'desktop',
        mobile_android_phone: 'mobile_android_phone',
        mobile_android_tablet: 'mobile_android_tablet',
        mobile_ipad: 'mobile_ipad',
        mobile_iphone: 'mobile_iphone',
        mobile_ipod: 'mobile_ipod',
        mobile_phone: 'mobile_phone',
        mobile_tablet: 'mobile_tablet',
        mobile_windows_phone: 'mobile_windows_phone',
        unknown: 'unknown'
      });
    }
  }, {
    key: 'Event',
    get: function get() {
      return Object.freeze({
        addtocart: 'AddToCart',
        addtowishlist: 'AddToWishlist',
        initiatecheckout: 'InitiateCheckout',
        lead: 'Lead',
        purchase: 'Purchase',
        search: 'Search',
        subscribe: 'Subscribe',
        viewcontent: 'ViewContent'
      });
    }
  }, {
    key: 'Breakdowns',
    get: function get() {
      return Object.freeze({
        device_type: 'DEVICE_TYPE'
      });
    }
  }]);
  return ProductEventStat;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExternalEventSource
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExternalEventSource = function (_AbstractCrudObject) {
  inherits(ExternalEventSource, _AbstractCrudObject);

  function ExternalEventSource() {
    classCallCheck(this, ExternalEventSource);
    return possibleConstructorReturn(this, (ExternalEventSource.__proto__ || Object.getPrototypeOf(ExternalEventSource)).apply(this, arguments));
  }

  createClass(ExternalEventSource, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        source_type: 'source_type'
      });
    }
  }]);
  return ExternalEventSource;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Flight
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Flight = function (_AbstractCrudObject) {
  inherits(Flight, _AbstractCrudObject);

  function Flight() {
    classCallCheck(this, Flight);
    return possibleConstructorReturn(this, (Flight.__proto__ || Object.getPrototypeOf(Flight)).apply(this, arguments));
  }

  createClass(Flight, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'getVideosMetadata',
    value: function getVideosMetadata(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicVideoMetadata, fields, params, fetchFirstPage, '/videos_metadata');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Flight.prototype.__proto__ || Object.getPrototypeOf(Flight.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        applinks: 'applinks',
        category_specific_fields: 'category_specific_fields',
        currency: 'currency',
        description: 'description',
        destination_airport: 'destination_airport',
        destination_city: 'destination_city',
        flight_id: 'flight_id',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        oneway_currency: 'oneway_currency',
        oneway_price: 'oneway_price',
        origin_airport: 'origin_airport',
        origin_city: 'origin_city',
        price: 'price',
        sanitized_images: 'sanitized_images',
        tags: 'tags',
        unit_price: 'unit_price',
        url: 'url',
        visibility: 'visibility'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }]);
  return Flight;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * HomeListing
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var HomeListing = function (_AbstractCrudObject) {
  inherits(HomeListing, _AbstractCrudObject);

  function HomeListing() {
    classCallCheck(this, HomeListing);
    return possibleConstructorReturn(this, (HomeListing.__proto__ || Object.getPrototypeOf(HomeListing)).apply(this, arguments));
  }

  createClass(HomeListing, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'getVideosMetadata',
    value: function getVideosMetadata(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicVideoMetadata, fields, params, fetchFirstPage, '/videos_metadata');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(HomeListing.prototype.__proto__ || Object.getPrototypeOf(HomeListing.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(HomeListing.prototype.__proto__ || Object.getPrototypeOf(HomeListing.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ac_type: 'ac_type',
        additional_fees_description: 'additional_fees_description',
        address: 'address',
        agent_company: 'agent_company',
        agent_email: 'agent_email',
        agent_fb_page_id: 'agent_fb_page_id',
        agent_name: 'agent_name',
        agent_phone: 'agent_phone',
        applinks: 'applinks',
        area_size: 'area_size',
        area_unit: 'area_unit',
        availability: 'availability',
        category_specific_fields: 'category_specific_fields',
        co_2_emission_rating_eu: 'co_2_emission_rating_eu',
        currency: 'currency',
        days_on_market: 'days_on_market',
        description: 'description',
        energy_rating_eu: 'energy_rating_eu',
        furnish_type: 'furnish_type',
        group_id: 'group_id',
        heating_type: 'heating_type',
        home_listing_id: 'home_listing_id',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        laundry_type: 'laundry_type',
        listing_type: 'listing_type',
        max_currency: 'max_currency',
        max_price: 'max_price',
        min_currency: 'min_currency',
        min_price: 'min_price',
        name: 'name',
        num_baths: 'num_baths',
        num_beds: 'num_beds',
        num_rooms: 'num_rooms',
        num_units: 'num_units',
        parking_type: 'parking_type',
        partner_verification: 'partner_verification',
        pet_policy: 'pet_policy',
        price: 'price',
        property_type: 'property_type',
        sanitized_images: 'sanitized_images',
        unit_price: 'unit_price',
        url: 'url',
        visibility: 'visibility',
        year_built: 'year_built'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }]);
  return HomeListing;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogHotelRoomsBatch
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogHotelRoomsBatch = function (_AbstractCrudObject) {
  inherits(ProductCatalogHotelRoomsBatch, _AbstractCrudObject);

  function ProductCatalogHotelRoomsBatch() {
    classCallCheck(this, ProductCatalogHotelRoomsBatch);
    return possibleConstructorReturn(this, (ProductCatalogHotelRoomsBatch.__proto__ || Object.getPrototypeOf(ProductCatalogHotelRoomsBatch)).apply(this, arguments));
  }

  createClass(ProductCatalogHotelRoomsBatch, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        errors: 'errors',
        errors_total_count: 'errors_total_count',
        handle: 'handle',
        status: 'status'
      });
    }
  }]);
  return ProductCatalogHotelRoomsBatch;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DynamicPriceConfigByDate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DynamicPriceConfigByDate = function (_AbstractCrudObject) {
  inherits(DynamicPriceConfigByDate, _AbstractCrudObject);

  function DynamicPriceConfigByDate() {
    classCallCheck(this, DynamicPriceConfigByDate);
    return possibleConstructorReturn(this, (DynamicPriceConfigByDate.__proto__ || Object.getPrototypeOf(DynamicPriceConfigByDate)).apply(this, arguments));
  }

  createClass(DynamicPriceConfigByDate, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        checkin_date: 'checkin_date',
        prices: 'prices',
        prices_pretty: 'prices_pretty',
        id: 'id'
      });
    }
  }]);
  return DynamicPriceConfigByDate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * HotelRoom
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var HotelRoom = function (_AbstractCrudObject) {
  inherits(HotelRoom, _AbstractCrudObject);

  function HotelRoom() {
    classCallCheck(this, HotelRoom);
    return possibleConstructorReturn(this, (HotelRoom.__proto__ || Object.getPrototypeOf(HotelRoom)).apply(this, arguments));
  }

  createClass(HotelRoom, [{
    key: 'getPricingVariables',
    value: function getPricingVariables(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicPriceConfigByDate, fields, params, fetchFirstPage, '/pricing_variables');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        applinks: 'applinks',
        base_price: 'base_price',
        currency: 'currency',
        description: 'description',
        id: 'id',
        images: 'images',
        margin_level: 'margin_level',
        name: 'name',
        room_id: 'room_id',
        sale_price: 'sale_price',
        url: 'url'
      });
    }
  }]);
  return HotelRoom;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Hotel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Hotel = function (_AbstractCrudObject) {
  inherits(Hotel, _AbstractCrudObject);

  function Hotel() {
    classCallCheck(this, Hotel);
    return possibleConstructorReturn(this, (Hotel.__proto__ || Object.getPrototypeOf(Hotel)).apply(this, arguments));
  }

  createClass(Hotel, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getHotelRooms',
    value: function getHotelRooms(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(HotelRoom, fields, params, fetchFirstPage, '/hotel_rooms');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'getVideosMetadata',
    value: function getVideosMetadata(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicVideoMetadata, fields, params, fetchFirstPage, '/videos_metadata');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Hotel.prototype.__proto__ || Object.getPrototypeOf(Hotel.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Hotel.prototype.__proto__ || Object.getPrototypeOf(Hotel.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        address: 'address',
        applinks: 'applinks',
        brand: 'brand',
        category: 'category',
        category_specific_fields: 'category_specific_fields',
        currency: 'currency',
        description: 'description',
        guest_ratings: 'guest_ratings',
        hotel_id: 'hotel_id',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        lowest_base_price: 'lowest_base_price',
        loyalty_program: 'loyalty_program',
        margin_level: 'margin_level',
        name: 'name',
        phone: 'phone',
        product_priority_0: 'product_priority_0',
        product_priority_1: 'product_priority_1',
        product_priority_2: 'product_priority_2',
        product_priority_3: 'product_priority_3',
        product_priority_4: 'product_priority_4',
        sale_price: 'sale_price',
        sanitized_images: 'sanitized_images',
        star_rating: 'star_rating',
        tags: 'tags',
        unit_price: 'unit_price',
        url: 'url',
        visibility: 'visibility'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }]);
  return Hotel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogPricingVariablesBatch
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogPricingVariablesBatch = function (_AbstractCrudObject) {
  inherits(ProductCatalogPricingVariablesBatch, _AbstractCrudObject);

  function ProductCatalogPricingVariablesBatch() {
    classCallCheck(this, ProductCatalogPricingVariablesBatch);
    return possibleConstructorReturn(this, (ProductCatalogPricingVariablesBatch.__proto__ || Object.getPrototypeOf(ProductCatalogPricingVariablesBatch)).apply(this, arguments));
  }

  createClass(ProductCatalogPricingVariablesBatch, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        errors: 'errors',
        errors_total_count: 'errors_total_count',
        handle: 'handle',
        status: 'status'
      });
    }
  }]);
  return ProductCatalogPricingVariablesBatch;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MediaTitle
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MediaTitle = function (_AbstractCrudObject) {
  inherits(MediaTitle, _AbstractCrudObject);

  function MediaTitle() {
    classCallCheck(this, MediaTitle);
    return possibleConstructorReturn(this, (MediaTitle.__proto__ || Object.getPrototypeOf(MediaTitle)).apply(this, arguments));
  }

  createClass(MediaTitle, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'getVideosMetadata',
    value: function getVideosMetadata(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicVideoMetadata, fields, params, fetchFirstPage, '/videos_metadata');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(MediaTitle.prototype.__proto__ || Object.getPrototypeOf(MediaTitle.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(MediaTitle.prototype.__proto__ || Object.getPrototypeOf(MediaTitle.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        applinks: 'applinks',
        category_specific_fields: 'category_specific_fields',
        content_category: 'content_category',
        currency: 'currency',
        description: 'description',
        fb_page_alias: 'fb_page_alias',
        fb_page_id: 'fb_page_id',
        genres: 'genres',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        kg_fb_id: 'kg_fb_id',
        media_title_id: 'media_title_id',
        price: 'price',
        sanitized_images: 'sanitized_images',
        title: 'title',
        title_display_name: 'title_display_name',
        unit_price: 'unit_price',
        url: 'url',
        visibility: 'visibility',
        wiki_data_item: 'wiki_data_item'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }, {
    key: 'ContentCategory',
    get: function get() {
      return Object.freeze({
        movie: 'MOVIE',
        music: 'MUSIC',
        tv_show: 'TV_SHOW'
      });
    }
  }]);
  return MediaTitle;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VehicleOffer
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VehicleOffer = function (_AbstractCrudObject) {
  inherits(VehicleOffer, _AbstractCrudObject);

  function VehicleOffer() {
    classCallCheck(this, VehicleOffer);
    return possibleConstructorReturn(this, (VehicleOffer.__proto__ || Object.getPrototypeOf(VehicleOffer)).apply(this, arguments));
  }

  createClass(VehicleOffer, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'getVideosMetadata',
    value: function getVideosMetadata(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicVideoMetadata, fields, params, fetchFirstPage, '/videos_metadata');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount_currency: 'amount_currency',
        amount_percentage: 'amount_percentage',
        amount_price: 'amount_price',
        amount_qualifier: 'amount_qualifier',
        applinks: 'applinks',
        availability: 'availability',
        body_style: 'body_style',
        cashback_currency: 'cashback_currency',
        cashback_price: 'cashback_price',
        category_specific_fields: 'category_specific_fields',
        currency: 'currency',
        dma_codes: 'dma_codes',
        downpayment_currency: 'downpayment_currency',
        downpayment_price: 'downpayment_price',
        downpayment_qualifier: 'downpayment_qualifier',
        drivetrain: 'drivetrain',
        end_date: 'end_date',
        end_time: 'end_time',
        exterior_color: 'exterior_color',
        fuel_type: 'fuel_type',
        generation: 'generation',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        interior_color: 'interior_color',
        interior_upholstery: 'interior_upholstery',
        make: 'make',
        model: 'model',
        offer_description: 'offer_description',
        offer_disclaimer: 'offer_disclaimer',
        offer_type: 'offer_type',
        price: 'price',
        product_priority_0: 'product_priority_0',
        product_priority_1: 'product_priority_1',
        product_priority_2: 'product_priority_2',
        product_priority_3: 'product_priority_3',
        product_priority_4: 'product_priority_4',
        sanitized_images: 'sanitized_images',
        start_date: 'start_date',
        start_time: 'start_time',
        term_length: 'term_length',
        term_qualifier: 'term_qualifier',
        title: 'title',
        transmission: 'transmission',
        trim: 'trim',
        unit_price: 'unit_price',
        url: 'url',
        vehicle_offer_id: 'vehicle_offer_id',
        visibility: 'visibility',
        year: 'year'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }]);
  return VehicleOffer;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Vehicle
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Vehicle = function (_AbstractCrudObject) {
  inherits(Vehicle, _AbstractCrudObject);

  function Vehicle() {
    classCallCheck(this, Vehicle);
    return possibleConstructorReturn(this, (Vehicle.__proto__ || Object.getPrototypeOf(Vehicle)).apply(this, arguments));
  }

  createClass(Vehicle, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'getVideosMetadata',
    value: function getVideosMetadata(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicVideoMetadata, fields, params, fetchFirstPage, '/videos_metadata');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Vehicle.prototype.__proto__ || Object.getPrototypeOf(Vehicle.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        address: 'address',
        applinks: 'applinks',
        availability: 'availability',
        body_style: 'body_style',
        category_specific_fields: 'category_specific_fields',
        condition: 'condition',
        currency: 'currency',
        custom_label_0: 'custom_label_0',
        date_first_on_lot: 'date_first_on_lot',
        dealer_communication_channel: 'dealer_communication_channel',
        dealer_email: 'dealer_email',
        dealer_id: 'dealer_id',
        dealer_name: 'dealer_name',
        dealer_phone: 'dealer_phone',
        dealer_privacy_policy_url: 'dealer_privacy_policy_url',
        description: 'description',
        drivetrain: 'drivetrain',
        exterior_color: 'exterior_color',
        fb_page_id: 'fb_page_id',
        features: 'features',
        fuel_type: 'fuel_type',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        interior_color: 'interior_color',
        legal_disclosure_impressum_url: 'legal_disclosure_impressum_url',
        make: 'make',
        mileage: 'mileage',
        model: 'model',
        previous_currency: 'previous_currency',
        previous_price: 'previous_price',
        price: 'price',
        product_priority_0: 'product_priority_0',
        product_priority_1: 'product_priority_1',
        product_priority_2: 'product_priority_2',
        product_priority_3: 'product_priority_3',
        product_priority_4: 'product_priority_4',
        sale_currency: 'sale_currency',
        sale_price: 'sale_price',
        sanitized_images: 'sanitized_images',
        state_of_vehicle: 'state_of_vehicle',
        title: 'title',
        transmission: 'transmission',
        trim: 'trim',
        unit_price: 'unit_price',
        url: 'url',
        vehicle_id: 'vehicle_id',
        vehicle_registration_plate: 'vehicle_registration_plate',
        vehicle_specifications: 'vehicle_specifications',
        vehicle_type: 'vehicle_type',
        vin: 'vin',
        visibility: 'visibility',
        year: 'year'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }, {
    key: 'Availability',
    get: function get() {
      return Object.freeze({
        available: 'AVAILABLE',
        not_available: 'NOT_AVAILABLE',
        pending: 'PENDING'
      });
    }
  }, {
    key: 'BodyStyle',
    get: function get() {
      return Object.freeze({
        convertible: 'CONVERTIBLE',
        coupe: 'COUPE',
        crossover: 'CROSSOVER',
        estate: 'ESTATE',
        grandtourer: 'GRANDTOURER',
        hatchback: 'HATCHBACK',
        minibus: 'MINIBUS',
        minivan: 'MINIVAN',
        mpv: 'MPV',
        none: 'NONE',
        other: 'OTHER',
        pickup: 'PICKUP',
        roadster: 'ROADSTER',
        saloon: 'SALOON',
        sedan: 'SEDAN',
        small_car: 'SMALL_CAR',
        sportscar: 'SPORTSCAR',
        supercar: 'SUPERCAR',
        supermini: 'SUPERMINI',
        suv: 'SUV',
        truck: 'TRUCK',
        van: 'VAN',
        wagon: 'WAGON'
      });
    }
  }, {
    key: 'Condition',
    get: function get() {
      return Object.freeze({
        excellent: 'EXCELLENT',
        fair: 'FAIR',
        good: 'GOOD',
        none: 'NONE',
        other: 'OTHER',
        poor: 'POOR',
        very_good: 'VERY_GOOD'
      });
    }
  }, {
    key: 'Drivetrain',
    get: function get() {
      return Object.freeze({
        awd: 'AWD',
        four_wd: 'FOUR_WD',
        fwd: 'FWD',
        none: 'NONE',
        other: 'OTHER',
        rwd: 'RWD',
        two_wd: 'TWO_WD'
      });
    }
  }, {
    key: 'FuelType',
    get: function get() {
      return Object.freeze({
        diesel: 'DIESEL',
        electric: 'ELECTRIC',
        flex: 'FLEX',
        gasoline: 'GASOLINE',
        hybrid: 'HYBRID',
        none: 'NONE',
        other: 'OTHER',
        petrol: 'PETROL',
        plugin_hybrid: 'PLUGIN_HYBRID'
      });
    }
  }, {
    key: 'StateOfVehicle',
    get: function get() {
      return Object.freeze({
        cpo: 'CPO',
        new: 'NEW',
        used: 'USED'
      });
    }
  }, {
    key: 'Transmission',
    get: function get() {
      return Object.freeze({
        automatic: 'AUTOMATIC',
        manual: 'MANUAL',
        none: 'NONE',
        other: 'OTHER'
      });
    }
  }, {
    key: 'VehicleType',
    get: function get() {
      return Object.freeze({
        boat: 'BOAT',
        car_truck: 'CAR_TRUCK',
        commercial: 'COMMERCIAL',
        motorcycle: 'MOTORCYCLE',
        other: 'OTHER',
        powersport: 'POWERSPORT',
        rv_camper: 'RV_CAMPER',
        trailer: 'TRAILER'
      });
    }
  }]);
  return Vehicle;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductSet
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductSet = function (_AbstractCrudObject) {
  inherits(ProductSet, _AbstractCrudObject);

  function ProductSet() {
    classCallCheck(this, ProductSet);
    return possibleConstructorReturn(this, (ProductSet.__proto__ || Object.getPrototypeOf(ProductSet)).apply(this, arguments));
  }

  createClass(ProductSet, [{
    key: 'getAutomotiveModels',
    value: function getAutomotiveModels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AutomotiveModel, fields, params, fetchFirstPage, '/automotive_models');
    }
  }, {
    key: 'getDestinations',
    value: function getDestinations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Destination, fields, params, fetchFirstPage, '/destinations');
    }
  }, {
    key: 'getFlights',
    value: function getFlights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Flight, fields, params, fetchFirstPage, '/flights');
    }
  }, {
    key: 'getHomeListings',
    value: function getHomeListings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(HomeListing, fields, params, fetchFirstPage, '/home_listings');
    }
  }, {
    key: 'getHotels',
    value: function getHotels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Hotel, fields, params, fetchFirstPage, '/hotels');
    }
  }, {
    key: 'getMediaTitles',
    value: function getMediaTitles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MediaTitle, fields, params, fetchFirstPage, '/media_titles');
    }
  }, {
    key: 'getProducts',
    value: function getProducts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductItem, fields, params, fetchFirstPage, '/products');
    }
  }, {
    key: 'getVehicleOffers',
    value: function getVehicleOffers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(VehicleOffer, fields, params, fetchFirstPage, '/vehicle_offers');
    }
  }, {
    key: 'getVehicles',
    value: function getVehicles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Vehicle, fields, params, fetchFirstPage, '/vehicles');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductSet.prototype.__proto__ || Object.getPrototypeOf(ProductSet.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductSet.prototype.__proto__ || Object.getPrototypeOf(ProductSet.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        auto_creation_url: 'auto_creation_url',
        filter: 'filter',
        id: 'id',
        latest_metadata: 'latest_metadata',
        live_metadata: 'live_metadata',
        name: 'name',
        ordering_info: 'ordering_info',
        product_catalog: 'product_catalog',
        product_count: 'product_count',
        retailer_id: 'retailer_id'
      });
    }
  }]);
  return ProductSet;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItem
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItem = function (_AbstractCrudObject) {
  inherits(ProductItem, _AbstractCrudObject);

  function ProductItem() {
    classCallCheck(this, ProductItem);
    return possibleConstructorReturn(this, (ProductItem.__proto__ || Object.getPrototypeOf(ProductItem)).apply(this, arguments));
  }

  createClass(ProductItem, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'getProductSets',
    value: function getProductSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductSet, fields, params, fetchFirstPage, '/product_sets');
    }
  }, {
    key: 'getVideosMetadata',
    value: function getVideosMetadata(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DynamicVideoMetadata, fields, params, fetchFirstPage, '/videos_metadata');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductItem.prototype.__proto__ || Object.getPrototypeOf(ProductItem.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductItem.prototype.__proto__ || Object.getPrototypeOf(ProductItem.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        additional_image_cdn_urls: 'additional_image_cdn_urls',
        additional_image_urls: 'additional_image_urls',
        additional_variant_attributes: 'additional_variant_attributes',
        age_group: 'age_group',
        applinks: 'applinks',
        availability: 'availability',
        brand: 'brand',
        bundle_items: 'bundle_items',
        bundle_retailer_ids: 'bundle_retailer_ids',
        capability_to_review_status: 'capability_to_review_status',
        category: 'category',
        category_specific_fields: 'category_specific_fields',
        color: 'color',
        commerce_insights: 'commerce_insights',
        condition: 'condition',
        currency: 'currency',
        custom_data: 'custom_data',
        custom_label_0: 'custom_label_0',
        custom_label_1: 'custom_label_1',
        custom_label_2: 'custom_label_2',
        custom_label_3: 'custom_label_3',
        custom_label_4: 'custom_label_4',
        custom_number_0: 'custom_number_0',
        custom_number_1: 'custom_number_1',
        custom_number_2: 'custom_number_2',
        custom_number_3: 'custom_number_3',
        custom_number_4: 'custom_number_4',
        description: 'description',
        errors: 'errors',
        expiration_date: 'expiration_date',
        fb_product_category: 'fb_product_category',
        gender: 'gender',
        gtin: 'gtin',
        id: 'id',
        image_cdn_urls: 'image_cdn_urls',
        image_fetch_status: 'image_fetch_status',
        image_url: 'image_url',
        images: 'images',
        importer_address: 'importer_address',
        importer_name: 'importer_name',
        invalidation_errors: 'invalidation_errors',
        inventory: 'inventory',
        is_bundle_hero: 'is_bundle_hero',
        manufacturer_info: 'manufacturer_info',
        manufacturer_part_number: 'manufacturer_part_number',
        marked_for_product_launch: 'marked_for_product_launch',
        material: 'material',
        mobile_link: 'mobile_link',
        name: 'name',
        ordering_index: 'ordering_index',
        origin_country: 'origin_country',
        parent_product_id: 'parent_product_id',
        pattern: 'pattern',
        post_conversion_signal_based_enforcement_appeal_eligibility: 'post_conversion_signal_based_enforcement_appeal_eligibility',
        price: 'price',
        product_catalog: 'product_catalog',
        product_feed: 'product_feed',
        product_group: 'product_group',
        product_local_info: 'product_local_info',
        product_type: 'product_type',
        quantity_to_sell_on_facebook: 'quantity_to_sell_on_facebook',
        retailer_id: 'retailer_id',
        retailer_product_group_id: 'retailer_product_group_id',
        review_rejection_reasons: 'review_rejection_reasons',
        review_status: 'review_status',
        sale_price: 'sale_price',
        sale_price_end_date: 'sale_price_end_date',
        sale_price_start_date: 'sale_price_start_date',
        shipping_weight_unit: 'shipping_weight_unit',
        shipping_weight_value: 'shipping_weight_value',
        short_description: 'short_description',
        size: 'size',
        start_date: 'start_date',
        tags: 'tags',
        url: 'url',
        video_fetch_status: 'video_fetch_status',
        visibility: 'visibility',
        wa_compliance_category: 'wa_compliance_category'
      });
    }
  }, {
    key: 'AgeGroup',
    get: function get() {
      return Object.freeze({
        adult: 'adult',
        all_ages: 'all ages',
        infant: 'infant',
        kids: 'kids',
        newborn: 'newborn',
        teen: 'teen',
        toddler: 'toddler'
      });
    }
  }, {
    key: 'Availability',
    get: function get() {
      return Object.freeze({
        available_for_order: 'available for order',
        discontinued: 'discontinued',
        in_stock: 'in stock',
        mark_as_sold: 'mark_as_sold',
        out_of_stock: 'out of stock',
        pending: 'pending',
        preorder: 'preorder'
      });
    }
  }, {
    key: 'CapabilityToReviewStatus',
    get: function get() {
      return Object.freeze({
        approved: 'APPROVED',
        no_review: 'NO_REVIEW',
        outdated: 'OUTDATED',
        pending: 'PENDING',
        rejected: 'REJECTED'
      });
    }
  }, {
    key: 'Condition',
    get: function get() {
      return Object.freeze({
        cpo: 'cpo',
        new: 'new',
        open_box_new: 'open_box_new',
        refurbished: 'refurbished',
        used: 'used',
        used_fair: 'used_fair',
        used_good: 'used_good',
        used_like_new: 'used_like_new'
      });
    }
  }, {
    key: 'Gender',
    get: function get() {
      return Object.freeze({
        female: 'female',
        male: 'male',
        unisex: 'unisex'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'ReviewStatus',
    get: function get() {
      return Object.freeze({
        approved: 'approved',
        outdated: 'outdated',
        pending: 'pending',
        rejected: 'rejected'
      });
    }
  }, {
    key: 'ShippingWeightUnit',
    get: function get() {
      return Object.freeze({
        g: 'g',
        kg: 'kg',
        lb: 'lb',
        oz: 'oz'
      });
    }
  }, {
    key: 'VideoFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'published',
        staging: 'staging'
      });
    }
  }, {
    key: 'CommerceTaxCategory',
    get: function get() {
      return Object.freeze({
        fb_animal: 'FB_ANIMAL',
        fb_animal_supp: 'FB_ANIMAL_SUPP',
        fb_aprl: 'FB_APRL',
        fb_aprl_accessories: 'FB_APRL_ACCESSORIES',
        fb_aprl_athl_unif: 'FB_APRL_ATHL_UNIF',
        fb_aprl_cases: 'FB_APRL_CASES',
        fb_aprl_clothing: 'FB_APRL_CLOTHING',
        fb_aprl_costume: 'FB_APRL_COSTUME',
        fb_aprl_cstm: 'FB_APRL_CSTM',
        fb_aprl_formal: 'FB_APRL_FORMAL',
        fb_aprl_handbag: 'FB_APRL_HANDBAG',
        fb_aprl_jewelry: 'FB_APRL_JEWELRY',
        fb_aprl_shoe: 'FB_APRL_SHOE',
        fb_aprl_shoe_acc: 'FB_APRL_SHOE_ACC',
        fb_aprl_swim: 'FB_APRL_SWIM',
        fb_aprl_swim_chil: 'FB_APRL_SWIM_CHIL',
        fb_aprl_swim_cvr: 'FB_APRL_SWIM_CVR',
        fb_arts: 'FB_ARTS',
        fb_arts_hobby: 'FB_ARTS_HOBBY',
        fb_arts_party: 'FB_ARTS_PARTY',
        fb_arts_party_gift_card: 'FB_ARTS_PARTY_GIFT_CARD',
        fb_arts_ticket: 'FB_ARTS_TICKET',
        fb_baby: 'FB_BABY',
        fb_baby_bath: 'FB_BABY_BATH',
        fb_baby_blanket: 'FB_BABY_BLANKET',
        fb_baby_diaper: 'FB_BABY_DIAPER',
        fb_baby_gift_set: 'FB_BABY_GIFT_SET',
        fb_baby_health: 'FB_BABY_HEALTH',
        fb_baby_nursing: 'FB_BABY_NURSING',
        fb_baby_potty_trn: 'FB_BABY_POTTY_TRN',
        fb_baby_safe: 'FB_BABY_SAFE',
        fb_baby_toys: 'FB_BABY_TOYS',
        fb_baby_transport: 'FB_BABY_TRANSPORT',
        fb_baby_transport_acc: 'FB_BABY_TRANSPORT_ACC',
        fb_bags: 'FB_BAGS',
        fb_bags_bkpk: 'FB_BAGS_BKPK',
        fb_bags_boxes: 'FB_BAGS_BOXES',
        fb_bags_brfcs: 'FB_BAGS_BRFCS',
        fb_bags_csmt_bag: 'FB_BAGS_CSMT_BAG',
        fb_bags_dffl: 'FB_BAGS_DFFL',
        fb_bags_dipr: 'FB_BAGS_DIPR',
        fb_bags_fnny: 'FB_BAGS_FNNY',
        fb_bags_grmt: 'FB_BAGS_GRMT',
        fb_bags_lugg: 'FB_BAGS_LUGG',
        fb_bags_lug_acc: 'FB_BAGS_LUG_ACC',
        fb_bags_msgr: 'FB_BAGS_MSGR',
        fb_bags_tote: 'FB_BAGS_TOTE',
        fb_bags_trn_cas: 'FB_BAGS_TRN_CAS',
        fb_bldg: 'FB_BLDG',
        fb_bldg_acc: 'FB_BLDG_ACC',
        fb_bldg_cnsmb: 'FB_BLDG_CNSMB',
        fb_bldg_fence: 'FB_BLDG_FENCE',
        fb_bldg_fuel_tnk: 'FB_BLDG_FUEL_TNK',
        fb_bldg_ht_vnt: 'FB_BLDG_HT_VNT',
        fb_bldg_lock: 'FB_BLDG_LOCK',
        fb_bldg_matrl: 'FB_BLDG_MATRL',
        fb_bldg_plmb: 'FB_BLDG_PLMB',
        fb_bldg_pump: 'FB_BLDG_PUMP',
        fb_bldg_pwrs: 'FB_BLDG_PWRS',
        fb_bldg_str_tank: 'FB_BLDG_STR_TANK',
        fb_bldg_s_eng: 'FB_BLDG_S_ENG',
        fb_bldg_tl_acc: 'FB_BLDG_TL_ACC',
        fb_bldg_tool: 'FB_BLDG_TOOL',
        fb_busind: 'FB_BUSIND',
        fb_busind_advertising: 'FB_BUSIND_ADVERTISING',
        fb_busind_agriculture: 'FB_BUSIND_AGRICULTURE',
        fb_busind_automation: 'FB_BUSIND_AUTOMATION',
        fb_busind_heavy_mach: 'FB_BUSIND_HEAVY_MACH',
        fb_busind_lab: 'FB_BUSIND_LAB',
        fb_busind_medical: 'FB_BUSIND_MEDICAL',
        fb_busind_retail: 'FB_BUSIND_RETAIL',
        fb_busind_sanitary_ct: 'FB_BUSIND_SANITARY_CT',
        fb_busind_sign: 'FB_BUSIND_SIGN',
        fb_busind_storage: 'FB_BUSIND_STORAGE',
        fb_busind_storage_acc: 'FB_BUSIND_STORAGE_ACC',
        fb_busind_work_gear: 'FB_BUSIND_WORK_GEAR',
        fb_camera_acc: 'FB_CAMERA_ACC',
        fb_camera_camera: 'FB_CAMERA_CAMERA',
        fb_camera_optic: 'FB_CAMERA_OPTIC',
        fb_camera_optics: 'FB_CAMERA_OPTICS',
        fb_camera_photo: 'FB_CAMERA_PHOTO',
        fb_elec: 'FB_ELEC',
        fb_elec_acc: 'FB_ELEC_ACC',
        fb_elec_arcdade: 'FB_ELEC_ARCDADE',
        fb_elec_audio: 'FB_ELEC_AUDIO',
        fb_elec_circuit: 'FB_ELEC_CIRCUIT',
        fb_elec_comm: 'FB_ELEC_COMM',
        fb_elec_computer: 'FB_ELEC_COMPUTER',
        fb_elec_gps_acc: 'FB_ELEC_GPS_ACC',
        fb_elec_gps_nav: 'FB_ELEC_GPS_NAV',
        fb_elec_gps_trk: 'FB_ELEC_GPS_TRK',
        fb_elec_marine: 'FB_ELEC_MARINE',
        fb_elec_network: 'FB_ELEC_NETWORK',
        fb_elec_part: 'FB_ELEC_PART',
        fb_elec_print: 'FB_ELEC_PRINT',
        fb_elec_radar: 'FB_ELEC_RADAR',
        fb_elec_sftwr: 'FB_ELEC_SFTWR',
        fb_elec_speed_rdr: 'FB_ELEC_SPEED_RDR',
        fb_elec_television: 'FB_ELEC_TELEVISION',
        fb_elec_toll: 'FB_ELEC_TOLL',
        fb_elec_video: 'FB_ELEC_VIDEO',
        fb_elec_vid_gm_acc: 'FB_ELEC_VID_GM_ACC',
        fb_elec_vid_gm_cnsl: 'FB_ELEC_VID_GM_CNSL',
        fb_food: 'FB_FOOD',
        fb_furn: 'FB_FURN',
        fb_furn_baby: 'FB_FURN_BABY',
        fb_furn_bench: 'FB_FURN_BENCH',
        fb_furn_cart: 'FB_FURN_CART',
        fb_furn_chair: 'FB_FURN_CHAIR',
        fb_furn_chair_acc: 'FB_FURN_CHAIR_ACC',
        fb_furn_divide: 'FB_FURN_DIVIDE',
        fb_furn_divide_acc: 'FB_FURN_DIVIDE_ACC',
        fb_furn_ent_ctr: 'FB_FURN_ENT_CTR',
        fb_furn_futn: 'FB_FURN_FUTN',
        fb_furn_futn_pad: 'FB_FURN_FUTN_PAD',
        fb_furn_office: 'FB_FURN_OFFICE',
        fb_furn_office_acc: 'FB_FURN_OFFICE_ACC',
        fb_furn_otto: 'FB_FURN_OTTO',
        fb_furn_outdoor: 'FB_FURN_OUTDOOR',
        fb_furn_outdoor_acc: 'FB_FURN_OUTDOOR_ACC',
        fb_furn_sets: 'FB_FURN_SETS',
        fb_furn_shelve_acc: 'FB_FURN_SHELVE_ACC',
        fb_furn_shlf: 'FB_FURN_SHLF',
        fb_furn_sofa: 'FB_FURN_SOFA',
        fb_furn_sofa_acc: 'FB_FURN_SOFA_ACC',
        fb_furn_storage: 'FB_FURN_STORAGE',
        fb_furn_tabl: 'FB_FURN_TABL',
        fb_furn_tabl_acc: 'FB_FURN_TABL_ACC',
        fb_generic_taxable: 'FB_GENERIC_TAXABLE',
        fb_hlth: 'FB_HLTH',
        fb_hlth_hlth: 'FB_HLTH_HLTH',
        fb_hlth_jwl_cr: 'FB_HLTH_JWL_CR',
        fb_hlth_lilp_blm: 'FB_HLTH_LILP_BLM',
        fb_hlth_ltn_spf: 'FB_HLTH_LTN_SPF',
        fb_hlth_prsl_cr: 'FB_HLTH_PRSL_CR',
        fb_hlth_skn_cr: 'FB_HLTH_SKN_CR',
        fb_hmgn: 'FB_HMGN',
        fb_hmgn_bath: 'FB_HMGN_BATH',
        fb_hmgn_dcor: 'FB_HMGN_DCOR',
        fb_hmgn_emgy: 'FB_HMGN_EMGY',
        fb_hmgn_fplc: 'FB_HMGN_FPLC',
        fb_hmgn_fplc_acc: 'FB_HMGN_FPLC_ACC',
        fb_hmgn_gs_sft: 'FB_HMGN_GS_SFT',
        fb_hmgn_hs_acc: 'FB_HMGN_HS_ACC',
        fb_hmgn_hs_app: 'FB_HMGN_HS_APP',
        fb_hmgn_hs_spl: 'FB_HMGN_HS_SPL',
        fb_hmgn_ktcn: 'FB_HMGN_KTCN',
        fb_hmgn_lawn: 'FB_HMGN_LAWN',
        fb_hmgn_lght: 'FB_HMGN_LGHT',
        fb_hmgn_linn: 'FB_HMGN_LINN',
        fb_hmgn_lt_acc: 'FB_HMGN_LT_ACC',
        fb_hmgn_otdr: 'FB_HMGN_OTDR',
        fb_hmgn_pool: 'FB_HMGN_POOL',
        fb_hmgn_scty: 'FB_HMGN_SCTY',
        fb_hmgn_smk_acc: 'FB_HMGN_SMK_ACC',
        fb_hmgn_umbr: 'FB_HMGN_UMBR',
        fb_hmgn_umbr_acc: 'FB_HMGN_UMBR_ACC',
        fb_mdia: 'FB_MDIA',
        fb_mdia_book: 'FB_MDIA_BOOK',
        fb_mdia_dvds: 'FB_MDIA_DVDS',
        fb_mdia_mag: 'FB_MDIA_MAG',
        fb_mdia_manl: 'FB_MDIA_MANL',
        fb_mdia_musc: 'FB_MDIA_MUSC',
        fb_mdia_prj_pln: 'FB_MDIA_PRJ_PLN',
        fb_mdia_sht_mus: 'FB_MDIA_SHT_MUS',
        fb_offc: 'FB_OFFC',
        fb_offc_bkac: 'FB_OFFC_BKAC',
        fb_offc_crts: 'FB_OFFC_CRTS',
        fb_offc_dskp: 'FB_OFFC_DSKP',
        fb_offc_eqip: 'FB_OFFC_EQIP',
        fb_offc_flng: 'FB_OFFC_FLNG',
        fb_offc_gnrl: 'FB_OFFC_GNRL',
        fb_offc_instm: 'FB_OFFC_INSTM',
        fb_offc_lp_dsk: 'FB_OFFC_LP_DSK',
        fb_offc_mats: 'FB_OFFC_MATS',
        fb_offc_nm_plt: 'FB_OFFC_NM_PLT',
        fb_offc_ppr_hndl: 'FB_OFFC_PPR_HNDL',
        fb_offc_prsnt_spl: 'FB_OFFC_PRSNT_SPL',
        fb_offc_sealr: 'FB_OFFC_SEALR',
        fb_offc_ship_spl: 'FB_OFFC_SHIP_SPL',
        fb_rlgn: 'FB_RLGN',
        fb_rlgn_cmny: 'FB_RLGN_CMNY',
        fb_rlgn_item: 'FB_RLGN_ITEM',
        fb_rlgn_wedd: 'FB_RLGN_WEDD',
        fb_sftwr: 'FB_SFTWR',
        fb_sfwr_cmptr: 'FB_SFWR_CMPTR',
        fb_sfwr_dgtl_gd: 'FB_SFWR_DGTL_GD',
        fb_sfwr_game: 'FB_SFWR_GAME',
        fb_shipping: 'FB_SHIPPING',
        fb_spor: 'FB_SPOR',
        fb_sport_athl: 'FB_SPORT_ATHL',
        fb_sport_athl_clth: 'FB_SPORT_ATHL_CLTH',
        fb_sport_athl_shoe: 'FB_SPORT_ATHL_SHOE',
        fb_sport_athl_sprt: 'FB_SPORT_ATHL_SPRT',
        fb_sport_exrcs: 'FB_SPORT_EXRCS',
        fb_sport_indr_gm: 'FB_SPORT_INDR_GM',
        fb_sport_otdr_gm: 'FB_SPORT_OTDR_GM',
        fb_toys: 'FB_TOYS',
        fb_toys_eqip: 'FB_TOYS_EQIP',
        fb_toys_game: 'FB_TOYS_GAME',
        fb_toys_pzzl: 'FB_TOYS_PZZL',
        fb_toys_tmrs: 'FB_TOYS_TMRS',
        fb_toys_toys: 'FB_TOYS_TOYS',
        fb_vehi: 'FB_VEHI',
        fb_vehi_part: 'FB_VEHI_PART'
      });
    }
  }, {
    key: 'ErrorPriority',
    get: function get() {
      return Object.freeze({
        high: 'HIGH',
        low: 'LOW',
        medium: 'MEDIUM'
      });
    }
  }, {
    key: 'ErrorType',
    get: function get() {
      return Object.freeze({
        address_blocklisted_in_market: 'ADDRESS_BLOCKLISTED_IN_MARKET',
        aggregated_localization_issues: 'AGGREGATED_LOCALIZATION_ISSUES',
        app_has_no_aem_setup: 'APP_HAS_NO_AEM_SETUP',
        ar_deleted_due_to_update: 'AR_DELETED_DUE_TO_UPDATE',
        ar_policy_violated: 'AR_POLICY_VIOLATED',
        available: 'AVAILABLE',
        bad_quality_image: 'BAD_QUALITY_IMAGE',
        big_catalog_with_all_items_in_stock: 'BIG_CATALOG_WITH_ALL_ITEMS_IN_STOCK',
        biz_msg_ai_agent_disabled_by_user: 'BIZ_MSG_AI_AGENT_DISABLED_BY_USER',
        biz_msg_gen_ai_policy_violated: 'BIZ_MSG_GEN_AI_POLICY_VIOLATED',
        cannot_edit_subscription_products: 'CANNOT_EDIT_SUBSCRIPTION_PRODUCTS',
        catalog_not_connected_to_event_source: 'CATALOG_NOT_CONNECTED_TO_EVENT_SOURCE',
        checkout_disabled_by_user: 'CHECKOUT_DISABLED_BY_USER',
        commerce_account_legal_address_invalid: 'COMMERCE_ACCOUNT_LEGAL_ADDRESS_INVALID',
        commerce_account_not_legally_compliant: 'COMMERCE_ACCOUNT_NOT_LEGALLY_COMPLIANT',
        crawled_availability_mismatch: 'CRAWLED_AVAILABILITY_MISMATCH',
        da_disabled_by_user: 'DA_DISABLED_BY_USER',
        da_policy_violation: 'DA_POLICY_VIOLATION',
        deleted_item: 'DELETED_ITEM',
        digital_goods_not_available_for_checkout: 'DIGITAL_GOODS_NOT_AVAILABLE_FOR_CHECKOUT',
        duplicate_images: 'DUPLICATE_IMAGES',
        duplicate_title_and_description: 'DUPLICATE_TITLE_AND_DESCRIPTION',
        empty_availability: 'EMPTY_AVAILABILITY',
        empty_condition: 'EMPTY_CONDITION',
        empty_description: 'EMPTY_DESCRIPTION',
        empty_image_url: 'EMPTY_IMAGE_URL',
        empty_price: 'EMPTY_PRICE',
        empty_product_url: 'EMPTY_PRODUCT_URL',
        empty_seller_description: 'EMPTY_SELLER_DESCRIPTION',
        empty_title: 'EMPTY_TITLE',
        external_merchant_id_mismatch: 'EXTERNAL_MERCHANT_ID_MISMATCH',
        generic_invalid_field: 'GENERIC_INVALID_FIELD',
        groups_disabled_by_user: 'GROUPS_DISABLED_BY_USER',
        hidden_until_product_launch: 'HIDDEN_UNTIL_PRODUCT_LAUNCH',
        illegal_product_category: 'ILLEGAL_PRODUCT_CATEGORY',
        image_fetch_failed: 'IMAGE_FETCH_FAILED',
        image_fetch_failed_bad_gateway: 'IMAGE_FETCH_FAILED_BAD_GATEWAY',
        image_fetch_failed_file_size_exceeded: 'IMAGE_FETCH_FAILED_FILE_SIZE_EXCEEDED',
        image_fetch_failed_forbidden: 'IMAGE_FETCH_FAILED_FORBIDDEN',
        image_fetch_failed_link_broken: 'IMAGE_FETCH_FAILED_LINK_BROKEN',
        image_fetch_failed_timed_out: 'IMAGE_FETCH_FAILED_TIMED_OUT',
        image_resolution_low: 'IMAGE_RESOLUTION_LOW',
        inactive_shopify_product: 'INACTIVE_SHOPIFY_PRODUCT',
        invalid_commerce_tax_category: 'INVALID_COMMERCE_TAX_CATEGORY',
        invalid_consolidated_locality_information: 'INVALID_CONSOLIDATED_LOCALITY_INFORMATION',
        invalid_content_id: 'INVALID_CONTENT_ID',
        invalid_dealer_communication_parameters: 'INVALID_DEALER_COMMUNICATION_PARAMETERS',
        invalid_dma_codes: 'INVALID_DMA_CODES',
        invalid_fb_page_id: 'INVALID_FB_PAGE_ID',
        invalid_images: 'INVALID_IMAGES',
        invalid_monetizer_return_policy: 'INVALID_MONETIZER_RETURN_POLICY',
        invalid_offer_disclaimer_url: 'INVALID_OFFER_DISCLAIMER_URL',
        invalid_offer_end_date: 'INVALID_OFFER_END_DATE',
        invalid_pre_order_params: 'INVALID_PRE_ORDER_PARAMS',
        invalid_range_for_area_size: 'INVALID_RANGE_FOR_AREA_SIZE',
        invalid_range_for_built_up_area_size: 'INVALID_RANGE_FOR_BUILT_UP_AREA_SIZE',
        invalid_range_for_num_of_baths: 'INVALID_RANGE_FOR_NUM_OF_BATHS',
        invalid_range_for_num_of_beds: 'INVALID_RANGE_FOR_NUM_OF_BEDS',
        invalid_range_for_num_of_rooms: 'INVALID_RANGE_FOR_NUM_OF_ROOMS',
        invalid_range_for_parking_spaces: 'INVALID_RANGE_FOR_PARKING_SPACES',
        invalid_shelter_page_id: 'INVALID_SHELTER_PAGE_ID',
        invalid_shipping_profile_params: 'INVALID_SHIPPING_PROFILE_PARAMS',
        invalid_subscription_disable_params: 'INVALID_SUBSCRIPTION_DISABLE_PARAMS',
        invalid_subscription_enable_params: 'INVALID_SUBSCRIPTION_ENABLE_PARAMS',
        invalid_subscription_params: 'INVALID_SUBSCRIPTION_PARAMS',
        invalid_tax_extension_state: 'INVALID_TAX_EXTENSION_STATE',
        invalid_vehicle_state: 'INVALID_VEHICLE_STATE',
        invalid_virtual_tour_url_domain: 'INVALID_VIRTUAL_TOUR_URL_DOMAIN',
        inventory_zero_availability_in_stock: 'INVENTORY_ZERO_AVAILABILITY_IN_STOCK',
        in_another_product_launch: 'IN_ANOTHER_PRODUCT_LAUNCH',
        item_group_not_specified: 'ITEM_GROUP_NOT_SPECIFIED',
        item_not_shippable_for_sca_shop: 'ITEM_NOT_SHIPPABLE_FOR_SCA_SHOP',
        item_override_empty_availability: 'ITEM_OVERRIDE_EMPTY_AVAILABILITY',
        item_override_empty_price: 'ITEM_OVERRIDE_EMPTY_PRICE',
        item_override_not_visible: 'ITEM_OVERRIDE_NOT_VISIBLE',
        item_price_not_positive: 'ITEM_PRICE_NOT_POSITIVE',
        item_stale_out_of_stock: 'ITEM_STALE_OUT_OF_STOCK',
        marketplace_disabled_by_user: 'MARKETPLACE_DISABLED_BY_USER',
        mini_shops_disabled_by_user: 'MINI_SHOPS_DISABLED_BY_USER',
        missing_checkout: 'MISSING_CHECKOUT',
        missing_checkout_currency: 'MISSING_CHECKOUT_CURRENCY',
        missing_color: 'MISSING_COLOR',
        missing_country_override_in_shipping_profile: 'MISSING_COUNTRY_OVERRIDE_IN_SHIPPING_PROFILE',
        missing_event: 'MISSING_EVENT',
        missing_india_compliance_fields: 'MISSING_INDIA_COMPLIANCE_FIELDS',
        missing_shipping_profile: 'MISSING_SHIPPING_PROFILE',
        missing_size: 'MISSING_SIZE',
        missing_tax_category: 'MISSING_TAX_CATEGORY',
        negative_community_feedback: 'NEGATIVE_COMMUNITY_FEEDBACK',
        negative_price: 'NEGATIVE_PRICE',
        not_enough_images: 'NOT_ENOUGH_IMAGES',
        not_enough_unique_products: 'NOT_ENOUGH_UNIQUE_PRODUCTS',
        no_content_id: 'NO_CONTENT_ID',
        overlay_disclaimer_exceeded_max_length: 'OVERLAY_DISCLAIMER_EXCEEDED_MAX_LENGTH',
        part_of_product_launch: 'PART_OF_PRODUCT_LAUNCH',
        passing_multiple_content_ids: 'PASSING_MULTIPLE_CONTENT_IDS',
        product_dominant_currency_mismatch: 'PRODUCT_DOMINANT_CURRENCY_MISMATCH',
        product_expired: 'PRODUCT_EXPIRED',
        product_item_hidden_from_all_shops: 'PRODUCT_ITEM_HIDDEN_FROM_ALL_SHOPS',
        product_item_invalid_partner_tokens: 'PRODUCT_ITEM_INVALID_PARTNER_TOKENS',
        product_item_not_included_in_any_shop: 'PRODUCT_ITEM_NOT_INCLUDED_IN_ANY_SHOP',
        product_item_not_visible: 'PRODUCT_ITEM_NOT_VISIBLE',
        product_not_approved: 'PRODUCT_NOT_APPROVED',
        product_not_dominant_currency: 'PRODUCT_NOT_DOMINANT_CURRENCY',
        product_out_of_stock: 'PRODUCT_OUT_OF_STOCK',
        product_url_equals_domain: 'PRODUCT_URL_EQUALS_DOMAIN',
        property_price_currency_not_supported: 'PROPERTY_PRICE_CURRENCY_NOT_SUPPORTED',
        property_price_too_high: 'PROPERTY_PRICE_TOO_HIGH',
        property_price_too_low: 'PROPERTY_PRICE_TOO_LOW',
        property_unit_price_currency_mismatch_item_price_currency: 'PROPERTY_UNIT_PRICE_CURRENCY_MISMATCH_ITEM_PRICE_CURRENCY',
        property_value_contains_html_tags: 'PROPERTY_VALUE_CONTAINS_HTML_TAGS',
        property_value_description_contains_off_platform_link: 'PROPERTY_VALUE_DESCRIPTION_CONTAINS_OFF_PLATFORM_LINK',
        property_value_format: 'PROPERTY_VALUE_FORMAT',
        property_value_missing: 'PROPERTY_VALUE_MISSING',
        property_value_missing_warning: 'PROPERTY_VALUE_MISSING_WARNING',
        property_value_non_positive: 'PROPERTY_VALUE_NON_POSITIVE',
        property_value_string_exceeds_length: 'PROPERTY_VALUE_STRING_EXCEEDS_LENGTH',
        property_value_string_too_short: 'PROPERTY_VALUE_STRING_TOO_SHORT',
        property_value_uppercase: 'PROPERTY_VALUE_UPPERCASE',
        property_value_uppercase_warning: 'PROPERTY_VALUE_UPPERCASE_WARNING',
        purchase_rate_below_addtocart: 'PURCHASE_RATE_BELOW_ADDTOCART',
        purchase_rate_below_viewcontent: 'PURCHASE_RATE_BELOW_VIEWCONTENT',
        quality_duplicated_description: 'QUALITY_DUPLICATED_DESCRIPTION',
        quality_item_link_broken: 'QUALITY_ITEM_LINK_BROKEN',
        quality_item_link_redirecting: 'QUALITY_ITEM_LINK_REDIRECTING',
        retailer_id_not_provided: 'RETAILER_ID_NOT_PROVIDED',
        shopify_invalid_retailer_id: 'SHOPIFY_INVALID_RETAILER_ID',
        shopify_item_missing_shipping_profile: 'SHOPIFY_ITEM_MISSING_SHIPPING_PROFILE',
        shops_policy_violation: 'SHOPS_POLICY_VIOLATION',
        subscription_info_not_enabled_for_feed: 'SUBSCRIPTION_INFO_NOT_ENABLED_FOR_FEED',
        tax_category_not_supported_in_uk: 'TAX_CATEGORY_NOT_SUPPORTED_IN_UK',
        unique_product_identifier_missing: 'UNIQUE_PRODUCT_IDENTIFIER_MISSING',
        unmatched_events: 'UNMATCHED_EVENTS',
        unsupported_product_category: 'UNSUPPORTED_PRODUCT_CATEGORY',
        variant_attribute_issue: 'VARIANT_ATTRIBUTE_ISSUE',
        video_fetch_failed: 'VIDEO_FETCH_FAILED',
        video_fetch_failed_bad_gateway: 'VIDEO_FETCH_FAILED_BAD_GATEWAY',
        video_fetch_failed_file_size_exceeded: 'VIDEO_FETCH_FAILED_FILE_SIZE_EXCEEDED',
        video_fetch_failed_forbidden: 'VIDEO_FETCH_FAILED_FORBIDDEN',
        video_fetch_failed_link_broken: 'VIDEO_FETCH_FAILED_LINK_BROKEN',
        video_fetch_failed_timed_out: 'VIDEO_FETCH_FAILED_TIMED_OUT',
        video_not_downloadable: 'VIDEO_NOT_DOWNLOADABLE',
        whatsapp_disabled_by_user: 'WHATSAPP_DISABLED_BY_USER',
        whatsapp_marketing_message_disabled_by_user: 'WHATSAPP_MARKETING_MESSAGE_DISABLED_BY_USER',
        whatsapp_marketing_message_policy_violation: 'WHATSAPP_MARKETING_MESSAGE_POLICY_VIOLATION',
        whatsapp_policy_violation: 'WHATSAPP_POLICY_VIOLATION'
      });
    }
  }, {
    key: 'MarkedForProductLaunch',
    get: function get() {
      return Object.freeze({
        default: 'default',
        marked: 'marked',
        not_marked: 'not_marked'
      });
    }
  }, {
    key: 'OriginCountry',
    get: function get() {
      return Object.freeze({
        ad: 'AD',
        ae: 'AE',
        af: 'AF',
        ag: 'AG',
        ai: 'AI',
        al: 'AL',
        am: 'AM',
        an: 'AN',
        ao: 'AO',
        aq: 'AQ',
        ar: 'AR',
        as: 'AS',
        at: 'AT',
        au: 'AU',
        aw: 'AW',
        ax: 'AX',
        az: 'AZ',
        ba: 'BA',
        bb: 'BB',
        bd: 'BD',
        be: 'BE',
        bf: 'BF',
        bg: 'BG',
        bh: 'BH',
        bi: 'BI',
        bj: 'BJ',
        bl: 'BL',
        bm: 'BM',
        bn: 'BN',
        bo: 'BO',
        bq: 'BQ',
        br: 'BR',
        bs: 'BS',
        bt: 'BT',
        bv: 'BV',
        bw: 'BW',
        by: 'BY',
        bz: 'BZ',
        ca: 'CA',
        cc: 'CC',
        cd: 'CD',
        cf: 'CF',
        cg: 'CG',
        ch: 'CH',
        ci: 'CI',
        ck: 'CK',
        cl: 'CL',
        cm: 'CM',
        cn: 'CN',
        co: 'CO',
        cr: 'CR',
        cu: 'CU',
        cv: 'CV',
        cw: 'CW',
        cx: 'CX',
        cy: 'CY',
        cz: 'CZ',
        de: 'DE',
        dj: 'DJ',
        dk: 'DK',
        dm: 'DM',
        do: 'DO',
        dz: 'DZ',
        ec: 'EC',
        ee: 'EE',
        eg: 'EG',
        eh: 'EH',
        er: 'ER',
        es: 'ES',
        et: 'ET',
        fi: 'FI',
        fj: 'FJ',
        fk: 'FK',
        fm: 'FM',
        fo: 'FO',
        fr: 'FR',
        ga: 'GA',
        gb: 'GB',
        gd: 'GD',
        ge: 'GE',
        gf: 'GF',
        gg: 'GG',
        gh: 'GH',
        gi: 'GI',
        gl: 'GL',
        gm: 'GM',
        gn: 'GN',
        gp: 'GP',
        gq: 'GQ',
        gr: 'GR',
        gs: 'GS',
        gt: 'GT',
        gu: 'GU',
        gw: 'GW',
        gy: 'GY',
        hk: 'HK',
        hm: 'HM',
        hn: 'HN',
        hr: 'HR',
        ht: 'HT',
        hu: 'HU',
        id: 'ID',
        ie: 'IE',
        il: 'IL',
        im: 'IM',
        in: 'IN',
        io: 'IO',
        iq: 'IQ',
        ir: 'IR',
        is: 'IS',
        it: 'IT',
        je: 'JE',
        jm: 'JM',
        jo: 'JO',
        jp: 'JP',
        ke: 'KE',
        kg: 'KG',
        kh: 'KH',
        ki: 'KI',
        km: 'KM',
        kn: 'KN',
        kp: 'KP',
        kr: 'KR',
        kw: 'KW',
        ky: 'KY',
        kz: 'KZ',
        la: 'LA',
        lb: 'LB',
        lc: 'LC',
        li: 'LI',
        lk: 'LK',
        lr: 'LR',
        ls: 'LS',
        lt: 'LT',
        lu: 'LU',
        lv: 'LV',
        ly: 'LY',
        ma: 'MA',
        mc: 'MC',
        md: 'MD',
        me: 'ME',
        mf: 'MF',
        mg: 'MG',
        mh: 'MH',
        mk: 'MK',
        ml: 'ML',
        mm: 'MM',
        mn: 'MN',
        mo: 'MO',
        mp: 'MP',
        mq: 'MQ',
        mr: 'MR',
        ms: 'MS',
        mt: 'MT',
        mu: 'MU',
        mv: 'MV',
        mw: 'MW',
        mx: 'MX',
        my: 'MY',
        mz: 'MZ',
        na: 'NA',
        nc: 'NC',
        ne: 'NE',
        nf: 'NF',
        ng: 'NG',
        ni: 'NI',
        nl: 'NL',
        no: 'NO',
        np: 'NP',
        nr: 'NR',
        nu: 'NU',
        nz: 'NZ',
        om: 'OM',
        pa: 'PA',
        pe: 'PE',
        pf: 'PF',
        pg: 'PG',
        ph: 'PH',
        pk: 'PK',
        pl: 'PL',
        pm: 'PM',
        pn: 'PN',
        pr: 'PR',
        ps: 'PS',
        pt: 'PT',
        pw: 'PW',
        py: 'PY',
        qa: 'QA',
        re: 'RE',
        ro: 'RO',
        rs: 'RS',
        ru: 'RU',
        rw: 'RW',
        sa: 'SA',
        sb: 'SB',
        sc: 'SC',
        sd: 'SD',
        se: 'SE',
        sg: 'SG',
        sh: 'SH',
        si: 'SI',
        sj: 'SJ',
        sk: 'SK',
        sl: 'SL',
        sm: 'SM',
        sn: 'SN',
        so: 'SO',
        sr: 'SR',
        ss: 'SS',
        st: 'ST',
        sv: 'SV',
        sx: 'SX',
        sy: 'SY',
        sz: 'SZ',
        tc: 'TC',
        td: 'TD',
        tf: 'TF',
        tg: 'TG',
        th: 'TH',
        tj: 'TJ',
        tk: 'TK',
        tl: 'TL',
        tm: 'TM',
        tn: 'TN',
        to: 'TO',
        tr: 'TR',
        tt: 'TT',
        tv: 'TV',
        tw: 'TW',
        tz: 'TZ',
        ua: 'UA',
        ug: 'UG',
        um: 'UM',
        us: 'US',
        uy: 'UY',
        uz: 'UZ',
        va: 'VA',
        vc: 'VC',
        ve: 'VE',
        vg: 'VG',
        vi: 'VI',
        vn: 'VN',
        vu: 'VU',
        wf: 'WF',
        ws: 'WS',
        xk: 'XK',
        ye: 'YE',
        yt: 'YT',
        za: 'ZA',
        zm: 'ZM',
        zw: 'ZW'
      });
    }
  }, {
    key: 'WaComplianceCategory',
    get: function get() {
      return Object.freeze({
        country_origin_exempt: 'COUNTRY_ORIGIN_EXEMPT',
        default: 'DEFAULT'
      });
    }
  }]);
  return ProductItem;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeedRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeedRule = function (_AbstractCrudObject) {
  inherits(ProductFeedRule, _AbstractCrudObject);

  function ProductFeedRule() {
    classCallCheck(this, ProductFeedRule);
    return possibleConstructorReturn(this, (ProductFeedRule.__proto__ || Object.getPrototypeOf(ProductFeedRule)).apply(this, arguments));
  }

  createClass(ProductFeedRule, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductFeedRule.prototype.__proto__ || Object.getPrototypeOf(ProductFeedRule.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductFeedRule.prototype.__proto__ || Object.getPrototypeOf(ProductFeedRule.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        attribute: 'attribute',
        id: 'id',
        params: 'params',
        rule_type: 'rule_type'
      });
    }
  }, {
    key: 'RuleType',
    get: function get() {
      return Object.freeze({
        fallback_rule: 'fallback_rule',
        letter_case_rule: 'letter_case_rule',
        mapping_rule: 'mapping_rule',
        regex_replace_rule: 'regex_replace_rule',
        value_mapping_rule: 'value_mapping_rule'
      });
    }
  }]);
  return ProductFeedRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeedSchedule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeedSchedule = function (_AbstractCrudObject) {
  inherits(ProductFeedSchedule, _AbstractCrudObject);

  function ProductFeedSchedule() {
    classCallCheck(this, ProductFeedSchedule);
    return possibleConstructorReturn(this, (ProductFeedSchedule.__proto__ || Object.getPrototypeOf(ProductFeedSchedule)).apply(this, arguments));
  }

  createClass(ProductFeedSchedule, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        day_of_month: 'day_of_month',
        day_of_week: 'day_of_week',
        hour: 'hour',
        id: 'id',
        interval: 'interval',
        interval_count: 'interval_count',
        minute: 'minute',
        timezone: 'timezone',
        url: 'url',
        username: 'username'
      });
    }
  }, {
    key: 'Interval',
    get: function get() {
      return Object.freeze({
        daily: 'DAILY',
        hourly: 'HOURLY',
        monthly: 'MONTHLY',
        weekly: 'WEEKLY'
      });
    }
  }]);
  return ProductFeedSchedule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeedUploadErrorSample
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeedUploadErrorSample = function (_AbstractCrudObject) {
  inherits(ProductFeedUploadErrorSample, _AbstractCrudObject);

  function ProductFeedUploadErrorSample() {
    classCallCheck(this, ProductFeedUploadErrorSample);
    return possibleConstructorReturn(this, (ProductFeedUploadErrorSample.__proto__ || Object.getPrototypeOf(ProductFeedUploadErrorSample)).apply(this, arguments));
  }

  createClass(ProductFeedUploadErrorSample, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        retailer_id: 'retailer_id',
        row_number: 'row_number'
      });
    }
  }]);
  return ProductFeedUploadErrorSample;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeedRuleSuggestion
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeedRuleSuggestion = function (_AbstractCrudObject) {
  inherits(ProductFeedRuleSuggestion, _AbstractCrudObject);

  function ProductFeedRuleSuggestion() {
    classCallCheck(this, ProductFeedRuleSuggestion);
    return possibleConstructorReturn(this, (ProductFeedRuleSuggestion.__proto__ || Object.getPrototypeOf(ProductFeedRuleSuggestion)).apply(this, arguments));
  }

  createClass(ProductFeedRuleSuggestion, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        attribute: 'attribute',
        params: 'params',
        type: 'type'
      });
    }
  }]);
  return ProductFeedRuleSuggestion;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeedUploadError
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeedUploadError = function (_AbstractCrudObject) {
  inherits(ProductFeedUploadError, _AbstractCrudObject);

  function ProductFeedUploadError() {
    classCallCheck(this, ProductFeedUploadError);
    return possibleConstructorReturn(this, (ProductFeedUploadError.__proto__ || Object.getPrototypeOf(ProductFeedUploadError)).apply(this, arguments));
  }

  createClass(ProductFeedUploadError, [{
    key: 'getSamples',
    value: function getSamples(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductFeedUploadErrorSample, fields, params, fetchFirstPage, '/samples');
    }
  }, {
    key: 'getSuggestedRules',
    value: function getSuggestedRules(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductFeedRuleSuggestion, fields, params, fetchFirstPage, '/suggested_rules');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        affected_surfaces: 'affected_surfaces',
        description: 'description',
        error_type: 'error_type',
        id: 'id',
        severity: 'severity',
        summary: 'summary',
        total_count: 'total_count'
      });
    }
  }, {
    key: 'AffectedSurfaces',
    get: function get() {
      return Object.freeze({
        dynamic_ads: 'Dynamic Ads',
        marketplace: 'Marketplace',
        us_marketplace: 'US Marketplace'
      });
    }
  }, {
    key: 'Severity',
    get: function get() {
      return Object.freeze({
        fatal: 'fatal',
        warning: 'warning'
      });
    }
  }, {
    key: 'ErrorPriority',
    get: function get() {
      return Object.freeze({
        high: 'HIGH',
        low: 'LOW',
        medium: 'MEDIUM'
      });
    }
  }]);
  return ProductFeedUploadError;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeedUpload
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeedUpload = function (_AbstractCrudObject) {
  inherits(ProductFeedUpload, _AbstractCrudObject);

  function ProductFeedUpload() {
    classCallCheck(this, ProductFeedUpload);
    return possibleConstructorReturn(this, (ProductFeedUpload.__proto__ || Object.getPrototypeOf(ProductFeedUpload)).apply(this, arguments));
  }

  createClass(ProductFeedUpload, [{
    key: 'createErrorReport',
    value: function createErrorReport(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/error_report', fields, params, ProductFeedUpload, pathOverride);
    }
  }, {
    key: 'getErrors',
    value: function getErrors(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductFeedUploadError, fields, params, fetchFirstPage, '/errors');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        end_time: 'end_time',
        error_count: 'error_count',
        error_report: 'error_report',
        filename: 'filename',
        id: 'id',
        input_method: 'input_method',
        num_deleted_items: 'num_deleted_items',
        num_detected_items: 'num_detected_items',
        num_invalid_items: 'num_invalid_items',
        num_persisted_items: 'num_persisted_items',
        start_time: 'start_time',
        url: 'url',
        warning_count: 'warning_count'
      });
    }
  }, {
    key: 'InputMethod',
    get: function get() {
      return Object.freeze({
        google_sheets_fetch: 'Google Sheets Fetch',
        manual_upload: 'Manual Upload',
        reupload_last_file: 'Reupload Last File',
        server_fetch: 'Server Fetch',
        user_initiated_server_fetch: 'User initiated server fetch'
      });
    }
  }]);
  return ProductFeedUpload;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeed
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeed = function (_AbstractCrudObject) {
  inherits(ProductFeed, _AbstractCrudObject);

  function ProductFeed() {
    classCallCheck(this, ProductFeed);
    return possibleConstructorReturn(this, (ProductFeed.__proto__ || Object.getPrototypeOf(ProductFeed)).apply(this, arguments));
  }

  createClass(ProductFeed, [{
    key: 'getAutomotiveModels',
    value: function getAutomotiveModels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AutomotiveModel, fields, params, fetchFirstPage, '/automotive_models');
    }
  }, {
    key: 'getDestinations',
    value: function getDestinations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Destination, fields, params, fetchFirstPage, '/destinations');
    }
  }, {
    key: 'getFlights',
    value: function getFlights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Flight, fields, params, fetchFirstPage, '/flights');
    }
  }, {
    key: 'getHomeListings',
    value: function getHomeListings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(HomeListing, fields, params, fetchFirstPage, '/home_listings');
    }
  }, {
    key: 'getHotels',
    value: function getHotels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Hotel, fields, params, fetchFirstPage, '/hotels');
    }
  }, {
    key: 'getMediaTitles',
    value: function getMediaTitles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MediaTitle, fields, params, fetchFirstPage, '/media_titles');
    }
  }, {
    key: 'getProducts',
    value: function getProducts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductItem, fields, params, fetchFirstPage, '/products');
    }
  }, {
    key: 'getRules',
    value: function getRules(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductFeedRule, fields, params, fetchFirstPage, '/rules');
    }
  }, {
    key: 'createRule',
    value: function createRule(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/rules', fields, params, ProductFeedRule, pathOverride);
    }
  }, {
    key: 'createSupplementaryFeedAssoc',
    value: function createSupplementaryFeedAssoc(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/supplementary_feed_assocs', fields, params, null, pathOverride);
    }
  }, {
    key: 'getUploadSchedules',
    value: function getUploadSchedules(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductFeedSchedule, fields, params, fetchFirstPage, '/upload_schedules');
    }
  }, {
    key: 'createUploadSchedule',
    value: function createUploadSchedule(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/upload_schedules', fields, params, ProductFeed, pathOverride);
    }
  }, {
    key: 'getUploads',
    value: function getUploads(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductFeedUpload, fields, params, fetchFirstPage, '/uploads');
    }
  }, {
    key: 'createUpload',
    value: function createUpload(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/uploads', fields, params, ProductFeedUpload, pathOverride);
    }
  }, {
    key: 'getVehicleOffers',
    value: function getVehicleOffers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(VehicleOffer, fields, params, fetchFirstPage, '/vehicle_offers');
    }
  }, {
    key: 'getVehicles',
    value: function getVehicles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Vehicle, fields, params, fetchFirstPage, '/vehicles');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductFeed.prototype.__proto__ || Object.getPrototypeOf(ProductFeed.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductFeed.prototype.__proto__ || Object.getPrototypeOf(ProductFeed.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        created_time: 'created_time',
        default_currency: 'default_currency',
        deletion_enabled: 'deletion_enabled',
        delimiter: 'delimiter',
        encoding: 'encoding',
        file_name: 'file_name',
        id: 'id',
        ingestion_source_type: 'ingestion_source_type',
        item_sub_type: 'item_sub_type',
        latest_upload: 'latest_upload',
        migrated_from_feed_id: 'migrated_from_feed_id',
        name: 'name',
        override_type: 'override_type',
        primary_feeds: 'primary_feeds',
        product_count: 'product_count',
        quoted_fields_mode: 'quoted_fields_mode',
        schedule: 'schedule',
        supplementary_feeds: 'supplementary_feeds',
        update_schedule: 'update_schedule'
      });
    }
  }, {
    key: 'Delimiter',
    get: function get() {
      return Object.freeze({
        autodetect: 'AUTODETECT',
        bar: 'BAR',
        comma: 'COMMA',
        semicolon: 'SEMICOLON',
        tab: 'TAB',
        tilde: 'TILDE'
      });
    }
  }, {
    key: 'IngestionSourceType',
    get: function get() {
      return Object.freeze({
        primary_feed: 'primary_feed',
        supplementary_feed: 'supplementary_feed'
      });
    }
  }, {
    key: 'QuotedFieldsMode',
    get: function get() {
      return Object.freeze({
        autodetect: 'AUTODETECT',
        off: 'OFF',
        on: 'ON'
      });
    }
  }, {
    key: 'Encoding',
    get: function get() {
      return Object.freeze({
        autodetect: 'AUTODETECT',
        latin1: 'LATIN1',
        utf16be: 'UTF16BE',
        utf16le: 'UTF16LE',
        utf32be: 'UTF32BE',
        utf32le: 'UTF32LE',
        utf8: 'UTF8'
      });
    }
  }, {
    key: 'FeedType',
    get: function get() {
      return Object.freeze({
        automotive_model: 'AUTOMOTIVE_MODEL',
        collection: 'COLLECTION',
        destination: 'DESTINATION',
        flight: 'FLIGHT',
        home_listing: 'HOME_LISTING',
        hotel: 'HOTEL',
        hotel_room: 'HOTEL_ROOM',
        local_inventory: 'LOCAL_INVENTORY',
        media_title: 'MEDIA_TITLE',
        offer: 'OFFER',
        products: 'PRODUCTS',
        transactable_items: 'TRANSACTABLE_ITEMS',
        vehicles: 'VEHICLES',
        vehicle_offer: 'VEHICLE_OFFER'
      });
    }
  }, {
    key: 'ItemSubType',
    get: function get() {
      return Object.freeze({
        appliances: 'APPLIANCES',
        baby_feeding: 'BABY_FEEDING',
        baby_transport: 'BABY_TRANSPORT',
        beauty: 'BEAUTY',
        bedding: 'BEDDING',
        cameras: 'CAMERAS',
        cell_phones_and_smart_watches: 'CELL_PHONES_AND_SMART_WATCHES',
        cleaning_supplies: 'CLEANING_SUPPLIES',
        clothing: 'CLOTHING',
        clothing_accessories: 'CLOTHING_ACCESSORIES',
        computers_and_tablets: 'COMPUTERS_AND_TABLETS',
        diapering_and_potty_training: 'DIAPERING_AND_POTTY_TRAINING',
        electronics_accessories: 'ELECTRONICS_ACCESSORIES',
        furniture: 'FURNITURE',
        health: 'HEALTH',
        home_goods: 'HOME_GOODS',
        jewelry: 'JEWELRY',
        nursery: 'NURSERY',
        printers_and_scanners: 'PRINTERS_AND_SCANNERS',
        projectors: 'PROJECTORS',
        shoes_and_footwear: 'SHOES_AND_FOOTWEAR',
        software: 'SOFTWARE',
        toys: 'TOYS',
        tvs_and_monitors: 'TVS_AND_MONITORS',
        video_game_consoles_and_video_games: 'VIDEO_GAME_CONSOLES_AND_VIDEO_GAMES',
        watches: 'WATCHES'
      });
    }
  }, {
    key: 'OverrideType',
    get: function get() {
      return Object.freeze({
        batch_api_language_or_country: 'BATCH_API_LANGUAGE_OR_COUNTRY',
        catalog_segment_customize_default: 'CATALOG_SEGMENT_CUSTOMIZE_DEFAULT',
        country: 'COUNTRY',
        language: 'LANGUAGE',
        language_and_country: 'LANGUAGE_AND_COUNTRY',
        local: 'LOCAL',
        smart_pixel_language_or_country: 'SMART_PIXEL_LANGUAGE_OR_COUNTRY',
        version: 'VERSION'
      });
    }
  }]);
  return ProductFeed;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductGroup = function (_AbstractCrudObject) {
  inherits(ProductGroup, _AbstractCrudObject);

  function ProductGroup() {
    classCallCheck(this, ProductGroup);
    return possibleConstructorReturn(this, (ProductGroup.__proto__ || Object.getPrototypeOf(ProductGroup)).apply(this, arguments));
  }

  createClass(ProductGroup, [{
    key: 'getProducts',
    value: function getProducts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductItem, fields, params, fetchFirstPage, '/products');
    }
  }, {
    key: 'createProduct',
    value: function createProduct(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/products', fields, params, ProductItem, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductGroup.prototype.__proto__ || Object.getPrototypeOf(ProductGroup.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductGroup.prototype.__proto__ || Object.getPrototypeOf(ProductGroup.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        product_catalog: 'product_catalog',
        retailer_id: 'retailer_id',
        variants: 'variants'
      });
    }
  }]);
  return ProductGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogProductSetsBatch
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogProductSetsBatch = function (_AbstractCrudObject) {
  inherits(ProductCatalogProductSetsBatch, _AbstractCrudObject);

  function ProductCatalogProductSetsBatch() {
    classCallCheck(this, ProductCatalogProductSetsBatch);
    return possibleConstructorReturn(this, (ProductCatalogProductSetsBatch.__proto__ || Object.getPrototypeOf(ProductCatalogProductSetsBatch)).apply(this, arguments));
  }

  createClass(ProductCatalogProductSetsBatch, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        errors: 'errors',
        errors_total_count: 'errors_total_count',
        handle: 'handle',
        status: 'status'
      });
    }
  }]);
  return ProductCatalogProductSetsBatch;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalog
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalog = function (_AbstractCrudObject) {
  inherits(ProductCatalog, _AbstractCrudObject);

  function ProductCatalog() {
    classCallCheck(this, ProductCatalog);
    return possibleConstructorReturn(this, (ProductCatalog.__proto__ || Object.getPrototypeOf(ProductCatalog)).apply(this, arguments));
  }

  createClass(ProductCatalog, [{
    key: 'deleteAgencies',
    value: function deleteAgencies() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(ProductCatalog.prototype.__proto__ || Object.getPrototypeOf(ProductCatalog.prototype), 'deleteEdge', this).call(this, '/agencies', params);
    }
  }, {
    key: 'getAgencies',
    value: function getAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/agencies');
    }
  }, {
    key: 'createAgency',
    value: function createAgency(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/agencies', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'deleteAssignedUsers',
    value: function deleteAssignedUsers() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(ProductCatalog.prototype.__proto__ || Object.getPrototypeOf(ProductCatalog.prototype), 'deleteEdge', this).call(this, '/assigned_users', params);
    }
  }, {
    key: 'getAssignedUsers',
    value: function getAssignedUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AssignedUser, fields, params, fetchFirstPage, '/assigned_users');
    }
  }, {
    key: 'createAssignedUser',
    value: function createAssignedUser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/assigned_users', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'getAutomotiveModels',
    value: function getAutomotiveModels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AutomotiveModel, fields, params, fetchFirstPage, '/automotive_models');
    }
  }, {
    key: 'createBatch',
    value: function createBatch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/batch', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'createCatalogStore',
    value: function createCatalogStore(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/catalog_store', fields, params, StoreCatalogSettings, pathOverride);
    }
  }, {
    key: 'getCategories',
    value: function getCategories(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalogCategory, fields, params, fetchFirstPage, '/categories');
    }
  }, {
    key: 'createCategory',
    value: function createCategory(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/categories', fields, params, ProductCatalogCategory, pathOverride);
    }
  }, {
    key: 'getCheckBatchRequestStatus',
    value: function getCheckBatchRequestStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CheckBatchRequestStatus, fields, params, fetchFirstPage, '/check_batch_request_status');
    }
  }, {
    key: 'getCollaborativeAdsLsbImageBank',
    value: function getCollaborativeAdsLsbImageBank(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CPASLsbImageBank, fields, params, fetchFirstPage, '/collaborative_ads_lsb_image_bank');
    }
  }, {
    key: 'getCollaborativeAdsShareSettings',
    value: function getCollaborativeAdsShareSettings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CollaborativeAdsShareSettings, fields, params, fetchFirstPage, '/collaborative_ads_share_settings');
    }
  }, {
    key: 'createCpasLsbImageBank',
    value: function createCpasLsbImageBank(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/cpas_lsb_image_bank', fields, params, CPASLsbImageBank, pathOverride);
    }
  }, {
    key: 'getCreatorAssetCreatives',
    value: function getCreatorAssetCreatives(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CreatorAssetCreative, fields, params, fetchFirstPage, '/creator_asset_creatives');
    }
  }, {
    key: 'getDataSources',
    value: function getDataSources(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalogDataSource, fields, params, fetchFirstPage, '/data_sources');
    }
  }, {
    key: 'getDestinations',
    value: function getDestinations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Destination, fields, params, fetchFirstPage, '/destinations');
    }
  }, {
    key: 'getDiagnostics',
    value: function getDiagnostics(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalogDiagnosticGroup, fields, params, fetchFirstPage, '/diagnostics');
    }
  }, {
    key: 'getEventStats',
    value: function getEventStats(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductEventStat, fields, params, fetchFirstPage, '/event_stats');
    }
  }, {
    key: 'deleteExternalEventSources',
    value: function deleteExternalEventSources() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(ProductCatalog.prototype.__proto__ || Object.getPrototypeOf(ProductCatalog.prototype), 'deleteEdge', this).call(this, '/external_event_sources', params);
    }
  }, {
    key: 'getExternalEventSources',
    value: function getExternalEventSources(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ExternalEventSource, fields, params, fetchFirstPage, '/external_event_sources');
    }
  }, {
    key: 'createExternalEventSource',
    value: function createExternalEventSource(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/external_event_sources', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'getFlights',
    value: function getFlights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Flight, fields, params, fetchFirstPage, '/flights');
    }
  }, {
    key: 'getHomeListings',
    value: function getHomeListings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(HomeListing, fields, params, fetchFirstPage, '/home_listings');
    }
  }, {
    key: 'createHomeListing',
    value: function createHomeListing(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/home_listings', fields, params, HomeListing, pathOverride);
    }
  }, {
    key: 'getHotelRoomsBatch',
    value: function getHotelRoomsBatch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalogHotelRoomsBatch, fields, params, fetchFirstPage, '/hotel_rooms_batch');
    }
  }, {
    key: 'createHotelRoomsBatch',
    value: function createHotelRoomsBatch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/hotel_rooms_batch', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'getHotels',
    value: function getHotels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Hotel, fields, params, fetchFirstPage, '/hotels');
    }
  }, {
    key: 'createHotel',
    value: function createHotel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/hotels', fields, params, Hotel, pathOverride);
    }
  }, {
    key: 'createItemsBatch',
    value: function createItemsBatch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/items_batch', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'createLocalizedItemsBatch',
    value: function createLocalizedItemsBatch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/localized_items_batch', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'createMarketPlacePartnerSellersDetail',
    value: function createMarketPlacePartnerSellersDetail(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/marketplace_partner_sellers_details', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'getPricingVariablesBatch',
    value: function getPricingVariablesBatch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalogPricingVariablesBatch, fields, params, fetchFirstPage, '/pricing_variables_batch');
    }
  }, {
    key: 'createPricingVariablesBatch',
    value: function createPricingVariablesBatch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/pricing_variables_batch', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'getProductFeeds',
    value: function getProductFeeds(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductFeed, fields, params, fetchFirstPage, '/product_feeds');
    }
  }, {
    key: 'createProductFeed',
    value: function createProductFeed(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/product_feeds', fields, params, ProductFeed, pathOverride);
    }
  }, {
    key: 'getProductGroups',
    value: function getProductGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductGroup, fields, params, fetchFirstPage, '/product_groups');
    }
  }, {
    key: 'createProductGroup',
    value: function createProductGroup(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/product_groups', fields, params, ProductGroup, pathOverride);
    }
  }, {
    key: 'getProductSets',
    value: function getProductSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductSet, fields, params, fetchFirstPage, '/product_sets');
    }
  }, {
    key: 'createProductSet',
    value: function createProductSet(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/product_sets', fields, params, ProductSet, pathOverride);
    }
  }, {
    key: 'getProductSetsBatch',
    value: function getProductSetsBatch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalogProductSetsBatch, fields, params, fetchFirstPage, '/product_sets_batch');
    }
  }, {
    key: 'getProducts',
    value: function getProducts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductItem, fields, params, fetchFirstPage, '/products');
    }
  }, {
    key: 'createProduct',
    value: function createProduct(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/products', fields, params, ProductItem, pathOverride);
    }
  }, {
    key: 'getVehicleOffers',
    value: function getVehicleOffers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(VehicleOffer, fields, params, fetchFirstPage, '/vehicle_offers');
    }
  }, {
    key: 'getVehicles',
    value: function getVehicles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Vehicle, fields, params, fetchFirstPage, '/vehicles');
    }
  }, {
    key: 'createVehicle',
    value: function createVehicle(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/vehicles', fields, params, Vehicle, pathOverride);
    }
  }, {
    key: 'createVersionItemsBatch',
    value: function createVersionItemsBatch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/version_items_batch', fields, params, ProductCatalog, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductCatalog.prototype.__proto__ || Object.getPrototypeOf(ProductCatalog.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ProductCatalog.prototype.__proto__ || Object.getPrototypeOf(ProductCatalog.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_to_collaborative_ads_share_settings: 'ad_account_to_collaborative_ads_share_settings',
        agency_collaborative_ads_share_settings: 'agency_collaborative_ads_share_settings',
        business: 'business',
        catalog_store: 'catalog_store',
        commerce_merchant_settings: 'commerce_merchant_settings',
        creator_user: 'creator_user',
        da_display_settings: 'da_display_settings',
        default_image_url: 'default_image_url',
        fallback_image_url: 'fallback_image_url',
        feed_count: 'feed_count',
        id: 'id',
        is_catalog_segment: 'is_catalog_segment',
        is_local_catalog: 'is_local_catalog',
        name: 'name',
        owner_business: 'owner_business',
        product_count: 'product_count',
        store_catalog_settings: 'store_catalog_settings',
        user_access_expire_time: 'user_access_expire_time',
        vertical: 'vertical'
      });
    }
  }, {
    key: 'AdditionalVerticalOption',
    get: function get() {
      return Object.freeze({
        local_da_catalog: 'LOCAL_DA_CATALOG',
        local_products: 'LOCAL_PRODUCTS'
      });
    }
  }, {
    key: 'Vertical',
    get: function get() {
      return Object.freeze({
        adoptable_pets: 'adoptable_pets',
        commerce: 'commerce',
        destinations: 'destinations',
        flights: 'flights',
        generic: 'generic',
        home_listings: 'home_listings',
        hotels: 'hotels',
        jobs: 'jobs',
        local_service_businesses: 'local_service_businesses',
        offer_items: 'offer_items',
        offline_commerce: 'offline_commerce',
        transactable_items: 'transactable_items',
        vehicles: 'vehicles'
      });
    }
  }, {
    key: 'PermittedRoles',
    get: function get() {
      return Object.freeze({
        admin: 'ADMIN',
        advertiser: 'ADVERTISER'
      });
    }
  }, {
    key: 'PermittedTasks',
    get: function get() {
      return Object.freeze({
        aa_analyze: 'AA_ANALYZE',
        advertise: 'ADVERTISE',
        manage: 'MANAGE',
        manage_ar: 'MANAGE_AR'
      });
    }
  }, {
    key: 'Tasks',
    get: function get() {
      return Object.freeze({
        aa_analyze: 'AA_ANALYZE',
        advertise: 'ADVERTISE',
        manage: 'MANAGE',
        manage_ar: 'MANAGE_AR'
      });
    }
  }, {
    key: 'Standard',
    get: function get() {
      return Object.freeze({
        google: 'google'
      });
    }
  }, {
    key: 'ItemSubType',
    get: function get() {
      return Object.freeze({
        appliances: 'APPLIANCES',
        baby_feeding: 'BABY_FEEDING',
        baby_transport: 'BABY_TRANSPORT',
        beauty: 'BEAUTY',
        bedding: 'BEDDING',
        cameras: 'CAMERAS',
        cell_phones_and_smart_watches: 'CELL_PHONES_AND_SMART_WATCHES',
        cleaning_supplies: 'CLEANING_SUPPLIES',
        clothing: 'CLOTHING',
        clothing_accessories: 'CLOTHING_ACCESSORIES',
        computers_and_tablets: 'COMPUTERS_AND_TABLETS',
        diapering_and_potty_training: 'DIAPERING_AND_POTTY_TRAINING',
        electronics_accessories: 'ELECTRONICS_ACCESSORIES',
        furniture: 'FURNITURE',
        health: 'HEALTH',
        home_goods: 'HOME_GOODS',
        jewelry: 'JEWELRY',
        nursery: 'NURSERY',
        printers_and_scanners: 'PRINTERS_AND_SCANNERS',
        projectors: 'PROJECTORS',
        shoes_and_footwear: 'SHOES_AND_FOOTWEAR',
        software: 'SOFTWARE',
        toys: 'TOYS',
        tvs_and_monitors: 'TVS_AND_MONITORS',
        video_game_consoles_and_video_games: 'VIDEO_GAME_CONSOLES_AND_VIDEO_GAMES',
        watches: 'WATCHES'
      });
    }
  }]);
  return ProductCatalog;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CommerceMerchantSettingsSetupStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CommerceMerchantSettingsSetupStatus = function (_AbstractCrudObject) {
  inherits(CommerceMerchantSettingsSetupStatus, _AbstractCrudObject);

  function CommerceMerchantSettingsSetupStatus() {
    classCallCheck(this, CommerceMerchantSettingsSetupStatus);
    return possibleConstructorReturn(this, (CommerceMerchantSettingsSetupStatus.__proto__ || Object.getPrototypeOf(CommerceMerchantSettingsSetupStatus)).apply(this, arguments));
  }

  createClass(CommerceMerchantSettingsSetupStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        deals_setup: 'deals_setup',
        marketplace_approval_status: 'marketplace_approval_status',
        marketplace_approval_status_details: 'marketplace_approval_status_details',
        payment_setup: 'payment_setup',
        review_status: 'review_status',
        shop_setup: 'shop_setup'
      });
    }
  }]);
  return CommerceMerchantSettingsSetupStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Shop
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Shop = function (_AbstractCrudObject) {
  inherits(Shop, _AbstractCrudObject);

  function Shop() {
    classCallCheck(this, Shop);
    return possibleConstructorReturn(this, (Shop.__proto__ || Object.getPrototypeOf(Shop)).apply(this, arguments));
  }

  createClass(Shop, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        commerce_merchant_settings: 'commerce_merchant_settings',
        fb_sales_channel: 'fb_sales_channel',
        id: 'id',
        ig_sales_channel: 'ig_sales_channel',
        is_onsite_enabled: 'is_onsite_enabled',
        shop_status: 'shop_status',
        workspace: 'workspace'
      });
    }
  }]);
  return Shop;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CommerceMerchantSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CommerceMerchantSettings = function (_AbstractCrudObject) {
  inherits(CommerceMerchantSettings, _AbstractCrudObject);

  function CommerceMerchantSettings() {
    classCallCheck(this, CommerceMerchantSettings);
    return possibleConstructorReturn(this, (CommerceMerchantSettings.__proto__ || Object.getPrototypeOf(CommerceMerchantSettings)).apply(this, arguments));
  }

  createClass(CommerceMerchantSettings, [{
    key: 'createAcknowledgeOrder',
    value: function createAcknowledgeOrder(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/acknowledge_orders', fields, params, CommerceMerchantSettings, pathOverride);
    }
  }, {
    key: 'getCommerceOrders',
    value: function getCommerceOrders(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommerceOrder, fields, params, fetchFirstPage, '/commerce_orders');
    }
  }, {
    key: 'getCommercePayouts',
    value: function getCommercePayouts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommercePayout, fields, params, fetchFirstPage, '/commerce_payouts');
    }
  }, {
    key: 'getCommerceTransactions',
    value: function getCommerceTransactions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommerceOrderTransactionDetail, fields, params, fetchFirstPage, '/commerce_transactions');
    }
  }, {
    key: 'getOrderManagementApps',
    value: function getOrderManagementApps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/order_management_apps');
    }
  }, {
    key: 'createOrderManagementApp',
    value: function createOrderManagementApp(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/order_management_apps', fields, params, CommerceMerchantSettings, pathOverride);
    }
  }, {
    key: 'getProductCatalogs',
    value: function getProductCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalog, fields, params, fetchFirstPage, '/product_catalogs');
    }
  }, {
    key: 'getReturns',
    value: function getReturns(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/returns');
    }
  }, {
    key: 'getSetupStatus',
    value: function getSetupStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommerceMerchantSettingsSetupStatus, fields, params, fetchFirstPage, '/setup_status');
    }
  }, {
    key: 'getShippingProfiles',
    value: function getShippingProfiles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/shipping_profiles');
    }
  }, {
    key: 'createShippingProfile',
    value: function createShippingProfile(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/shipping_profiles', fields, params, null, pathOverride);
    }
  }, {
    key: 'getShops',
    value: function getShops(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Shop, fields, params, fetchFirstPage, '/shops');
    }
  }, {
    key: 'getTaxSettings',
    value: function getTaxSettings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/tax_settings');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        checkout_message: 'checkout_message',
        contact_email: 'contact_email',
        cta: 'cta',
        display_name: 'display_name',
        facebook_channel: 'facebook_channel',
        id: 'id',
        instagram_channel: 'instagram_channel',
        merchant_page: 'merchant_page',
        merchant_status: 'merchant_status',
        onsite_commerce_merchant: 'onsite_commerce_merchant',
        payment_provider: 'payment_provider',
        review_rejection_messages: 'review_rejection_messages',
        review_rejection_reasons: 'review_rejection_reasons',
        terms: 'terms'
      });
    }
  }]);
  return CommerceMerchantSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UnifiedThread
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UnifiedThread = function (_AbstractCrudObject) {
  inherits(UnifiedThread, _AbstractCrudObject);

  function UnifiedThread() {
    classCallCheck(this, UnifiedThread);
    return possibleConstructorReturn(this, (UnifiedThread.__proto__ || Object.getPrototypeOf(UnifiedThread)).apply(this, arguments));
  }

  createClass(UnifiedThread, [{
    key: 'getMessages',
    value: function getMessages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/messages');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_reply: 'can_reply',
        folder: 'folder',
        former_participants: 'former_participants',
        id: 'id',
        is_subscribed: 'is_subscribed',
        link: 'link',
        linked_group: 'linked_group',
        message_count: 'message_count',
        name: 'name',
        participants: 'participants',
        scoped_thread_key: 'scoped_thread_key',
        senders: 'senders',
        snippet: 'snippet',
        subject: 'subject',
        unread_count: 'unread_count',
        updated_time: 'updated_time',
        wallpaper: 'wallpaper'
      });
    }
  }, {
    key: 'Platform',
    get: function get() {
      return Object.freeze({
        instagram: 'INSTAGRAM',
        messenger: 'MESSENGER'
      });
    }
  }]);
  return UnifiedThread;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoCopyrightMatch
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoCopyrightMatch = function (_AbstractCrudObject) {
  inherits(VideoCopyrightMatch, _AbstractCrudObject);

  function VideoCopyrightMatch() {
    classCallCheck(this, VideoCopyrightMatch);
    return possibleConstructorReturn(this, (VideoCopyrightMatch.__proto__ || Object.getPrototypeOf(VideoCopyrightMatch)).apply(this, arguments));
  }

  createClass(VideoCopyrightMatch, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        created_date: 'created_date',
        id: 'id',
        last_modified_user: 'last_modified_user',
        match_data: 'match_data',
        match_status: 'match_status',
        notes: 'notes',
        permalink: 'permalink'
      });
    }
  }, {
    key: 'Action',
    get: function get() {
      return Object.freeze({
        block: 'BLOCK',
        claim_ad_earnings: 'CLAIM_AD_EARNINGS',
        manual_review: 'MANUAL_REVIEW',
        monitor: 'MONITOR',
        request_takedown: 'REQUEST_TAKEDOWN'
      });
    }
  }, {
    key: 'ActionReason',
    get: function get() {
      return Object.freeze({
        article_17_preflagging: 'ARTICLE_17_PREFLAGGING',
        artist_objection: 'ARTIST_OBJECTION',
        objectionable_content: 'OBJECTIONABLE_CONTENT',
        premium_music_video: 'PREMIUM_MUSIC_VIDEO',
        prerelease_content: 'PRERELEASE_CONTENT',
        product_parameters: 'PRODUCT_PARAMETERS',
        restricted_content: 'RESTRICTED_CONTENT',
        unauthorized_commercial_use: 'UNAUTHORIZED_COMMERCIAL_USE'
      });
    }
  }, {
    key: 'MatchContentType',
    get: function get() {
      return Object.freeze({
        audio_only: 'AUDIO_ONLY',
        video_and_audio: 'VIDEO_AND_AUDIO',
        video_only: 'VIDEO_ONLY'
      });
    }
  }]);
  return VideoCopyrightMatch;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CTXOptimizationEligibility
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CTXOptimizationEligibility = function (_AbstractCrudObject) {
  inherits(CTXOptimizationEligibility, _AbstractCrudObject);

  function CTXOptimizationEligibility() {
    classCallCheck(this, CTXOptimizationEligibility);
    return possibleConstructorReturn(this, (CTXOptimizationEligibility.__proto__ || Object.getPrototypeOf(CTXOptimizationEligibility)).apply(this, arguments));
  }

  createClass(CTXOptimizationEligibility, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ctm: 'ctm'
      });
    }
  }]);
  return CTXOptimizationEligibility;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageUserMessageThreadLabel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageUserMessageThreadLabel = function (_AbstractCrudObject) {
  inherits(PageUserMessageThreadLabel, _AbstractCrudObject);

  function PageUserMessageThreadLabel() {
    classCallCheck(this, PageUserMessageThreadLabel);
    return possibleConstructorReturn(this, (PageUserMessageThreadLabel.__proto__ || Object.getPrototypeOf(PageUserMessageThreadLabel)).apply(this, arguments));
  }

  createClass(PageUserMessageThreadLabel, [{
    key: 'deleteLabel',
    value: function deleteLabel() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(PageUserMessageThreadLabel.prototype.__proto__ || Object.getPrototypeOf(PageUserMessageThreadLabel.prototype), 'deleteEdge', this).call(this, '/label', params);
    }
  }, {
    key: 'createLabel',
    value: function createLabel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/label', fields, params, PageUserMessageThreadLabel, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(PageUserMessageThreadLabel.prototype.__proto__ || Object.getPrototypeOf(PageUserMessageThreadLabel.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        page_label_name: 'page_label_name'
      });
    }
  }]);
  return PageUserMessageThreadLabel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomUserSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomUserSettings = function (_AbstractCrudObject) {
  inherits(CustomUserSettings, _AbstractCrudObject);

  function CustomUserSettings() {
    classCallCheck(this, CustomUserSettings);
    return possibleConstructorReturn(this, (CustomUserSettings.__proto__ || Object.getPrototypeOf(CustomUserSettings)).apply(this, arguments));
  }

  createClass(CustomUserSettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        page_level_persistent_menu: 'page_level_persistent_menu',
        user_level_persistent_menu: 'user_level_persistent_menu'
      });
    }
  }]);
  return CustomUserSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Dataset
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Dataset = function (_AbstractCrudObject) {
  inherits(Dataset, _AbstractCrudObject);

  function Dataset() {
    classCallCheck(this, Dataset);
    return possibleConstructorReturn(this, (Dataset.__proto__ || Object.getPrototypeOf(Dataset)).apply(this, arguments));
  }

  createClass(Dataset, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return Dataset;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * NullNode
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var NullNode = function (_AbstractCrudObject) {
  inherits(NullNode, _AbstractCrudObject);

  function NullNode() {
    classCallCheck(this, NullNode);
    return possibleConstructorReturn(this, (NullNode.__proto__ || Object.getPrototypeOf(NullNode)).apply(this, arguments));
  }

  createClass(NullNode, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return NullNode;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AppRequestFormerRecipient
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AppRequestFormerRecipient = function (_AbstractCrudObject) {
  inherits(AppRequestFormerRecipient, _AbstractCrudObject);

  function AppRequestFormerRecipient() {
    classCallCheck(this, AppRequestFormerRecipient);
    return possibleConstructorReturn(this, (AppRequestFormerRecipient.__proto__ || Object.getPrototypeOf(AppRequestFormerRecipient)).apply(this, arguments));
  }

  createClass(AppRequestFormerRecipient, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        recipient_id: 'recipient_id'
      });
    }
  }]);
  return AppRequestFormerRecipient;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AppRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AppRequest = function (_AbstractCrudObject) {
  inherits(AppRequest, _AbstractCrudObject);

  function AppRequest() {
    classCallCheck(this, AppRequest);
    return possibleConstructorReturn(this, (AppRequest.__proto__ || Object.getPrototypeOf(AppRequest)).apply(this, arguments));
  }

  createClass(AppRequest, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AppRequest.prototype.__proto__ || Object.getPrototypeOf(AppRequest.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action_type: 'action_type',
        application: 'application',
        created_time: 'created_time',
        data: 'data',
        from: 'from',
        id: 'id',
        message: 'message',
        object: 'object',
        to: 'to'
      });
    }
  }]);
  return AppRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomConversionStatsResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomConversionStatsResult = function (_AbstractCrudObject) {
  inherits(CustomConversionStatsResult, _AbstractCrudObject);

  function CustomConversionStatsResult() {
    classCallCheck(this, CustomConversionStatsResult);
    return possibleConstructorReturn(this, (CustomConversionStatsResult.__proto__ || Object.getPrototypeOf(CustomConversionStatsResult)).apply(this, arguments));
  }

  createClass(CustomConversionStatsResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        aggregation: 'aggregation',
        data: 'data',
        timestamp: 'timestamp'
      });
    }
  }, {
    key: 'Aggregation',
    get: function get() {
      return Object.freeze({
        count: 'count',
        device_type: 'device_type',
        host: 'host',
        pixel_fire: 'pixel_fire',
        unmatched_count: 'unmatched_count',
        unmatched_usd_amount: 'unmatched_usd_amount',
        url: 'url',
        usd_amount: 'usd_amount'
      });
    }
  }]);
  return CustomConversionStatsResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomConversion
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomConversion = function (_AbstractCrudObject) {
  inherits(CustomConversion, _AbstractCrudObject);

  function CustomConversion() {
    classCallCheck(this, CustomConversion);
    return possibleConstructorReturn(this, (CustomConversion.__proto__ || Object.getPrototypeOf(CustomConversion)).apply(this, arguments));
  }

  createClass(CustomConversion, [{
    key: 'getStats',
    value: function getStats(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomConversionStatsResult, fields, params, fetchFirstPage, '/stats');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(CustomConversion.prototype.__proto__ || Object.getPrototypeOf(CustomConversion.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(CustomConversion.prototype.__proto__ || Object.getPrototypeOf(CustomConversion.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        aggregation_rule: 'aggregation_rule',
        business: 'business',
        creation_time: 'creation_time',
        custom_event_type: 'custom_event_type',
        data_sources: 'data_sources',
        default_conversion_value: 'default_conversion_value',
        description: 'description',
        event_source_type: 'event_source_type',
        first_fired_time: 'first_fired_time',
        id: 'id',
        is_archived: 'is_archived',
        is_unavailable: 'is_unavailable',
        last_fired_time: 'last_fired_time',
        name: 'name',
        offline_conversion_data_set: 'offline_conversion_data_set',
        pixel: 'pixel',
        retention_days: 'retention_days',
        rule: 'rule'
      });
    }
  }, {
    key: 'CustomEventType',
    get: function get() {
      return Object.freeze({
        add_payment_info: 'ADD_PAYMENT_INFO',
        add_to_cart: 'ADD_TO_CART',
        add_to_wishlist: 'ADD_TO_WISHLIST',
        complete_registration: 'COMPLETE_REGISTRATION',
        contact: 'CONTACT',
        content_view: 'CONTENT_VIEW',
        customize_product: 'CUSTOMIZE_PRODUCT',
        donate: 'DONATE',
        facebook_selected: 'FACEBOOK_SELECTED',
        find_location: 'FIND_LOCATION',
        initiated_checkout: 'INITIATED_CHECKOUT',
        lead: 'LEAD',
        listing_interaction: 'LISTING_INTERACTION',
        other: 'OTHER',
        purchase: 'PURCHASE',
        schedule: 'SCHEDULE',
        search: 'SEARCH',
        start_trial: 'START_TRIAL',
        submit_application: 'SUBMIT_APPLICATION',
        subscribe: 'SUBSCRIBE'
      });
    }
  }, {
    key: 'ActionSourceType',
    get: function get() {
      return Object.freeze({
        app: 'app',
        business_messaging: 'business_messaging',
        chat: 'chat',
        email: 'email',
        other: 'other',
        phone_call: 'phone_call',
        physical_store: 'physical_store',
        system_generated: 'system_generated',
        website: 'website'
      });
    }
  }]);
  return CustomConversion;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGUpcomingEvent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGUpcomingEvent = function (_AbstractCrudObject) {
  inherits(IGUpcomingEvent, _AbstractCrudObject);

  function IGUpcomingEvent() {
    classCallCheck(this, IGUpcomingEvent);
    return possibleConstructorReturn(this, (IGUpcomingEvent.__proto__ || Object.getPrototypeOf(IGUpcomingEvent)).apply(this, arguments));
  }

  createClass(IGUpcomingEvent, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(IGUpcomingEvent.prototype.__proto__ || Object.getPrototypeOf(IGUpcomingEvent.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        end_time: 'end_time',
        id: 'id',
        notification_subtypes: 'notification_subtypes',
        notification_target_time: 'notification_target_time',
        start_time: 'start_time',
        title: 'title'
      });
    }
  }, {
    key: 'NotificationSubtypes',
    get: function get() {
      return Object.freeze({
        after_event_1day: 'AFTER_EVENT_1DAY',
        after_event_2day: 'AFTER_EVENT_2DAY',
        after_event_3day: 'AFTER_EVENT_3DAY',
        after_event_4day: 'AFTER_EVENT_4DAY',
        after_event_5day: 'AFTER_EVENT_5DAY',
        after_event_6day: 'AFTER_EVENT_6DAY',
        after_event_7day: 'AFTER_EVENT_7DAY',
        before_event_15min: 'BEFORE_EVENT_15MIN',
        before_event_1day: 'BEFORE_EVENT_1DAY',
        before_event_1hour: 'BEFORE_EVENT_1HOUR',
        before_event_2day: 'BEFORE_EVENT_2DAY',
        event_start: 'EVENT_START',
        rescheduled: 'RESCHEDULED'
      });
    }
  }, {
    key: 'NotificationTargetTime',
    get: function get() {
      return Object.freeze({
        event_end: 'EVENT_END',
        event_start: 'EVENT_START'
      });
    }
  }]);
  return IGUpcomingEvent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramUser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramUser = function (_AbstractCrudObject) {
  inherits(InstagramUser, _AbstractCrudObject);

  function InstagramUser() {
    classCallCheck(this, InstagramUser);
    return possibleConstructorReturn(this, (InstagramUser.__proto__ || Object.getPrototypeOf(InstagramUser)).apply(this, arguments));
  }

  createClass(InstagramUser, [{
    key: 'getAgencies',
    value: function getAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/agencies');
    }
  }, {
    key: 'getArEffects',
    value: function getArEffects(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AREffect, fields, params, fetchFirstPage, '/ar_effects');
    }
  }, {
    key: 'getAuthorizedAdAccounts',
    value: function getAuthorizedAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/authorized_adaccounts');
    }
  }, {
    key: 'createAuthorizedAdAccount',
    value: function createAuthorizedAdAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/authorized_adaccounts', fields, params, InstagramUser, pathOverride);
    }
  }, {
    key: 'getUpcomingEvents',
    value: function getUpcomingEvents(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGUpcomingEvent, fields, params, fetchFirstPage, '/upcoming_events');
    }
  }, {
    key: 'createUpcomingEvent',
    value: function createUpcomingEvent(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/upcoming_events', fields, params, IGUpcomingEvent, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        follow_count: 'follow_count',
        followed_by_count: 'followed_by_count',
        has_profile_picture: 'has_profile_picture',
        id: 'id',
        is_private: 'is_private',
        is_published: 'is_published',
        media_count: 'media_count',
        mini_shop_storefront: 'mini_shop_storefront',
        owner_business: 'owner_business',
        profile_pic: 'profile_pic',
        username: 'username'
      });
    }
  }]);
  return InstagramUser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessAssetGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessAssetGroup = function (_AbstractCrudObject) {
  inherits(BusinessAssetGroup, _AbstractCrudObject);

  function BusinessAssetGroup() {
    classCallCheck(this, BusinessAssetGroup);
    return possibleConstructorReturn(this, (BusinessAssetGroup.__proto__ || Object.getPrototypeOf(BusinessAssetGroup)).apply(this, arguments));
  }

  createClass(BusinessAssetGroup, [{
    key: 'deleteAssignedUsers',
    value: function deleteAssignedUsers() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(BusinessAssetGroup.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetGroup.prototype), 'deleteEdge', this).call(this, '/assigned_users', params);
    }
  }, {
    key: 'getAssignedUsers',
    value: function getAssignedUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AssignedUser, fields, params, fetchFirstPage, '/assigned_users');
    }
  }, {
    key: 'createAssignedUser',
    value: function createAssignedUser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/assigned_users', fields, params, BusinessAssetGroup, pathOverride);
    }
  }, {
    key: 'deleteContainedAdAccounts',
    value: function deleteContainedAdAccounts() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(BusinessAssetGroup.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetGroup.prototype), 'deleteEdge', this).call(this, '/contained_adaccounts', params);
    }
  }, {
    key: 'getContainedAdAccounts',
    value: function getContainedAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/contained_adaccounts');
    }
  }, {
    key: 'createContainedAdAccount',
    value: function createContainedAdAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/contained_adaccounts', fields, params, BusinessAssetGroup, pathOverride);
    }
  }, {
    key: 'deleteContainedApplications',
    value: function deleteContainedApplications() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(BusinessAssetGroup.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetGroup.prototype), 'deleteEdge', this).call(this, '/contained_applications', params);
    }
  }, {
    key: 'getContainedApplications',
    value: function getContainedApplications(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/contained_applications');
    }
  }, {
    key: 'createContainedApplication',
    value: function createContainedApplication(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/contained_applications', fields, params, BusinessAssetGroup, pathOverride);
    }
  }, {
    key: 'deleteContainedCustomConversions',
    value: function deleteContainedCustomConversions() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(BusinessAssetGroup.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetGroup.prototype), 'deleteEdge', this).call(this, '/contained_custom_conversions', params);
    }
  }, {
    key: 'getContainedCustomConversions',
    value: function getContainedCustomConversions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomConversion, fields, params, fetchFirstPage, '/contained_custom_conversions');
    }
  }, {
    key: 'createContainedCustomConversion',
    value: function createContainedCustomConversion(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/contained_custom_conversions', fields, params, BusinessAssetGroup, pathOverride);
    }
  }, {
    key: 'deleteContainedInstagramAccounts',
    value: function deleteContainedInstagramAccounts() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(BusinessAssetGroup.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetGroup.prototype), 'deleteEdge', this).call(this, '/contained_instagram_accounts', params);
    }
  }, {
    key: 'getContainedInstagramAccounts',
    value: function getContainedInstagramAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramUser, fields, params, fetchFirstPage, '/contained_instagram_accounts');
    }
  }, {
    key: 'createContainedInstagramAccount',
    value: function createContainedInstagramAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/contained_instagram_accounts', fields, params, BusinessAssetGroup, pathOverride);
    }
  }, {
    key: 'deleteContainedPages',
    value: function deleteContainedPages() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(BusinessAssetGroup.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetGroup.prototype), 'deleteEdge', this).call(this, '/contained_pages', params);
    }
  }, {
    key: 'getContainedPages',
    value: function getContainedPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/contained_pages');
    }
  }, {
    key: 'createContainedPage',
    value: function createContainedPage(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/contained_pages', fields, params, BusinessAssetGroup, pathOverride);
    }
  }, {
    key: 'deleteContainedPixels',
    value: function deleteContainedPixels() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(BusinessAssetGroup.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetGroup.prototype), 'deleteEdge', this).call(this, '/contained_pixels', params);
    }
  }, {
    key: 'getContainedPixels',
    value: function getContainedPixels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsPixel, fields, params, fetchFirstPage, '/contained_pixels');
    }
  }, {
    key: 'createContainedPixel',
    value: function createContainedPixel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/contained_pixels', fields, params, BusinessAssetGroup, pathOverride);
    }
  }, {
    key: 'deleteContainedProductCatalogs',
    value: function deleteContainedProductCatalogs() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(BusinessAssetGroup.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetGroup.prototype), 'deleteEdge', this).call(this, '/contained_product_catalogs', params);
    }
  }, {
    key: 'getContainedProductCatalogs',
    value: function getContainedProductCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalog, fields, params, fetchFirstPage, '/contained_product_catalogs');
    }
  }, {
    key: 'createContainedProductCatalog',
    value: function createContainedProductCatalog(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/contained_product_catalogs', fields, params, BusinessAssetGroup, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(BusinessAssetGroup.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetGroup.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        owner_business: 'owner_business'
      });
    }
  }, {
    key: 'AdaccountTasks',
    get: function get() {
      return Object.freeze({
        aa_analyze: 'AA_ANALYZE',
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        draft: 'DRAFT',
        manage: 'MANAGE'
      });
    }
  }, {
    key: 'OfflineConversionDataSetTasks',
    get: function get() {
      return Object.freeze({
        aa_analyze: 'AA_ANALYZE',
        advertise: 'ADVERTISE',
        manage: 'MANAGE',
        upload: 'UPLOAD',
        view: 'VIEW'
      });
    }
  }, {
    key: 'PageTasks',
    get: function get() {
      return Object.freeze({
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        cashier_role: 'CASHIER_ROLE',
        create_content: 'CREATE_CONTENT',
        manage: 'MANAGE',
        manage_jobs: 'MANAGE_JOBS',
        manage_leads: 'MANAGE_LEADS',
        messaging: 'MESSAGING',
        moderate: 'MODERATE',
        moderate_community: 'MODERATE_COMMUNITY',
        pages_messaging: 'PAGES_MESSAGING',
        pages_messaging_subscriptions: 'PAGES_MESSAGING_SUBSCRIPTIONS',
        profile_plus_advertise: 'PROFILE_PLUS_ADVERTISE',
        profile_plus_analyze: 'PROFILE_PLUS_ANALYZE',
        profile_plus_create_content: 'PROFILE_PLUS_CREATE_CONTENT',
        profile_plus_facebook_access: 'PROFILE_PLUS_FACEBOOK_ACCESS',
        profile_plus_full_control: 'PROFILE_PLUS_FULL_CONTROL',
        profile_plus_manage: 'PROFILE_PLUS_MANAGE',
        profile_plus_manage_leads: 'PROFILE_PLUS_MANAGE_LEADS',
        profile_plus_messaging: 'PROFILE_PLUS_MESSAGING',
        profile_plus_moderate: 'PROFILE_PLUS_MODERATE',
        profile_plus_moderate_delegate_community: 'PROFILE_PLUS_MODERATE_DELEGATE_COMMUNITY',
        profile_plus_revenue: 'PROFILE_PLUS_REVENUE',
        read_page_mailboxes: 'READ_PAGE_MAILBOXES',
        view_monetization_insights: 'VIEW_MONETIZATION_INSIGHTS'
      });
    }
  }, {
    key: 'PixelTasks',
    get: function get() {
      return Object.freeze({
        aa_analyze: 'AA_ANALYZE',
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        edit: 'EDIT',
        upload: 'UPLOAD'
      });
    }
  }]);
  return BusinessAssetGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Avatar
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Avatar = function (_AbstractCrudObject) {
  inherits(Avatar, _AbstractCrudObject);

  function Avatar() {
    classCallCheck(this, Avatar);
    return possibleConstructorReturn(this, (Avatar.__proto__ || Object.getPrototypeOf(Avatar)).apply(this, arguments));
  }

  createClass(Avatar, [{
    key: 'getModels',
    value: function getModels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/models');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return Avatar;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessUser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessUser = function (_AbstractCrudObject) {
  inherits(BusinessUser, _AbstractCrudObject);

  function BusinessUser() {
    classCallCheck(this, BusinessUser);
    return possibleConstructorReturn(this, (BusinessUser.__proto__ || Object.getPrototypeOf(BusinessUser)).apply(this, arguments));
  }

  createClass(BusinessUser, [{
    key: 'getAssignedAdAccounts',
    value: function getAssignedAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/assigned_ad_accounts');
    }
  }, {
    key: 'getAssignedBusinessAssetGroups',
    value: function getAssignedBusinessAssetGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessAssetGroup, fields, params, fetchFirstPage, '/assigned_business_asset_groups');
    }
  }, {
    key: 'getAssignedPages',
    value: function getAssignedPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/assigned_pages');
    }
  }, {
    key: 'getAssignedProductCatalogs',
    value: function getAssignedProductCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalog, fields, params, fetchFirstPage, '/assigned_product_catalogs');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(BusinessUser.prototype.__proto__ || Object.getPrototypeOf(BusinessUser.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(BusinessUser.prototype.__proto__ || Object.getPrototypeOf(BusinessUser.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        business_role_request: 'business_role_request',
        email: 'email',
        finance_permission: 'finance_permission',
        first_name: 'first_name',
        id: 'id',
        ip_permission: 'ip_permission',
        last_name: 'last_name',
        marked_for_removal: 'marked_for_removal',
        name: 'name',
        pending_email: 'pending_email',
        role: 'role',
        title: 'title',
        two_fac_status: 'two_fac_status'
      });
    }
  }, {
    key: 'InvitedUserType',
    get: function get() {
      return Object.freeze({
        fb: 'FB',
        mwa: 'MWA'
      });
    }
  }, {
    key: 'Role',
    get: function get() {
      return Object.freeze({
        admin: 'ADMIN',
        ads_rights_reviewer: 'ADS_RIGHTS_REVIEWER',
        default: 'DEFAULT',
        developer: 'DEVELOPER',
        employee: 'EMPLOYEE',
        finance_analyst: 'FINANCE_ANALYST',
        finance_edit: 'FINANCE_EDIT',
        finance_editor: 'FINANCE_EDITOR',
        finance_view: 'FINANCE_VIEW',
        manage: 'MANAGE',
        partner_center_admin: 'PARTNER_CENTER_ADMIN',
        partner_center_analyst: 'PARTNER_CENTER_ANALYST',
        partner_center_education: 'PARTNER_CENTER_EDUCATION',
        partner_center_marketing: 'PARTNER_CENTER_MARKETING',
        partner_center_operations: 'PARTNER_CENTER_OPERATIONS'
      });
    }
  }]);
  return BusinessUser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FundraiserPersonToCharity
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FundraiserPersonToCharity = function (_AbstractCrudObject) {
  inherits(FundraiserPersonToCharity, _AbstractCrudObject);

  function FundraiserPersonToCharity() {
    classCallCheck(this, FundraiserPersonToCharity);
    return possibleConstructorReturn(this, (FundraiserPersonToCharity.__proto__ || Object.getPrototypeOf(FundraiserPersonToCharity)).apply(this, arguments));
  }

  createClass(FundraiserPersonToCharity, [{
    key: 'getDonations',
    value: function getDonations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/donations');
    }
  }, {
    key: 'createEndFundraiser',
    value: function createEndFundraiser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/end_fundraiser', fields, params, null, pathOverride);
    }
  }, {
    key: 'getExternalDonations',
    value: function getExternalDonations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/external_donations');
    }
  }, {
    key: 'createExternalDonation',
    value: function createExternalDonation(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/external_donations', fields, params, null, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(FundraiserPersonToCharity.prototype.__proto__ || Object.getPrototypeOf(FundraiserPersonToCharity.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount_raised: 'amount_raised',
        charity_id: 'charity_id',
        currency: 'currency',
        description: 'description',
        donations_count: 'donations_count',
        donors_count: 'donors_count',
        end_time: 'end_time',
        external_amount_raised: 'external_amount_raised',
        external_donations_count: 'external_donations_count',
        external_donors_count: 'external_donors_count',
        external_event_name: 'external_event_name',
        external_event_start_time: 'external_event_start_time',
        external_event_uri: 'external_event_uri',
        external_fundraiser_uri: 'external_fundraiser_uri',
        external_id: 'external_id',
        goal_amount: 'goal_amount',
        id: 'id',
        internal_amount_raised: 'internal_amount_raised',
        internal_donations_count: 'internal_donations_count',
        internal_donors_count: 'internal_donors_count',
        name: 'name',
        uri: 'uri'
      });
    }
  }, {
    key: 'FundraiserType',
    get: function get() {
      return Object.freeze({
        person_for_charity: 'person_for_charity'
      });
    }
  }]);
  return FundraiserPersonToCharity;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserIDForApp
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserIDForApp = function (_AbstractCrudObject) {
  inherits(UserIDForApp, _AbstractCrudObject);

  function UserIDForApp() {
    classCallCheck(this, UserIDForApp);
    return possibleConstructorReturn(this, (UserIDForApp.__proto__ || Object.getPrototypeOf(UserIDForApp)).apply(this, arguments));
  }

  createClass(UserIDForApp, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app: 'app',
        id: 'id'
      });
    }
  }]);
  return UserIDForApp;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserIDForPage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserIDForPage = function (_AbstractCrudObject) {
  inherits(UserIDForPage, _AbstractCrudObject);

  function UserIDForPage() {
    classCallCheck(this, UserIDForPage);
    return possibleConstructorReturn(this, (UserIDForPage.__proto__ || Object.getPrototypeOf(UserIDForPage)).apply(this, arguments));
  }

  createClass(UserIDForPage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        page: 'page'
      });
    }
  }]);
  return UserIDForPage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PaymentEnginePayment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PaymentEnginePayment = function (_AbstractCrudObject) {
  inherits(PaymentEnginePayment, _AbstractCrudObject);

  function PaymentEnginePayment() {
    classCallCheck(this, PaymentEnginePayment);
    return possibleConstructorReturn(this, (PaymentEnginePayment.__proto__ || Object.getPrototypeOf(PaymentEnginePayment)).apply(this, arguments));
  }

  createClass(PaymentEnginePayment, [{
    key: 'createDispute',
    value: function createDispute(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/dispute', fields, params, PaymentEnginePayment, pathOverride);
    }
  }, {
    key: 'createRefund',
    value: function createRefund(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/refunds', fields, params, PaymentEnginePayment, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actions: 'actions',
        application: 'application',
        country: 'country',
        created_time: 'created_time',
        disputes: 'disputes',
        fraud_status: 'fraud_status',
        fulfillment_status: 'fulfillment_status',
        id: 'id',
        is_from_ad: 'is_from_ad',
        is_from_page_post: 'is_from_page_post',
        items: 'items',
        payout_foreign_exchange_rate: 'payout_foreign_exchange_rate',
        phone_support_eligible: 'phone_support_eligible',
        platform: 'platform',
        refundable_amount: 'refundable_amount',
        request_id: 'request_id',
        tax: 'tax',
        tax_country: 'tax_country',
        test: 'test',
        user: 'user'
      });
    }
  }, {
    key: 'Reason',
    get: function get() {
      return Object.freeze({
        banned_user: 'BANNED_USER',
        denied_refund: 'DENIED_REFUND',
        granted_replacement_item: 'GRANTED_REPLACEMENT_ITEM'
      });
    }
  }]);
  return PaymentEnginePayment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Permission
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Permission = function (_AbstractCrudObject) {
  inherits(Permission, _AbstractCrudObject);

  function Permission() {
    classCallCheck(this, Permission);
    return possibleConstructorReturn(this, (Permission.__proto__ || Object.getPrototypeOf(Permission)).apply(this, arguments));
  }

  createClass(Permission, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        permission: 'permission',
        status: 'status'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        declined: 'declined',
        expired: 'expired',
        granted: 'granted'
      });
    }
  }]);
  return Permission;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * User
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var User = function (_AbstractCrudObject) {
  inherits(User, _AbstractCrudObject);

  function User() {
    classCallCheck(this, User);
    return possibleConstructorReturn(this, (User.__proto__ || Object.getPrototypeOf(User)).apply(this, arguments));
  }

  createClass(User, [{
    key: 'deleteAccessTokens',
    value: function deleteAccessTokens() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(User.prototype.__proto__ || Object.getPrototypeOf(User.prototype), 'deleteEdge', this).call(this, '/access_tokens', params);
    }
  }, {
    key: 'createAccessToken',
    value: function createAccessToken(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/access_tokens', fields, params, User, pathOverride);
    }
  }, {
    key: 'getAccounts',
    value: function getAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/accounts');
    }
  }, {
    key: 'createAccount',
    value: function createAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/accounts', fields, params, null, pathOverride);
    }
  }, {
    key: 'getAdStudies',
    value: function getAdStudies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdStudy, fields, params, fetchFirstPage, '/ad_studies');
    }
  }, {
    key: 'createAdStudy',
    value: function createAdStudy(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/ad_studies', fields, params, AdStudy, pathOverride);
    }
  }, {
    key: 'getAdAccounts',
    value: function getAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/adaccounts');
    }
  }, {
    key: 'getAlbums',
    value: function getAlbums(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Album, fields, params, fetchFirstPage, '/albums');
    }
  }, {
    key: 'createApplication',
    value: function createApplication(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/applications', fields, params, User, pathOverride);
    }
  }, {
    key: 'getAppRequestFormerRecipients',
    value: function getAppRequestFormerRecipients(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AppRequestFormerRecipient, fields, params, fetchFirstPage, '/apprequestformerrecipients');
    }
  }, {
    key: 'getAppRequests',
    value: function getAppRequests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AppRequest, fields, params, fetchFirstPage, '/apprequests');
    }
  }, {
    key: 'getAssignedAdAccounts',
    value: function getAssignedAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/assigned_ad_accounts');
    }
  }, {
    key: 'getAssignedApplications',
    value: function getAssignedApplications(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/assigned_applications');
    }
  }, {
    key: 'getAssignedBusinessAssetGroups',
    value: function getAssignedBusinessAssetGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessAssetGroup, fields, params, fetchFirstPage, '/assigned_business_asset_groups');
    }
  }, {
    key: 'getAssignedPages',
    value: function getAssignedPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/assigned_pages');
    }
  }, {
    key: 'getAssignedProductCatalogs',
    value: function getAssignedProductCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalog, fields, params, fetchFirstPage, '/assigned_product_catalogs');
    }
  }, {
    key: 'getAvatars',
    value: function getAvatars(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Avatar, fields, params, fetchFirstPage, '/avatars');
    }
  }, {
    key: 'getBusinessUsers',
    value: function getBusinessUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessUser, fields, params, fetchFirstPage, '/business_users');
    }
  }, {
    key: 'deleteBusinesses',
    value: function deleteBusinesses() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(User.prototype.__proto__ || Object.getPrototypeOf(User.prototype), 'deleteEdge', this).call(this, '/businesses', params);
    }
  }, {
    key: 'getBusinesses',
    value: function getBusinesses(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/businesses');
    }
  }, {
    key: 'createBusiness',
    value: function createBusiness(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/businesses', fields, params, Business, pathOverride);
    }
  }, {
    key: 'getConversations',
    value: function getConversations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UnifiedThread, fields, params, fetchFirstPage, '/conversations');
    }
  }, {
    key: 'getCustomLabels',
    value: function getCustomLabels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PageUserMessageThreadLabel, fields, params, fetchFirstPage, '/custom_labels');
    }
  }, {
    key: 'getEvents',
    value: function getEvents(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Event, fields, params, fetchFirstPage, '/events');
    }
  }, {
    key: 'getFeed',
    value: function getFeed(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Post, fields, params, fetchFirstPage, '/feed');
    }
  }, {
    key: 'createFeed',
    value: function createFeed(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/feed', fields, params, Post, pathOverride);
    }
  }, {
    key: 'getFriends',
    value: function getFriends(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(User, fields, params, fetchFirstPage, '/friends');
    }
  }, {
    key: 'getFundraisers',
    value: function getFundraisers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(FundraiserPersonToCharity, fields, params, fetchFirstPage, '/fundraisers');
    }
  }, {
    key: 'createFundraiser',
    value: function createFundraiser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/fundraisers', fields, params, FundraiserPersonToCharity, pathOverride);
    }
  }, {
    key: 'getGroups',
    value: function getGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Group, fields, params, fetchFirstPage, '/groups');
    }
  }, {
    key: 'getIdsForApps',
    value: function getIdsForApps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UserIDForApp, fields, params, fetchFirstPage, '/ids_for_apps');
    }
  }, {
    key: 'getIdsForBusiness',
    value: function getIdsForBusiness(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UserIDForApp, fields, params, fetchFirstPage, '/ids_for_business');
    }
  }, {
    key: 'getIdsForPages',
    value: function getIdsForPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UserIDForPage, fields, params, fetchFirstPage, '/ids_for_pages');
    }
  }, {
    key: 'getLikes',
    value: function getLikes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/likes');
    }
  }, {
    key: 'getLiveVideos',
    value: function getLiveVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(LiveVideo, fields, params, fetchFirstPage, '/live_videos');
    }
  }, {
    key: 'createLiveVideo',
    value: function createLiveVideo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/live_videos', fields, params, LiveVideo, pathOverride);
    }
  }, {
    key: 'createMessengerDesktopPerformanceTrace',
    value: function createMessengerDesktopPerformanceTrace(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/messenger_desktop_performance_traces', fields, params, User, pathOverride);
    }
  }, {
    key: 'getMusic',
    value: function getMusic(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/music');
    }
  }, {
    key: 'createNotification',
    value: function createNotification(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/notifications', fields, params, User, pathOverride);
    }
  }, {
    key: 'getPaymentTransactions',
    value: function getPaymentTransactions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PaymentEnginePayment, fields, params, fetchFirstPage, '/payment_transactions');
    }
  }, {
    key: 'deletePermissions',
    value: function deletePermissions() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(User.prototype.__proto__ || Object.getPrototypeOf(User.prototype), 'deleteEdge', this).call(this, '/permissions', params);
    }
  }, {
    key: 'getPermissions',
    value: function getPermissions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Permission, fields, params, fetchFirstPage, '/permissions');
    }
  }, {
    key: 'getPersonalAdAccounts',
    value: function getPersonalAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/personal_ad_accounts');
    }
  }, {
    key: 'getPhotos',
    value: function getPhotos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Photo, fields, params, fetchFirstPage, '/photos');
    }
  }, {
    key: 'createPhoto',
    value: function createPhoto(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/photos', fields, params, Photo, pathOverride);
    }
  }, {
    key: 'getPicture',
    value: function getPicture(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProfilePictureSource, fields, params, fetchFirstPage, '/picture');
    }
  }, {
    key: 'getPosts',
    value: function getPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Post, fields, params, fetchFirstPage, '/posts');
    }
  }, {
    key: 'getRichMediaDocuments',
    value: function getRichMediaDocuments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Canvas, fields, params, fetchFirstPage, '/rich_media_documents');
    }
  }, {
    key: 'createStagingResource',
    value: function createStagingResource(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/staging_resources', fields, params, User, pathOverride);
    }
  }, {
    key: 'getVideos',
    value: function getVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdVideo, fields, params, fetchFirstPage, '/videos');
    }
  }, {
    key: 'createVideo',
    value: function createVideo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/videos', fields, params, AdVideo, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(User.prototype.__proto__ || Object.getPrototypeOf(User.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(User.prototype.__proto__ || Object.getPrototypeOf(User.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        about: 'about',
        age_range: 'age_range',
        avatar_2d_profile_picture: 'avatar_2d_profile_picture',
        birthday: 'birthday',
        community: 'community',
        cover: 'cover',
        currency: 'currency',
        education: 'education',
        email: 'email',
        favorite_athletes: 'favorite_athletes',
        favorite_teams: 'favorite_teams',
        first_name: 'first_name',
        gender: 'gender',
        hometown: 'hometown',
        id: 'id',
        id_for_avatars: 'id_for_avatars',
        inspirational_people: 'inspirational_people',
        install_type: 'install_type',
        installed: 'installed',
        is_guest_user: 'is_guest_user',
        is_work_account: 'is_work_account',
        languages: 'languages',
        last_name: 'last_name',
        link: 'link',
        local_news_megaphone_dismiss_status: 'local_news_megaphone_dismiss_status',
        local_news_subscription_status: 'local_news_subscription_status',
        locale: 'locale',
        location: 'location',
        meeting_for: 'meeting_for',
        middle_name: 'middle_name',
        name: 'name',
        name_format: 'name_format',
        payment_pricepoints: 'payment_pricepoints',
        political: 'political',
        profile_pic: 'profile_pic',
        quotes: 'quotes',
        relationship_status: 'relationship_status',
        shared_login_upgrade_required_by: 'shared_login_upgrade_required_by',
        short_name: 'short_name',
        significant_other: 'significant_other',
        sports: 'sports',
        supports_donate_button_in_live_video: 'supports_donate_button_in_live_video',
        third_party_id: 'third_party_id',
        timezone: 'timezone',
        token_for_business: 'token_for_business',
        updated_time: 'updated_time',
        verified: 'verified',
        video_upload_limits: 'video_upload_limits',
        website: 'website'
      });
    }
  }, {
    key: 'LocalNewsMegaphoneDismissStatus',
    get: function get() {
      return Object.freeze({
        no: 'NO',
        yes: 'YES'
      });
    }
  }, {
    key: 'LocalNewsSubscriptionStatus',
    get: function get() {
      return Object.freeze({
        status_off: 'STATUS_OFF',
        status_on: 'STATUS_ON'
      });
    }
  }, {
    key: 'Filtering',
    get: function get() {
      return Object.freeze({
        ema: 'ema',
        groups: 'groups',
        groups_social: 'groups_social'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        content_update: 'content_update',
        generic: 'generic'
      });
    }
  }]);
  return User;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LiveVideoError
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LiveVideoError = function (_AbstractCrudObject) {
  inherits(LiveVideoError, _AbstractCrudObject);

  function LiveVideoError() {
    classCallCheck(this, LiveVideoError);
    return possibleConstructorReturn(this, (LiveVideoError.__proto__ || Object.getPrototypeOf(LiveVideoError)).apply(this, arguments));
  }

  createClass(LiveVideoError, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        error_code: 'error_code',
        error_message: 'error_message',
        error_type: 'error_type',
        id: 'id'
      });
    }
  }]);
  return LiveVideoError;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LiveVideoInputStream
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LiveVideoInputStream = function (_AbstractCrudObject) {
  inherits(LiveVideoInputStream, _AbstractCrudObject);

  function LiveVideoInputStream() {
    classCallCheck(this, LiveVideoInputStream);
    return possibleConstructorReturn(this, (LiveVideoInputStream.__proto__ || Object.getPrototypeOf(LiveVideoInputStream)).apply(this, arguments));
  }

  createClass(LiveVideoInputStream, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        dash_ingest_url: 'dash_ingest_url',
        dash_preview_url: 'dash_preview_url',
        id: 'id',
        is_master: 'is_master',
        secure_stream_url: 'secure_stream_url',
        stream_health: 'stream_health',
        stream_id: 'stream_id',
        stream_url: 'stream_url'
      });
    }
  }]);
  return LiveVideoInputStream;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoPoll
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoPoll = function (_AbstractCrudObject) {
  inherits(VideoPoll, _AbstractCrudObject);

  function VideoPoll() {
    classCallCheck(this, VideoPoll);
    return possibleConstructorReturn(this, (VideoPoll.__proto__ || Object.getPrototypeOf(VideoPoll)).apply(this, arguments));
  }

  createClass(VideoPoll, [{
    key: 'getPollOptions',
    value: function getPollOptions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/poll_options');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(VideoPoll.prototype.__proto__ || Object.getPrototypeOf(VideoPoll.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        close_after_voting: 'close_after_voting',
        default_open: 'default_open',
        id: 'id',
        question: 'question',
        show_gradient: 'show_gradient',
        show_results: 'show_results',
        status: 'status'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        closed: 'closed',
        results_open: 'results_open',
        voting_open: 'voting_open'
      });
    }
  }, {
    key: 'Action',
    get: function get() {
      return Object.freeze({
        attach_to_video: 'ATTACH_TO_VIDEO',
        close: 'CLOSE',
        delete_poll: 'DELETE_POLL',
        show_results: 'SHOW_RESULTS',
        show_voting: 'SHOW_VOTING'
      });
    }
  }]);
  return VideoPoll;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LiveVideo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LiveVideo = function (_AbstractCrudObject) {
  inherits(LiveVideo, _AbstractCrudObject);

  function LiveVideo() {
    classCallCheck(this, LiveVideo);
    return possibleConstructorReturn(this, (LiveVideo.__proto__ || Object.getPrototypeOf(LiveVideo)).apply(this, arguments));
  }

  createClass(LiveVideo, [{
    key: 'getBlockedUsers',
    value: function getBlockedUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(User, fields, params, fetchFirstPage, '/blocked_users');
    }
  }, {
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Comment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'getCrosspostSharedPages',
    value: function getCrosspostSharedPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/crosspost_shared_pages');
    }
  }, {
    key: 'getCrosspostedBroadcasts',
    value: function getCrosspostedBroadcasts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(LiveVideo, fields, params, fetchFirstPage, '/crossposted_broadcasts');
    }
  }, {
    key: 'getErrors',
    value: function getErrors(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(LiveVideoError, fields, params, fetchFirstPage, '/errors');
    }
  }, {
    key: 'createInputStream',
    value: function createInputStream(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/input_streams', fields, params, LiveVideoInputStream, pathOverride);
    }
  }, {
    key: 'getPolls',
    value: function getPolls(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(VideoPoll, fields, params, fetchFirstPage, '/polls');
    }
  }, {
    key: 'createPoll',
    value: function createPoll(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/polls', fields, params, VideoPoll, pathOverride);
    }
  }, {
    key: 'getReactions',
    value: function getReactions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/reactions');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(LiveVideo.prototype.__proto__ || Object.getPrototypeOf(LiveVideo.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(LiveVideo.prototype.__proto__ || Object.getPrototypeOf(LiveVideo.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_break_config: 'ad_break_config',
        ad_break_failure_reason: 'ad_break_failure_reason',
        broadcast_start_time: 'broadcast_start_time',
        copyright: 'copyright',
        creation_time: 'creation_time',
        dash_ingest_url: 'dash_ingest_url',
        dash_preview_url: 'dash_preview_url',
        description: 'description',
        embed_html: 'embed_html',
        from: 'from',
        id: 'id',
        ingest_streams: 'ingest_streams',
        is_manual_mode: 'is_manual_mode',
        is_reference_only: 'is_reference_only',
        live_views: 'live_views',
        overlay_url: 'overlay_url',
        permalink_url: 'permalink_url',
        planned_start_time: 'planned_start_time',
        recommended_encoder_settings: 'recommended_encoder_settings',
        seconds_left: 'seconds_left',
        secure_stream_url: 'secure_stream_url',
        status: 'status',
        stream_url: 'stream_url',
        targeting: 'targeting',
        title: 'title',
        total_views: 'total_views',
        video: 'video'
      });
    }
  }, {
    key: 'Projection',
    get: function get() {
      return Object.freeze({
        cubemap: 'CUBEMAP',
        equirectangular: 'EQUIRECTANGULAR',
        half_equirectangular: 'HALF_EQUIRECTANGULAR'
      });
    }
  }, {
    key: 'SpatialAudioFormat',
    get: function get() {
      return Object.freeze({
        ambix_4: 'ambiX_4'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        live_now: 'LIVE_NOW',
        scheduled_canceled: 'SCHEDULED_CANCELED',
        scheduled_live: 'SCHEDULED_LIVE',
        scheduled_unpublished: 'SCHEDULED_UNPUBLISHED',
        unpublished: 'UNPUBLISHED'
      });
    }
  }, {
    key: 'StereoscopicMode',
    get: function get() {
      return Object.freeze({
        left_right: 'LEFT_RIGHT',
        mono: 'MONO',
        top_bottom: 'TOP_BOTTOM'
      });
    }
  }, {
    key: 'StreamType',
    get: function get() {
      return Object.freeze({
        ambient: 'AMBIENT',
        regular: 'REGULAR'
      });
    }
  }, {
    key: 'BroadcastStatus',
    get: function get() {
      return Object.freeze({
        live: 'LIVE',
        live_stopped: 'LIVE_STOPPED',
        processing: 'PROCESSING',
        scheduled_canceled: 'SCHEDULED_CANCELED',
        scheduled_expired: 'SCHEDULED_EXPIRED',
        scheduled_live: 'SCHEDULED_LIVE',
        scheduled_unpublished: 'SCHEDULED_UNPUBLISHED',
        unpublished: 'UNPUBLISHED',
        vod: 'VOD'
      });
    }
  }, {
    key: 'Source',
    get: function get() {
      return Object.freeze({
        owner: 'owner',
        target: 'target'
      });
    }
  }, {
    key: 'LiveCommentModerationSetting',
    get: function get() {
      return Object.freeze({
        default: 'DEFAULT',
        discussion: 'DISCUSSION',
        followed: 'FOLLOWED',
        follower: 'FOLLOWER',
        no_hyperlink: 'NO_HYPERLINK',
        protected_mode: 'PROTECTED_MODE',
        restricted: 'RESTRICTED',
        slow: 'SLOW',
        supporter: 'SUPPORTER',
        tagged: 'TAGGED'
      });
    }
  }, {
    key: 'PersistentStreamKeyStatus',
    get: function get() {
      return Object.freeze({
        disable: 'DISABLE',
        enable: 'ENABLE',
        regenerate: 'REGENERATE'
      });
    }
  }]);
  return LiveVideo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EventTicketTier
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EventTicketTier = function (_AbstractCrudObject) {
  inherits(EventTicketTier, _AbstractCrudObject);

  function EventTicketTier() {
    classCallCheck(this, EventTicketTier);
    return possibleConstructorReturn(this, (EventTicketTier.__proto__ || Object.getPrototypeOf(EventTicketTier)).apply(this, arguments));
  }

  createClass(EventTicketTier, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        currency: 'currency',
        description: 'description',
        end_sales_time: 'end_sales_time',
        end_show_time: 'end_show_time',
        fee_settings: 'fee_settings',
        id: 'id',
        maximum_quantity: 'maximum_quantity',
        metadata: 'metadata',
        minimum_quantity: 'minimum_quantity',
        name: 'name',
        price: 'price',
        priority: 'priority',
        retailer_id: 'retailer_id',
        seating_map_image_url: 'seating_map_image_url',
        start_sales_time: 'start_sales_time',
        start_show_time: 'start_show_time',
        status: 'status',
        total_quantity: 'total_quantity'
      });
    }
  }]);
  return EventTicketTier;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Event
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Event = function (_AbstractCrudObject) {
  inherits(Event, _AbstractCrudObject);

  function Event() {
    classCallCheck(this, Event);
    return possibleConstructorReturn(this, (Event.__proto__ || Object.getPrototypeOf(Event)).apply(this, arguments));
  }

  createClass(Event, [{
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NullNode, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'getFeed',
    value: function getFeed(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NullNode, fields, params, fetchFirstPage, '/feed');
    }
  }, {
    key: 'getLiveVideos',
    value: function getLiveVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NullNode, fields, params, fetchFirstPage, '/live_videos');
    }
  }, {
    key: 'createLiveVideo',
    value: function createLiveVideo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/live_videos', fields, params, LiveVideo, pathOverride);
    }
  }, {
    key: 'getPhotos',
    value: function getPhotos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NullNode, fields, params, fetchFirstPage, '/photos');
    }
  }, {
    key: 'getPicture',
    value: function getPicture(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NullNode, fields, params, fetchFirstPage, '/picture');
    }
  }, {
    key: 'getPosts',
    value: function getPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NullNode, fields, params, fetchFirstPage, '/posts');
    }
  }, {
    key: 'getRoles',
    value: function getRoles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/roles');
    }
  }, {
    key: 'getTicketTiers',
    value: function getTicketTiers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(EventTicketTier, fields, params, fetchFirstPage, '/ticket_tiers');
    }
  }, {
    key: 'getVideos',
    value: function getVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NullNode, fields, params, fetchFirstPage, '/videos');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        attending_count: 'attending_count',
        can_guests_invite: 'can_guests_invite',
        category: 'category',
        cover: 'cover',
        created_time: 'created_time',
        declined_count: 'declined_count',
        description: 'description',
        discount_code_enabled: 'discount_code_enabled',
        end_time: 'end_time',
        event_times: 'event_times',
        guest_list_enabled: 'guest_list_enabled',
        id: 'id',
        interested_count: 'interested_count',
        is_canceled: 'is_canceled',
        is_draft: 'is_draft',
        is_online: 'is_online',
        is_page_owned: 'is_page_owned',
        maybe_count: 'maybe_count',
        name: 'name',
        noreply_count: 'noreply_count',
        online_event_format: 'online_event_format',
        online_event_third_party_url: 'online_event_third_party_url',
        owner: 'owner',
        parent_group: 'parent_group',
        place: 'place',
        registration_setting: 'registration_setting',
        scheduled_publish_time: 'scheduled_publish_time',
        start_time: 'start_time',
        ticket_setting: 'ticket_setting',
        ticket_uri: 'ticket_uri',
        ticket_uri_start_sales_time: 'ticket_uri_start_sales_time',
        ticketing_privacy_uri: 'ticketing_privacy_uri',
        ticketing_terms_uri: 'ticketing_terms_uri',
        timezone: 'timezone',
        type: 'type',
        updated_time: 'updated_time'
      });
    }
  }, {
    key: 'Category',
    get: function get() {
      return Object.freeze({
        classic_literature: 'CLASSIC_LITERATURE',
        comedy: 'COMEDY',
        crafts: 'CRAFTS',
        dance: 'DANCE',
        drinks: 'DRINKS',
        fitness_and_workouts: 'FITNESS_AND_WORKOUTS',
        foods: 'FOODS',
        games: 'GAMES',
        gardening: 'GARDENING',
        healthy_living_and_self_care: 'HEALTHY_LIVING_AND_SELF_CARE',
        health_and_medical: 'HEALTH_AND_MEDICAL',
        home_and_garden: 'HOME_AND_GARDEN',
        music_and_audio: 'MUSIC_AND_AUDIO',
        parties: 'PARTIES',
        professional_networking: 'PROFESSIONAL_NETWORKING',
        religions: 'RELIGIONS',
        shopping_event: 'SHOPPING_EVENT',
        social_issues: 'SOCIAL_ISSUES',
        sports: 'SPORTS',
        theater: 'THEATER',
        tv_and_movies: 'TV_AND_MOVIES',
        visual_arts: 'VISUAL_ARTS'
      });
    }
  }, {
    key: 'OnlineEventFormat',
    get: function get() {
      return Object.freeze({
        fb_live: 'fb_live',
        messenger_room: 'messenger_room',
        none: 'none',
        other: 'other',
        third_party: 'third_party'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        community: 'community',
        friends: 'friends',
        group: 'group',
        private: 'private',
        public: 'public',
        work_company: 'work_company'
      });
    }
  }, {
    key: 'EventStateFilter',
    get: function get() {
      return Object.freeze({
        canceled: 'canceled',
        draft: 'draft',
        published: 'published',
        scheduled_draft_for_publication: 'scheduled_draft_for_publication'
      });
    }
  }, {
    key: 'TimeFilter',
    get: function get() {
      return Object.freeze({
        past: 'past',
        upcoming: 'upcoming'
      });
    }
  }]);
  return Event;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FantasyGame
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FantasyGame = function (_AbstractCrudObject) {
  inherits(FantasyGame, _AbstractCrudObject);

  function FantasyGame() {
    classCallCheck(this, FantasyGame);
    return possibleConstructorReturn(this, (FantasyGame.__proto__ || Object.getPrototypeOf(FantasyGame)).apply(this, arguments));
  }

  createClass(FantasyGame, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return FantasyGame;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ImageCopyright
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ImageCopyright = function (_AbstractCrudObject) {
  inherits(ImageCopyright, _AbstractCrudObject);

  function ImageCopyright() {
    classCallCheck(this, ImageCopyright);
    return possibleConstructorReturn(this, (ImageCopyright.__proto__ || Object.getPrototypeOf(ImageCopyright)).apply(this, arguments));
  }

  createClass(ImageCopyright, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ImageCopyright.prototype.__proto__ || Object.getPrototypeOf(ImageCopyright.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        artist: 'artist',
        copyright_monitoring_status: 'copyright_monitoring_status',
        creation_time: 'creation_time',
        creator: 'creator',
        custom_id: 'custom_id',
        description: 'description',
        filename: 'filename',
        id: 'id',
        image: 'image',
        matches_count: 'matches_count',
        original_content_creation_date: 'original_content_creation_date',
        ownership_countries: 'ownership_countries',
        tags: 'tags',
        title: 'title',
        update_time: 'update_time'
      });
    }
  }, {
    key: 'GeoOwnership',
    get: function get() {
      return Object.freeze({
        ad: 'AD',
        ae: 'AE',
        af: 'AF',
        ag: 'AG',
        ai: 'AI',
        al: 'AL',
        am: 'AM',
        an: 'AN',
        ao: 'AO',
        aq: 'AQ',
        ar: 'AR',
        as: 'AS',
        at: 'AT',
        au: 'AU',
        aw: 'AW',
        ax: 'AX',
        az: 'AZ',
        ba: 'BA',
        bb: 'BB',
        bd: 'BD',
        be: 'BE',
        bf: 'BF',
        bg: 'BG',
        bh: 'BH',
        bi: 'BI',
        bj: 'BJ',
        bl: 'BL',
        bm: 'BM',
        bn: 'BN',
        bo: 'BO',
        bq: 'BQ',
        br: 'BR',
        bs: 'BS',
        bt: 'BT',
        bv: 'BV',
        bw: 'BW',
        by: 'BY',
        bz: 'BZ',
        ca: 'CA',
        cc: 'CC',
        cd: 'CD',
        cf: 'CF',
        cg: 'CG',
        ch: 'CH',
        ci: 'CI',
        ck: 'CK',
        cl: 'CL',
        cm: 'CM',
        cn: 'CN',
        co: 'CO',
        cr: 'CR',
        cu: 'CU',
        cv: 'CV',
        cw: 'CW',
        cx: 'CX',
        cy: 'CY',
        cz: 'CZ',
        de: 'DE',
        dj: 'DJ',
        dk: 'DK',
        dm: 'DM',
        do: 'DO',
        dz: 'DZ',
        ec: 'EC',
        ee: 'EE',
        eg: 'EG',
        eh: 'EH',
        er: 'ER',
        es: 'ES',
        et: 'ET',
        fi: 'FI',
        fj: 'FJ',
        fk: 'FK',
        fm: 'FM',
        fo: 'FO',
        fr: 'FR',
        ga: 'GA',
        gb: 'GB',
        gd: 'GD',
        ge: 'GE',
        gf: 'GF',
        gg: 'GG',
        gh: 'GH',
        gi: 'GI',
        gl: 'GL',
        gm: 'GM',
        gn: 'GN',
        gp: 'GP',
        gq: 'GQ',
        gr: 'GR',
        gs: 'GS',
        gt: 'GT',
        gu: 'GU',
        gw: 'GW',
        gy: 'GY',
        hk: 'HK',
        hm: 'HM',
        hn: 'HN',
        hr: 'HR',
        ht: 'HT',
        hu: 'HU',
        id: 'ID',
        ie: 'IE',
        il: 'IL',
        im: 'IM',
        in: 'IN',
        io: 'IO',
        iq: 'IQ',
        ir: 'IR',
        is: 'IS',
        it: 'IT',
        je: 'JE',
        jm: 'JM',
        jo: 'JO',
        jp: 'JP',
        ke: 'KE',
        kg: 'KG',
        kh: 'KH',
        ki: 'KI',
        km: 'KM',
        kn: 'KN',
        kp: 'KP',
        kr: 'KR',
        kw: 'KW',
        ky: 'KY',
        kz: 'KZ',
        la: 'LA',
        lb: 'LB',
        lc: 'LC',
        li: 'LI',
        lk: 'LK',
        lr: 'LR',
        ls: 'LS',
        lt: 'LT',
        lu: 'LU',
        lv: 'LV',
        ly: 'LY',
        ma: 'MA',
        mc: 'MC',
        md: 'MD',
        me: 'ME',
        mf: 'MF',
        mg: 'MG',
        mh: 'MH',
        mk: 'MK',
        ml: 'ML',
        mm: 'MM',
        mn: 'MN',
        mo: 'MO',
        mp: 'MP',
        mq: 'MQ',
        mr: 'MR',
        ms: 'MS',
        mt: 'MT',
        mu: 'MU',
        mv: 'MV',
        mw: 'MW',
        mx: 'MX',
        my: 'MY',
        mz: 'MZ',
        na: 'NA',
        nc: 'NC',
        ne: 'NE',
        nf: 'NF',
        ng: 'NG',
        ni: 'NI',
        nl: 'NL',
        no: 'NO',
        np: 'NP',
        nr: 'NR',
        nu: 'NU',
        nz: 'NZ',
        om: 'OM',
        pa: 'PA',
        pe: 'PE',
        pf: 'PF',
        pg: 'PG',
        ph: 'PH',
        pk: 'PK',
        pl: 'PL',
        pm: 'PM',
        pn: 'PN',
        pr: 'PR',
        ps: 'PS',
        pt: 'PT',
        pw: 'PW',
        py: 'PY',
        qa: 'QA',
        re: 'RE',
        ro: 'RO',
        rs: 'RS',
        ru: 'RU',
        rw: 'RW',
        sa: 'SA',
        sb: 'SB',
        sc: 'SC',
        sd: 'SD',
        se: 'SE',
        sg: 'SG',
        sh: 'SH',
        si: 'SI',
        sj: 'SJ',
        sk: 'SK',
        sl: 'SL',
        sm: 'SM',
        sn: 'SN',
        so: 'SO',
        sr: 'SR',
        ss: 'SS',
        st: 'ST',
        sv: 'SV',
        sx: 'SX',
        sy: 'SY',
        sz: 'SZ',
        tc: 'TC',
        td: 'TD',
        tf: 'TF',
        tg: 'TG',
        th: 'TH',
        tj: 'TJ',
        tk: 'TK',
        tl: 'TL',
        tm: 'TM',
        tn: 'TN',
        to: 'TO',
        tp: 'TP',
        tr: 'TR',
        tt: 'TT',
        tv: 'TV',
        tw: 'TW',
        tz: 'TZ',
        ua: 'UA',
        ug: 'UG',
        um: 'UM',
        us: 'US',
        uy: 'UY',
        uz: 'UZ',
        va: 'VA',
        vc: 'VC',
        ve: 'VE',
        vg: 'VG',
        vi: 'VI',
        vn: 'VN',
        vu: 'VU',
        wf: 'WF',
        ws: 'WS',
        xk: 'XK',
        ye: 'YE',
        yt: 'YT',
        za: 'ZA',
        zm: 'ZM',
        zw: 'ZW'
      });
    }
  }]);
  return ImageCopyright;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadgenForm
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadgenForm = function (_AbstractCrudObject) {
  inherits(LeadgenForm, _AbstractCrudObject);

  function LeadgenForm() {
    classCallCheck(this, LeadgenForm);
    return possibleConstructorReturn(this, (LeadgenForm.__proto__ || Object.getPrototypeOf(LeadgenForm)).apply(this, arguments));
  }

  createClass(LeadgenForm, [{
    key: 'getLeads',
    value: function getLeads(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Lead, fields, params, fetchFirstPage, '/leads');
    }
  }, {
    key: 'getTestLeads',
    value: function getTestLeads(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Lead, fields, params, fetchFirstPage, '/test_leads');
    }
  }, {
    key: 'createTestLead',
    value: function createTestLead(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/test_leads', fields, params, Lead, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(LeadgenForm.prototype.__proto__ || Object.getPrototypeOf(LeadgenForm.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        allow_organic_lead: 'allow_organic_lead',
        block_display_for_non_targeted_viewer: 'block_display_for_non_targeted_viewer',
        context_card: 'context_card',
        created_time: 'created_time',
        creator: 'creator',
        expired_leads_count: 'expired_leads_count',
        follow_up_action_text: 'follow_up_action_text',
        follow_up_action_url: 'follow_up_action_url',
        id: 'id',
        is_optimized_for_quality: 'is_optimized_for_quality',
        leads_count: 'leads_count',
        legal_content: 'legal_content',
        locale: 'locale',
        name: 'name',
        organic_leads_count: 'organic_leads_count',
        page: 'page',
        page_id: 'page_id',
        privacy_policy_url: 'privacy_policy_url',
        question_page_custom_headline: 'question_page_custom_headline',
        questions: 'questions',
        status: 'status',
        thank_you_page: 'thank_you_page',
        tracking_parameters: 'tracking_parameters'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        archived: 'ARCHIVED',
        deleted: 'DELETED',
        draft: 'DRAFT'
      });
    }
  }, {
    key: 'Locale',
    get: function get() {
      return Object.freeze({
        ar_ar: 'AR_AR',
        cs_cz: 'CS_CZ',
        da_dk: 'DA_DK',
        de_de: 'DE_DE',
        el_gr: 'EL_GR',
        en_gb: 'EN_GB',
        en_us: 'EN_US',
        es_es: 'ES_ES',
        es_la: 'ES_LA',
        fi_fi: 'FI_FI',
        fr_fr: 'FR_FR',
        he_il: 'HE_IL',
        hi_in: 'HI_IN',
        hu_hu: 'HU_HU',
        id_id: 'ID_ID',
        it_it: 'IT_IT',
        ja_jp: 'JA_JP',
        ko_kr: 'KO_KR',
        nb_no: 'NB_NO',
        nl_nl: 'NL_NL',
        pl_pl: 'PL_PL',
        pt_br: 'PT_BR',
        pt_pt: 'PT_PT',
        ro_ro: 'RO_RO',
        ru_ru: 'RU_RU',
        sv_se: 'SV_SE',
        th_th: 'TH_TH',
        tr_tr: 'TR_TR',
        vi_vn: 'VI_VN',
        zh_cn: 'ZH_CN',
        zh_hk: 'ZH_HK',
        zh_tw: 'ZH_TW'
      });
    }
  }]);
  return LeadgenForm;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MediaFingerprint
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MediaFingerprint = function (_AbstractCrudObject) {
  inherits(MediaFingerprint, _AbstractCrudObject);

  function MediaFingerprint() {
    classCallCheck(this, MediaFingerprint);
    return possibleConstructorReturn(this, (MediaFingerprint.__proto__ || Object.getPrototypeOf(MediaFingerprint)).apply(this, arguments));
  }

  createClass(MediaFingerprint, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(MediaFingerprint.prototype.__proto__ || Object.getPrototypeOf(MediaFingerprint.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        duration_in_sec: 'duration_in_sec',
        fingerprint_content_type: 'fingerprint_content_type',
        fingerprint_type: 'fingerprint_type',
        id: 'id',
        metadata: 'metadata',
        title: 'title',
        universal_content_id: 'universal_content_id'
      });
    }
  }, {
    key: 'FingerprintContentType',
    get: function get() {
      return Object.freeze({
        am_songtrack: 'AM_SONGTRACK',
        episode: 'EPISODE',
        movie: 'MOVIE',
        other: 'OTHER',
        songtrack: 'SONGTRACK'
      });
    }
  }]);
  return MediaFingerprint;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MessagingFeatureReview
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MessagingFeatureReview = function (_AbstractCrudObject) {
  inherits(MessagingFeatureReview, _AbstractCrudObject);

  function MessagingFeatureReview() {
    classCallCheck(this, MessagingFeatureReview);
    return possibleConstructorReturn(this, (MessagingFeatureReview.__proto__ || Object.getPrototypeOf(MessagingFeatureReview)).apply(this, arguments));
  }

  createClass(MessagingFeatureReview, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        feature: 'feature',
        status: 'status'
      });
    }
  }]);
  return MessagingFeatureReview;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MessengerCallSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MessengerCallSettings = function (_AbstractCrudObject) {
  inherits(MessengerCallSettings, _AbstractCrudObject);

  function MessengerCallSettings() {
    classCallCheck(this, MessengerCallSettings);
    return possibleConstructorReturn(this, (MessengerCallSettings.__proto__ || Object.getPrototypeOf(MessengerCallSettings)).apply(this, arguments));
  }

  createClass(MessengerCallSettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audio_enabled: 'audio_enabled'
      });
    }
  }]);
  return MessengerCallSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MessengerAdsPartialAutomatedStepList
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MessengerAdsPartialAutomatedStepList = function (_AbstractCrudObject) {
  inherits(MessengerAdsPartialAutomatedStepList, _AbstractCrudObject);

  function MessengerAdsPartialAutomatedStepList() {
    classCallCheck(this, MessengerAdsPartialAutomatedStepList);
    return possibleConstructorReturn(this, (MessengerAdsPartialAutomatedStepList.__proto__ || Object.getPrototypeOf(MessengerAdsPartialAutomatedStepList)).apply(this, arguments));
  }

  createClass(MessengerAdsPartialAutomatedStepList, [{
    key: 'getSteps',
    value: function getSteps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/steps');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        fblead_form: 'fblead_form',
        first_step_id: 'first_step_id',
        id: 'id',
        page: 'page',
        privacy_url: 'privacy_url',
        reminder_text: 'reminder_text',
        stop_question_message: 'stop_question_message'
      });
    }
  }]);
  return MessengerAdsPartialAutomatedStepList;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MessengerProfile
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MessengerProfile = function (_AbstractCrudObject) {
  inherits(MessengerProfile, _AbstractCrudObject);

  function MessengerProfile() {
    classCallCheck(this, MessengerProfile);
    return possibleConstructorReturn(this, (MessengerProfile.__proto__ || Object.getPrototypeOf(MessengerProfile)).apply(this, arguments));
  }

  createClass(MessengerProfile, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_linking_url: 'account_linking_url',
        commands: 'commands',
        get_started: 'get_started',
        greeting: 'greeting',
        ice_breakers: 'ice_breakers',
        payment_settings: 'payment_settings',
        persistent_menu: 'persistent_menu',
        subject_to_new_eu_privacy_rules: 'subject_to_new_eu_privacy_rules',
        target_audience: 'target_audience',
        whitelisted_domains: 'whitelisted_domains'
      });
    }
  }]);
  return MessengerProfile;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserPageOneTimeOptInTokenSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserPageOneTimeOptInTokenSettings = function (_AbstractCrudObject) {
  inherits(UserPageOneTimeOptInTokenSettings, _AbstractCrudObject);

  function UserPageOneTimeOptInTokenSettings() {
    classCallCheck(this, UserPageOneTimeOptInTokenSettings);
    return possibleConstructorReturn(this, (UserPageOneTimeOptInTokenSettings.__proto__ || Object.getPrototypeOf(UserPageOneTimeOptInTokenSettings)).apply(this, arguments));
  }

  createClass(UserPageOneTimeOptInTokenSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_timestamp: 'creation_timestamp',
        next_eligible_time: 'next_eligible_time',
        notification_messages_frequency: 'notification_messages_frequency',
        notification_messages_reoptin: 'notification_messages_reoptin',
        notification_messages_timezone: 'notification_messages_timezone',
        notification_messages_token: 'notification_messages_token',
        recipient_id: 'recipient_id',
        token_expiry_timestamp: 'token_expiry_timestamp',
        topic_title: 'topic_title',
        user_token_status: 'user_token_status',
        id: 'id'
      });
    }
  }]);
  return UserPageOneTimeOptInTokenSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Persona
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Persona = function (_AbstractCrudObject) {
  inherits(Persona, _AbstractCrudObject);

  function Persona() {
    classCallCheck(this, Persona);
    return possibleConstructorReturn(this, (Persona.__proto__ || Object.getPrototypeOf(Persona)).apply(this, arguments));
  }

  createClass(Persona, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Persona.prototype.__proto__ || Object.getPrototypeOf(Persona.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        profile_picture_url: 'profile_picture_url'
      });
    }
  }]);
  return Persona;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Recommendation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Recommendation = function (_AbstractCrudObject) {
  inherits(Recommendation, _AbstractCrudObject);

  function Recommendation() {
    classCallCheck(this, Recommendation);
    return possibleConstructorReturn(this, (Recommendation.__proto__ || Object.getPrototypeOf(Recommendation)).apply(this, arguments));
  }

  createClass(Recommendation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        created_time: 'created_time',
        has_rating: 'has_rating',
        has_review: 'has_review',
        open_graph_story: 'open_graph_story',
        rating: 'rating',
        recommendation_type: 'recommendation_type',
        review_text: 'review_text',
        reviewer: 'reviewer'
      });
    }
  }]);
  return Recommendation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageSettings = function (_AbstractCrudObject) {
  inherits(PageSettings, _AbstractCrudObject);

  function PageSettings() {
    classCallCheck(this, PageSettings);
    return possibleConstructorReturn(this, (PageSettings.__proto__ || Object.getPrototypeOf(PageSettings)).apply(this, arguments));
  }

  createClass(PageSettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        setting: 'setting',
        value: 'value'
      });
    }
  }]);
  return PageSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Stories
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Stories = function (_AbstractCrudObject) {
  inherits(Stories, _AbstractCrudObject);

  function Stories() {
    classCallCheck(this, Stories);
    return possibleConstructorReturn(this, (Stories.__proto__ || Object.getPrototypeOf(Stories)).apply(this, arguments));
  }

  createClass(Stories, [{
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InsightsResult, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        media_id: 'media_id',
        media_type: 'media_type',
        post_id: 'post_id',
        status: 'status',
        url: 'url',
        id: 'id'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        archived: 'ARCHIVED',
        published: 'PUBLISHED'
      });
    }
  }]);
  return Stories;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Tab
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Tab = function (_AbstractCrudObject) {
  inherits(Tab, _AbstractCrudObject);

  function Tab() {
    classCallCheck(this, Tab);
    return possibleConstructorReturn(this, (Tab.__proto__ || Object.getPrototypeOf(Tab)).apply(this, arguments));
  }

  createClass(Tab, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        application: 'application',
        custom_image_url: 'custom_image_url',
        custom_name: 'custom_name',
        id: 'id',
        image_url: 'image_url',
        is_non_connection_landing_tab: 'is_non_connection_landing_tab',
        is_permanent: 'is_permanent',
        link: 'link',
        name: 'name',
        position: 'position'
      });
    }
  }]);
  return Tab;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageThreadOwner
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageThreadOwner = function (_AbstractCrudObject) {
  inherits(PageThreadOwner, _AbstractCrudObject);

  function PageThreadOwner() {
    classCallCheck(this, PageThreadOwner);
    return possibleConstructorReturn(this, (PageThreadOwner.__proto__ || Object.getPrototypeOf(PageThreadOwner)).apply(this, arguments));
  }

  createClass(PageThreadOwner, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        thread_owner: 'thread_owner'
      });
    }
  }]);
  return PageThreadOwner;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoCopyrightRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoCopyrightRule = function (_AbstractCrudObject) {
  inherits(VideoCopyrightRule, _AbstractCrudObject);

  function VideoCopyrightRule() {
    classCallCheck(this, VideoCopyrightRule);
    return possibleConstructorReturn(this, (VideoCopyrightRule.__proto__ || Object.getPrototypeOf(VideoCopyrightRule)).apply(this, arguments));
  }

  createClass(VideoCopyrightRule, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        condition_groups: 'condition_groups',
        copyrights: 'copyrights',
        created_date: 'created_date',
        creator: 'creator',
        id: 'id',
        is_in_migration: 'is_in_migration',
        name: 'name'
      });
    }
  }, {
    key: 'Source',
    get: function get() {
      return Object.freeze({
        match_settings_dialog: 'MATCH_SETTINGS_DIALOG',
        rules_selector: 'RULES_SELECTOR',
        rules_tab: 'RULES_TAB'
      });
    }
  }]);
  return VideoCopyrightRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MediaCopyrightUpdateRecord
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MediaCopyrightUpdateRecord = function (_AbstractCrudObject) {
  inherits(MediaCopyrightUpdateRecord, _AbstractCrudObject);

  function MediaCopyrightUpdateRecord() {
    classCallCheck(this, MediaCopyrightUpdateRecord);
    return possibleConstructorReturn(this, (MediaCopyrightUpdateRecord.__proto__ || Object.getPrototypeOf(MediaCopyrightUpdateRecord)).apply(this, arguments));
  }

  createClass(MediaCopyrightUpdateRecord, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action_types: 'action_types',
        actor: 'actor',
        actor_type: 'actor_type',
        creation_time: 'creation_time',
        id: 'id',
        ownership_countries: 'ownership_countries',
        whitelisted_accounts: 'whitelisted_accounts'
      });
    }
  }]);
  return MediaCopyrightUpdateRecord;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoCopyright
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoCopyright = function (_AbstractCrudObject) {
  inherits(VideoCopyright, _AbstractCrudObject);

  function VideoCopyright() {
    classCallCheck(this, VideoCopyright);
    return possibleConstructorReturn(this, (VideoCopyright.__proto__ || Object.getPrototypeOf(VideoCopyright)).apply(this, arguments));
  }

  createClass(VideoCopyright, [{
    key: 'getUpdateRecords',
    value: function getUpdateRecords(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MediaCopyrightUpdateRecord, fields, params, fetchFirstPage, '/update_records');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(VideoCopyright.prototype.__proto__ || Object.getPrototypeOf(VideoCopyright.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        content_category: 'content_category',
        copyright_content_id: 'copyright_content_id',
        creator: 'creator',
        excluded_ownership_segments: 'excluded_ownership_segments',
        id: 'id',
        in_conflict: 'in_conflict',
        monitoring_status: 'monitoring_status',
        monitoring_type: 'monitoring_type',
        ownership_countries: 'ownership_countries',
        reference_file: 'reference_file',
        reference_file_disabled: 'reference_file_disabled',
        reference_file_disabled_by_ops: 'reference_file_disabled_by_ops',
        reference_owner_id: 'reference_owner_id',
        rule_ids: 'rule_ids',
        tags: 'tags',
        whitelisted_ids: 'whitelisted_ids'
      });
    }
  }, {
    key: 'ContentCategory',
    get: function get() {
      return Object.freeze({
        episode: 'episode',
        movie: 'movie',
        web: 'web'
      });
    }
  }, {
    key: 'MonitoringType',
    get: function get() {
      return Object.freeze({
        audio_only: 'AUDIO_ONLY',
        video_and_audio: 'VIDEO_AND_AUDIO',
        video_only: 'VIDEO_ONLY'
      });
    }
  }]);
  return VideoCopyright;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoList
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoList = function (_AbstractCrudObject) {
  inherits(VideoList, _AbstractCrudObject);

  function VideoList() {
    classCallCheck(this, VideoList);
    return possibleConstructorReturn(this, (VideoList.__proto__ || Object.getPrototypeOf(VideoList)).apply(this, arguments));
  }

  createClass(VideoList, [{
    key: 'getVideos',
    value: function getVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdVideo, fields, params, fetchFirstPage, '/videos');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        description: 'description',
        id: 'id',
        last_modified: 'last_modified',
        owner: 'owner',
        season_number: 'season_number',
        thumbnail: 'thumbnail',
        title: 'title',
        videos_count: 'videos_count'
      });
    }
  }]);
  return VideoList;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CTXPartnerAppWelcomeMessageFlow
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CTXPartnerAppWelcomeMessageFlow = function (_AbstractCrudObject) {
  inherits(CTXPartnerAppWelcomeMessageFlow, _AbstractCrudObject);

  function CTXPartnerAppWelcomeMessageFlow() {
    classCallCheck(this, CTXPartnerAppWelcomeMessageFlow);
    return possibleConstructorReturn(this, (CTXPartnerAppWelcomeMessageFlow.__proto__ || Object.getPrototypeOf(CTXPartnerAppWelcomeMessageFlow)).apply(this, arguments));
  }

  createClass(CTXPartnerAppWelcomeMessageFlow, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        compatible_platforms: 'compatible_platforms',
        eligible_platforms: 'eligible_platforms',
        id: 'id',
        is_ig_only_flow: 'is_ig_only_flow',
        is_used_in_ad: 'is_used_in_ad',
        last_update_time: 'last_update_time',
        name: 'name',
        welcome_message_flow: 'welcome_message_flow',
        welcome_message_sequence: 'welcome_message_sequence'
      });
    }
  }]);
  return CTXPartnerAppWelcomeMessageFlow;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Page
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Page = function (_AbstractCrudObject) {
  inherits(Page, _AbstractCrudObject);

  function Page() {
    classCallCheck(this, Page);
    return possibleConstructorReturn(this, (Page.__proto__ || Object.getPrototypeOf(Page)).apply(this, arguments));
  }

  createClass(Page, [{
    key: 'getAbTests',
    value: function getAbTests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PagePostExperiment, fields, params, fetchFirstPage, '/ab_tests');
    }
  }, {
    key: 'createAbTest',
    value: function createAbTest(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/ab_tests', fields, params, PagePostExperiment, pathOverride);
    }
  }, {
    key: 'createAcknowledgeOrder',
    value: function createAcknowledgeOrder(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/acknowledge_orders', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getAdsPosts',
    value: function getAdsPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PagePost, fields, params, fetchFirstPage, '/ads_posts');
    }
  }, {
    key: 'deleteAgencies',
    value: function deleteAgencies() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Page.prototype.__proto__ || Object.getPrototypeOf(Page.prototype), 'deleteEdge', this).call(this, '/agencies', params);
    }
  }, {
    key: 'getAgencies',
    value: function getAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/agencies');
    }
  }, {
    key: 'createAgency',
    value: function createAgency(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/agencies', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getAlbums',
    value: function getAlbums(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Album, fields, params, fetchFirstPage, '/albums');
    }
  }, {
    key: 'getArExperience',
    value: function getArExperience(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ArAdsDataContainer, fields, params, fetchFirstPage, '/ar_experience');
    }
  }, {
    key: 'deleteAssignedUsers',
    value: function deleteAssignedUsers() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Page.prototype.__proto__ || Object.getPrototypeOf(Page.prototype), 'deleteEdge', this).call(this, '/assigned_users', params);
    }
  }, {
    key: 'getAssignedUsers',
    value: function getAssignedUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AssignedUser, fields, params, fetchFirstPage, '/assigned_users');
    }
  }, {
    key: 'createAssignedUser',
    value: function createAssignedUser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/assigned_users', fields, params, Page, pathOverride);
    }
  }, {
    key: 'deleteBlocked',
    value: function deleteBlocked() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Page.prototype.__proto__ || Object.getPrototypeOf(Page.prototype), 'deleteEdge', this).call(this, '/blocked', params);
    }
  }, {
    key: 'getBlocked',
    value: function getBlocked(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/blocked');
    }
  }, {
    key: 'createBlocked',
    value: function createBlocked(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/blocked', fields, params, null, pathOverride);
    }
  }, {
    key: 'createBusinessDatum',
    value: function createBusinessDatum(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/business_data', fields, params, null, pathOverride);
    }
  }, {
    key: 'getBusinessProjects',
    value: function getBusinessProjects(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessProject, fields, params, fetchFirstPage, '/businessprojects');
    }
  }, {
    key: 'getCallToActions',
    value: function getCallToActions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PageCallToAction, fields, params, fetchFirstPage, '/call_to_actions');
    }
  }, {
    key: 'createCall',
    value: function createCall(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/calls', fields, params, null, pathOverride);
    }
  }, {
    key: 'getCanvasElements',
    value: function getCanvasElements(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CanvasBodyElement, fields, params, fetchFirstPage, '/canvas_elements');
    }
  }, {
    key: 'createCanvasElement',
    value: function createCanvasElement(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/canvas_elements', fields, params, CanvasBodyElement, pathOverride);
    }
  }, {
    key: 'getCanvases',
    value: function getCanvases(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Canvas, fields, params, fetchFirstPage, '/canvases');
    }
  }, {
    key: 'createCanvase',
    value: function createCanvase(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/canvases', fields, params, Canvas, pathOverride);
    }
  }, {
    key: 'getChatPlugin',
    value: function getChatPlugin(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ChatPlugin, fields, params, fetchFirstPage, '/chat_plugin');
    }
  }, {
    key: 'createChatPlugin',
    value: function createChatPlugin(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/chat_plugin', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getCommerceMerchantSettings',
    value: function getCommerceMerchantSettings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommerceMerchantSettings, fields, params, fetchFirstPage, '/commerce_merchant_settings');
    }
  }, {
    key: 'getCommerceOrders',
    value: function getCommerceOrders(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommerceOrder, fields, params, fetchFirstPage, '/commerce_orders');
    }
  }, {
    key: 'getCommercePayouts',
    value: function getCommercePayouts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommercePayout, fields, params, fetchFirstPage, '/commerce_payouts');
    }
  }, {
    key: 'getCommerceTransactions',
    value: function getCommerceTransactions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommerceOrderTransactionDetail, fields, params, fetchFirstPage, '/commerce_transactions');
    }
  }, {
    key: 'getConversations',
    value: function getConversations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UnifiedThread, fields, params, fetchFirstPage, '/conversations');
    }
  }, {
    key: 'createCopyrightManualClaim',
    value: function createCopyrightManualClaim(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/copyright_manual_claims', fields, params, VideoCopyrightMatch, pathOverride);
    }
  }, {
    key: 'getCrosspostWhitelistedPages',
    value: function getCrosspostWhitelistedPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/crosspost_whitelisted_pages');
    }
  }, {
    key: 'getCtxOptimizationEligibility',
    value: function getCtxOptimizationEligibility(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CTXOptimizationEligibility, fields, params, fetchFirstPage, '/ctx_optimization_eligibility');
    }
  }, {
    key: 'getCustomLabels',
    value: function getCustomLabels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PageUserMessageThreadLabel, fields, params, fetchFirstPage, '/custom_labels');
    }
  }, {
    key: 'createCustomLabel',
    value: function createCustomLabel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/custom_labels', fields, params, PageUserMessageThreadLabel, pathOverride);
    }
  }, {
    key: 'deleteCustomUserSettings',
    value: function deleteCustomUserSettings() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Page.prototype.__proto__ || Object.getPrototypeOf(Page.prototype), 'deleteEdge', this).call(this, '/custom_user_settings', params);
    }
  }, {
    key: 'getCustomUserSettings',
    value: function getCustomUserSettings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomUserSettings, fields, params, fetchFirstPage, '/custom_user_settings');
    }
  }, {
    key: 'createCustomUserSetting',
    value: function createCustomUserSetting(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/custom_user_settings', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getDataset',
    value: function getDataset(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Dataset, fields, params, fetchFirstPage, '/dataset');
    }
  }, {
    key: 'createDataset',
    value: function createDataset(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/dataset', fields, params, Dataset, pathOverride);
    }
  }, {
    key: 'getEvents',
    value: function getEvents(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Event, fields, params, fetchFirstPage, '/events');
    }
  }, {
    key: 'createExtendThreadControl',
    value: function createExtendThreadControl(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/extend_thread_control', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getFantasyGames',
    value: function getFantasyGames(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(FantasyGame, fields, params, fetchFirstPage, '/fantasy_games');
    }
  }, {
    key: 'getFeed',
    value: function getFeed(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PagePost, fields, params, fetchFirstPage, '/feed');
    }
  }, {
    key: 'createFeed',
    value: function createFeed(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/feed', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getGlobalBrandChildren',
    value: function getGlobalBrandChildren(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/global_brand_children');
    }
  }, {
    key: 'getImageCopyrights',
    value: function getImageCopyrights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ImageCopyright, fields, params, fetchFirstPage, '/image_copyrights');
    }
  }, {
    key: 'createImageCopyright',
    value: function createImageCopyright(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/image_copyrights', fields, params, ImageCopyright, pathOverride);
    }
  }, {
    key: 'getIndexedVideos',
    value: function getIndexedVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdVideo, fields, params, fetchFirstPage, '/indexed_videos');
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InsightsResult, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'getInstagramAccounts',
    value: function getInstagramAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramUser, fields, params, fetchFirstPage, '/instagram_accounts');
    }
  }, {
    key: 'getLeadGenForms',
    value: function getLeadGenForms(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(LeadgenForm, fields, params, fetchFirstPage, '/leadgen_forms');
    }
  }, {
    key: 'createLeadGenForm',
    value: function createLeadGenForm(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/leadgen_forms', fields, params, LeadgenForm, pathOverride);
    }
  }, {
    key: 'getLikes',
    value: function getLikes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/likes');
    }
  }, {
    key: 'getLiveVideos',
    value: function getLiveVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(LiveVideo, fields, params, fetchFirstPage, '/live_videos');
    }
  }, {
    key: 'createLiveVideo',
    value: function createLiveVideo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/live_videos', fields, params, LiveVideo, pathOverride);
    }
  }, {
    key: 'deleteLocations',
    value: function deleteLocations() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Page.prototype.__proto__ || Object.getPrototypeOf(Page.prototype), 'deleteEdge', this).call(this, '/locations', params);
    }
  }, {
    key: 'getLocations',
    value: function getLocations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/locations');
    }
  }, {
    key: 'createLocation',
    value: function createLocation(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/locations', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getMediaFingerprints',
    value: function getMediaFingerprints(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MediaFingerprint, fields, params, fetchFirstPage, '/media_fingerprints');
    }
  }, {
    key: 'createMediaFingerprint',
    value: function createMediaFingerprint(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/media_fingerprints', fields, params, MediaFingerprint, pathOverride);
    }
  }, {
    key: 'createMessageAttachment',
    value: function createMessageAttachment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/message_attachments', fields, params, null, pathOverride);
    }
  }, {
    key: 'createMessage',
    value: function createMessage(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/messages', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getMessagingFeatureReview',
    value: function getMessagingFeatureReview(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MessagingFeatureReview, fields, params, fetchFirstPage, '/messaging_feature_review');
    }
  }, {
    key: 'getMessengerCallSettings',
    value: function getMessengerCallSettings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MessengerCallSettings, fields, params, fetchFirstPage, '/messenger_call_settings');
    }
  }, {
    key: 'createMessengerCallSetting',
    value: function createMessengerCallSetting(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/messenger_call_settings', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getMessengerLeadForms',
    value: function getMessengerLeadForms(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MessengerAdsPartialAutomatedStepList, fields, params, fetchFirstPage, '/messenger_lead_forms');
    }
  }, {
    key: 'createMessengerLeadForm',
    value: function createMessengerLeadForm(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/messenger_lead_forms', fields, params, Page, pathOverride);
    }
  }, {
    key: 'deleteMessengerProfile',
    value: function deleteMessengerProfile() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Page.prototype.__proto__ || Object.getPrototypeOf(Page.prototype), 'deleteEdge', this).call(this, '/messenger_profile', params);
    }
  }, {
    key: 'getMessengerProfile',
    value: function getMessengerProfile(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MessengerProfile, fields, params, fetchFirstPage, '/messenger_profile');
    }
  }, {
    key: 'createMessengerProfile',
    value: function createMessengerProfile(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/messenger_profile', fields, params, Page, pathOverride);
    }
  }, {
    key: 'createNlpConfig',
    value: function createNlpConfig(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/nlp_configs', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getNotificationMessageTokens',
    value: function getNotificationMessageTokens(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UserPageOneTimeOptInTokenSettings, fields, params, fetchFirstPage, '/notification_message_tokens');
    }
  }, {
    key: 'createNotificationMessagesDevSupport',
    value: function createNotificationMessagesDevSupport(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/notification_messages_dev_support', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getPageBackedInstagramAccounts',
    value: function getPageBackedInstagramAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramUser, fields, params, fetchFirstPage, '/page_backed_instagram_accounts');
    }
  }, {
    key: 'createPageBackedInstagramAccount',
    value: function createPageBackedInstagramAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/page_backed_instagram_accounts', fields, params, InstagramUser, pathOverride);
    }
  }, {
    key: 'createPageWhatsAppNumberVerification',
    value: function createPageWhatsAppNumberVerification(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/page_whatsapp_number_verification', fields, params, Page, pathOverride);
    }
  }, {
    key: 'createPassThreadControl',
    value: function createPassThreadControl(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/pass_thread_control', fields, params, Page, pathOverride);
    }
  }, {
    key: 'createPassThreadMetadatum',
    value: function createPassThreadMetadatum(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/pass_thread_metadata', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getPersonas',
    value: function getPersonas(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Persona, fields, params, fetchFirstPage, '/personas');
    }
  }, {
    key: 'createPersona',
    value: function createPersona(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/personas', fields, params, Persona, pathOverride);
    }
  }, {
    key: 'createPhotoStory',
    value: function createPhotoStory(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/photo_stories', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getPhotos',
    value: function getPhotos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Photo, fields, params, fetchFirstPage, '/photos');
    }
  }, {
    key: 'createPhoto',
    value: function createPhoto(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/photos', fields, params, Photo, pathOverride);
    }
  }, {
    key: 'getPicture',
    value: function getPicture(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProfilePictureSource, fields, params, fetchFirstPage, '/picture');
    }
  }, {
    key: 'createPicture',
    value: function createPicture(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/picture', fields, params, ProfilePictureSource, pathOverride);
    }
  }, {
    key: 'getPosts',
    value: function getPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PagePost, fields, params, fetchFirstPage, '/posts');
    }
  }, {
    key: 'getProductCatalogs',
    value: function getProductCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalog, fields, params, fetchFirstPage, '/product_catalogs');
    }
  }, {
    key: 'getPublishedPosts',
    value: function getPublishedPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PagePost, fields, params, fetchFirstPage, '/published_posts');
    }
  }, {
    key: 'getRatings',
    value: function getRatings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Recommendation, fields, params, fetchFirstPage, '/ratings');
    }
  }, {
    key: 'createReleaseThreadControl',
    value: function createReleaseThreadControl(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/release_thread_control', fields, params, Page, pathOverride);
    }
  }, {
    key: 'createRequestThreadControl',
    value: function createRequestThreadControl(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/request_thread_control', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getRoles',
    value: function getRoles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(User, fields, params, fetchFirstPage, '/roles');
    }
  }, {
    key: 'getRtbDynamicPosts',
    value: function getRtbDynamicPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(RTBDynamicPost, fields, params, fetchFirstPage, '/rtb_dynamic_posts');
    }
  }, {
    key: 'getScheduledPosts',
    value: function getScheduledPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PagePost, fields, params, fetchFirstPage, '/scheduled_posts');
    }
  }, {
    key: 'getSecondaryReceivers',
    value: function getSecondaryReceivers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/secondary_receivers');
    }
  }, {
    key: 'getSettings',
    value: function getSettings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PageSettings, fields, params, fetchFirstPage, '/settings');
    }
  }, {
    key: 'createSetting',
    value: function createSetting(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/settings', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getShopSetupStatus',
    value: function getShopSetupStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommerceMerchantSettingsSetupStatus, fields, params, fetchFirstPage, '/shop_setup_status');
    }
  }, {
    key: 'getStories',
    value: function getStories(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Stories, fields, params, fetchFirstPage, '/stories');
    }
  }, {
    key: 'deleteSubscribedApps',
    value: function deleteSubscribedApps() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Page.prototype.__proto__ || Object.getPrototypeOf(Page.prototype), 'deleteEdge', this).call(this, '/subscribed_apps', params);
    }
  }, {
    key: 'getSubscribedApps',
    value: function getSubscribedApps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/subscribed_apps');
    }
  }, {
    key: 'createSubscribedApp',
    value: function createSubscribedApp(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/subscribed_apps', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getTabs',
    value: function getTabs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Tab, fields, params, fetchFirstPage, '/tabs');
    }
  }, {
    key: 'getTagged',
    value: function getTagged(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PagePost, fields, params, fetchFirstPage, '/tagged');
    }
  }, {
    key: 'createTakeThreadControl',
    value: function createTakeThreadControl(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/take_thread_control', fields, params, Page, pathOverride);
    }
  }, {
    key: 'createThreadAction',
    value: function createThreadAction(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/thread_action', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getThreadOwner',
    value: function getThreadOwner(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PageThreadOwner, fields, params, fetchFirstPage, '/thread_owner');
    }
  }, {
    key: 'getThreads',
    value: function getThreads(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UnifiedThread, fields, params, fetchFirstPage, '/threads');
    }
  }, {
    key: 'createUnlinkAccount',
    value: function createUnlinkAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/unlink_accounts', fields, params, Page, pathOverride);
    }
  }, {
    key: 'getVideoCopyrightRules',
    value: function getVideoCopyrightRules(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(VideoCopyrightRule, fields, params, fetchFirstPage, '/video_copyright_rules');
    }
  }, {
    key: 'createVideoCopyrightRule',
    value: function createVideoCopyrightRule(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/video_copyright_rules', fields, params, VideoCopyrightRule, pathOverride);
    }
  }, {
    key: 'createVideoCopyright',
    value: function createVideoCopyright(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/video_copyrights', fields, params, VideoCopyright, pathOverride);
    }
  }, {
    key: 'getVideoLists',
    value: function getVideoLists(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(VideoList, fields, params, fetchFirstPage, '/video_lists');
    }
  }, {
    key: 'getVideoReels',
    value: function getVideoReels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdVideo, fields, params, fetchFirstPage, '/video_reels');
    }
  }, {
    key: 'createVideoReel',
    value: function createVideoReel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/video_reels', fields, params, AdVideo, pathOverride);
    }
  }, {
    key: 'createVideoStory',
    value: function createVideoStory(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/video_stories', fields, params, null, pathOverride);
    }
  }, {
    key: 'getVideos',
    value: function getVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdVideo, fields, params, fetchFirstPage, '/videos');
    }
  }, {
    key: 'createVideo',
    value: function createVideo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/videos', fields, params, AdVideo, pathOverride);
    }
  }, {
    key: 'getVisitorPosts',
    value: function getVisitorPosts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PagePost, fields, params, fetchFirstPage, '/visitor_posts');
    }
  }, {
    key: 'deleteWelcomeMessageFlows',
    value: function deleteWelcomeMessageFlows() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Page.prototype.__proto__ || Object.getPrototypeOf(Page.prototype), 'deleteEdge', this).call(this, '/welcome_message_flows', params);
    }
  }, {
    key: 'getWelcomeMessageFlows',
    value: function getWelcomeMessageFlows(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CTXPartnerAppWelcomeMessageFlow, fields, params, fetchFirstPage, '/welcome_message_flows');
    }
  }, {
    key: 'createWelcomeMessageFlow',
    value: function createWelcomeMessageFlow(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/welcome_message_flows', fields, params, null, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Page.prototype.__proto__ || Object.getPrototypeOf(Page.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        about: 'about',
        access_token: 'access_token',
        ad_campaign: 'ad_campaign',
        affiliation: 'affiliation',
        app_id: 'app_id',
        artists_we_like: 'artists_we_like',
        attire: 'attire',
        available_promo_offer_ids: 'available_promo_offer_ids',
        awards: 'awards',
        band_interests: 'band_interests',
        band_members: 'band_members',
        best_page: 'best_page',
        bio: 'bio',
        birthday: 'birthday',
        booking_agent: 'booking_agent',
        breaking_news_usage: 'breaking_news_usage',
        built: 'built',
        business: 'business',
        can_checkin: 'can_checkin',
        can_post: 'can_post',
        category: 'category',
        category_list: 'category_list',
        checkins: 'checkins',
        company_overview: 'company_overview',
        connected_instagram_account: 'connected_instagram_account',
        connected_page_backed_instagram_account: 'connected_page_backed_instagram_account',
        contact_address: 'contact_address',
        copyright_whitelisted_ig_partners: 'copyright_whitelisted_ig_partners',
        country_page_likes: 'country_page_likes',
        cover: 'cover',
        culinary_team: 'culinary_team',
        current_location: 'current_location',
        delivery_and_pickup_option_info: 'delivery_and_pickup_option_info',
        description: 'description',
        description_html: 'description_html',
        differently_open_offerings: 'differently_open_offerings',
        directed_by: 'directed_by',
        display_subtext: 'display_subtext',
        displayed_message_response_time: 'displayed_message_response_time',
        does_viewer_have_page_permission_link_ig: 'does_viewer_have_page_permission_link_ig',
        emails: 'emails',
        engagement: 'engagement',
        fan_count: 'fan_count',
        featured_video: 'featured_video',
        features: 'features',
        followers_count: 'followers_count',
        food_styles: 'food_styles',
        founded: 'founded',
        general_info: 'general_info',
        general_manager: 'general_manager',
        genre: 'genre',
        global_brand_page_name: 'global_brand_page_name',
        global_brand_root_id: 'global_brand_root_id',
        has_added_app: 'has_added_app',
        has_lead_access: 'has_lead_access',
        has_transitioned_to_new_page_experience: 'has_transitioned_to_new_page_experience',
        has_whatsapp_business_number: 'has_whatsapp_business_number',
        has_whatsapp_number: 'has_whatsapp_number',
        hometown: 'hometown',
        hours: 'hours',
        id: 'id',
        impressum: 'impressum',
        influences: 'influences',
        instagram_business_account: 'instagram_business_account',
        is_always_open: 'is_always_open',
        is_calling_eligible: 'is_calling_eligible',
        is_chain: 'is_chain',
        is_community_page: 'is_community_page',
        is_eligible_for_branded_content: 'is_eligible_for_branded_content',
        is_eligible_for_disable_connect_ig_btn_for_non_page_admin_am_web: 'is_eligible_for_disable_connect_ig_btn_for_non_page_admin_am_web',
        is_messenger_bot_get_started_enabled: 'is_messenger_bot_get_started_enabled',
        is_messenger_platform_bot: 'is_messenger_platform_bot',
        is_owned: 'is_owned',
        is_permanently_closed: 'is_permanently_closed',
        is_published: 'is_published',
        is_unclaimed: 'is_unclaimed',
        is_verified: 'is_verified',
        is_webhooks_subscribed: 'is_webhooks_subscribed',
        keywords: 'keywords',
        leadgen_tos_acceptance_time: 'leadgen_tos_acceptance_time',
        leadgen_tos_accepted: 'leadgen_tos_accepted',
        leadgen_tos_accepting_user: 'leadgen_tos_accepting_user',
        link: 'link',
        location: 'location',
        members: 'members',
        merchant_id: 'merchant_id',
        merchant_review_status: 'merchant_review_status',
        messaging_feature_status: 'messaging_feature_status',
        messenger_ads_default_icebreakers: 'messenger_ads_default_icebreakers',
        messenger_ads_default_quick_replies: 'messenger_ads_default_quick_replies',
        messenger_ads_quick_replies_type: 'messenger_ads_quick_replies_type',
        mini_shop_storefront: 'mini_shop_storefront',
        mission: 'mission',
        mpg: 'mpg',
        name: 'name',
        name_with_location_descriptor: 'name_with_location_descriptor',
        network: 'network',
        new_like_count: 'new_like_count',
        offer_eligible: 'offer_eligible',
        overall_star_rating: 'overall_star_rating',
        owner_business: 'owner_business',
        page_token: 'page_token',
        parent_page: 'parent_page',
        parking: 'parking',
        payment_options: 'payment_options',
        personal_info: 'personal_info',
        personal_interests: 'personal_interests',
        pharma_safety_info: 'pharma_safety_info',
        phone: 'phone',
        pickup_options: 'pickup_options',
        place_type: 'place_type',
        plot_outline: 'plot_outline',
        preferred_audience: 'preferred_audience',
        press_contact: 'press_contact',
        price_range: 'price_range',
        privacy_info_url: 'privacy_info_url',
        produced_by: 'produced_by',
        products: 'products',
        promotion_eligible: 'promotion_eligible',
        promotion_ineligible_reason: 'promotion_ineligible_reason',
        public_transit: 'public_transit',
        rating_count: 'rating_count',
        recipient: 'recipient',
        record_label: 'record_label',
        release_date: 'release_date',
        restaurant_services: 'restaurant_services',
        restaurant_specialties: 'restaurant_specialties',
        schedule: 'schedule',
        screenplay_by: 'screenplay_by',
        season: 'season',
        single_line_address: 'single_line_address',
        starring: 'starring',
        start_info: 'start_info',
        store_code: 'store_code',
        store_location_descriptor: 'store_location_descriptor',
        store_number: 'store_number',
        studio: 'studio',
        supports_donate_button_in_live_video: 'supports_donate_button_in_live_video',
        talking_about_count: 'talking_about_count',
        temporary_status: 'temporary_status',
        unread_message_count: 'unread_message_count',
        unread_notif_count: 'unread_notif_count',
        unseen_message_count: 'unseen_message_count',
        user_access_expire_time: 'user_access_expire_time',
        username: 'username',
        verification_status: 'verification_status',
        voip_info: 'voip_info',
        website: 'website',
        were_here_count: 'were_here_count',
        whatsapp_number: 'whatsapp_number',
        written_by: 'written_by'
      });
    }
  }, {
    key: 'Attire',
    get: function get() {
      return Object.freeze({
        casual: 'Casual',
        dressy: 'Dressy',
        unspecified: 'Unspecified'
      });
    }
  }, {
    key: 'FoodStyles',
    get: function get() {
      return Object.freeze({
        afghani: 'Afghani',
        american_new_: 'American (New)',
        american_traditional_: 'American (Traditional)',
        asian_fusion: 'Asian Fusion',
        barbeque: 'Barbeque',
        brazilian: 'Brazilian',
        breakfast: 'Breakfast',
        british: 'British',
        brunch: 'Brunch',
        buffets: 'Buffets',
        burgers: 'Burgers',
        burmese: 'Burmese',
        cajun_creole: 'Cajun/Creole',
        caribbean: 'Caribbean',
        chinese: 'Chinese',
        creperies: 'Creperies',
        cuban: 'Cuban',
        delis: 'Delis',
        diners: 'Diners',
        ethiopian: 'Ethiopian',
        fast_food: 'Fast Food',
        filipino: 'Filipino',
        fondue: 'Fondue',
        food_stands: 'Food Stands',
        french: 'French',
        german: 'German',
        greek_and_mediterranean: 'Greek and Mediterranean',
        hawaiian: 'Hawaiian',
        himalayan_nepalese: 'Himalayan/Nepalese',
        hot_dogs: 'Hot Dogs',
        indian_pakistani: 'Indian/Pakistani',
        irish: 'Irish',
        italian: 'Italian',
        japanese: 'Japanese',
        korean: 'Korean',
        latin_american: 'Latin American',
        mexican: 'Mexican',
        middle_eastern: 'Middle Eastern',
        moroccan: 'Moroccan',
        pizza: 'Pizza',
        russian: 'Russian',
        sandwiches: 'Sandwiches',
        seafood: 'Seafood',
        singaporean: 'Singaporean',
        soul_food: 'Soul Food',
        southern: 'Southern',
        spanish_basque: 'Spanish/Basque',
        steakhouses: 'Steakhouses',
        sushi_bars: 'Sushi Bars',
        taiwanese: 'Taiwanese',
        tapas_bars: 'Tapas Bars',
        tex_mex: 'Tex-Mex',
        thai: 'Thai',
        turkish: 'Turkish',
        vegan: 'Vegan',
        vegetarian: 'Vegetarian',
        vietnamese: 'Vietnamese'
      });
    }
  }, {
    key: 'PickupOptions',
    get: function get() {
      return Object.freeze({
        curbside: 'CURBSIDE',
        in_store: 'IN_STORE',
        other: 'OTHER'
      });
    }
  }, {
    key: 'TemporaryStatus',
    get: function get() {
      return Object.freeze({
        differently_open: 'DIFFERENTLY_OPEN',
        no_data: 'NO_DATA',
        operating_as_usual: 'OPERATING_AS_USUAL',
        temporarily_closed: 'TEMPORARILY_CLOSED'
      });
    }
  }, {
    key: 'PermittedTasks',
    get: function get() {
      return Object.freeze({
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        cashier_role: 'CASHIER_ROLE',
        create_content: 'CREATE_CONTENT',
        manage: 'MANAGE',
        manage_jobs: 'MANAGE_JOBS',
        manage_leads: 'MANAGE_LEADS',
        messaging: 'MESSAGING',
        moderate: 'MODERATE',
        moderate_community: 'MODERATE_COMMUNITY',
        pages_messaging: 'PAGES_MESSAGING',
        pages_messaging_subscriptions: 'PAGES_MESSAGING_SUBSCRIPTIONS',
        profile_plus_advertise: 'PROFILE_PLUS_ADVERTISE',
        profile_plus_analyze: 'PROFILE_PLUS_ANALYZE',
        profile_plus_create_content: 'PROFILE_PLUS_CREATE_CONTENT',
        profile_plus_facebook_access: 'PROFILE_PLUS_FACEBOOK_ACCESS',
        profile_plus_full_control: 'PROFILE_PLUS_FULL_CONTROL',
        profile_plus_manage: 'PROFILE_PLUS_MANAGE',
        profile_plus_manage_leads: 'PROFILE_PLUS_MANAGE_LEADS',
        profile_plus_messaging: 'PROFILE_PLUS_MESSAGING',
        profile_plus_moderate: 'PROFILE_PLUS_MODERATE',
        profile_plus_moderate_delegate_community: 'PROFILE_PLUS_MODERATE_DELEGATE_COMMUNITY',
        profile_plus_revenue: 'PROFILE_PLUS_REVENUE',
        read_page_mailboxes: 'READ_PAGE_MAILBOXES',
        view_monetization_insights: 'VIEW_MONETIZATION_INSIGHTS'
      });
    }
  }, {
    key: 'Tasks',
    get: function get() {
      return Object.freeze({
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        cashier_role: 'CASHIER_ROLE',
        create_content: 'CREATE_CONTENT',
        manage: 'MANAGE',
        manage_jobs: 'MANAGE_JOBS',
        manage_leads: 'MANAGE_LEADS',
        messaging: 'MESSAGING',
        moderate: 'MODERATE',
        moderate_community: 'MODERATE_COMMUNITY',
        pages_messaging: 'PAGES_MESSAGING',
        pages_messaging_subscriptions: 'PAGES_MESSAGING_SUBSCRIPTIONS',
        profile_plus_advertise: 'PROFILE_PLUS_ADVERTISE',
        profile_plus_analyze: 'PROFILE_PLUS_ANALYZE',
        profile_plus_create_content: 'PROFILE_PLUS_CREATE_CONTENT',
        profile_plus_facebook_access: 'PROFILE_PLUS_FACEBOOK_ACCESS',
        profile_plus_full_control: 'PROFILE_PLUS_FULL_CONTROL',
        profile_plus_manage: 'PROFILE_PLUS_MANAGE',
        profile_plus_manage_leads: 'PROFILE_PLUS_MANAGE_LEADS',
        profile_plus_messaging: 'PROFILE_PLUS_MESSAGING',
        profile_plus_moderate: 'PROFILE_PLUS_MODERATE',
        profile_plus_moderate_delegate_community: 'PROFILE_PLUS_MODERATE_DELEGATE_COMMUNITY',
        profile_plus_revenue: 'PROFILE_PLUS_REVENUE',
        read_page_mailboxes: 'READ_PAGE_MAILBOXES',
        view_monetization_insights: 'VIEW_MONETIZATION_INSIGHTS'
      });
    }
  }, {
    key: 'Alignment',
    get: function get() {
      return Object.freeze({
        left: 'LEFT',
        right: 'RIGHT'
      });
    }
  }, {
    key: 'EntryPointIcon',
    get: function get() {
      return Object.freeze({
        chat_angular_icon: 'CHAT_ANGULAR_ICON',
        chat_round_icon: 'CHAT_ROUND_ICON',
        messenger_icon: 'MESSENGER_ICON',
        none: 'NONE'
      });
    }
  }, {
    key: 'EntryPointLabel',
    get: function get() {
      return Object.freeze({
        ask_us: 'ASK_US',
        chat: 'CHAT',
        help: 'HELP',
        none: 'NONE'
      });
    }
  }, {
    key: 'GreetingDialogDisplay',
    get: function get() {
      return Object.freeze({
        hide: 'HIDE',
        show: 'SHOW',
        welcome_message: 'WELCOME_MESSAGE'
      });
    }
  }, {
    key: 'GuestChatMode',
    get: function get() {
      return Object.freeze({
        disabled: 'DISABLED',
        enabled: 'ENABLED'
      });
    }
  }, {
    key: 'MobileChatDisplay',
    get: function get() {
      return Object.freeze({
        app_switch: 'APP_SWITCH',
        chat_tab: 'CHAT_TAB'
      });
    }
  }, {
    key: 'BackdatedTimeGranularity',
    get: function get() {
      return Object.freeze({
        day: 'day',
        hour: 'hour',
        min: 'min',
        month: 'month',
        none: 'none',
        year: 'year'
      });
    }
  }, {
    key: 'Formatting',
    get: function get() {
      return Object.freeze({
        markdown: 'MARKDOWN',
        plaintext: 'PLAINTEXT'
      });
    }
  }, {
    key: 'PlaceAttachmentSetting',
    get: function get() {
      return Object.freeze({
        value_1: '1',
        value_2: '2'
      });
    }
  }, {
    key: 'PostSurfacesBlacklist',
    get: function get() {
      return Object.freeze({
        value_1: '1',
        value_2: '2',
        value_3: '3',
        value_4: '4',
        value_5: '5'
      });
    }
  }, {
    key: 'PostingToRedspace',
    get: function get() {
      return Object.freeze({
        disabled: 'disabled',
        enabled: 'enabled'
      });
    }
  }, {
    key: 'TargetSurface',
    get: function get() {
      return Object.freeze({
        story: 'STORY',
        timeline: 'TIMELINE'
      });
    }
  }, {
    key: 'UnpublishedContentType',
    get: function get() {
      return Object.freeze({
        ads_post: 'ADS_POST',
        draft: 'DRAFT',
        inline_created: 'INLINE_CREATED',
        published: 'PUBLISHED',
        reviewable_branded_content: 'REVIEWABLE_BRANDED_CONTENT',
        scheduled: 'SCHEDULED',
        scheduled_recurring: 'SCHEDULED_RECURRING'
      });
    }
  }, {
    key: 'MessagingType',
    get: function get() {
      return Object.freeze({
        message_tag: 'MESSAGE_TAG',
        response: 'RESPONSE',
        update: 'UPDATE',
        utility: 'UTILITY'
      });
    }
  }, {
    key: 'NotificationType',
    get: function get() {
      return Object.freeze({
        no_push: 'NO_PUSH',
        regular: 'REGULAR',
        silent_push: 'SILENT_PUSH'
      });
    }
  }, {
    key: 'SenderAction',
    get: function get() {
      return Object.freeze({
        mark_seen: 'MARK_SEEN',
        react: 'REACT',
        typing_off: 'TYPING_OFF',
        typing_on: 'TYPING_ON',
        unreact: 'UNREACT'
      });
    }
  }, {
    key: 'SuggestionAction',
    get: function get() {
      return Object.freeze({
        accept: 'ACCEPT',
        dismiss: 'DISMISS',
        impression: 'IMPRESSION'
      });
    }
  }, {
    key: 'Platform',
    get: function get() {
      return Object.freeze({
        instagram: 'INSTAGRAM',
        messenger: 'MESSENGER'
      });
    }
  }, {
    key: 'Model',
    get: function get() {
      return Object.freeze({
        arabic: 'ARABIC',
        chinese: 'CHINESE',
        croatian: 'CROATIAN',
        custom: 'CUSTOM',
        danish: 'DANISH',
        dutch: 'DUTCH',
        english: 'ENGLISH',
        french_standard: 'FRENCH_STANDARD',
        georgian: 'GEORGIAN',
        german_standard: 'GERMAN_STANDARD',
        greek: 'GREEK',
        hebrew: 'HEBREW',
        hungarian: 'HUNGARIAN',
        irish: 'IRISH',
        italian_standard: 'ITALIAN_STANDARD',
        korean: 'KOREAN',
        norwegian_bokmal: 'NORWEGIAN_BOKMAL',
        polish: 'POLISH',
        portuguese: 'PORTUGUESE',
        romanian: 'ROMANIAN',
        spanish: 'SPANISH',
        swedish: 'SWEDISH',
        vietnamese: 'VIETNAMESE'
      });
    }
  }, {
    key: 'DeveloperAction',
    get: function get() {
      return Object.freeze({
        enable_followup_message: 'ENABLE_FOLLOWUP_MESSAGE'
      });
    }
  }, {
    key: 'SubscribedFields',
    get: function get() {
      return Object.freeze({
        affiliation: 'affiliation',
        attire: 'attire',
        awards: 'awards',
        bio: 'bio',
        birthday: 'birthday',
        call_permission_reply: 'call_permission_reply',
        calls: 'calls',
        category: 'category',
        checkins: 'checkins',
        company_overview: 'company_overview',
        conversations: 'conversations',
        culinary_team: 'culinary_team',
        current_location: 'current_location',
        description: 'description',
        email: 'email',
        feature_access_list: 'feature_access_list',
        feed: 'feed',
        founded: 'founded',
        general_info: 'general_info',
        general_manager: 'general_manager',
        group_feed: 'group_feed',
        hometown: 'hometown',
        hours: 'hours',
        inbox_labels: 'inbox_labels',
        invalid_topic_placeholder: 'invalid_topic_placeholder',
        invoice_access_bank_slip_events: 'invoice_access_bank_slip_events',
        invoice_access_invoice_change: 'invoice_access_invoice_change',
        invoice_access_invoice_draft_change: 'invoice_access_invoice_draft_change',
        invoice_access_onboarding_status_active: 'invoice_access_onboarding_status_active',
        leadgen: 'leadgen',
        leadgen_fat: 'leadgen_fat',
        live_videos: 'live_videos',
        local_delivery: 'local_delivery',
        location: 'location',
        mcom_invoice_change: 'mcom_invoice_change',
        members: 'members',
        mention: 'mention',
        merchant_review: 'merchant_review',
        message_context: 'message_context',
        message_deliveries: 'message_deliveries',
        message_echoes: 'message_echoes',
        message_edits: 'message_edits',
        message_mention: 'message_mention',
        message_reactions: 'message_reactions',
        message_reads: 'message_reads',
        messages: 'messages',
        messaging_account_linking: 'messaging_account_linking',
        messaging_appointments: 'messaging_appointments',
        messaging_checkout_updates: 'messaging_checkout_updates',
        messaging_customer_information: 'messaging_customer_information',
        messaging_direct_sends: 'messaging_direct_sends',
        messaging_fblogin_account_linking: 'messaging_fblogin_account_linking',
        messaging_feedback: 'messaging_feedback',
        messaging_game_plays: 'messaging_game_plays',
        messaging_handovers: 'messaging_handovers',
        messaging_in_thread_lead_form_submit: 'messaging_in_thread_lead_form_submit',
        messaging_integrity: 'messaging_integrity',
        messaging_optins: 'messaging_optins',
        messaging_optouts: 'messaging_optouts',
        messaging_payments: 'messaging_payments',
        messaging_policy_enforcement: 'messaging_policy_enforcement',
        messaging_postbacks: 'messaging_postbacks',
        messaging_pre_checkouts: 'messaging_pre_checkouts',
        messaging_referrals: 'messaging_referrals',
        mission: 'mission',
        name: 'name',
        otp_verification: 'otp_verification',
        page_about_story: 'page_about_story',
        page_change_proposal: 'page_change_proposal',
        page_upcoming_change: 'page_upcoming_change',
        parking: 'parking',
        payment_options: 'payment_options',
        payment_request_update: 'payment_request_update',
        personal_info: 'personal_info',
        personal_interests: 'personal_interests',
        phone: 'phone',
        picture: 'picture',
        price_range: 'price_range',
        product_review: 'product_review',
        products: 'products',
        public_transit: 'public_transit',
        publisher_subscriptions: 'publisher_subscriptions',
        ratings: 'ratings',
        registration: 'registration',
        response_feedback: 'response_feedback',
        send_cart: 'send_cart',
        standby: 'standby',
        user_action: 'user_action',
        video_text_question_responses: 'video_text_question_responses',
        videos: 'videos',
        website: 'website'
      });
    }
  }, {
    key: 'Action',
    get: function get() {
      return Object.freeze({
        spam: 'SPAM'
      });
    }
  }, {
    key: 'ActionType',
    get: function get() {
      return Object.freeze({
        report_thread: 'REPORT_THREAD'
      });
    }
  }]);
  return Page;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Photo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Photo = function (_AbstractCrudObject) {
  inherits(Photo, _AbstractCrudObject);

  function Photo() {
    classCallCheck(this, Photo);
    return possibleConstructorReturn(this, (Photo.__proto__ || Object.getPrototypeOf(Photo)).apply(this, arguments));
  }

  createClass(Photo, [{
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Comment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, Comment, pathOverride);
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InsightsResult, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'getLikes',
    value: function getLikes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/likes');
    }
  }, {
    key: 'createLike',
    value: function createLike(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/likes', fields, params, Photo, pathOverride);
    }
  }, {
    key: 'getSponsorTags',
    value: function getSponsorTags(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/sponsor_tags');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Photo.prototype.__proto__ || Object.getPrototypeOf(Photo.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        album: 'album',
        alt_text: 'alt_text',
        alt_text_custom: 'alt_text_custom',
        backdated_time: 'backdated_time',
        backdated_time_granularity: 'backdated_time_granularity',
        can_backdate: 'can_backdate',
        can_delete: 'can_delete',
        can_tag: 'can_tag',
        created_time: 'created_time',
        event: 'event',
        from: 'from',
        height: 'height',
        icon: 'icon',
        id: 'id',
        images: 'images',
        link: 'link',
        name: 'name',
        name_tags: 'name_tags',
        page_story_id: 'page_story_id',
        picture: 'picture',
        place: 'place',
        position: 'position',
        source: 'source',
        target: 'target',
        updated_time: 'updated_time',
        webp_images: 'webp_images',
        width: 'width'
      });
    }
  }, {
    key: 'BackdatedTimeGranularity',
    get: function get() {
      return Object.freeze({
        day: 'day',
        hour: 'hour',
        min: 'min',
        month: 'month',
        none: 'none',
        year: 'year'
      });
    }
  }, {
    key: 'UnpublishedContentType',
    get: function get() {
      return Object.freeze({
        ads_post: 'ADS_POST',
        draft: 'DRAFT',
        inline_created: 'INLINE_CREATED',
        published: 'PUBLISHED',
        reviewable_branded_content: 'REVIEWABLE_BRANDED_CONTENT',
        scheduled: 'SCHEDULED',
        scheduled_recurring: 'SCHEDULED_RECURRING'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        profile: 'profile',
        tagged: 'tagged',
        uploaded: 'uploaded'
      });
    }
  }]);
  return Photo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Album
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Album = function (_AbstractCrudObject) {
  inherits(Album, _AbstractCrudObject);

  function Album() {
    classCallCheck(this, Album);
    return possibleConstructorReturn(this, (Album.__proto__ || Object.getPrototypeOf(Album)).apply(this, arguments));
  }

  createClass(Album, [{
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Comment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, Comment, pathOverride);
    }
  }, {
    key: 'getLikes',
    value: function getLikes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/likes');
    }
  }, {
    key: 'createLike',
    value: function createLike(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/likes', fields, params, Album, pathOverride);
    }
  }, {
    key: 'getPhotos',
    value: function getPhotos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Photo, fields, params, fetchFirstPage, '/photos');
    }
  }, {
    key: 'createPhoto',
    value: function createPhoto(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/photos', fields, params, Photo, pathOverride);
    }
  }, {
    key: 'getPicture',
    value: function getPicture(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProfilePictureSource, fields, params, fetchFirstPage, '/picture');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        backdated_time: 'backdated_time',
        backdated_time_granularity: 'backdated_time_granularity',
        can_backdate: 'can_backdate',
        can_upload: 'can_upload',
        count: 'count',
        cover_photo: 'cover_photo',
        created_time: 'created_time',
        description: 'description',
        edit_link: 'edit_link',
        event: 'event',
        from: 'from',
        id: 'id',
        is_user_facing: 'is_user_facing',
        link: 'link',
        location: 'location',
        modified_major: 'modified_major',
        name: 'name',
        photo_count: 'photo_count',
        place: 'place',
        privacy: 'privacy',
        type: 'type',
        updated_time: 'updated_time',
        video_count: 'video_count'
      });
    }
  }]);
  return Album;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Group
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Group = function (_AbstractCrudObject) {
  inherits(Group, _AbstractCrudObject);

  function Group() {
    classCallCheck(this, Group);
    return possibleConstructorReturn(this, (Group.__proto__ || Object.getPrototypeOf(Group)).apply(this, arguments));
  }

  createClass(Group, [{
    key: 'deleteAdmins',
    value: function deleteAdmins() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Group.prototype.__proto__ || Object.getPrototypeOf(Group.prototype), 'deleteEdge', this).call(this, '/admins', params);
    }
  }, {
    key: 'createAdmin',
    value: function createAdmin(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/admins', fields, params, Group, pathOverride);
    }
  }, {
    key: 'getAlbums',
    value: function getAlbums(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Album, fields, params, fetchFirstPage, '/albums');
    }
  }, {
    key: 'getDocs',
    value: function getDocs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/docs');
    }
  }, {
    key: 'getEvents',
    value: function getEvents(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Event, fields, params, fetchFirstPage, '/events');
    }
  }, {
    key: 'getFeed',
    value: function getFeed(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Post, fields, params, fetchFirstPage, '/feed');
    }
  }, {
    key: 'createFeed',
    value: function createFeed(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/feed', fields, params, Post, pathOverride);
    }
  }, {
    key: 'getFiles',
    value: function getFiles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/files');
    }
  }, {
    key: 'getGroups',
    value: function getGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Group, fields, params, fetchFirstPage, '/groups');
    }
  }, {
    key: 'createGroup',
    value: function createGroup(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/groups', fields, params, Group, pathOverride);
    }
  }, {
    key: 'getLiveVideos',
    value: function getLiveVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(LiveVideo, fields, params, fetchFirstPage, '/live_videos');
    }
  }, {
    key: 'createLiveVideo',
    value: function createLiveVideo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/live_videos', fields, params, LiveVideo, pathOverride);
    }
  }, {
    key: 'deleteMembers',
    value: function deleteMembers() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Group.prototype.__proto__ || Object.getPrototypeOf(Group.prototype), 'deleteEdge', this).call(this, '/members', params);
    }
  }, {
    key: 'createMember',
    value: function createMember(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/members', fields, params, Group, pathOverride);
    }
  }, {
    key: 'getOptedInMembers',
    value: function getOptedInMembers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(User, fields, params, fetchFirstPage, '/opted_in_members');
    }
  }, {
    key: 'createPhoto',
    value: function createPhoto(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/photos', fields, params, Photo, pathOverride);
    }
  }, {
    key: 'getPicture',
    value: function getPicture(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProfilePictureSource, fields, params, fetchFirstPage, '/picture');
    }
  }, {
    key: 'getVideos',
    value: function getVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdVideo, fields, params, fetchFirstPage, '/videos');
    }
  }, {
    key: 'createVideo',
    value: function createVideo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/videos', fields, params, AdVideo, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Group.prototype.__proto__ || Object.getPrototypeOf(Group.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        archived: 'archived',
        cover: 'cover',
        created_time: 'created_time',
        description: 'description',
        email: 'email',
        icon: 'icon',
        id: 'id',
        install: 'install',
        link: 'link',
        member_count: 'member_count',
        member_request_count: 'member_request_count',
        name: 'name',
        parent: 'parent',
        permissions: 'permissions',
        privacy: 'privacy',
        purpose: 'purpose',
        subdomain: 'subdomain',
        updated_time: 'updated_time',
        venue: 'venue'
      });
    }
  }, {
    key: 'JoinSetting',
    get: function get() {
      return Object.freeze({
        admin_only: 'ADMIN_ONLY',
        anyone: 'ANYONE',
        none: 'NONE'
      });
    }
  }, {
    key: 'PostPermissions',
    get: function get() {
      return Object.freeze({
        admin_only: 'ADMIN_ONLY',
        anyone: 'ANYONE',
        none: 'NONE'
      });
    }
  }, {
    key: 'Purpose',
    get: function get() {
      return Object.freeze({
        casual: 'CASUAL',
        coworkers: 'COWORKERS',
        custom: 'CUSTOM',
        for_sale: 'FOR_SALE',
        for_work: 'FOR_WORK',
        game: 'GAME',
        health_support: 'HEALTH_SUPPORT',
        jobs: 'JOBS',
        learning: 'LEARNING',
        none: 'NONE',
        parenting: 'PARENTING',
        streamer: 'STREAMER',
        work_announcement: 'WORK_ANNOUNCEMENT',
        work_demo_group: 'WORK_DEMO_GROUP',
        work_discussion: 'WORK_DISCUSSION',
        work_ephemeral: 'WORK_EPHEMERAL',
        work_feedback: 'WORK_FEEDBACK',
        work_for_sale: 'WORK_FOR_SALE',
        work_garden: 'WORK_GARDEN',
        work_integrity: 'WORK_INTEGRITY',
        work_learning: 'WORK_LEARNING',
        work_mentorship: 'WORK_MENTORSHIP',
        work_multi_company: 'WORK_MULTI_COMPANY',
        work_recruiting: 'WORK_RECRUITING',
        work_social: 'WORK_SOCIAL',
        work_stages: 'WORK_STAGES',
        work_team: 'WORK_TEAM',
        work_teamwork: 'WORK_TEAMWORK'
      });
    }
  }, {
    key: 'GroupType',
    get: function get() {
      return Object.freeze({
        casual: 'CASUAL',
        coworkers: 'COWORKERS',
        custom: 'CUSTOM',
        for_sale: 'FOR_SALE',
        for_work: 'FOR_WORK',
        game: 'GAME',
        health_support: 'HEALTH_SUPPORT',
        jobs: 'JOBS',
        learning: 'LEARNING',
        none: 'NONE',
        parenting: 'PARENTING',
        streamer: 'STREAMER',
        work_announcement: 'WORK_ANNOUNCEMENT',
        work_demo_group: 'WORK_DEMO_GROUP',
        work_discussion: 'WORK_DISCUSSION',
        work_ephemeral: 'WORK_EPHEMERAL',
        work_feedback: 'WORK_FEEDBACK',
        work_for_sale: 'WORK_FOR_SALE',
        work_garden: 'WORK_GARDEN',
        work_integrity: 'WORK_INTEGRITY',
        work_learning: 'WORK_LEARNING',
        work_mentorship: 'WORK_MENTORSHIP',
        work_multi_company: 'WORK_MULTI_COMPANY',
        work_recruiting: 'WORK_RECRUITING',
        work_social: 'WORK_SOCIAL',
        work_stages: 'WORK_STAGES',
        work_team: 'WORK_TEAM',
        work_teamwork: 'WORK_TEAMWORK'
      });
    }
  }]);
  return Group;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DACheck
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DACheck = function (_AbstractCrudObject) {
  inherits(DACheck, _AbstractCrudObject);

  function DACheck() {
    classCallCheck(this, DACheck);
    return possibleConstructorReturn(this, (DACheck.__proto__ || Object.getPrototypeOf(DACheck)).apply(this, arguments));
  }

  createClass(DACheck, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action_uri: 'action_uri',
        description: 'description',
        key: 'key',
        result: 'result',
        title: 'title',
        user_message: 'user_message'
      });
    }
  }, {
    key: 'ConnectionMethod',
    get: function get() {
      return Object.freeze({
        all: 'ALL',
        app: 'APP',
        browser: 'BROWSER',
        server: 'SERVER'
      });
    }
  }]);
  return DACheck;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsDataset
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsDataset = function (_AbstractCrudObject) {
  inherits(AdsDataset, _AbstractCrudObject);

  function AdsDataset() {
    classCallCheck(this, AdsDataset);
    return possibleConstructorReturn(this, (AdsDataset.__proto__ || Object.getPrototypeOf(AdsDataset)).apply(this, arguments));
  }

  createClass(AdsDataset, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_proxy: 'can_proxy',
        collection_rate: 'collection_rate',
        config: 'config',
        creation_time: 'creation_time',
        creator: 'creator',
        dataset_id: 'dataset_id',
        description: 'description',
        duplicate_entries: 'duplicate_entries',
        enable_auto_assign_to_accounts: 'enable_auto_assign_to_accounts',
        enable_automatic_events: 'enable_automatic_events',
        enable_automatic_matching: 'enable_automatic_matching',
        enable_real_time_event_log: 'enable_real_time_event_log',
        event_stats: 'event_stats',
        event_time_max: 'event_time_max',
        event_time_min: 'event_time_min',
        first_party_cookie_status: 'first_party_cookie_status',
        has_bapi_domains: 'has_bapi_domains',
        has_catalog_microdata_activity: 'has_catalog_microdata_activity',
        has_ofa_redacted_keys: 'has_ofa_redacted_keys',
        has_sent_pii: 'has_sent_pii',
        id: 'id',
        is_consolidated_container: 'is_consolidated_container',
        is_created_by_business: 'is_created_by_business',
        is_crm: 'is_crm',
        is_eligible_for_sharing_to_ad_account: 'is_eligible_for_sharing_to_ad_account',
        is_eligible_for_sharing_to_business: 'is_eligible_for_sharing_to_business',
        is_eligible_for_value_optimization: 'is_eligible_for_value_optimization',
        is_mta_use: 'is_mta_use',
        is_restricted_use: 'is_restricted_use',
        is_unavailable: 'is_unavailable',
        last_fired_time: 'last_fired_time',
        last_upload_app: 'last_upload_app',
        last_upload_app_changed_time: 'last_upload_app_changed_time',
        last_upload_time: 'last_upload_time',
        late_upload_reminder_eligibility: 'late_upload_reminder_eligibility',
        match_rate_approx: 'match_rate_approx',
        matched_entries: 'matched_entries',
        name: 'name',
        no_ads_tracked_for_weekly_uploaded_events_reminder_eligibility: 'no_ads_tracked_for_weekly_uploaded_events_reminder_eligibility',
        num_active_ad_set_tracked: 'num_active_ad_set_tracked',
        num_recent_offline_conversions_uploaded: 'num_recent_offline_conversions_uploaded',
        num_uploads: 'num_uploads',
        owner_ad_account: 'owner_ad_account',
        owner_business: 'owner_business',
        percentage_of_late_uploads_in_external_suboptimal_window: 'percentage_of_late_uploads_in_external_suboptimal_window',
        permissions: 'permissions',
        server_last_fired_time: 'server_last_fired_time',
        show_automatic_events: 'show_automatic_events',
        upload_rate: 'upload_rate',
        upload_reminder_eligibility: 'upload_reminder_eligibility',
        usage: 'usage',
        valid_entries: 'valid_entries'
      });
    }
  }]);
  return AdsDataset;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Application
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Application = function (_AbstractCrudObject) {
  inherits(Application, _AbstractCrudObject);

  function Application() {
    classCallCheck(this, Application);
    return possibleConstructorReturn(this, (Application.__proto__ || Object.getPrototypeOf(Application)).apply(this, arguments));
  }

  createClass(Application, [{
    key: 'deleteAccounts',
    value: function deleteAccounts() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Application.prototype.__proto__ || Object.getPrototypeOf(Application.prototype), 'deleteEdge', this).call(this, '/accounts', params);
    }
  }, {
    key: 'getAccounts',
    value: function getAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/accounts');
    }
  }, {
    key: 'createAccount',
    value: function createAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/accounts', fields, params, null, pathOverride);
    }
  }, {
    key: 'createActivity',
    value: function createActivity(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/activities', fields, params, null, pathOverride);
    }
  }, {
    key: 'getAdPlacementGroups',
    value: function getAdPlacementGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/ad_placement_groups');
    }
  }, {
    key: 'getAdNetworkPlacements',
    value: function getAdNetworkPlacements(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdPlacement, fields, params, fetchFirstPage, '/adnetwork_placements');
    }
  }, {
    key: 'getAdNetworkAnalytics',
    value: function getAdNetworkAnalytics(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdNetworkAnalyticsSyncQueryResult, fields, params, fetchFirstPage, '/adnetworkanalytics');
    }
  }, {
    key: 'createAdNetworkAnalytic',
    value: function createAdNetworkAnalytic(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adnetworkanalytics', fields, params, Application, pathOverride);
    }
  }, {
    key: 'getAdNetworkAnalyticsResults',
    value: function getAdNetworkAnalyticsResults(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdNetworkAnalyticsAsyncQueryResult, fields, params, fetchFirstPage, '/adnetworkanalytics_results');
    }
  }, {
    key: 'getAemAttribution',
    value: function getAemAttribution(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/aem_attribution');
    }
  }, {
    key: 'getAemConversionConfigs',
    value: function getAemConversionConfigs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/aem_conversion_configs');
    }
  }, {
    key: 'getAemConversionFilter',
    value: function getAemConversionFilter(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/aem_conversion_filter');
    }
  }, {
    key: 'createAemConversion',
    value: function createAemConversion(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/aem_conversions', fields, params, null, pathOverride);
    }
  }, {
    key: 'createAemSkanReadiness',
    value: function createAemSkanReadiness(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/aem_skan_readiness', fields, params, null, pathOverride);
    }
  }, {
    key: 'getAgencies',
    value: function getAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/agencies');
    }
  }, {
    key: 'createAggregateRevenue',
    value: function createAggregateRevenue(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/aggregate_revenue', fields, params, null, pathOverride);
    }
  }, {
    key: 'getAndroidDialogConfigs',
    value: function getAndroidDialogConfigs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/android_dialog_configs');
    }
  }, {
    key: 'getAppCapiSettings',
    value: function getAppCapiSettings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/app_capi_settings');
    }
  }, {
    key: 'getAppEventTypes',
    value: function getAppEventTypes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/app_event_types');
    }
  }, {
    key: 'createAppIndexing',
    value: function createAppIndexing(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/app_indexing', fields, params, Application, pathOverride);
    }
  }, {
    key: 'createAppIndexingSession',
    value: function createAppIndexingSession(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/app_indexing_session', fields, params, Application, pathOverride);
    }
  }, {
    key: 'getAppInstalledGroups',
    value: function getAppInstalledGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Group, fields, params, fetchFirstPage, '/app_installed_groups');
    }
  }, {
    key: 'createAppPushDeviceToken',
    value: function createAppPushDeviceToken(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/app_push_device_token', fields, params, Application, pathOverride);
    }
  }, {
    key: 'getAppAssets',
    value: function getAppAssets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/appassets');
    }
  }, {
    key: 'createAsset',
    value: function createAsset(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/assets', fields, params, Application, pathOverride);
    }
  }, {
    key: 'getAuthorizedAdAccounts',
    value: function getAuthorizedAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/authorized_adaccounts');
    }
  }, {
    key: 'getButtonAutoDetectionDeviceSelection',
    value: function getButtonAutoDetectionDeviceSelection(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/button_auto_detection_device_selection');
    }
  }, {
    key: 'getCloudbridgeSettings',
    value: function getCloudbridgeSettings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/cloudbridge_settings');
    }
  }, {
    key: 'createCodelessEventMapping',
    value: function createCodelessEventMapping(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/codeless_event_mappings', fields, params, Application, pathOverride);
    }
  }, {
    key: 'getDaChecks',
    value: function getDaChecks(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DACheck, fields, params, fetchFirstPage, '/da_checks');
    }
  }, {
    key: 'createDomainReport',
    value: function createDomainReport(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/domain_reports', fields, params, null, pathOverride);
    }
  }, {
    key: 'getIapPurchases',
    value: function getIapPurchases(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/iap_purchases');
    }
  }, {
    key: 'getIosDialogConfigs',
    value: function getIosDialogConfigs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/ios_dialog_configs');
    }
  }, {
    key: 'getLinkedDataset',
    value: function getLinkedDataset(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsDataset, fields, params, fetchFirstPage, '/linked_dataset');
    }
  }, {
    key: 'getMessageTemplates',
    value: function getMessageTemplates(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/message_templates');
    }
  }, {
    key: 'createMmpAuditing',
    value: function createMmpAuditing(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/mmp_auditing', fields, params, null, pathOverride);
    }
  }, {
    key: 'getMobileSdkGk',
    value: function getMobileSdkGk(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/mobile_sdk_gk');
    }
  }, {
    key: 'getMonetizedDigitalStoreObjects',
    value: function getMonetizedDigitalStoreObjects(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/monetized_digital_store_objects');
    }
  }, {
    key: 'createMonetizedDigitalStoreObject',
    value: function createMonetizedDigitalStoreObject(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/monetized_digital_store_objects', fields, params, null, pathOverride);
    }
  }, {
    key: 'getObjectTypes',
    value: function getObjectTypes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NullNode, fields, params, fetchFirstPage, '/object_types');
    }
  }, {
    key: 'getObjects',
    value: function getObjects(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NullNode, fields, params, fetchFirstPage, '/objects');
    }
  }, {
    key: 'createOccludesPopup',
    value: function createOccludesPopup(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/occludespopups', fields, params, null, pathOverride);
    }
  }, {
    key: 'createPaymentCurrency',
    value: function createPaymentCurrency(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/payment_currencies', fields, params, Application, pathOverride);
    }
  }, {
    key: 'getPermissions',
    value: function getPermissions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/permissions');
    }
  }, {
    key: 'getProducts',
    value: function getProducts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/products');
    }
  }, {
    key: 'getPurchases',
    value: function getPurchases(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/purchases');
    }
  }, {
    key: 'getRoles',
    value: function getRoles(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/roles');
    }
  }, {
    key: 'getServerDomainInfos',
    value: function getServerDomainInfos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/server_domain_infos');
    }
  }, {
    key: 'getSubscribedDomains',
    value: function getSubscribedDomains(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/subscribed_domains');
    }
  }, {
    key: 'createSubscribedDomain',
    value: function createSubscribedDomain(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/subscribed_domains', fields, params, Application, pathOverride);
    }
  }, {
    key: 'getSubscribedDomainsPhishing',
    value: function getSubscribedDomainsPhishing(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/subscribed_domains_phishing');
    }
  }, {
    key: 'createSubscribedDomainsPhishing',
    value: function createSubscribedDomainsPhishing(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/subscribed_domains_phishing', fields, params, Application, pathOverride);
    }
  }, {
    key: 'deleteSubscriptions',
    value: function deleteSubscriptions() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Application.prototype.__proto__ || Object.getPrototypeOf(Application.prototype), 'deleteEdge', this).call(this, '/subscriptions', params);
    }
  }, {
    key: 'getSubscriptions',
    value: function getSubscriptions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/subscriptions');
    }
  }, {
    key: 'createSubscription',
    value: function createSubscription(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/subscriptions', fields, params, null, pathOverride);
    }
  }, {
    key: 'createUpload',
    value: function createUpload(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/uploads', fields, params, null, pathOverride);
    }
  }, {
    key: 'createWhatsAppBusinessSolution',
    value: function createWhatsAppBusinessSolution(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/whatsapp_business_solution', fields, params, Application, pathOverride);
    }
  }, {
    key: 'getWhatsAppBusinessSolutions',
    value: function getWhatsAppBusinessSolutions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/whatsapp_business_solutions');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Application.prototype.__proto__ || Object.getPrototypeOf(Application.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        aam_rules: 'aam_rules',
        an_ad_space_limit: 'an_ad_space_limit',
        an_platforms: 'an_platforms',
        android_key_hash: 'android_key_hash',
        android_sdk_error_categories: 'android_sdk_error_categories',
        app_domains: 'app_domains',
        app_events_config: 'app_events_config',
        app_events_feature_bitmask: 'app_events_feature_bitmask',
        app_events_session_timeout: 'app_events_session_timeout',
        app_install_tracked: 'app_install_tracked',
        app_name: 'app_name',
        app_signals_binding_ios: 'app_signals_binding_ios',
        app_type: 'app_type',
        auth_dialog_data_help_url: 'auth_dialog_data_help_url',
        auth_dialog_headline: 'auth_dialog_headline',
        auth_dialog_perms_explanation: 'auth_dialog_perms_explanation',
        auth_referral_default_activity_privacy: 'auth_referral_default_activity_privacy',
        auth_referral_enabled: 'auth_referral_enabled',
        auth_referral_extended_perms: 'auth_referral_extended_perms',
        auth_referral_friend_perms: 'auth_referral_friend_perms',
        auth_referral_response_type: 'auth_referral_response_type',
        auth_referral_user_perms: 'auth_referral_user_perms',
        auto_event_mapping_android: 'auto_event_mapping_android',
        auto_event_mapping_ios: 'auto_event_mapping_ios',
        auto_event_setup_enabled: 'auto_event_setup_enabled',
        auto_log_app_events_default: 'auto_log_app_events_default',
        auto_log_app_events_enabled: 'auto_log_app_events_enabled',
        business: 'business',
        canvas_fluid_height: 'canvas_fluid_height',
        canvas_fluid_width: 'canvas_fluid_width',
        canvas_url: 'canvas_url',
        category: 'category',
        client_config: 'client_config',
        company: 'company',
        configured_ios_sso: 'configured_ios_sso',
        contact_email: 'contact_email',
        created_time: 'created_time',
        creator_uid: 'creator_uid',
        daily_active_users: 'daily_active_users',
        daily_active_users_rank: 'daily_active_users_rank',
        deauth_callback_url: 'deauth_callback_url',
        default_share_mode: 'default_share_mode',
        description: 'description',
        financial_id: 'financial_id',
        gdpv4_chrome_custom_tabs_enabled: 'gdpv4_chrome_custom_tabs_enabled',
        gdpv4_enabled: 'gdpv4_enabled',
        gdpv4_nux_content: 'gdpv4_nux_content',
        gdpv4_nux_enabled: 'gdpv4_nux_enabled',
        has_messenger_product: 'has_messenger_product',
        hosting_url: 'hosting_url',
        icon_url: 'icon_url',
        id: 'id',
        ios_bundle_id: 'ios_bundle_id',
        ios_sdk_dialog_flows: 'ios_sdk_dialog_flows',
        ios_sdk_error_categories: 'ios_sdk_error_categories',
        ios_sfvc_attr: 'ios_sfvc_attr',
        ios_supports_native_proxy_auth_flow: 'ios_supports_native_proxy_auth_flow',
        ios_supports_system_auth: 'ios_supports_system_auth',
        ipad_app_store_id: 'ipad_app_store_id',
        iphone_app_store_id: 'iphone_app_store_id',
        latest_sdk_version: 'latest_sdk_version',
        link: 'link',
        logging_token: 'logging_token',
        logo_url: 'logo_url',
        migrations: 'migrations',
        mobile_profile_section_url: 'mobile_profile_section_url',
        mobile_web_url: 'mobile_web_url',
        monthly_active_users: 'monthly_active_users',
        monthly_active_users_rank: 'monthly_active_users_rank',
        name: 'name',
        namespace: 'namespace',
        object_store_urls: 'object_store_urls',
        owner_business: 'owner_business',
        page_tab_default_name: 'page_tab_default_name',
        page_tab_url: 'page_tab_url',
        photo_url: 'photo_url',
        privacy_policy_url: 'privacy_policy_url',
        profile_section_url: 'profile_section_url',
        property_id: 'property_id',
        protected_mode_rules: 'protected_mode_rules',
        real_time_mode_devices: 'real_time_mode_devices',
        restrictions: 'restrictions',
        restrictive_data_filter_params: 'restrictive_data_filter_params',
        restrictive_data_filter_rules: 'restrictive_data_filter_rules',
        sdk_update_message: 'sdk_update_message',
        seamless_login: 'seamless_login',
        secure_canvas_url: 'secure_canvas_url',
        secure_page_tab_url: 'secure_page_tab_url',
        server_ip_whitelist: 'server_ip_whitelist',
        smart_login_bookmark_icon_url: 'smart_login_bookmark_icon_url',
        smart_login_menu_icon_url: 'smart_login_menu_icon_url',
        social_discovery: 'social_discovery',
        subcategory: 'subcategory',
        suggested_events_setting: 'suggested_events_setting',
        supported_platforms: 'supported_platforms',
        supports_apprequests_fast_app_switch: 'supports_apprequests_fast_app_switch',
        supports_attribution: 'supports_attribution',
        supports_implicit_sdk_logging: 'supports_implicit_sdk_logging',
        suppress_native_ios_gdp: 'suppress_native_ios_gdp',
        terms_of_service_url: 'terms_of_service_url',
        url_scheme_suffix: 'url_scheme_suffix',
        user_support_email: 'user_support_email',
        user_support_url: 'user_support_url',
        website_url: 'website_url',
        weekly_active_users: 'weekly_active_users'
      });
    }
  }, {
    key: 'SupportedPlatforms',
    get: function get() {
      return Object.freeze({
        amazon: 'AMAZON',
        android: 'ANDROID',
        canvas: 'CANVAS',
        gameroom: 'GAMEROOM',
        instant_game: 'INSTANT_GAME',
        ipad: 'IPAD',
        iphone: 'IPHONE',
        mobile_web: 'MOBILE_WEB',
        oculus: 'OCULUS',
        samsung: 'SAMSUNG',
        supplementary_images: 'SUPPLEMENTARY_IMAGES',
        web: 'WEB',
        windows: 'WINDOWS',
        xiaomi: 'XIAOMI'
      });
    }
  }, {
    key: 'AnPlatforms',
    get: function get() {
      return Object.freeze({
        android: 'ANDROID',
        desktop: 'DESKTOP',
        galaxy: 'GALAXY',
        instant_articles: 'INSTANT_ARTICLES',
        ios: 'IOS',
        mobile_web: 'MOBILE_WEB',
        oculus: 'OCULUS',
        unknown: 'UNKNOWN',
        xiaomi: 'XIAOMI'
      });
    }
  }, {
    key: 'Platform',
    get: function get() {
      return Object.freeze({
        android: 'ANDROID',
        ios: 'IOS'
      });
    }
  }, {
    key: 'RequestType',
    get: function get() {
      return Object.freeze({
        app_indexing: 'APP_INDEXING',
        button_sampling: 'BUTTON_SAMPLING',
        plugin: 'PLUGIN'
      });
    }
  }, {
    key: 'MutationMethod',
    get: function get() {
      return Object.freeze({
        add: 'ADD',
        delete: 'DELETE',
        replace: 'REPLACE'
      });
    }
  }, {
    key: 'PostMethod',
    get: function get() {
      return Object.freeze({
        codeless: 'CODELESS',
        eymt: 'EYMT'
      });
    }
  }, {
    key: 'OwnerPermissions',
    get: function get() {
      return Object.freeze({
        develop: 'DEVELOP',
        manage: 'MANAGE',
        manage_extensions: 'MANAGE_EXTENSIONS',
        manage_phone: 'MANAGE_PHONE',
        manage_phone_assets: 'MANAGE_PHONE_ASSETS',
        manage_templates: 'MANAGE_TEMPLATES',
        messaging: 'MESSAGING',
        view_cost: 'VIEW_COST',
        view_phone_assets: 'VIEW_PHONE_ASSETS',
        view_templates: 'VIEW_TEMPLATES'
      });
    }
  }, {
    key: 'PartnerPermissions',
    get: function get() {
      return Object.freeze({
        develop: 'DEVELOP',
        manage: 'MANAGE',
        manage_extensions: 'MANAGE_EXTENSIONS',
        manage_phone: 'MANAGE_PHONE',
        manage_phone_assets: 'MANAGE_PHONE_ASSETS',
        manage_templates: 'MANAGE_TEMPLATES',
        messaging: 'MESSAGING',
        view_cost: 'VIEW_COST',
        view_phone_assets: 'VIEW_PHONE_ASSETS',
        view_templates: 'VIEW_TEMPLATES'
      });
    }
  }]);
  return Application;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsReportBuilderMMMReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsReportBuilderMMMReport = function (_AbstractCrudObject) {
  inherits(AdsReportBuilderMMMReport, _AbstractCrudObject);

  function AdsReportBuilderMMMReport() {
    classCallCheck(this, AdsReportBuilderMMMReport);
    return possibleConstructorReturn(this, (AdsReportBuilderMMMReport.__proto__ || Object.getPrototypeOf(AdsReportBuilderMMMReport)).apply(this, arguments));
  }

  createClass(AdsReportBuilderMMMReport, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        async_status: 'async_status',
        export_format: 'export_format',
        export_name: 'export_name',
        export_type: 'export_type',
        has_seen: 'has_seen',
        id: 'id',
        mmm_status: 'mmm_status',
        time_start: 'time_start'
      });
    }
  }]);
  return AdsReportBuilderMMMReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsReportBuilderMMMReportScheduler
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsReportBuilderMMMReportScheduler = function (_AbstractCrudObject) {
  inherits(AdsReportBuilderMMMReportScheduler, _AbstractCrudObject);

  function AdsReportBuilderMMMReportScheduler() {
    classCallCheck(this, AdsReportBuilderMMMReportScheduler);
    return possibleConstructorReturn(this, (AdsReportBuilderMMMReportScheduler.__proto__ || Object.getPrototypeOf(AdsReportBuilderMMMReportScheduler)).apply(this, arguments));
  }

  createClass(AdsReportBuilderMMMReportScheduler, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_ids: 'ad_account_ids',
        filtering: 'filtering',
        id: 'id',
        report_name: 'report_name',
        schedule_frequency: 'schedule_frequency'
      });
    }
  }]);
  return AdsReportBuilderMMMReportScheduler;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OmegaCustomerTrx
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OmegaCustomerTrx = function (_AbstractCrudObject) {
  inherits(OmegaCustomerTrx, _AbstractCrudObject);

  function OmegaCustomerTrx() {
    classCallCheck(this, OmegaCustomerTrx);
    return possibleConstructorReturn(this, (OmegaCustomerTrx.__proto__ || Object.getPrototypeOf(OmegaCustomerTrx)).apply(this, arguments));
  }

  createClass(OmegaCustomerTrx, [{
    key: 'getCampaigns',
    value: function getCampaigns(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/campaigns');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_ids: 'ad_account_ids',
        advertiser_name: 'advertiser_name',
        amount: 'amount',
        amount_due: 'amount_due',
        billed_amount_details: 'billed_amount_details',
        billing_period: 'billing_period',
        cdn_download_uri: 'cdn_download_uri',
        currency: 'currency',
        download_uri: 'download_uri',
        due_date: 'due_date',
        entity: 'entity',
        id: 'id',
        invoice_date: 'invoice_date',
        invoice_id: 'invoice_id',
        invoice_type: 'invoice_type',
        liability_type: 'liability_type',
        payment_status: 'payment_status',
        payment_term: 'payment_term',
        type: 'type'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        cm: 'CM',
        dm: 'DM',
        inv: 'INV',
        pro_forma: 'PRO_FORMA'
      });
    }
  }]);
  return OmegaCustomerTrx;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OffsiteSignalContainerBusinessObject
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OffsiteSignalContainerBusinessObject = function (_AbstractCrudObject) {
  inherits(OffsiteSignalContainerBusinessObject, _AbstractCrudObject);

  function OffsiteSignalContainerBusinessObject() {
    classCallCheck(this, OffsiteSignalContainerBusinessObject);
    return possibleConstructorReturn(this, (OffsiteSignalContainerBusinessObject.__proto__ || Object.getPrototypeOf(OffsiteSignalContainerBusinessObject)).apply(this, arguments));
  }

  createClass(OffsiteSignalContainerBusinessObject, [{
    key: 'getLinkedApplication',
    value: function getLinkedApplication(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsDataset, fields, params, fetchFirstPage, '/linked_application');
    }
  }, {
    key: 'getLinkedPage',
    value: function getLinkedPage(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/linked_page');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        id: 'id',
        is_eligible_for_sharing_to_ad_account: 'is_eligible_for_sharing_to_ad_account',
        is_eligible_for_sharing_to_business: 'is_eligible_for_sharing_to_business',
        is_unavailable: 'is_unavailable',
        name: 'name',
        primary_container_id: 'primary_container_id'
      });
    }
  }]);
  return OffsiteSignalContainerBusinessObject;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WhatsAppBusinessAccount
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WhatsAppBusinessAccount = function (_AbstractCrudObject) {
  inherits(WhatsAppBusinessAccount, _AbstractCrudObject);

  function WhatsAppBusinessAccount() {
    classCallCheck(this, WhatsAppBusinessAccount);
    return possibleConstructorReturn(this, (WhatsAppBusinessAccount.__proto__ || Object.getPrototypeOf(WhatsAppBusinessAccount)).apply(this, arguments));
  }

  createClass(WhatsAppBusinessAccount, [{
    key: 'getActivities',
    value: function getActivities(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/activities');
    }
  }, {
    key: 'deleteAssignedUsers',
    value: function deleteAssignedUsers() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(WhatsAppBusinessAccount.prototype.__proto__ || Object.getPrototypeOf(WhatsAppBusinessAccount.prototype), 'deleteEdge', this).call(this, '/assigned_users', params);
    }
  }, {
    key: 'getAssignedUsers',
    value: function getAssignedUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AssignedUser, fields, params, fetchFirstPage, '/assigned_users');
    }
  }, {
    key: 'createAssignedUser',
    value: function createAssignedUser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/assigned_users', fields, params, WhatsAppBusinessAccount, pathOverride);
    }
  }, {
    key: 'getAudiences',
    value: function getAudiences(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/audiences');
    }
  }, {
    key: 'getCallAnalytics',
    value: function getCallAnalytics(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/call_analytics');
    }
  }, {
    key: 'getConversationAnalytics',
    value: function getConversationAnalytics(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/conversation_analytics');
    }
  }, {
    key: 'getDataset',
    value: function getDataset(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Dataset, fields, params, fetchFirstPage, '/dataset');
    }
  }, {
    key: 'createDataset',
    value: function createDataset(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/dataset', fields, params, Dataset, pathOverride);
    }
  }, {
    key: 'getDccConfig',
    value: function getDccConfig(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/dcc_config');
    }
  }, {
    key: 'getFlows',
    value: function getFlows(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/flows');
    }
  }, {
    key: 'createFlow',
    value: function createFlow(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/flows', fields, params, null, pathOverride);
    }
  }, {
    key: 'createGeneratePaymentConfigurationOauthLink',
    value: function createGeneratePaymentConfigurationOauthLink(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/generate_payment_configuration_oauth_link', fields, params, WhatsAppBusinessAccount, pathOverride);
    }
  }, {
    key: 'getMessageCampaigns',
    value: function getMessageCampaigns(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/message_campaigns');
    }
  }, {
    key: 'getMessageTemplatePreviews',
    value: function getMessageTemplatePreviews(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/message_template_previews');
    }
  }, {
    key: 'deleteMessageTemplates',
    value: function deleteMessageTemplates() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(WhatsAppBusinessAccount.prototype.__proto__ || Object.getPrototypeOf(WhatsAppBusinessAccount.prototype), 'deleteEdge', this).call(this, '/message_templates', params);
    }
  }, {
    key: 'getMessageTemplates',
    value: function getMessageTemplates(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/message_templates');
    }
  }, {
    key: 'createMessageTemplate',
    value: function createMessageTemplate(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/message_templates', fields, params, WhatsAppBusinessAccount, pathOverride);
    }
  }, {
    key: 'createMigrateFlow',
    value: function createMigrateFlow(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/migrate_flows', fields, params, WhatsAppBusinessAccount, pathOverride);
    }
  }, {
    key: 'createMigrateMessageTemplate',
    value: function createMigrateMessageTemplate(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/migrate_message_templates', fields, params, WhatsAppBusinessAccount, pathOverride);
    }
  }, {
    key: 'deletePaymentConfiguration',
    value: function deletePaymentConfiguration() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(WhatsAppBusinessAccount.prototype.__proto__ || Object.getPrototypeOf(WhatsAppBusinessAccount.prototype), 'deleteEdge', this).call(this, '/payment_configuration', params);
    }
  }, {
    key: 'getPaymentConfiguration',
    value: function getPaymentConfiguration(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/payment_configuration');
    }
  }, {
    key: 'createPaymentConfiguration',
    value: function createPaymentConfiguration(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/payment_configuration', fields, params, WhatsAppBusinessAccount, pathOverride);
    }
  }, {
    key: 'getPaymentConfigurations',
    value: function getPaymentConfigurations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/payment_configurations');
    }
  }, {
    key: 'getPhoneNumbers',
    value: function getPhoneNumbers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/phone_numbers');
    }
  }, {
    key: 'createPhoneNumber',
    value: function createPhoneNumber(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/phone_numbers', fields, params, null, pathOverride);
    }
  }, {
    key: 'deleteProductCatalogs',
    value: function deleteProductCatalogs() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(WhatsAppBusinessAccount.prototype.__proto__ || Object.getPrototypeOf(WhatsAppBusinessAccount.prototype), 'deleteEdge', this).call(this, '/product_catalogs', params);
    }
  }, {
    key: 'getProductCatalogs',
    value: function getProductCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalog, fields, params, fetchFirstPage, '/product_catalogs');
    }
  }, {
    key: 'createProductCatalog',
    value: function createProductCatalog(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/product_catalogs', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'getSchedules',
    value: function getSchedules(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/schedules');
    }
  }, {
    key: 'createSetOboMobilityIntent',
    value: function createSetOboMobilityIntent(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/set_obo_mobility_intent', fields, params, null, pathOverride);
    }
  }, {
    key: 'createSetSolutionMigrationInTEnt',
    value: function createSetSolutionMigrationInTEnt(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/set_solution_migration_intent', fields, params, null, pathOverride);
    }
  }, {
    key: 'getSolutions',
    value: function getSolutions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/solutions');
    }
  }, {
    key: 'deleteSubscribedApps',
    value: function deleteSubscribedApps() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(WhatsAppBusinessAccount.prototype.__proto__ || Object.getPrototypeOf(WhatsAppBusinessAccount.prototype), 'deleteEdge', this).call(this, '/subscribed_apps', params);
    }
  }, {
    key: 'getSubscribedApps',
    value: function getSubscribedApps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/subscribed_apps');
    }
  }, {
    key: 'createSubscribedApp',
    value: function createSubscribedApp(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/subscribed_apps', fields, params, WhatsAppBusinessAccount, pathOverride);
    }
  }, {
    key: 'getTemplateAnalytics',
    value: function getTemplateAnalytics(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/template_analytics');
    }
  }, {
    key: 'getTemplatePerformanceMetrics',
    value: function getTemplatePerformanceMetrics(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/template_performance_metrics');
    }
  }, {
    key: 'createUpsertMessageTemplate',
    value: function createUpsertMessageTemplate(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/upsert_message_templates', fields, params, WhatsAppBusinessAccount, pathOverride);
    }
  }, {
    key: 'getWelcomeMessageSequences',
    value: function getWelcomeMessageSequences(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CTXPartnerAppWelcomeMessageFlow, fields, params, fetchFirstPage, '/welcome_message_sequences');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(WhatsAppBusinessAccount.prototype.__proto__ || Object.getPrototypeOf(WhatsAppBusinessAccount.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_review_status: 'account_review_status',
        analytics: 'analytics',
        auth_international_rate_eligibility: 'auth_international_rate_eligibility',
        business_verification_status: 'business_verification_status',
        country: 'country',
        creation_time: 'creation_time',
        currency: 'currency',
        health_status: 'health_status',
        id: 'id',
        is_enabled_for_insights: 'is_enabled_for_insights',
        linked_commerce_account: 'linked_commerce_account',
        message_template_namespace: 'message_template_namespace',
        name: 'name',
        on_behalf_of_business_info: 'on_behalf_of_business_info',
        owner_business: 'owner_business',
        owner_business_info: 'owner_business_info',
        ownership_type: 'ownership_type',
        primary_business_location: 'primary_business_location',
        primary_funding_id: 'primary_funding_id',
        purchase_order_number: 'purchase_order_number',
        status: 'status',
        timezone_id: 'timezone_id'
      });
    }
  }, {
    key: 'Tasks',
    get: function get() {
      return Object.freeze({
        develop: 'DEVELOP',
        manage: 'MANAGE',
        manage_extensions: 'MANAGE_EXTENSIONS',
        manage_phone: 'MANAGE_PHONE',
        manage_phone_assets: 'MANAGE_PHONE_ASSETS',
        manage_templates: 'MANAGE_TEMPLATES',
        messaging: 'MESSAGING',
        view_cost: 'VIEW_COST',
        view_phone_assets: 'VIEW_PHONE_ASSETS',
        view_templates: 'VIEW_TEMPLATES'
      });
    }
  }, {
    key: 'Category',
    get: function get() {
      return Object.freeze({
        authentication: 'AUTHENTICATION',
        marketing: 'MARKETING',
        utility: 'UTILITY'
      });
    }
  }, {
    key: 'DisplayFormat',
    get: function get() {
      return Object.freeze({
        order_details: 'ORDER_DETAILS'
      });
    }
  }, {
    key: 'SubCategory',
    get: function get() {
      return Object.freeze({
        order_details: 'ORDER_DETAILS',
        order_status: 'ORDER_STATUS'
      });
    }
  }, {
    key: 'ProviderName',
    get: function get() {
      return Object.freeze({
        billdesk: 'BILLDESK',
        payu: 'PAYU',
        razorpay: 'RAZORPAY',
        upi_vpa: 'UPI_VPA',
        zaakpay: 'ZAAKPAY'
      });
    }
  }]);
  return WhatsAppBusinessAccount;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CPASCollaborationRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CPASCollaborationRequest = function (_AbstractCrudObject) {
  inherits(CPASCollaborationRequest, _AbstractCrudObject);

  function CPASCollaborationRequest() {
    classCallCheck(this, CPASCollaborationRequest);
    return possibleConstructorReturn(this, (CPASCollaborationRequest.__proto__ || Object.getPrototypeOf(CPASCollaborationRequest)).apply(this, arguments));
  }

  createClass(CPASCollaborationRequest, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        brands: 'brands',
        contact_email: 'contact_email',
        contact_first_name: 'contact_first_name',
        contact_last_name: 'contact_last_name',
        id: 'id',
        phone_number: 'phone_number',
        receiver_business: 'receiver_business',
        requester_agency_or_brand: 'requester_agency_or_brand',
        sender_client_business: 'sender_client_business',
        status: 'status'
      });
    }
  }, {
    key: 'RequesterAgencyOrBrand',
    get: function get() {
      return Object.freeze({
        agency: 'AGENCY',
        brand: 'BRAND',
        merchant: 'MERCHANT'
      });
    }
  }]);
  return CPASCollaborationRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CPASAdvertiserPartnershipRecommendation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CPASAdvertiserPartnershipRecommendation = function (_AbstractCrudObject) {
  inherits(CPASAdvertiserPartnershipRecommendation, _AbstractCrudObject);

  function CPASAdvertiserPartnershipRecommendation() {
    classCallCheck(this, CPASAdvertiserPartnershipRecommendation);
    return possibleConstructorReturn(this, (CPASAdvertiserPartnershipRecommendation.__proto__ || Object.getPrototypeOf(CPASAdvertiserPartnershipRecommendation)).apply(this, arguments));
  }

  createClass(CPASAdvertiserPartnershipRecommendation, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        advertiser_business_id: 'advertiser_business_id',
        brand_business_id: 'brand_business_id',
        brands: 'brands',
        countries: 'countries',
        id: 'id',
        merchant_business_id: 'merchant_business_id',
        merchant_categories: 'merchant_categories',
        status: 'status',
        status_reason: 'status_reason'
      });
    }
  }]);
  return CPASAdvertiserPartnershipRecommendation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CPASBusinessSetupConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CPASBusinessSetupConfig = function (_AbstractCrudObject) {
  inherits(CPASBusinessSetupConfig, _AbstractCrudObject);

  function CPASBusinessSetupConfig() {
    classCallCheck(this, CPASBusinessSetupConfig);
    return possibleConstructorReturn(this, (CPASBusinessSetupConfig.__proto__ || Object.getPrototypeOf(CPASBusinessSetupConfig)).apply(this, arguments));
  }

  createClass(CPASBusinessSetupConfig, [{
    key: 'getAdAccounts',
    value: function getAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/ad_accounts');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        accepted_collab_ads_tos: 'accepted_collab_ads_tos',
        business: 'business',
        business_capabilities_status: 'business_capabilities_status',
        capabilities_compliance_status: 'capabilities_compliance_status',
        id: 'id'
      });
    }
  }]);
  return CPASBusinessSetupConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CPASMerchantConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CPASMerchantConfig = function (_AbstractCrudObject) {
  inherits(CPASMerchantConfig, _AbstractCrudObject);

  function CPASMerchantConfig() {
    classCallCheck(this, CPASMerchantConfig);
    return possibleConstructorReturn(this, (CPASMerchantConfig.__proto__ || Object.getPrototypeOf(CPASMerchantConfig)).apply(this, arguments));
  }

  createClass(CPASMerchantConfig, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        accepted_tos: 'accepted_tos',
        beta_features: 'beta_features',
        business_outcomes_status: 'business_outcomes_status',
        id: 'id',
        is_test_merchant: 'is_test_merchant',
        outcomes_compliance_status: 'outcomes_compliance_status',
        qualified_to_onboard: 'qualified_to_onboard'
      });
    }
  }]);
  return CPASMerchantConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessCreativeFolder
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessCreativeFolder = function (_AbstractCrudObject) {
  inherits(BusinessCreativeFolder, _AbstractCrudObject);

  function BusinessCreativeFolder() {
    classCallCheck(this, BusinessCreativeFolder);
    return possibleConstructorReturn(this, (BusinessCreativeFolder.__proto__ || Object.getPrototypeOf(BusinessCreativeFolder)).apply(this, arguments));
  }

  createClass(BusinessCreativeFolder, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        creation_time: 'creation_time',
        creative_insight_permissions: 'creative_insight_permissions',
        description: 'description',
        id: 'id',
        media_library_url: 'media_library_url',
        name: 'name',
        owner_business: 'owner_business'
      });
    }
  }]);
  return BusinessCreativeFolder;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CreditCard
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CreditCard = function (_AbstractCrudObject) {
  inherits(CreditCard, _AbstractCrudObject);

  function CreditCard() {
    classCallCheck(this, CreditCard);
    return possibleConstructorReturn(this, (CreditCard.__proto__ || Object.getPrototypeOf(CreditCard)).apply(this, arguments));
  }

  createClass(CreditCard, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        billing_address: 'billing_address',
        card_cobadging: 'card_cobadging',
        card_holder_name: 'card_holder_name',
        card_type: 'card_type',
        credential_id: 'credential_id',
        default_receiving_method_products: 'default_receiving_method_products',
        expiry_month: 'expiry_month',
        expiry_year: 'expiry_year',
        id: 'id',
        is_cvv_tricky_bin: 'is_cvv_tricky_bin',
        is_enabled: 'is_enabled',
        is_last_used: 'is_last_used',
        is_network_tokenized_in_india: 'is_network_tokenized_in_india',
        is_soft_disabled: 'is_soft_disabled',
        is_user_verified: 'is_user_verified',
        is_zip_verified: 'is_zip_verified',
        last4: 'last4',
        readable_card_type: 'readable_card_type',
        time_created: 'time_created',
        time_created_ts: 'time_created_ts',
        type: 'type'
      });
    }
  }]);
  return CreditCard;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EventSourceGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EventSourceGroup = function (_AbstractCrudObject) {
  inherits(EventSourceGroup, _AbstractCrudObject);

  function EventSourceGroup() {
    classCallCheck(this, EventSourceGroup);
    return possibleConstructorReturn(this, (EventSourceGroup.__proto__ || Object.getPrototypeOf(EventSourceGroup)).apply(this, arguments));
  }

  createClass(EventSourceGroup, [{
    key: 'getSharedAccounts',
    value: function getSharedAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/shared_accounts');
    }
  }, {
    key: 'createSharedAccount',
    value: function createSharedAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/shared_accounts', fields, params, EventSourceGroup, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(EventSourceGroup.prototype.__proto__ || Object.getPrototypeOf(EventSourceGroup.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        event_sources: 'event_sources',
        id: 'id',
        name: 'name',
        owner_business: 'owner_business'
      });
    }
  }]);
  return EventSourceGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExtendedCreditApplication
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExtendedCreditApplication = function (_AbstractCrudObject) {
  inherits(ExtendedCreditApplication, _AbstractCrudObject);

  function ExtendedCreditApplication() {
    classCallCheck(this, ExtendedCreditApplication);
    return possibleConstructorReturn(this, (ExtendedCreditApplication.__proto__ || Object.getPrototypeOf(ExtendedCreditApplication)).apply(this, arguments));
  }

  createClass(ExtendedCreditApplication, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        billing_country: 'billing_country',
        city: 'city',
        cnpj: 'cnpj',
        country: 'country',
        display_currency: 'display_currency',
        duns_number: 'duns_number',
        id: 'id',
        invoice_email_address: 'invoice_email_address',
        is_umi: 'is_umi',
        legal_entity_name: 'legal_entity_name',
        original_online_limit: 'original_online_limit',
        phone_number: 'phone_number',
        postal_code: 'postal_code',
        product_types: 'product_types',
        proposed_credit_limit: 'proposed_credit_limit',
        registration_number: 'registration_number',
        run_id: 'run_id',
        state: 'state',
        status: 'status',
        street1: 'street1',
        street2: 'street2',
        submitter: 'submitter',
        tax_exempt_status: 'tax_exempt_status',
        tax_id: 'tax_id',
        terms: 'terms'
      });
    }
  }]);
  return ExtendedCreditApplication;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExtendedCreditInvoiceGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExtendedCreditInvoiceGroup = function (_AbstractCrudObject) {
  inherits(ExtendedCreditInvoiceGroup, _AbstractCrudObject);

  function ExtendedCreditInvoiceGroup() {
    classCallCheck(this, ExtendedCreditInvoiceGroup);
    return possibleConstructorReturn(this, (ExtendedCreditInvoiceGroup.__proto__ || Object.getPrototypeOf(ExtendedCreditInvoiceGroup)).apply(this, arguments));
  }

  createClass(ExtendedCreditInvoiceGroup, [{
    key: 'deleteAdAccounts',
    value: function deleteAdAccounts() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(ExtendedCreditInvoiceGroup.prototype.__proto__ || Object.getPrototypeOf(ExtendedCreditInvoiceGroup.prototype), 'deleteEdge', this).call(this, '/ad_accounts', params);
    }
  }, {
    key: 'getAdAccounts',
    value: function getAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/ad_accounts');
    }
  }, {
    key: 'createAdAccount',
    value: function createAdAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/ad_accounts', fields, params, AdAccount, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ExtendedCreditInvoiceGroup.prototype.__proto__ || Object.getPrototypeOf(ExtendedCreditInvoiceGroup.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ExtendedCreditInvoiceGroup.prototype.__proto__ || Object.getPrototypeOf(ExtendedCreditInvoiceGroup.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        auto_enroll: 'auto_enroll',
        bill_to_address: 'bill_to_address',
        customer_po_number: 'customer_po_number',
        email: 'email',
        emails: 'emails',
        id: 'id',
        liable_address: 'liable_address',
        name: 'name',
        sold_to_address: 'sold_to_address'
      });
    }
  }]);
  return ExtendedCreditInvoiceGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExtendedCreditAllocationConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExtendedCreditAllocationConfig = function (_AbstractCrudObject) {
  inherits(ExtendedCreditAllocationConfig, _AbstractCrudObject);

  function ExtendedCreditAllocationConfig() {
    classCallCheck(this, ExtendedCreditAllocationConfig);
    return possibleConstructorReturn(this, (ExtendedCreditAllocationConfig.__proto__ || Object.getPrototypeOf(ExtendedCreditAllocationConfig)).apply(this, arguments));
  }

  createClass(ExtendedCreditAllocationConfig, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ExtendedCreditAllocationConfig.prototype.__proto__ || Object.getPrototypeOf(ExtendedCreditAllocationConfig.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(ExtendedCreditAllocationConfig.prototype.__proto__ || Object.getPrototypeOf(ExtendedCreditAllocationConfig.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        currency_amount: 'currency_amount',
        id: 'id',
        liability_type: 'liability_type',
        owning_business: 'owning_business',
        owning_credential: 'owning_credential',
        partition_type: 'partition_type',
        receiving_business: 'receiving_business',
        receiving_credential: 'receiving_credential',
        request_status: 'request_status',
        send_bill_to: 'send_bill_to'
      });
    }
  }, {
    key: 'LiabilityType',
    get: function get() {
      return Object.freeze({
        msa: 'MSA',
        normal: 'Normal',
        sequential: 'Sequential'
      });
    }
  }, {
    key: 'PartitionType',
    get: function get() {
      return Object.freeze({
        auth: 'AUTH',
        fixed: 'FIXED',
        fixed_without_partition: 'FIXED_WITHOUT_PARTITION'
      });
    }
  }, {
    key: 'SendBillTo',
    get: function get() {
      return Object.freeze({
        advertiser: 'Advertiser',
        agency: 'Agency'
      });
    }
  }]);
  return ExtendedCreditAllocationConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExtendedCredit
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExtendedCredit = function (_AbstractCrudObject) {
  inherits(ExtendedCredit, _AbstractCrudObject);

  function ExtendedCredit() {
    classCallCheck(this, ExtendedCredit);
    return possibleConstructorReturn(this, (ExtendedCredit.__proto__ || Object.getPrototypeOf(ExtendedCredit)).apply(this, arguments));
  }

  createClass(ExtendedCredit, [{
    key: 'getExtendedCreditInvoiceGroups',
    value: function getExtendedCreditInvoiceGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ExtendedCreditInvoiceGroup, fields, params, fetchFirstPage, '/extended_credit_invoice_groups');
    }
  }, {
    key: 'createExtendedCreditInvoiceGroup',
    value: function createExtendedCreditInvoiceGroup(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/extended_credit_invoice_groups', fields, params, ExtendedCreditInvoiceGroup, pathOverride);
    }
  }, {
    key: 'getOwningCreditAllocationConfigs',
    value: function getOwningCreditAllocationConfigs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ExtendedCreditAllocationConfig, fields, params, fetchFirstPage, '/owning_credit_allocation_configs');
    }
  }, {
    key: 'createOwningCreditAllocationConfig',
    value: function createOwningCreditAllocationConfig(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/owning_credit_allocation_configs', fields, params, ExtendedCreditAllocationConfig, pathOverride);
    }
  }, {
    key: 'createWhatsAppCreditAttach',
    value: function createWhatsAppCreditAttach(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/whatsapp_credit_attach', fields, params, null, pathOverride);
    }
  }, {
    key: 'createWhatsAppCreditSharing',
    value: function createWhatsAppCreditSharing(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/whatsapp_credit_sharing', fields, params, null, pathOverride);
    }
  }, {
    key: 'createWhatsAppCreditSharingAndAttach',
    value: function createWhatsAppCreditSharingAndAttach(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/whatsapp_credit_sharing_and_attach', fields, params, null, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        allocated_amount: 'allocated_amount',
        balance: 'balance',
        credit_available: 'credit_available',
        credit_type: 'credit_type',
        id: 'id',
        is_access_revoked: 'is_access_revoked',
        is_automated_experience: 'is_automated_experience',
        legal_entity_name: 'legal_entity_name',
        liable_address: 'liable_address',
        liable_biz_name: 'liable_biz_name',
        max_balance: 'max_balance',
        online_max_balance: 'online_max_balance',
        owner_business: 'owner_business',
        owner_business_name: 'owner_business_name',
        partition_from: 'partition_from',
        receiving_credit_allocation_config: 'receiving_credit_allocation_config',
        send_bill_to_address: 'send_bill_to_address',
        send_bill_to_biz_name: 'send_bill_to_biz_name',
        sold_to_address: 'sold_to_address'
      });
    }
  }]);
  return ExtendedCredit;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessImage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessImage = function (_AbstractCrudObject) {
  inherits(BusinessImage, _AbstractCrudObject);

  function BusinessImage() {
    classCallCheck(this, BusinessImage);
    return possibleConstructorReturn(this, (BusinessImage.__proto__ || Object.getPrototypeOf(BusinessImage)).apply(this, arguments));
  }

  createClass(BusinessImage, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        creation_time: 'creation_time',
        hash: 'hash',
        height: 'height',
        id: 'id',
        media_library_url: 'media_library_url',
        name: 'name',
        url: 'url',
        url_128: 'url_128',
        width: 'width'
      });
    }
  }, {
    key: 'ValidationAdPlacements',
    get: function get() {
      return Object.freeze({
        audience_network_instream_video: 'AUDIENCE_NETWORK_INSTREAM_VIDEO',
        audience_network_instream_video_mobile: 'AUDIENCE_NETWORK_INSTREAM_VIDEO_MOBILE',
        audience_network_rewarded_video: 'AUDIENCE_NETWORK_REWARDED_VIDEO',
        desktop_feed_standard: 'DESKTOP_FEED_STANDARD',
        facebook_story_mobile: 'FACEBOOK_STORY_MOBILE',
        facebook_story_sticker_mobile: 'FACEBOOK_STORY_STICKER_MOBILE',
        instagram_standard: 'INSTAGRAM_STANDARD',
        instagram_story: 'INSTAGRAM_STORY',
        instant_article_standard: 'INSTANT_ARTICLE_STANDARD',
        instream_banner_desktop: 'INSTREAM_BANNER_DESKTOP',
        instream_banner_mobile: 'INSTREAM_BANNER_MOBILE',
        instream_video_desktop: 'INSTREAM_VIDEO_DESKTOP',
        instream_video_image: 'INSTREAM_VIDEO_IMAGE',
        instream_video_mobile: 'INSTREAM_VIDEO_MOBILE',
        messenger_mobile_inbox_media: 'MESSENGER_MOBILE_INBOX_MEDIA',
        messenger_mobile_story_media: 'MESSENGER_MOBILE_STORY_MEDIA',
        mobile_feed_standard: 'MOBILE_FEED_STANDARD',
        mobile_fullwidth: 'MOBILE_FULLWIDTH',
        mobile_interstitial: 'MOBILE_INTERSTITIAL',
        mobile_medium_rectangle: 'MOBILE_MEDIUM_RECTANGLE',
        mobile_native: 'MOBILE_NATIVE',
        right_column_standard: 'RIGHT_COLUMN_STANDARD',
        suggested_video_mobile: 'SUGGESTED_VIDEO_MOBILE'
      });
    }
  }]);
  return BusinessImage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessAssetSharingAgreement
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessAssetSharingAgreement = function (_AbstractCrudObject) {
  inherits(BusinessAssetSharingAgreement, _AbstractCrudObject);

  function BusinessAssetSharingAgreement() {
    classCallCheck(this, BusinessAssetSharingAgreement);
    return possibleConstructorReturn(this, (BusinessAssetSharingAgreement.__proto__ || Object.getPrototypeOf(BusinessAssetSharingAgreement)).apply(this, arguments));
  }

  createClass(BusinessAssetSharingAgreement, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(BusinessAssetSharingAgreement.prototype.__proto__ || Object.getPrototypeOf(BusinessAssetSharingAgreement.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        initiator: 'initiator',
        recipient: 'recipient',
        relationship_type: 'relationship_type',
        request_status: 'request_status',
        request_type: 'request_type'
      });
    }
  }, {
    key: 'RequestStatus',
    get: function get() {
      return Object.freeze({
        approve: 'APPROVE',
        decline: 'DECLINE',
        expired: 'EXPIRED',
        in_progress: 'IN_PROGRESS',
        pending: 'PENDING',
        pending_email_verification: 'PENDING_EMAIL_VERIFICATION',
        pending_integrity_review: 'PENDING_INTEGRITY_REVIEW'
      });
    }
  }]);
  return BusinessAssetSharingAgreement;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserAvailableCatalogs
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserAvailableCatalogs = function (_AbstractCrudObject) {
  inherits(UserAvailableCatalogs, _AbstractCrudObject);

  function UserAvailableCatalogs() {
    classCallCheck(this, UserAvailableCatalogs);
    return possibleConstructorReturn(this, (UserAvailableCatalogs.__proto__ || Object.getPrototypeOf(UserAvailableCatalogs)).apply(this, arguments));
  }

  createClass(UserAvailableCatalogs, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        catalog_id: 'catalog_id',
        catalog_name: 'catalog_name',
        product_count: 'product_count',
        shop_name: 'shop_name'
      });
    }
  }]);
  return UserAvailableCatalogs;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGBCAdsPermission
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGBCAdsPermission = function (_AbstractCrudObject) {
  inherits(IGBCAdsPermission, _AbstractCrudObject);

  function IGBCAdsPermission() {
    classCallCheck(this, IGBCAdsPermission);
    return possibleConstructorReturn(this, (IGBCAdsPermission.__proto__ || Object.getPrototypeOf(IGBCAdsPermission)).apply(this, arguments));
  }

  createClass(IGBCAdsPermission, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        permission_type: 'permission_type',
        status: 'status'
      });
    }
  }]);
  return IGBCAdsPermission;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BrandedContentShadowIGMediaID
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BrandedContentShadowIGMediaID = function (_AbstractCrudObject) {
  inherits(BrandedContentShadowIGMediaID, _AbstractCrudObject);

  function BrandedContentShadowIGMediaID() {
    classCallCheck(this, BrandedContentShadowIGMediaID);
    return possibleConstructorReturn(this, (BrandedContentShadowIGMediaID.__proto__ || Object.getPrototypeOf(BrandedContentShadowIGMediaID)).apply(this, arguments));
  }

  createClass(BrandedContentShadowIGMediaID, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        eligibility_errors: 'eligibility_errors',
        has_permission_for_partnership_ad: 'has_permission_for_partnership_ad',
        id: 'id',
        owner_id: 'owner_id',
        permalink: 'permalink'
      });
    }
  }]);
  return BrandedContentShadowIGMediaID;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BrandedContentShadowIGUserID
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BrandedContentShadowIGUserID = function (_AbstractCrudObject) {
  inherits(BrandedContentShadowIGUserID, _AbstractCrudObject);

  function BrandedContentShadowIGUserID() {
    classCallCheck(this, BrandedContentShadowIGUserID);
    return possibleConstructorReturn(this, (BrandedContentShadowIGUserID.__proto__ || Object.getPrototypeOf(BrandedContentShadowIGUserID)).apply(this, arguments));
  }

  createClass(BrandedContentShadowIGUserID, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return BrandedContentShadowIGUserID;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ShadowIGUserCatalogProductSearch
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ShadowIGUserCatalogProductSearch = function (_AbstractCrudObject) {
  inherits(ShadowIGUserCatalogProductSearch, _AbstractCrudObject);

  function ShadowIGUserCatalogProductSearch() {
    classCallCheck(this, ShadowIGUserCatalogProductSearch);
    return possibleConstructorReturn(this, (ShadowIGUserCatalogProductSearch.__proto__ || Object.getPrototypeOf(ShadowIGUserCatalogProductSearch)).apply(this, arguments));
  }

  createClass(ShadowIGUserCatalogProductSearch, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        image_url: 'image_url',
        is_checkout_flow: 'is_checkout_flow',
        merchant_id: 'merchant_id',
        product_id: 'product_id',
        product_name: 'product_name',
        product_variants: 'product_variants',
        retailer_id: 'retailer_id',
        review_status: 'review_status'
      });
    }
  }]);
  return ShadowIGUserCatalogProductSearch;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ContentPublishingLimitResponse
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ContentPublishingLimitResponse = function (_AbstractCrudObject) {
  inherits(ContentPublishingLimitResponse, _AbstractCrudObject);

  function ContentPublishingLimitResponse() {
    classCallCheck(this, ContentPublishingLimitResponse);
    return possibleConstructorReturn(this, (ContentPublishingLimitResponse.__proto__ || Object.getPrototypeOf(ContentPublishingLimitResponse)).apply(this, arguments));
  }

  createClass(ContentPublishingLimitResponse, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        config: 'config',
        quota_usage: 'quota_usage'
      });
    }
  }]);
  return ContentPublishingLimitResponse;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramInsightsResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramInsightsResult = function (_AbstractCrudObject) {
  inherits(InstagramInsightsResult, _AbstractCrudObject);

  function InstagramInsightsResult() {
    classCallCheck(this, InstagramInsightsResult);
    return possibleConstructorReturn(this, (InstagramInsightsResult.__proto__ || Object.getPrototypeOf(InstagramInsightsResult)).apply(this, arguments));
  }

  createClass(InstagramInsightsResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        id: 'id',
        name: 'name',
        period: 'period',
        title: 'title',
        total_value: 'total_value',
        values: 'values'
      });
    }
  }, {
    key: 'Breakdown',
    get: function get() {
      return Object.freeze({
        action_type: 'action_type',
        follow_type: 'follow_type',
        story_navigation_action_type: 'story_navigation_action_type',
        surface_type: 'surface_type'
      });
    }
  }, {
    key: 'Metric',
    get: function get() {
      return Object.freeze({
        clips_replays_count: 'clips_replays_count',
        comments: 'comments',
        follows: 'follows',
        ig_reels_aggregated_all_plays_count: 'ig_reels_aggregated_all_plays_count',
        ig_reels_avg_watch_time: 'ig_reels_avg_watch_time',
        ig_reels_video_view_total_time: 'ig_reels_video_view_total_time',
        impressions: 'impressions',
        likes: 'likes',
        navigation: 'navigation',
        peak_concurrent_viewers: 'peak_concurrent_viewers',
        plays: 'plays',
        profile_activity: 'profile_activity',
        profile_visits: 'profile_visits',
        quotes: 'quotes',
        reach: 'reach',
        replies: 'replies',
        reposts: 'reposts',
        saved: 'saved',
        shares: 'shares',
        thread_replies: 'thread_replies',
        thread_shares: 'thread_shares',
        total_interactions: 'total_interactions',
        video_views: 'video_views',
        views: 'views'
      });
    }
  }, {
    key: 'Period',
    get: function get() {
      return Object.freeze({
        day: 'day',
        days_28: 'days_28',
        lifetime: 'lifetime',
        month: 'month',
        total_over_range: 'total_over_range',
        week: 'week'
      });
    }
  }, {
    key: 'MetricType',
    get: function get() {
      return Object.freeze({
        default: 'default',
        time_series: 'time_series',
        total_value: 'total_value'
      });
    }
  }, {
    key: 'Timeframe',
    get: function get() {
      return Object.freeze({
        last_14_days: 'last_14_days',
        last_30_days: 'last_30_days',
        last_90_days: 'last_90_days',
        prev_month: 'prev_month',
        this_month: 'this_month',
        this_week: 'this_week'
      });
    }
  }]);
  return InstagramInsightsResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGBoostMediaAd
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGBoostMediaAd = function (_AbstractCrudObject) {
  inherits(IGBoostMediaAd, _AbstractCrudObject);

  function IGBoostMediaAd() {
    classCallCheck(this, IGBoostMediaAd);
    return possibleConstructorReturn(this, (IGBoostMediaAd.__proto__ || Object.getPrototypeOf(IGBoostMediaAd)).apply(this, arguments));
  }

  createClass(IGBoostMediaAd, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_id: 'ad_id',
        ad_status: 'ad_status',
        id: 'id'
      });
    }
  }]);
  return IGBoostMediaAd;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ShadowIGMediaCollaborators
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ShadowIGMediaCollaborators = function (_AbstractCrudObject) {
  inherits(ShadowIGMediaCollaborators, _AbstractCrudObject);

  function ShadowIGMediaCollaborators() {
    classCallCheck(this, ShadowIGMediaCollaborators);
    return possibleConstructorReturn(this, (ShadowIGMediaCollaborators.__proto__ || Object.getPrototypeOf(ShadowIGMediaCollaborators)).apply(this, arguments));
  }

  createClass(ShadowIGMediaCollaborators, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        invite_status: 'invite_status',
        username: 'username'
      });
    }
  }]);
  return ShadowIGMediaCollaborators;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGComment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGComment = function (_AbstractCrudObject) {
  inherits(IGComment, _AbstractCrudObject);

  function IGComment() {
    classCallCheck(this, IGComment);
    return possibleConstructorReturn(this, (IGComment.__proto__ || Object.getPrototypeOf(IGComment)).apply(this, arguments));
  }

  createClass(IGComment, [{
    key: 'getReplies',
    value: function getReplies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGComment, fields, params, fetchFirstPage, '/replies');
    }
  }, {
    key: 'createReply',
    value: function createReply(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/replies', fields, params, IGComment, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(IGComment.prototype.__proto__ || Object.getPrototypeOf(IGComment.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(IGComment.prototype.__proto__ || Object.getPrototypeOf(IGComment.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        from: 'from',
        hidden: 'hidden',
        id: 'id',
        like_count: 'like_count',
        media: 'media',
        parent_id: 'parent_id',
        text: 'text',
        timestamp: 'timestamp',
        user: 'user',
        username: 'username'
      });
    }
  }]);
  return IGComment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ShadowIGMediaProductTags
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ShadowIGMediaProductTags = function (_AbstractCrudObject) {
  inherits(ShadowIGMediaProductTags, _AbstractCrudObject);

  function ShadowIGMediaProductTags() {
    classCallCheck(this, ShadowIGMediaProductTags);
    return possibleConstructorReturn(this, (ShadowIGMediaProductTags.__proto__ || Object.getPrototypeOf(ShadowIGMediaProductTags)).apply(this, arguments));
  }

  createClass(ShadowIGMediaProductTags, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        image_url: 'image_url',
        is_checkout: 'is_checkout',
        merchant_id: 'merchant_id',
        name: 'name',
        price_string: 'price_string',
        product_id: 'product_id',
        review_status: 'review_status',
        stripped_price_string: 'stripped_price_string',
        stripped_sale_price_string: 'stripped_sale_price_string',
        x: 'x',
        y: 'y'
      });
    }
  }]);
  return ShadowIGMediaProductTags;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGMedia
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGMedia = function (_AbstractCrudObject) {
  inherits(IGMedia, _AbstractCrudObject);

  function IGMedia() {
    classCallCheck(this, IGMedia);
    return possibleConstructorReturn(this, (IGMedia.__proto__ || Object.getPrototypeOf(IGMedia)).apply(this, arguments));
  }

  createClass(IGMedia, [{
    key: 'getBoostAdsList',
    value: function getBoostAdsList(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGBoostMediaAd, fields, params, fetchFirstPage, '/boost_ads_list');
    }
  }, {
    key: 'getBrandedContentPartnerPromote',
    value: function getBrandedContentPartnerPromote(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BrandedContentShadowIGUserID, fields, params, fetchFirstPage, '/branded_content_partner_promote');
    }
  }, {
    key: 'createBrandedContentPartnerPromote',
    value: function createBrandedContentPartnerPromote(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/branded_content_partner_promote', fields, params, BrandedContentShadowIGUserID, pathOverride);
    }
  }, {
    key: 'getChildren',
    value: function getChildren(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGMedia, fields, params, fetchFirstPage, '/children');
    }
  }, {
    key: 'getCollaborators',
    value: function getCollaborators(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ShadowIGMediaCollaborators, fields, params, fetchFirstPage, '/collaborators');
    }
  }, {
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGComment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, IGComment, pathOverride);
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramInsightsResult, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'deletePartnershipAdCode',
    value: function deletePartnershipAdCode() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(IGMedia.prototype.__proto__ || Object.getPrototypeOf(IGMedia.prototype), 'deleteEdge', this).call(this, '/partnership_ad_code', params);
    }
  }, {
    key: 'createPartnershipAdCode',
    value: function createPartnershipAdCode(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/partnership_ad_code', fields, params, null, pathOverride);
    }
  }, {
    key: 'getProductTags',
    value: function getProductTags(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ShadowIGMediaProductTags, fields, params, fetchFirstPage, '/product_tags');
    }
  }, {
    key: 'createProductTag',
    value: function createProductTag(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/product_tags', fields, params, ShadowIGMediaProductTags, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(IGMedia.prototype.__proto__ || Object.getPrototypeOf(IGMedia.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        boost_eligibility_info: 'boost_eligibility_info',
        caption: 'caption',
        comments_count: 'comments_count',
        copyright_check_information: 'copyright_check_information',
        id: 'id',
        ig_id: 'ig_id',
        is_comment_enabled: 'is_comment_enabled',
        is_shared_to_feed: 'is_shared_to_feed',
        like_count: 'like_count',
        media_product_type: 'media_product_type',
        media_type: 'media_type',
        media_url: 'media_url',
        owner: 'owner',
        permalink: 'permalink',
        shortcode: 'shortcode',
        thumbnail_url: 'thumbnail_url',
        timestamp: 'timestamp',
        username: 'username'
      });
    }
  }]);
  return IGMedia;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGShoppingProductAppeal
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGShoppingProductAppeal = function (_AbstractCrudObject) {
  inherits(IGShoppingProductAppeal, _AbstractCrudObject);

  function IGShoppingProductAppeal() {
    classCallCheck(this, IGShoppingProductAppeal);
    return possibleConstructorReturn(this, (IGShoppingProductAppeal.__proto__ || Object.getPrototypeOf(IGShoppingProductAppeal)).apply(this, arguments));
  }

  createClass(IGShoppingProductAppeal, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        eligible_for_appeal: 'eligible_for_appeal',
        product_appeal_status: 'product_appeal_status',
        product_id: 'product_id',
        rejection_reasons: 'rejection_reasons',
        review_status: 'review_status'
      });
    }
  }]);
  return IGShoppingProductAppeal;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ShadowIGHashtag
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ShadowIGHashtag = function (_AbstractCrudObject) {
  inherits(ShadowIGHashtag, _AbstractCrudObject);

  function ShadowIGHashtag() {
    classCallCheck(this, ShadowIGHashtag);
    return possibleConstructorReturn(this, (ShadowIGHashtag.__proto__ || Object.getPrototypeOf(ShadowIGHashtag)).apply(this, arguments));
  }

  createClass(ShadowIGHashtag, [{
    key: 'getRecentMedia',
    value: function getRecentMedia(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGMedia, fields, params, fetchFirstPage, '/recent_media');
    }
  }, {
    key: 'getTopMedia',
    value: function getTopMedia(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGMedia, fields, params, fetchFirstPage, '/top_media');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return ShadowIGHashtag;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGUser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGUser = function (_AbstractCrudObject) {
  inherits(IGUser, _AbstractCrudObject);

  function IGUser() {
    classCallCheck(this, IGUser);
    return possibleConstructorReturn(this, (IGUser.__proto__ || Object.getPrototypeOf(IGUser)).apply(this, arguments));
  }

  createClass(IGUser, [{
    key: 'getAvailableCatalogs',
    value: function getAvailableCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UserAvailableCatalogs, fields, params, fetchFirstPage, '/available_catalogs');
    }
  }, {
    key: 'getBrandedContentAdPermissions',
    value: function getBrandedContentAdPermissions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGBCAdsPermission, fields, params, fetchFirstPage, '/branded_content_ad_permissions');
    }
  }, {
    key: 'createBrandedContentAdPermission',
    value: function createBrandedContentAdPermission(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/branded_content_ad_permissions', fields, params, IGBCAdsPermission, pathOverride);
    }
  }, {
    key: 'getBrandedContentAdvertisableMedias',
    value: function getBrandedContentAdvertisableMedias(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BrandedContentShadowIGMediaID, fields, params, fetchFirstPage, '/branded_content_advertisable_medias');
    }
  }, {
    key: 'deleteBrandedContentTagApproval',
    value: function deleteBrandedContentTagApproval() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(IGUser.prototype.__proto__ || Object.getPrototypeOf(IGUser.prototype), 'deleteEdge', this).call(this, '/branded_content_tag_approval', params);
    }
  }, {
    key: 'getBrandedContentTagApproval',
    value: function getBrandedContentTagApproval(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BrandedContentShadowIGUserID, fields, params, fetchFirstPage, '/branded_content_tag_approval');
    }
  }, {
    key: 'createBrandedContentTagApproval',
    value: function createBrandedContentTagApproval(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/branded_content_tag_approval', fields, params, BrandedContentShadowIGUserID, pathOverride);
    }
  }, {
    key: 'getCatalogProductSearch',
    value: function getCatalogProductSearch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ShadowIGUserCatalogProductSearch, fields, params, fetchFirstPage, '/catalog_product_search');
    }
  }, {
    key: 'getContentPublishingLimit',
    value: function getContentPublishingLimit(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ContentPublishingLimitResponse, fields, params, fetchFirstPage, '/content_publishing_limit');
    }
  }, {
    key: 'getDataset',
    value: function getDataset(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Dataset, fields, params, fetchFirstPage, '/dataset');
    }
  }, {
    key: 'createDataset',
    value: function createDataset(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/dataset', fields, params, Dataset, pathOverride);
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramInsightsResult, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'getLiveMedia',
    value: function getLiveMedia(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGMedia, fields, params, fetchFirstPage, '/live_media');
    }
  }, {
    key: 'getMedia',
    value: function getMedia(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGMedia, fields, params, fetchFirstPage, '/media');
    }
  }, {
    key: 'createMedia',
    value: function createMedia(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/media', fields, params, IGMedia, pathOverride);
    }
  }, {
    key: 'createMediaPublish',
    value: function createMediaPublish(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/media_publish', fields, params, IGMedia, pathOverride);
    }
  }, {
    key: 'createMention',
    value: function createMention(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/mentions', fields, params, null, pathOverride);
    }
  }, {
    key: 'getNotificationMessageTokens',
    value: function getNotificationMessageTokens(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UserPageOneTimeOptInTokenSettings, fields, params, fetchFirstPage, '/notification_message_tokens');
    }
  }, {
    key: 'getProductAppeal',
    value: function getProductAppeal(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGShoppingProductAppeal, fields, params, fetchFirstPage, '/product_appeal');
    }
  }, {
    key: 'createProductAppeal',
    value: function createProductAppeal(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/product_appeal', fields, params, IGShoppingProductAppeal, pathOverride);
    }
  }, {
    key: 'getRecentlySearchedHashtags',
    value: function getRecentlySearchedHashtags(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ShadowIGHashtag, fields, params, fetchFirstPage, '/recently_searched_hashtags');
    }
  }, {
    key: 'getStories',
    value: function getStories(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGMedia, fields, params, fetchFirstPage, '/stories');
    }
  }, {
    key: 'getTags',
    value: function getTags(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGMedia, fields, params, fetchFirstPage, '/tags');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        biography: 'biography',
        business_discovery: 'business_discovery',
        followers_count: 'followers_count',
        follows_count: 'follows_count',
        id: 'id',
        ig_id: 'ig_id',
        media_count: 'media_count',
        mentioned_comment: 'mentioned_comment',
        mentioned_media: 'mentioned_media',
        name: 'name',
        owner_business: 'owner_business',
        profile_picture_url: 'profile_picture_url',
        shopping_product_tag_eligibility: 'shopping_product_tag_eligibility',
        shopping_review_status: 'shopping_review_status',
        username: 'username',
        website: 'website'
      });
    }
  }]);
  return IGUser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * NegativeKeywordList
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var NegativeKeywordList = function (_AbstractCrudObject) {
  inherits(NegativeKeywordList, _AbstractCrudObject);

  function NegativeKeywordList() {
    classCallCheck(this, NegativeKeywordList);
    return possibleConstructorReturn(this, (NegativeKeywordList.__proto__ || Object.getPrototypeOf(NegativeKeywordList)).apply(this, arguments));
  }

  createClass(NegativeKeywordList, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(NegativeKeywordList.prototype.__proto__ || Object.getPrototypeOf(NegativeKeywordList.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        applied_active_ad_campaign_groups: 'applied_active_ad_campaign_groups',
        applied_inactive_ad_campaign_groups: 'applied_inactive_ad_campaign_groups',
        creator_id: 'creator_id',
        id: 'id',
        is_fully_reviewed: 'is_fully_reviewed',
        last_update_time: 'last_update_time',
        last_update_user_id: 'last_update_user_id',
        list_name: 'list_name',
        total_approved_keyword_count: 'total_approved_keyword_count',
        total_declined_keyword_count: 'total_declined_keyword_count',
        total_negative_keyword_count: 'total_negative_keyword_count',
        total_validated_keyword_count: 'total_validated_keyword_count'
      });
    }
  }]);
  return NegativeKeywordList;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OpenBridgeConfiguration
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OpenBridgeConfiguration = function (_AbstractCrudObject) {
  inherits(OpenBridgeConfiguration, _AbstractCrudObject);

  function OpenBridgeConfiguration() {
    classCallCheck(this, OpenBridgeConfiguration);
    return possibleConstructorReturn(this, (OpenBridgeConfiguration.__proto__ || Object.getPrototypeOf(OpenBridgeConfiguration)).apply(this, arguments));
  }

  createClass(OpenBridgeConfiguration, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(OpenBridgeConfiguration.prototype.__proto__ || Object.getPrototypeOf(OpenBridgeConfiguration.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(OpenBridgeConfiguration.prototype.__proto__ || Object.getPrototypeOf(OpenBridgeConfiguration.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        active: 'active',
        endpoint: 'endpoint',
        fallback_domain: 'fallback_domain',
        fallback_domain_enabled: 'fallback_domain_enabled',
        host_business_id: 'host_business_id',
        host_external_id: 'host_external_id',
        id: 'id',
        instance_id: 'instance_id',
        pixel_id: 'pixel_id'
      });
    }
  }]);
  return OpenBridgeConfiguration;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PartnerAccountLinking
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PartnerAccountLinking = function (_AbstractCrudObject) {
  inherits(PartnerAccountLinking, _AbstractCrudObject);

  function PartnerAccountLinking() {
    classCallCheck(this, PartnerAccountLinking);
    return possibleConstructorReturn(this, (PartnerAccountLinking.__proto__ || Object.getPrototypeOf(PartnerAccountLinking)).apply(this, arguments));
  }

  createClass(PartnerAccountLinking, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adaccount: 'adaccount',
        app: 'app',
        business: 'business',
        externalidentifier: 'externalidentifier',
        externalidentifieruri: 'externalidentifieruri',
        id: 'id',
        partnername: 'partnername',
        pixel: 'pixel'
      });
    }
  }]);
  return PartnerAccountLinking;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessAdAccountRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessAdAccountRequest = function (_AbstractCrudObject) {
  inherits(BusinessAdAccountRequest, _AbstractCrudObject);

  function BusinessAdAccountRequest() {
    classCallCheck(this, BusinessAdAccountRequest);
    return possibleConstructorReturn(this, (BusinessAdAccountRequest.__proto__ || Object.getPrototypeOf(BusinessAdAccountRequest)).apply(this, arguments));
  }

  createClass(BusinessAdAccountRequest, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account: 'ad_account',
        id: 'id'
      });
    }
  }]);
  return BusinessAdAccountRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessApplicationRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessApplicationRequest = function (_AbstractCrudObject) {
  inherits(BusinessApplicationRequest, _AbstractCrudObject);

  function BusinessApplicationRequest() {
    classCallCheck(this, BusinessApplicationRequest);
    return possibleConstructorReturn(this, (BusinessApplicationRequest.__proto__ || Object.getPrototypeOf(BusinessApplicationRequest)).apply(this, arguments));
  }

  createClass(BusinessApplicationRequest, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        application: 'application',
        id: 'id'
      });
    }
  }]);
  return BusinessApplicationRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessPageRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessPageRequest = function (_AbstractCrudObject) {
  inherits(BusinessPageRequest, _AbstractCrudObject);

  function BusinessPageRequest() {
    classCallCheck(this, BusinessPageRequest);
    return possibleConstructorReturn(this, (BusinessPageRequest.__proto__ || Object.getPrototypeOf(BusinessPageRequest)).apply(this, arguments));
  }

  createClass(BusinessPageRequest, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        page: 'page'
      });
    }
  }]);
  return BusinessPageRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessRoleRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessRoleRequest = function (_AbstractCrudObject) {
  inherits(BusinessRoleRequest, _AbstractCrudObject);

  function BusinessRoleRequest() {
    classCallCheck(this, BusinessRoleRequest);
    return possibleConstructorReturn(this, (BusinessRoleRequest.__proto__ || Object.getPrototypeOf(BusinessRoleRequest)).apply(this, arguments));
  }

  createClass(BusinessRoleRequest, [{
    key: 'delete',


    // $FlowFixMe : Support Generic Types
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(BusinessRoleRequest.prototype.__proto__ || Object.getPrototypeOf(BusinessRoleRequest.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(BusinessRoleRequest.prototype.__proto__ || Object.getPrototypeOf(BusinessRoleRequest.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        created_by: 'created_by',
        created_time: 'created_time',
        email: 'email',
        expiration_time: 'expiration_time',
        expiry_time: 'expiry_time',
        finance_role: 'finance_role',
        id: 'id',
        invite_link: 'invite_link',
        invited_user_type: 'invited_user_type',
        ip_role: 'ip_role',
        owner: 'owner',
        role: 'role',
        status: 'status',
        updated_by: 'updated_by',
        updated_time: 'updated_time'
      });
    }
  }, {
    key: 'Role',
    get: function get() {
      return Object.freeze({
        admin: 'ADMIN',
        ads_rights_reviewer: 'ADS_RIGHTS_REVIEWER',
        default: 'DEFAULT',
        developer: 'DEVELOPER',
        employee: 'EMPLOYEE',
        finance_analyst: 'FINANCE_ANALYST',
        finance_edit: 'FINANCE_EDIT',
        finance_editor: 'FINANCE_EDITOR',
        finance_view: 'FINANCE_VIEW',
        manage: 'MANAGE',
        partner_center_admin: 'PARTNER_CENTER_ADMIN',
        partner_center_analyst: 'PARTNER_CENTER_ANALYST',
        partner_center_education: 'PARTNER_CENTER_EDUCATION',
        partner_center_marketing: 'PARTNER_CENTER_MARKETING',
        partner_center_operations: 'PARTNER_CENTER_OPERATIONS'
      });
    }
  }]);
  return BusinessRoleRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WhatsAppBusinessPreVerifiedPhoneNumber
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WhatsAppBusinessPreVerifiedPhoneNumber = function (_AbstractCrudObject) {
  inherits(WhatsAppBusinessPreVerifiedPhoneNumber, _AbstractCrudObject);

  function WhatsAppBusinessPreVerifiedPhoneNumber() {
    classCallCheck(this, WhatsAppBusinessPreVerifiedPhoneNumber);
    return possibleConstructorReturn(this, (WhatsAppBusinessPreVerifiedPhoneNumber.__proto__ || Object.getPrototypeOf(WhatsAppBusinessPreVerifiedPhoneNumber)).apply(this, arguments));
  }

  createClass(WhatsAppBusinessPreVerifiedPhoneNumber, [{
    key: 'getPartners',
    value: function getPartners(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/partners');
    }
  }, {
    key: 'createRequestCode',
    value: function createRequestCode(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/request_code', fields, params, null, pathOverride);
    }
  }, {
    key: 'createVerifyCode',
    value: function createVerifyCode(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/verify_code', fields, params, null, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(WhatsAppBusinessPreVerifiedPhoneNumber.prototype.__proto__ || Object.getPrototypeOf(WhatsAppBusinessPreVerifiedPhoneNumber.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        code_verification_status: 'code_verification_status',
        code_verification_time: 'code_verification_time',
        id: 'id',
        owner_business: 'owner_business',
        phone_number: 'phone_number',
        verification_expiry_time: 'verification_expiry_time'
      });
    }
  }, {
    key: 'CodeVerificationStatus',
    get: function get() {
      return Object.freeze({
        expired: 'EXPIRED',
        not_verified: 'NOT_VERIFIED',
        verified: 'VERIFIED'
      });
    }
  }]);
  return WhatsAppBusinessPreVerifiedPhoneNumber;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ResellerGuidance
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ResellerGuidance = function (_AbstractCrudObject) {
  inherits(ResellerGuidance, _AbstractCrudObject);

  function ResellerGuidance() {
    classCallCheck(this, ResellerGuidance);
    return possibleConstructorReturn(this, (ResellerGuidance.__proto__ || Object.getPrototypeOf(ResellerGuidance)).apply(this, arguments));
  }

  createClass(ResellerGuidance, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_first_spend_date: 'ad_account_first_spend_date',
        ad_account_id: 'ad_account_id',
        adopted_guidance_l7d: 'adopted_guidance_l7d',
        advertiser_name: 'advertiser_name',
        attributed_to_reseller_l7d: 'attributed_to_reseller_l7d',
        available_guidance: 'available_guidance',
        guidance_adoption_rate_l7d: 'guidance_adoption_rate_l7d',
        nurtured_by_reseller_l7d: 'nurtured_by_reseller_l7d',
        planning_agency_name: 'planning_agency_name',
        recommendation_time: 'recommendation_time',
        reporting_ds: 'reporting_ds',
        reseller: 'reseller',
        revenue_l30d: 'revenue_l30d',
        ultimate_advertiser_name: 'ultimate_advertiser_name'
      });
    }
  }]);
  return ResellerGuidance;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WhatsAppBusinessPartnerClientVerificationSubmission
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WhatsAppBusinessPartnerClientVerificationSubmission = function (_AbstractCrudObject) {
  inherits(WhatsAppBusinessPartnerClientVerificationSubmission, _AbstractCrudObject);

  function WhatsAppBusinessPartnerClientVerificationSubmission() {
    classCallCheck(this, WhatsAppBusinessPartnerClientVerificationSubmission);
    return possibleConstructorReturn(this, (WhatsAppBusinessPartnerClientVerificationSubmission.__proto__ || Object.getPrototypeOf(WhatsAppBusinessPartnerClientVerificationSubmission)).apply(this, arguments));
  }

  createClass(WhatsAppBusinessPartnerClientVerificationSubmission, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        client_business_id: 'client_business_id',
        id: 'id',
        rejection_reasons: 'rejection_reasons',
        submitted_info: 'submitted_info',
        submitted_time: 'submitted_time',
        update_time: 'update_time',
        verification_status: 'verification_status'
      });
    }
  }, {
    key: 'RejectionReasons',
    get: function get() {
      return Object.freeze({
        address_not_matching: 'ADDRESS_NOT_MATCHING',
        business_not_eligible: 'BUSINESS_NOT_ELIGIBLE',
        legal_name_not_found_in_documents: 'LEGAL_NAME_NOT_FOUND_IN_DOCUMENTS',
        legal_name_not_matching: 'LEGAL_NAME_NOT_MATCHING',
        none: 'NONE',
        website_not_matching: 'WEBSITE_NOT_MATCHING'
      });
    }
  }, {
    key: 'VerificationStatus',
    get: function get() {
      return Object.freeze({
        approved: 'APPROVED',
        failed: 'FAILED',
        pending: 'PENDING',
        revoked: 'REVOKED'
      });
    }
  }]);
  return WhatsAppBusinessPartnerClientVerificationSubmission;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SystemUser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SystemUser = function (_AbstractCrudObject) {
  inherits(SystemUser, _AbstractCrudObject);

  function SystemUser() {
    classCallCheck(this, SystemUser);
    return possibleConstructorReturn(this, (SystemUser.__proto__ || Object.getPrototypeOf(SystemUser)).apply(this, arguments));
  }

  createClass(SystemUser, [{
    key: 'getAssignedAdAccounts',
    value: function getAssignedAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/assigned_ad_accounts');
    }
  }, {
    key: 'getAssignedBusinessAssetGroups',
    value: function getAssignedBusinessAssetGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessAssetGroup, fields, params, fetchFirstPage, '/assigned_business_asset_groups');
    }
  }, {
    key: 'getAssignedPages',
    value: function getAssignedPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/assigned_pages');
    }
  }, {
    key: 'getAssignedProductCatalogs',
    value: function getAssignedProductCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalog, fields, params, fetchFirstPage, '/assigned_product_catalogs');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        created_by: 'created_by',
        created_time: 'created_time',
        finance_permission: 'finance_permission',
        id: 'id',
        ip_permission: 'ip_permission',
        name: 'name'
      });
    }
  }, {
    key: 'Role',
    get: function get() {
      return Object.freeze({
        admin: 'ADMIN',
        ads_rights_reviewer: 'ADS_RIGHTS_REVIEWER',
        default: 'DEFAULT',
        developer: 'DEVELOPER',
        employee: 'EMPLOYEE',
        finance_analyst: 'FINANCE_ANALYST',
        finance_edit: 'FINANCE_EDIT',
        finance_editor: 'FINANCE_EDITOR',
        finance_view: 'FINANCE_VIEW',
        manage: 'MANAGE',
        partner_center_admin: 'PARTNER_CENTER_ADMIN',
        partner_center_analyst: 'PARTNER_CENTER_ANALYST',
        partner_center_education: 'PARTNER_CENTER_EDUCATION',
        partner_center_marketing: 'PARTNER_CENTER_MARKETING',
        partner_center_operations: 'PARTNER_CENTER_OPERATIONS'
      });
    }
  }]);
  return SystemUser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ThirdPartyMeasurementReportDataset
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ThirdPartyMeasurementReportDataset = function (_AbstractCrudObject) {
  inherits(ThirdPartyMeasurementReportDataset, _AbstractCrudObject);

  function ThirdPartyMeasurementReportDataset() {
    classCallCheck(this, ThirdPartyMeasurementReportDataset);
    return possibleConstructorReturn(this, (ThirdPartyMeasurementReportDataset.__proto__ || Object.getPrototypeOf(ThirdPartyMeasurementReportDataset)).apply(this, arguments));
  }

  createClass(ThirdPartyMeasurementReportDataset, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        category: 'category',
        id: 'id',
        partner: 'partner',
        product: 'product',
        schema: 'schema'
      });
    }
  }]);
  return ThirdPartyMeasurementReportDataset;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Business
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Business = function (_AbstractCrudObject) {
  inherits(Business, _AbstractCrudObject);

  function Business() {
    classCallCheck(this, Business);
    return possibleConstructorReturn(this, (Business.__proto__ || Object.getPrototypeOf(Business)).apply(this, arguments));
  }

  createClass(Business, [{
    key: 'createAccessToken',
    value: function createAccessToken(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/access_token', fields, params, Business, pathOverride);
    }
  }, {
    key: 'getAdAccountInfos',
    value: function getAdAccountInfos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ALMAdAccountInfo, fields, params, fetchFirstPage, '/ad_account_infos');
    }
  }, {
    key: 'deleteAdAccounts',
    value: function deleteAdAccounts() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'deleteEdge', this).call(this, '/ad_accounts', params);
    }
  }, {
    key: 'createAdReviewRequest',
    value: function createAdReviewRequest(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/ad_review_requests', fields, params, null, pathOverride);
    }
  }, {
    key: 'getAdStudies',
    value: function getAdStudies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdStudy, fields, params, fetchFirstPage, '/ad_studies');
    }
  }, {
    key: 'createAdStudy',
    value: function createAdStudy(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/ad_studies', fields, params, AdStudy, pathOverride);
    }
  }, {
    key: 'createAdAccount',
    value: function createAdAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adaccount', fields, params, AdAccount, pathOverride);
    }
  }, {
    key: 'createAddPhoneNumber',
    value: function createAddPhoneNumber(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/add_phone_numbers', fields, params, Business, pathOverride);
    }
  }, {
    key: 'createAdNetworkApplication',
    value: function createAdNetworkApplication(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adnetwork_applications', fields, params, Application, pathOverride);
    }
  }, {
    key: 'getAdNetworkAnalytics',
    value: function getAdNetworkAnalytics(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdNetworkAnalyticsSyncQueryResult, fields, params, fetchFirstPage, '/adnetworkanalytics');
    }
  }, {
    key: 'createAdNetworkAnalytic',
    value: function createAdNetworkAnalytic(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adnetworkanalytics', fields, params, Business, pathOverride);
    }
  }, {
    key: 'getAdNetworkAnalyticsResults',
    value: function getAdNetworkAnalyticsResults(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdNetworkAnalyticsAsyncQueryResult, fields, params, fetchFirstPage, '/adnetworkanalytics_results');
    }
  }, {
    key: 'getAdsReportingMmmReports',
    value: function getAdsReportingMmmReports(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsReportBuilderMMMReport, fields, params, fetchFirstPage, '/ads_reporting_mmm_reports');
    }
  }, {
    key: 'getAdsReportingMmmSchedulers',
    value: function getAdsReportingMmmSchedulers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsReportBuilderMMMReportScheduler, fields, params, fetchFirstPage, '/ads_reporting_mmm_schedulers');
    }
  }, {
    key: 'getAdsPixels',
    value: function getAdsPixels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsPixel, fields, params, fetchFirstPage, '/adspixels');
    }
  }, {
    key: 'createAdsPixel',
    value: function createAdsPixel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adspixels', fields, params, AdsPixel, pathOverride);
    }
  }, {
    key: 'deleteAgencies',
    value: function deleteAgencies() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'deleteEdge', this).call(this, '/agencies', params);
    }
  }, {
    key: 'getAgencies',
    value: function getAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/agencies');
    }
  }, {
    key: 'getAnPlacements',
    value: function getAnPlacements(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdPlacement, fields, params, fetchFirstPage, '/an_placements');
    }
  }, {
    key: 'createBlockListDraft',
    value: function createBlockListDraft(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/block_list_drafts', fields, params, Business, pathOverride);
    }
  }, {
    key: 'createBmReviewRequest',
    value: function createBmReviewRequest(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/bm_review_requests', fields, params, null, pathOverride);
    }
  }, {
    key: 'getBusinessAssetGroups',
    value: function getBusinessAssetGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessAssetGroup, fields, params, fetchFirstPage, '/business_asset_groups');
    }
  }, {
    key: 'getBusinessInvoices',
    value: function getBusinessInvoices(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OmegaCustomerTrx, fields, params, fetchFirstPage, '/business_invoices');
    }
  }, {
    key: 'getBusinessUsers',
    value: function getBusinessUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessUser, fields, params, fetchFirstPage, '/business_users');
    }
  }, {
    key: 'createBusinessUser',
    value: function createBusinessUser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/business_users', fields, params, BusinessUser, pathOverride);
    }
  }, {
    key: 'getBusinessProjects',
    value: function getBusinessProjects(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessProject, fields, params, fetchFirstPage, '/businessprojects');
    }
  }, {
    key: 'createClaimCustomConversion',
    value: function createClaimCustomConversion(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/claim_custom_conversions', fields, params, CustomConversion, pathOverride);
    }
  }, {
    key: 'getClientAdAccounts',
    value: function getClientAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/client_ad_accounts');
    }
  }, {
    key: 'getClientApps',
    value: function getClientApps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/client_apps');
    }
  }, {
    key: 'createClientApp',
    value: function createClientApp(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/client_apps', fields, params, Business, pathOverride);
    }
  }, {
    key: 'getClientOffsiteSignalContainerBusinessObjects',
    value: function getClientOffsiteSignalContainerBusinessObjects(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OffsiteSignalContainerBusinessObject, fields, params, fetchFirstPage, '/client_offsite_signal_container_business_objects');
    }
  }, {
    key: 'getClientPages',
    value: function getClientPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/client_pages');
    }
  }, {
    key: 'createClientPage',
    value: function createClientPage(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/client_pages', fields, params, Business, pathOverride);
    }
  }, {
    key: 'getClientPixels',
    value: function getClientPixels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsPixel, fields, params, fetchFirstPage, '/client_pixels');
    }
  }, {
    key: 'getClientProductCatalogs',
    value: function getClientProductCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalog, fields, params, fetchFirstPage, '/client_product_catalogs');
    }
  }, {
    key: 'getClientWhatsAppBusinessAccounts',
    value: function getClientWhatsAppBusinessAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(WhatsAppBusinessAccount, fields, params, fetchFirstPage, '/client_whatsapp_business_accounts');
    }
  }, {
    key: 'deleteClients',
    value: function deleteClients() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'deleteEdge', this).call(this, '/clients', params);
    }
  }, {
    key: 'getClients',
    value: function getClients(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/clients');
    }
  }, {
    key: 'getCollaborativeAdsCollaborationRequests',
    value: function getCollaborativeAdsCollaborationRequests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CPASCollaborationRequest, fields, params, fetchFirstPage, '/collaborative_ads_collaboration_requests');
    }
  }, {
    key: 'createCollaborativeAdsCollaborationRequest',
    value: function createCollaborativeAdsCollaborationRequest(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/collaborative_ads_collaboration_requests', fields, params, CPASCollaborationRequest, pathOverride);
    }
  }, {
    key: 'getCollaborativeAdsSuggestedPartners',
    value: function getCollaborativeAdsSuggestedPartners(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CPASAdvertiserPartnershipRecommendation, fields, params, fetchFirstPage, '/collaborative_ads_suggested_partners');
    }
  }, {
    key: 'getCommerceMerchantSettings',
    value: function getCommerceMerchantSettings(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CommerceMerchantSettings, fields, params, fetchFirstPage, '/commerce_merchant_settings');
    }
  }, {
    key: 'getCpasBusinessSetupConfig',
    value: function getCpasBusinessSetupConfig(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CPASBusinessSetupConfig, fields, params, fetchFirstPage, '/cpas_business_setup_config');
    }
  }, {
    key: 'createCpasBusinessSetupConfig',
    value: function createCpasBusinessSetupConfig(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/cpas_business_setup_config', fields, params, CPASBusinessSetupConfig, pathOverride);
    }
  }, {
    key: 'getCpasMerchantConfig',
    value: function getCpasMerchantConfig(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CPASMerchantConfig, fields, params, fetchFirstPage, '/cpas_merchant_config');
    }
  }, {
    key: 'createCreativeFolder',
    value: function createCreativeFolder(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/creative_folders', fields, params, BusinessCreativeFolder, pathOverride);
    }
  }, {
    key: 'getCreditCards',
    value: function getCreditCards(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CreditCard, fields, params, fetchFirstPage, '/creditcards');
    }
  }, {
    key: 'createCustomConversion',
    value: function createCustomConversion(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/customconversions', fields, params, CustomConversion, pathOverride);
    }
  }, {
    key: 'createDraftNegativeKeywordList',
    value: function createDraftNegativeKeywordList(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/draft_negative_keyword_lists', fields, params, null, pathOverride);
    }
  }, {
    key: 'getEventSourceGroups',
    value: function getEventSourceGroups(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(EventSourceGroup, fields, params, fetchFirstPage, '/event_source_groups');
    }
  }, {
    key: 'createEventSourceGroup',
    value: function createEventSourceGroup(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/event_source_groups', fields, params, EventSourceGroup, pathOverride);
    }
  }, {
    key: 'getExtendedCreditApplications',
    value: function getExtendedCreditApplications(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ExtendedCreditApplication, fields, params, fetchFirstPage, '/extendedcreditapplications');
    }
  }, {
    key: 'getExtendedCredits',
    value: function getExtendedCredits(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ExtendedCredit, fields, params, fetchFirstPage, '/extendedcredits');
    }
  }, {
    key: 'createImage',
    value: function createImage(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/images', fields, params, BusinessImage, pathOverride);
    }
  }, {
    key: 'getInitiatedAudienceSharingRequests',
    value: function getInitiatedAudienceSharingRequests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessAssetSharingAgreement, fields, params, fetchFirstPage, '/initiated_audience_sharing_requests');
    }
  }, {
    key: 'deleteInstagramAccounts',
    value: function deleteInstagramAccounts() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'deleteEdge', this).call(this, '/instagram_accounts', params);
    }
  }, {
    key: 'getInstagramAccounts',
    value: function getInstagramAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramUser, fields, params, fetchFirstPage, '/instagram_accounts');
    }
  }, {
    key: 'getInstagramBusinessAccounts',
    value: function getInstagramBusinessAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGUser, fields, params, fetchFirstPage, '/instagram_business_accounts');
    }
  }, {
    key: 'deleteManagedBusinesses',
    value: function deleteManagedBusinesses() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'deleteEdge', this).call(this, '/managed_businesses', params);
    }
  }, {
    key: 'createManagedBusiness',
    value: function createManagedBusiness(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/managed_businesses', fields, params, Business, pathOverride);
    }
  }, {
    key: 'createManagedPartnerBusinessSetup',
    value: function createManagedPartnerBusinessSetup(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/managed_partner_business_setup', fields, params, Business, pathOverride);
    }
  }, {
    key: 'deleteManagedPartnerBusinesses',
    value: function deleteManagedPartnerBusinesses() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'deleteEdge', this).call(this, '/managed_partner_businesses', params);
    }
  }, {
    key: 'createManagedPartnerBusiness',
    value: function createManagedPartnerBusiness(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/managed_partner_businesses', fields, params, null, pathOverride);
    }
  }, {
    key: 'getNegativeKeywordLists',
    value: function getNegativeKeywordLists(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(NegativeKeywordList, fields, params, fetchFirstPage, '/negative_keyword_lists');
    }
  }, {
    key: 'getOpenBridgeConfigurations',
    value: function getOpenBridgeConfigurations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OpenBridgeConfiguration, fields, params, fetchFirstPage, '/openbridge_configurations');
    }
  }, {
    key: 'createOpenBridgeConfiguration',
    value: function createOpenBridgeConfiguration(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/openbridge_configurations', fields, params, OpenBridgeConfiguration, pathOverride);
    }
  }, {
    key: 'getOwnedAdAccounts',
    value: function getOwnedAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/owned_ad_accounts');
    }
  }, {
    key: 'createOwnedAdAccount',
    value: function createOwnedAdAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/owned_ad_accounts', fields, params, Business, pathOverride);
    }
  }, {
    key: 'getOwnedApps',
    value: function getOwnedApps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/owned_apps');
    }
  }, {
    key: 'createOwnedApp',
    value: function createOwnedApp(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/owned_apps', fields, params, Business, pathOverride);
    }
  }, {
    key: 'deleteOwnedBusinesses',
    value: function deleteOwnedBusinesses() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'deleteEdge', this).call(this, '/owned_businesses', params);
    }
  }, {
    key: 'getOwnedBusinesses',
    value: function getOwnedBusinesses(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/owned_businesses');
    }
  }, {
    key: 'createOwnedBusiness',
    value: function createOwnedBusiness(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/owned_businesses', fields, params, Business, pathOverride);
    }
  }, {
    key: 'getOwnedInstagramAccounts',
    value: function getOwnedInstagramAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramUser, fields, params, fetchFirstPage, '/owned_instagram_accounts');
    }
  }, {
    key: 'getOwnedOffsiteSignalContainerBusinessObjects',
    value: function getOwnedOffsiteSignalContainerBusinessObjects(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OffsiteSignalContainerBusinessObject, fields, params, fetchFirstPage, '/owned_offsite_signal_container_business_objects');
    }
  }, {
    key: 'getOwnedPages',
    value: function getOwnedPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/owned_pages');
    }
  }, {
    key: 'createOwnedPage',
    value: function createOwnedPage(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/owned_pages', fields, params, Business, pathOverride);
    }
  }, {
    key: 'getOwnedPixels',
    value: function getOwnedPixels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsPixel, fields, params, fetchFirstPage, '/owned_pixels');
    }
  }, {
    key: 'getOwnedProductCatalogs',
    value: function getOwnedProductCatalogs(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProductCatalog, fields, params, fetchFirstPage, '/owned_product_catalogs');
    }
  }, {
    key: 'createOwnedProductCatalog',
    value: function createOwnedProductCatalog(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/owned_product_catalogs', fields, params, ProductCatalog, pathOverride);
    }
  }, {
    key: 'getOwnedWhatsAppBusinessAccounts',
    value: function getOwnedWhatsAppBusinessAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(WhatsAppBusinessAccount, fields, params, fetchFirstPage, '/owned_whatsapp_business_accounts');
    }
  }, {
    key: 'deletePages',
    value: function deletePages() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'deleteEdge', this).call(this, '/pages', params);
    }
  }, {
    key: 'getPartnerAccountLinking',
    value: function getPartnerAccountLinking(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PartnerAccountLinking, fields, params, fetchFirstPage, '/partner_account_linking');
    }
  }, {
    key: 'createPartnerPremiumOption',
    value: function createPartnerPremiumOption(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/partner_premium_options', fields, params, null, pathOverride);
    }
  }, {
    key: 'getPendingClientAdAccounts',
    value: function getPendingClientAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessAdAccountRequest, fields, params, fetchFirstPage, '/pending_client_ad_accounts');
    }
  }, {
    key: 'getPendingClientApps',
    value: function getPendingClientApps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessApplicationRequest, fields, params, fetchFirstPage, '/pending_client_apps');
    }
  }, {
    key: 'getPendingClientPages',
    value: function getPendingClientPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessPageRequest, fields, params, fetchFirstPage, '/pending_client_pages');
    }
  }, {
    key: 'getPendingOwnedAdAccounts',
    value: function getPendingOwnedAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessAdAccountRequest, fields, params, fetchFirstPage, '/pending_owned_ad_accounts');
    }
  }, {
    key: 'getPendingOwnedPages',
    value: function getPendingOwnedPages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessPageRequest, fields, params, fetchFirstPage, '/pending_owned_pages');
    }
  }, {
    key: 'getPendingSharedOffsiteSignalContainerBusinessObjects',
    value: function getPendingSharedOffsiteSignalContainerBusinessObjects(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OffsiteSignalContainerBusinessObject, fields, params, fetchFirstPage, '/pending_shared_offsite_signal_container_business_objects');
    }
  }, {
    key: 'getPendingUsers',
    value: function getPendingUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessRoleRequest, fields, params, fetchFirstPage, '/pending_users');
    }
  }, {
    key: 'getPicture',
    value: function getPicture(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ProfilePictureSource, fields, params, fetchFirstPage, '/picture');
    }
  }, {
    key: 'createPixelTo',
    value: function createPixelTo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/pixel_tos', fields, params, null, pathOverride);
    }
  }, {
    key: 'getPreVerifiedNumbers',
    value: function getPreVerifiedNumbers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(WhatsAppBusinessPreVerifiedPhoneNumber, fields, params, fetchFirstPage, '/preverified_numbers');
    }
  }, {
    key: 'getReceivedAudienceSharingRequests',
    value: function getReceivedAudienceSharingRequests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessAssetSharingAgreement, fields, params, fetchFirstPage, '/received_audience_sharing_requests');
    }
  }, {
    key: 'getResellerGuidances',
    value: function getResellerGuidances(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ResellerGuidance, fields, params, fetchFirstPage, '/reseller_guidances');
    }
  }, {
    key: 'getSelfCertifiedWhatsAppBusinessSubmissions',
    value: function getSelfCertifiedWhatsAppBusinessSubmissions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(WhatsAppBusinessPartnerClientVerificationSubmission, fields, params, fetchFirstPage, '/self_certified_whatsapp_business_submissions');
    }
  }, {
    key: 'createSetupManagedPartnerAdAccount',
    value: function createSetupManagedPartnerAdAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/setup_managed_partner_adaccounts', fields, params, Business, pathOverride);
    }
  }, {
    key: 'deleteSharePreVerifiedNumbers',
    value: function deleteSharePreVerifiedNumbers() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'deleteEdge', this).call(this, '/share_preverified_numbers', params);
    }
  }, {
    key: 'createSharePreVerifiedNumber',
    value: function createSharePreVerifiedNumber(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/share_preverified_numbers', fields, params, Business, pathOverride);
    }
  }, {
    key: 'createSystemUserAccessToken',
    value: function createSystemUserAccessToken(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/system_user_access_tokens', fields, params, Business, pathOverride);
    }
  }, {
    key: 'getSystemUsers',
    value: function getSystemUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(SystemUser, fields, params, fetchFirstPage, '/system_users');
    }
  }, {
    key: 'createSystemUser',
    value: function createSystemUser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/system_users', fields, params, SystemUser, pathOverride);
    }
  }, {
    key: 'getThirdPartyMeasurementReportDataset',
    value: function getThirdPartyMeasurementReportDataset(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ThirdPartyMeasurementReportDataset, fields, params, fetchFirstPage, '/third_party_measurement_report_dataset');
    }
  }, {
    key: 'createVideo',
    value: function createVideo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/videos', fields, params, AdVideo, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(Business.prototype.__proto__ || Object.getPrototypeOf(Business.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        block_offline_analytics: 'block_offline_analytics',
        collaborative_ads_managed_partner_business_info: 'collaborative_ads_managed_partner_business_info',
        collaborative_ads_managed_partner_eligibility: 'collaborative_ads_managed_partner_eligibility',
        collaborative_ads_partner_premium_options: 'collaborative_ads_partner_premium_options',
        created_by: 'created_by',
        created_time: 'created_time',
        extended_updated_time: 'extended_updated_time',
        id: 'id',
        is_hidden: 'is_hidden',
        link: 'link',
        name: 'name',
        payment_account_id: 'payment_account_id',
        primary_page: 'primary_page',
        profile_picture_uri: 'profile_picture_uri',
        timezone_id: 'timezone_id',
        two_factor_type: 'two_factor_type',
        updated_by: 'updated_by',
        updated_time: 'updated_time',
        user_access_expire_time: 'user_access_expire_time',
        verification_status: 'verification_status',
        vertical: 'vertical',
        vertical_id: 'vertical_id'
      });
    }
  }, {
    key: 'TwoFactorType',
    get: function get() {
      return Object.freeze({
        admin_required: 'admin_required',
        all_required: 'all_required',
        none: 'none'
      });
    }
  }, {
    key: 'Vertical',
    get: function get() {
      return Object.freeze({
        advertising: 'ADVERTISING',
        automotive: 'AUTOMOTIVE',
        consumer_packaged_goods: 'CONSUMER_PACKAGED_GOODS',
        ecommerce: 'ECOMMERCE',
        education: 'EDUCATION',
        energy_and_utilities: 'ENERGY_AND_UTILITIES',
        entertainment_and_media: 'ENTERTAINMENT_AND_MEDIA',
        financial_services: 'FINANCIAL_SERVICES',
        gaming: 'GAMING',
        government_and_politics: 'GOVERNMENT_AND_POLITICS',
        health: 'HEALTH',
        luxury: 'LUXURY',
        marketing: 'MARKETING',
        non_profit: 'NON_PROFIT',
        not_set: 'NOT_SET',
        organizations_and_associations: 'ORGANIZATIONS_AND_ASSOCIATIONS',
        other: 'OTHER',
        professional_services: 'PROFESSIONAL_SERVICES',
        restaurant: 'RESTAURANT',
        retail: 'RETAIL',
        technology: 'TECHNOLOGY',
        telecom: 'TELECOM',
        travel: 'TRAVEL'
      });
    }
  }, {
    key: 'PermittedTasks',
    get: function get() {
      return Object.freeze({
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        cashier_role: 'CASHIER_ROLE',
        create_content: 'CREATE_CONTENT',
        manage: 'MANAGE',
        manage_jobs: 'MANAGE_JOBS',
        manage_leads: 'MANAGE_LEADS',
        messaging: 'MESSAGING',
        moderate: 'MODERATE',
        moderate_community: 'MODERATE_COMMUNITY',
        pages_messaging: 'PAGES_MESSAGING',
        pages_messaging_subscriptions: 'PAGES_MESSAGING_SUBSCRIPTIONS',
        profile_plus_advertise: 'PROFILE_PLUS_ADVERTISE',
        profile_plus_analyze: 'PROFILE_PLUS_ANALYZE',
        profile_plus_create_content: 'PROFILE_PLUS_CREATE_CONTENT',
        profile_plus_facebook_access: 'PROFILE_PLUS_FACEBOOK_ACCESS',
        profile_plus_full_control: 'PROFILE_PLUS_FULL_CONTROL',
        profile_plus_manage: 'PROFILE_PLUS_MANAGE',
        profile_plus_manage_leads: 'PROFILE_PLUS_MANAGE_LEADS',
        profile_plus_messaging: 'PROFILE_PLUS_MESSAGING',
        profile_plus_moderate: 'PROFILE_PLUS_MODERATE',
        profile_plus_moderate_delegate_community: 'PROFILE_PLUS_MODERATE_DELEGATE_COMMUNITY',
        profile_plus_revenue: 'PROFILE_PLUS_REVENUE',
        read_page_mailboxes: 'READ_PAGE_MAILBOXES',
        view_monetization_insights: 'VIEW_MONETIZATION_INSIGHTS'
      });
    }
  }, {
    key: 'SurveyBusinessType',
    get: function get() {
      return Object.freeze({
        advertiser: 'ADVERTISER',
        agency: 'AGENCY',
        app_developer: 'APP_DEVELOPER',
        publisher: 'PUBLISHER'
      });
    }
  }, {
    key: 'TimezoneId',
    get: function get() {
      return Object.freeze({
        value_0: '0',
        value_1: '1',
        value_2: '2',
        value_3: '3',
        value_4: '4',
        value_5: '5',
        value_6: '6',
        value_7: '7',
        value_8: '8',
        value_9: '9',
        value_10: '10',
        value_11: '11',
        value_12: '12',
        value_13: '13',
        value_14: '14',
        value_15: '15',
        value_16: '16',
        value_17: '17',
        value_18: '18',
        value_19: '19',
        value_20: '20',
        value_21: '21',
        value_22: '22',
        value_23: '23',
        value_24: '24',
        value_25: '25',
        value_26: '26',
        value_27: '27',
        value_28: '28',
        value_29: '29',
        value_30: '30',
        value_31: '31',
        value_32: '32',
        value_33: '33',
        value_34: '34',
        value_35: '35',
        value_36: '36',
        value_37: '37',
        value_38: '38',
        value_39: '39',
        value_40: '40',
        value_41: '41',
        value_42: '42',
        value_43: '43',
        value_44: '44',
        value_45: '45',
        value_46: '46',
        value_47: '47',
        value_48: '48',
        value_49: '49',
        value_50: '50',
        value_51: '51',
        value_52: '52',
        value_53: '53',
        value_54: '54',
        value_55: '55',
        value_56: '56',
        value_57: '57',
        value_58: '58',
        value_59: '59',
        value_60: '60',
        value_61: '61',
        value_62: '62',
        value_63: '63',
        value_64: '64',
        value_65: '65',
        value_66: '66',
        value_67: '67',
        value_68: '68',
        value_69: '69',
        value_70: '70',
        value_71: '71',
        value_72: '72',
        value_73: '73',
        value_74: '74',
        value_75: '75',
        value_76: '76',
        value_77: '77',
        value_78: '78',
        value_79: '79',
        value_80: '80',
        value_81: '81',
        value_82: '82',
        value_83: '83',
        value_84: '84',
        value_85: '85',
        value_86: '86',
        value_87: '87',
        value_88: '88',
        value_89: '89',
        value_90: '90',
        value_91: '91',
        value_92: '92',
        value_93: '93',
        value_94: '94',
        value_95: '95',
        value_96: '96',
        value_97: '97',
        value_98: '98',
        value_99: '99',
        value_100: '100',
        value_101: '101',
        value_102: '102',
        value_103: '103',
        value_104: '104',
        value_105: '105',
        value_106: '106',
        value_107: '107',
        value_108: '108',
        value_109: '109',
        value_110: '110',
        value_111: '111',
        value_112: '112',
        value_113: '113',
        value_114: '114',
        value_115: '115',
        value_116: '116',
        value_117: '117',
        value_118: '118',
        value_119: '119',
        value_120: '120',
        value_121: '121',
        value_122: '122',
        value_123: '123',
        value_124: '124',
        value_125: '125',
        value_126: '126',
        value_127: '127',
        value_128: '128',
        value_129: '129',
        value_130: '130',
        value_131: '131',
        value_132: '132',
        value_133: '133',
        value_134: '134',
        value_135: '135',
        value_136: '136',
        value_137: '137',
        value_138: '138',
        value_139: '139',
        value_140: '140',
        value_141: '141',
        value_142: '142',
        value_143: '143',
        value_144: '144',
        value_145: '145',
        value_146: '146',
        value_147: '147',
        value_148: '148',
        value_149: '149',
        value_150: '150',
        value_151: '151',
        value_152: '152',
        value_153: '153',
        value_154: '154',
        value_155: '155',
        value_156: '156',
        value_157: '157',
        value_158: '158',
        value_159: '159',
        value_160: '160',
        value_161: '161',
        value_162: '162',
        value_163: '163',
        value_164: '164',
        value_165: '165',
        value_166: '166',
        value_167: '167',
        value_168: '168',
        value_169: '169',
        value_170: '170',
        value_171: '171',
        value_172: '172',
        value_173: '173',
        value_174: '174',
        value_175: '175',
        value_176: '176',
        value_177: '177',
        value_178: '178',
        value_179: '179',
        value_180: '180',
        value_181: '181',
        value_182: '182',
        value_183: '183',
        value_184: '184',
        value_185: '185',
        value_186: '186',
        value_187: '187',
        value_188: '188',
        value_189: '189',
        value_190: '190',
        value_191: '191',
        value_192: '192',
        value_193: '193',
        value_194: '194',
        value_195: '195',
        value_196: '196',
        value_197: '197',
        value_198: '198',
        value_199: '199',
        value_200: '200',
        value_201: '201',
        value_202: '202',
        value_203: '203',
        value_204: '204',
        value_205: '205',
        value_206: '206',
        value_207: '207',
        value_208: '208',
        value_209: '209',
        value_210: '210',
        value_211: '211',
        value_212: '212',
        value_213: '213',
        value_214: '214',
        value_215: '215',
        value_216: '216',
        value_217: '217',
        value_218: '218',
        value_219: '219',
        value_220: '220',
        value_221: '221',
        value_222: '222',
        value_223: '223',
        value_224: '224',
        value_225: '225',
        value_226: '226',
        value_227: '227',
        value_228: '228',
        value_229: '229',
        value_230: '230',
        value_231: '231',
        value_232: '232',
        value_233: '233',
        value_234: '234',
        value_235: '235',
        value_236: '236',
        value_237: '237',
        value_238: '238',
        value_239: '239',
        value_240: '240',
        value_241: '241',
        value_242: '242',
        value_243: '243',
        value_244: '244',
        value_245: '245',
        value_246: '246',
        value_247: '247',
        value_248: '248',
        value_249: '249',
        value_250: '250',
        value_251: '251',
        value_252: '252',
        value_253: '253',
        value_254: '254',
        value_255: '255',
        value_256: '256',
        value_257: '257',
        value_258: '258',
        value_259: '259',
        value_260: '260',
        value_261: '261',
        value_262: '262',
        value_263: '263',
        value_264: '264',
        value_265: '265',
        value_266: '266',
        value_267: '267',
        value_268: '268',
        value_269: '269',
        value_270: '270',
        value_271: '271',
        value_272: '272',
        value_273: '273',
        value_274: '274',
        value_275: '275',
        value_276: '276',
        value_277: '277',
        value_278: '278',
        value_279: '279',
        value_280: '280',
        value_281: '281',
        value_282: '282',
        value_283: '283',
        value_284: '284',
        value_285: '285',
        value_286: '286',
        value_287: '287',
        value_288: '288',
        value_289: '289',
        value_290: '290',
        value_291: '291',
        value_292: '292',
        value_293: '293',
        value_294: '294',
        value_295: '295',
        value_296: '296',
        value_297: '297',
        value_298: '298',
        value_299: '299',
        value_300: '300',
        value_301: '301',
        value_302: '302',
        value_303: '303',
        value_304: '304',
        value_305: '305',
        value_306: '306',
        value_307: '307',
        value_308: '308',
        value_309: '309',
        value_310: '310',
        value_311: '311',
        value_312: '312',
        value_313: '313',
        value_314: '314',
        value_315: '315',
        value_316: '316',
        value_317: '317',
        value_318: '318',
        value_319: '319',
        value_320: '320',
        value_321: '321',
        value_322: '322',
        value_323: '323',
        value_324: '324',
        value_325: '325',
        value_326: '326',
        value_327: '327',
        value_328: '328',
        value_329: '329',
        value_330: '330',
        value_331: '331',
        value_332: '332',
        value_333: '333',
        value_334: '334',
        value_335: '335',
        value_336: '336',
        value_337: '337',
        value_338: '338',
        value_339: '339',
        value_340: '340',
        value_341: '341',
        value_342: '342',
        value_343: '343',
        value_344: '344',
        value_345: '345',
        value_346: '346',
        value_347: '347',
        value_348: '348',
        value_349: '349',
        value_350: '350',
        value_351: '351',
        value_352: '352',
        value_353: '353',
        value_354: '354',
        value_355: '355',
        value_356: '356',
        value_357: '357',
        value_358: '358',
        value_359: '359',
        value_360: '360',
        value_361: '361',
        value_362: '362',
        value_363: '363',
        value_364: '364',
        value_365: '365',
        value_366: '366',
        value_367: '367',
        value_368: '368',
        value_369: '369',
        value_370: '370',
        value_371: '371',
        value_372: '372',
        value_373: '373',
        value_374: '374',
        value_375: '375',
        value_376: '376',
        value_377: '377',
        value_378: '378',
        value_379: '379',
        value_380: '380',
        value_381: '381',
        value_382: '382',
        value_383: '383',
        value_384: '384',
        value_385: '385',
        value_386: '386',
        value_387: '387',
        value_388: '388',
        value_389: '389',
        value_390: '390',
        value_391: '391',
        value_392: '392',
        value_393: '393',
        value_394: '394',
        value_395: '395',
        value_396: '396',
        value_397: '397',
        value_398: '398',
        value_399: '399',
        value_400: '400',
        value_401: '401',
        value_402: '402',
        value_403: '403',
        value_404: '404',
        value_405: '405',
        value_406: '406',
        value_407: '407',
        value_408: '408',
        value_409: '409',
        value_410: '410',
        value_411: '411',
        value_412: '412',
        value_413: '413',
        value_414: '414',
        value_415: '415',
        value_416: '416',
        value_417: '417',
        value_418: '418',
        value_419: '419',
        value_420: '420',
        value_421: '421',
        value_422: '422',
        value_423: '423',
        value_424: '424',
        value_425: '425',
        value_426: '426',
        value_427: '427',
        value_428: '428',
        value_429: '429',
        value_430: '430',
        value_431: '431',
        value_432: '432',
        value_433: '433',
        value_434: '434',
        value_435: '435',
        value_436: '436',
        value_437: '437',
        value_438: '438',
        value_439: '439',
        value_440: '440',
        value_441: '441',
        value_442: '442',
        value_443: '443',
        value_444: '444',
        value_445: '445',
        value_446: '446',
        value_447: '447',
        value_448: '448',
        value_449: '449',
        value_450: '450',
        value_451: '451',
        value_452: '452',
        value_453: '453',
        value_454: '454',
        value_455: '455',
        value_456: '456',
        value_457: '457',
        value_458: '458',
        value_459: '459',
        value_460: '460',
        value_461: '461',
        value_462: '462',
        value_463: '463',
        value_464: '464',
        value_465: '465',
        value_466: '466',
        value_467: '467',
        value_468: '468',
        value_469: '469',
        value_470: '470',
        value_471: '471',
        value_472: '472',
        value_473: '473',
        value_474: '474',
        value_475: '475',
        value_476: '476',
        value_477: '477',
        value_478: '478',
        value_479: '479',
        value_480: '480'
      });
    }
  }, {
    key: 'PagePermittedTasks',
    get: function get() {
      return Object.freeze({
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        cashier_role: 'CASHIER_ROLE',
        create_content: 'CREATE_CONTENT',
        manage: 'MANAGE',
        manage_jobs: 'MANAGE_JOBS',
        manage_leads: 'MANAGE_LEADS',
        messaging: 'MESSAGING',
        moderate: 'MODERATE',
        moderate_community: 'MODERATE_COMMUNITY',
        pages_messaging: 'PAGES_MESSAGING',
        pages_messaging_subscriptions: 'PAGES_MESSAGING_SUBSCRIPTIONS',
        profile_plus_advertise: 'PROFILE_PLUS_ADVERTISE',
        profile_plus_analyze: 'PROFILE_PLUS_ANALYZE',
        profile_plus_create_content: 'PROFILE_PLUS_CREATE_CONTENT',
        profile_plus_facebook_access: 'PROFILE_PLUS_FACEBOOK_ACCESS',
        profile_plus_full_control: 'PROFILE_PLUS_FULL_CONTROL',
        profile_plus_manage: 'PROFILE_PLUS_MANAGE',
        profile_plus_manage_leads: 'PROFILE_PLUS_MANAGE_LEADS',
        profile_plus_messaging: 'PROFILE_PLUS_MESSAGING',
        profile_plus_moderate: 'PROFILE_PLUS_MODERATE',
        profile_plus_moderate_delegate_community: 'PROFILE_PLUS_MODERATE_DELEGATE_COMMUNITY',
        profile_plus_revenue: 'PROFILE_PLUS_REVENUE',
        read_page_mailboxes: 'READ_PAGE_MAILBOXES',
        view_monetization_insights: 'VIEW_MONETIZATION_INSIGHTS'
      });
    }
  }, {
    key: 'SubverticalV2',
    get: function get() {
      return Object.freeze({
        accounting_and_tax: 'ACCOUNTING_AND_TAX',
        activities_and_leisure: 'ACTIVITIES_AND_LEISURE',
        air: 'AIR',
        apparel_and_accessories: 'APPAREL_AND_ACCESSORIES',
        arts_and_heritage_and_education: 'ARTS_AND_HERITAGE_AND_EDUCATION',
        ar_or_vr_gaming: 'AR_OR_VR_GAMING',
        audio_streaming: 'AUDIO_STREAMING',
        auto: 'AUTO',
        auto_insurance: 'AUTO_INSURANCE',
        auto_rental: 'AUTO_RENTAL',
        baby: 'BABY',
        ballot_initiative_or_referendum: 'BALLOT_INITIATIVE_OR_REFERENDUM',
        beauty: 'BEAUTY',
        beauty_and_fashion: 'BEAUTY_AND_FASHION',
        beer_and_wine_and_liquor_and_malt_beverages: 'BEER_AND_WINE_AND_LIQUOR_AND_MALT_BEVERAGES',
        bookstores: 'BOOKSTORES',
        broadcast_television: 'BROADCAST_TELEVISION',
        business_consultants: 'BUSINESS_CONSULTANTS',
        buying_agency: 'BUYING_AGENCY',
        cable_and_satellite: 'CABLE_AND_SATELLITE',
        cable_television: 'CABLE_TELEVISION',
        call_center_and_messaging_services: 'CALL_CENTER_AND_MESSAGING_SERVICES',
        candidate_or_politician: 'CANDIDATE_OR_POLITICIAN',
        career: 'CAREER',
        career_and_tech: 'CAREER_AND_TECH',
        casual_dining: 'CASUAL_DINING',
        chronic_conditions_and_medical_causes: 'CHRONIC_CONDITIONS_AND_MEDICAL_CAUSES',
        civic_influencers: 'CIVIC_INFLUENCERS',
        clinical_trials: 'CLINICAL_TRIALS',
        coffee: 'COFFEE',
        computer_and_software_and_hardware: 'COMPUTER_AND_SOFTWARE_AND_HARDWARE',
        console_and_cross_platform_gaming: 'CONSOLE_AND_CROSS_PLATFORM_GAMING',
        consulting: 'CONSULTING',
        consumer_electronics: 'CONSUMER_ELECTRONICS',
        counseling_and_psychotherapy: 'COUNSELING_AND_PSYCHOTHERAPY',
        creative_agency: 'CREATIVE_AGENCY',
        credit_and_financing_and_mortages: 'CREDIT_AND_FINANCING_AND_MORTAGES',
        cruises_and_marine: 'CRUISES_AND_MARINE',
        culture_and_lifestyle: 'CULTURE_AND_LIFESTYLE',
        data_analytics_and_data_management: 'DATA_ANALYTICS_AND_DATA_MANAGEMENT',
        dating_and_technology_apps: 'DATING_AND_TECHNOLOGY_APPS',
        department_store: 'DEPARTMENT_STORE',
        desktop_software: 'DESKTOP_SOFTWARE',
        dieting_and_fitness_programs: 'DIETING_AND_FITNESS_PROGRAMS',
        digital_native_education_or_training: 'DIGITAL_NATIVE_EDUCATION_OR_TRAINING',
        drinking_places: 'DRINKING_PLACES',
        education_resources: 'EDUCATION_RESOURCES',
        ed_tech: 'ED_TECH',
        elearning_and_massive_online_open_courses: 'ELEARNING_AND_MASSIVE_ONLINE_OPEN_COURSES',
        election_commission: 'ELECTION_COMMISSION',
        electronics_and_appliances: 'ELECTRONICS_AND_APPLIANCES',
        engineering_and_design: 'ENGINEERING_AND_DESIGN',
        environment_and_animal_welfare: 'ENVIRONMENT_AND_ANIMAL_WELFARE',
        esports: 'ESPORTS',
        events: 'EVENTS',
        farming_and_ranching: 'FARMING_AND_RANCHING',
        file_storage_and_cloud_and_data_services: 'FILE_STORAGE_AND_CLOUD_AND_DATA_SERVICES',
        finance: 'FINANCE',
        fin_tech: 'FIN_TECH',
        fishing_and_hunting_and_forestry_and_logging: 'FISHING_AND_HUNTING_AND_FORESTRY_AND_LOGGING',
        fitness: 'FITNESS',
        food: 'FOOD',
        footwear: 'FOOTWEAR',
        for_profit_colleges_and_universities: 'FOR_PROFIT_COLLEGES_AND_UNIVERSITIES',
        full_service_agency: 'FULL_SERVICE_AGENCY',
        government_controlled_entity: 'GOVERNMENT_CONTROLLED_ENTITY',
        government_department_or_agency: 'GOVERNMENT_DEPARTMENT_OR_AGENCY',
        government_official: 'GOVERNMENT_OFFICIAL',
        government_owned_media: 'GOVERNMENT_OWNED_MEDIA',
        grocery_and_drug_and_convenience: 'GROCERY_AND_DRUG_AND_CONVENIENCE',
        head_of_state: 'HEAD_OF_STATE',
        health_insurance: 'HEALTH_INSURANCE',
        health_systems_and_practitioners: 'HEALTH_SYSTEMS_AND_PRACTITIONERS',
        health_tech: 'HEALTH_TECH',
        home_and_furniture_and_office: 'HOME_AND_FURNITURE_AND_OFFICE',
        home_improvement: 'HOME_IMPROVEMENT',
        home_insurance: 'HOME_INSURANCE',
        home_tech: 'HOME_TECH',
        hotel_and_accomodation: 'HOTEL_AND_ACCOMODATION',
        household_goods_durable: 'HOUSEHOLD_GOODS_DURABLE',
        household_goods_non_durable: 'HOUSEHOLD_GOODS_NON_DURABLE',
        hr_and_financial_management: 'HR_AND_FINANCIAL_MANAGEMENT',
        humanitarian_or_disaster_relief: 'HUMANITARIAN_OR_DISASTER_RELIEF',
        independent_expenditure_group: 'INDEPENDENT_EXPENDITURE_GROUP',
        insurance_tech: 'INSURANCE_TECH',
        international_organizaton: 'INTERNATIONAL_ORGANIZATON',
        investment_bank_and_brokerage: 'INVESTMENT_BANK_AND_BROKERAGE',
        issue_advocacy: 'ISSUE_ADVOCACY',
        legal: 'LEGAL',
        life_insurance: 'LIFE_INSURANCE',
        logistics_and_transportation_and_fleet_management: 'LOGISTICS_AND_TRANSPORTATION_AND_FLEET_MANAGEMENT',
        manufacturing: 'MANUFACTURING',
        medical_devices_and_supplies_and_equipment: 'MEDICAL_DEVICES_AND_SUPPLIES_AND_EQUIPMENT',
        medspa_and_elective_surgeries_and_alternative_medicine: 'MEDSPA_AND_ELECTIVE_SURGERIES_AND_ALTERNATIVE_MEDICINE',
        mining_and_quarrying: 'MINING_AND_QUARRYING',
        mobile_gaming: 'MOBILE_GAMING',
        movies: 'MOVIES',
        museums_and_parks_and_libraries: 'MUSEUMS_AND_PARKS_AND_LIBRARIES',
        music: 'MUSIC',
        network_security_products: 'NETWORK_SECURITY_PRODUCTS',
        news_and_current_events: 'NEWS_AND_CURRENT_EVENTS',
        non_prescription: 'NON_PRESCRIPTION',
        not_for_profit_colleges_and_universities: 'NOT_FOR_PROFIT_COLLEGES_AND_UNIVERSITIES',
        office: 'OFFICE',
        office_or_business_supplies: 'OFFICE_OR_BUSINESS_SUPPLIES',
        oil_and_gas_and_consumable_fuel: 'OIL_AND_GAS_AND_CONSUMABLE_FUEL',
        online_only_publications: 'ONLINE_ONLY_PUBLICATIONS',
        package_or_freight_delivery: 'PACKAGE_OR_FREIGHT_DELIVERY',
        party_independent_expenditure_group_us: 'PARTY_INDEPENDENT_EXPENDITURE_GROUP_US',
        payment_processing_and_gateway_solutions: 'PAYMENT_PROCESSING_AND_GATEWAY_SOLUTIONS',
        pc_gaming: 'PC_GAMING',
        people: 'PEOPLE',
        personal_care: 'PERSONAL_CARE',
        pet: 'PET',
        photography_and_filming_services: 'PHOTOGRAPHY_AND_FILMING_SERVICES',
        pizza: 'PIZZA',
        planning_agency: 'PLANNING_AGENCY',
        political_party_or_committee: 'POLITICAL_PARTY_OR_COMMITTEE',
        prescription: 'PRESCRIPTION',
        professional_associations: 'PROFESSIONAL_ASSOCIATIONS',
        property_and_casualty: 'PROPERTY_AND_CASUALTY',
        quick_service: 'QUICK_SERVICE',
        radio: 'RADIO',
        railroads: 'RAILROADS',
        real_estate: 'REAL_ESTATE',
        real_money_gaming: 'REAL_MONEY_GAMING',
        recreational: 'RECREATIONAL',
        religious: 'RELIGIOUS',
        reseller: 'RESELLER',
        residential_and_long_term_care_facilities_and_outpatient_care_centers: 'RESIDENTIAL_AND_LONG_TERM_CARE_FACILITIES_AND_OUTPATIENT_CARE_CENTERS',
        retail_and_credit_union_and_commercial_bank: 'RETAIL_AND_CREDIT_UNION_AND_COMMERCIAL_BANK',
        ride_sharing_or_taxi_services: 'RIDE_SHARING_OR_TAXI_SERVICES',
        safety_services: 'SAFETY_SERVICES',
        scholarly: 'SCHOLARLY',
        school_and_early_children_edcation: 'SCHOOL_AND_EARLY_CHILDREN_EDCATION',
        social_media: 'SOCIAL_MEDIA',
        software_as_a_service: 'SOFTWARE_AS_A_SERVICE',
        sporting: 'SPORTING',
        sporting_and_outdoor: 'SPORTING_AND_OUTDOOR',
        sports: 'SPORTS',
        superstores: 'SUPERSTORES',
        t1_automotive_manufacturer: 'T1_AUTOMOTIVE_MANUFACTURER',
        t1_motorcycle: 'T1_MOTORCYCLE',
        t2_dealer_associations: 'T2_DEALER_ASSOCIATIONS',
        t3_auto_agency: 'T3_AUTO_AGENCY',
        t3_auto_resellers: 'T3_AUTO_RESELLERS',
        t3_dealer_groups: 'T3_DEALER_GROUPS',
        t3_franchise_dealer: 'T3_FRANCHISE_DEALER',
        t3_independent_dealer: 'T3_INDEPENDENT_DEALER',
        t3_parts_and_services: 'T3_PARTS_AND_SERVICES',
        t3_portals: 'T3_PORTALS',
        telecommunications_equipment_and_accessories: 'TELECOMMUNICATIONS_EQUIPMENT_AND_ACCESSORIES',
        telephone_service_providers_and_carriers: 'TELEPHONE_SERVICE_PROVIDERS_AND_CARRIERS',
        ticketing: 'TICKETING',
        tobacco: 'TOBACCO',
        tourism_and_travel_services: 'TOURISM_AND_TRAVEL_SERVICES',
        tourism_board: 'TOURISM_BOARD',
        toy_and_hobby: 'TOY_AND_HOBBY',
        trade_school: 'TRADE_SCHOOL',
        travel_agencies_and_guides_and_otas: 'TRAVEL_AGENCIES_AND_GUIDES_AND_OTAS',
        utilities_and_energy_equipment_and_services: 'UTILITIES_AND_ENERGY_EQUIPMENT_AND_SERVICES',
        veterinary_clinics_and_services: 'VETERINARY_CLINICS_AND_SERVICES',
        video_streaming: 'VIDEO_STREAMING',
        virtual_services: 'VIRTUAL_SERVICES',
        vitamins_or_wellness: 'VITAMINS_OR_WELLNESS',
        warehousing_and_storage: 'WAREHOUSING_AND_STORAGE',
        water_and_soft_drink_and_baverage: 'WATER_AND_SOFT_DRINK_AND_BAVERAGE',
        website_designers_or_graphic_designers: 'WEBSITE_DESIGNERS_OR_GRAPHIC_DESIGNERS',
        wholesale: 'WHOLESALE',
        wireless_services: 'WIRELESS_SERVICES'
      });
    }
  }, {
    key: 'VerticalV2',
    get: function get() {
      return Object.freeze({
        advertising_and_marketing: 'ADVERTISING_AND_MARKETING',
        agriculture: 'AGRICULTURE',
        automotive: 'AUTOMOTIVE',
        banking_and_credit_cards: 'BANKING_AND_CREDIT_CARDS',
        business_to_business: 'BUSINESS_TO_BUSINESS',
        consumer_packaged_goods: 'CONSUMER_PACKAGED_GOODS',
        ecommerce: 'ECOMMERCE',
        education: 'EDUCATION',
        energy_and_natural_resources_and_utilities: 'ENERGY_AND_NATURAL_RESOURCES_AND_UTILITIES',
        entertainment_and_media: 'ENTERTAINMENT_AND_MEDIA',
        gaming: 'GAMING',
        government: 'GOVERNMENT',
        healthcare_and_pharmaceuticals_and_biotech: 'HEALTHCARE_AND_PHARMACEUTICALS_AND_BIOTECH',
        insurance: 'INSURANCE',
        non_profit: 'NON_PROFIT',
        organizations_and_associations: 'ORGANIZATIONS_AND_ASSOCIATIONS',
        politics: 'POLITICS',
        professional_services: 'PROFESSIONAL_SERVICES',
        publishing: 'PUBLISHING',
        restaurants: 'RESTAURANTS',
        retail: 'RETAIL',
        technology: 'TECHNOLOGY',
        telecom: 'TELECOM',
        travel: 'TRAVEL'
      });
    }
  }, {
    key: 'ActionSource',
    get: function get() {
      return Object.freeze({
        physical_store: 'PHYSICAL_STORE',
        website: 'WEBSITE'
      });
    }
  }]);
  return Business;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OfflineConversionDataSetUpload
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OfflineConversionDataSetUpload = function (_AbstractCrudObject) {
  inherits(OfflineConversionDataSetUpload, _AbstractCrudObject);

  function OfflineConversionDataSetUpload() {
    classCallCheck(this, OfflineConversionDataSetUpload);
    return possibleConstructorReturn(this, (OfflineConversionDataSetUpload.__proto__ || Object.getPrototypeOf(OfflineConversionDataSetUpload)).apply(this, arguments));
  }

  createClass(OfflineConversionDataSetUpload, [{
    key: 'getProgress',
    value: function getProgress(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/progress');
    }
  }, {
    key: 'getPullSessions',
    value: function getPullSessions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/pull_sessions');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        api_calls: 'api_calls',
        creation_time: 'creation_time',
        duplicate_entries: 'duplicate_entries',
        event_stats: 'event_stats',
        event_time_max: 'event_time_max',
        event_time_min: 'event_time_min',
        first_upload_time: 'first_upload_time',
        id: 'id',
        is_excluded_for_lift: 'is_excluded_for_lift',
        last_upload_time: 'last_upload_time',
        match_rate_approx: 'match_rate_approx',
        matched_entries: 'matched_entries',
        upload_tag: 'upload_tag',
        valid_entries: 'valid_entries'
      });
    }
  }, {
    key: 'Order',
    get: function get() {
      return Object.freeze({
        ascending: 'ASCENDING',
        descending: 'DESCENDING'
      });
    }
  }, {
    key: 'SortBy',
    get: function get() {
      return Object.freeze({
        api_calls: 'API_CALLS',
        creation_time: 'CREATION_TIME',
        event_time_max: 'EVENT_TIME_MAX',
        event_time_min: 'EVENT_TIME_MIN',
        first_upload_time: 'FIRST_UPLOAD_TIME',
        is_excluded_for_lift: 'IS_EXCLUDED_FOR_LIFT',
        last_upload_time: 'LAST_UPLOAD_TIME'
      });
    }
  }]);
  return OfflineConversionDataSetUpload;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelStatsResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelStatsResult = function (_AbstractCrudObject) {
  inherits(AdsPixelStatsResult, _AbstractCrudObject);

  function AdsPixelStatsResult() {
    classCallCheck(this, AdsPixelStatsResult);
    return possibleConstructorReturn(this, (AdsPixelStatsResult.__proto__ || Object.getPrototypeOf(AdsPixelStatsResult)).apply(this, arguments));
  }

  createClass(AdsPixelStatsResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        aggregation: 'aggregation',
        data: 'data',
        start_time: 'start_time'
      });
    }
  }, {
    key: 'Aggregation',
    get: function get() {
      return Object.freeze({
        browser_type: 'browser_type',
        custom_data_field: 'custom_data_field',
        device_os: 'device_os',
        device_type: 'device_type',
        event: 'event',
        event_detection_method: 'event_detection_method',
        event_processing_results: 'event_processing_results',
        event_source: 'event_source',
        event_total_counts: 'event_total_counts',
        event_value_count: 'event_value_count',
        had_pii: 'had_pii',
        host: 'host',
        match_keys: 'match_keys',
        pixel_fire: 'pixel_fire',
        url: 'url',
        url_by_rule: 'url_by_rule'
      });
    }
  }]);
  return AdsPixelStatsResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixel = function (_AbstractCrudObject) {
  inherits(AdsPixel, _AbstractCrudObject);

  function AdsPixel() {
    classCallCheck(this, AdsPixel);
    return possibleConstructorReturn(this, (AdsPixel.__proto__ || Object.getPrototypeOf(AdsPixel)).apply(this, arguments));
  }

  createClass(AdsPixel, [{
    key: 'getAdAccounts',
    value: function getAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/adaccounts');
    }
  }, {
    key: 'deleteAgencies',
    value: function deleteAgencies() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdsPixel.prototype.__proto__ || Object.getPrototypeOf(AdsPixel.prototype), 'deleteEdge', this).call(this, '/agencies', params);
    }
  }, {
    key: 'getAgencies',
    value: function getAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/agencies');
    }
  }, {
    key: 'createAgency',
    value: function createAgency(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/agencies', fields, params, AdsPixel, pathOverride);
    }
  }, {
    key: 'createAhpConfig',
    value: function createAhpConfig(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/ahp_configs', fields, params, null, pathOverride);
    }
  }, {
    key: 'getAssignedUsers',
    value: function getAssignedUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AssignedUser, fields, params, fetchFirstPage, '/assigned_users');
    }
  }, {
    key: 'createAssignedUser',
    value: function createAssignedUser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/assigned_users', fields, params, AdsPixel, pathOverride);
    }
  }, {
    key: 'getDaChecks',
    value: function getDaChecks(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(DACheck, fields, params, fetchFirstPage, '/da_checks');
    }
  }, {
    key: 'createEvent',
    value: function createEvent(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/events', fields, params, null, pathOverride);
    }
  }, {
    key: 'getOfflineEventUploads',
    value: function getOfflineEventUploads(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OfflineConversionDataSetUpload, fields, params, fetchFirstPage, '/offline_event_uploads');
    }
  }, {
    key: 'getOpenBridgeConfigurations',
    value: function getOpenBridgeConfigurations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OpenBridgeConfiguration, fields, params, fetchFirstPage, '/openbridge_configurations');
    }
  }, {
    key: 'createShadowTrafficHelper',
    value: function createShadowTrafficHelper(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/shadowtraffichelper', fields, params, null, pathOverride);
    }
  }, {
    key: 'deleteSharedAccounts',
    value: function deleteSharedAccounts() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdsPixel.prototype.__proto__ || Object.getPrototypeOf(AdsPixel.prototype), 'deleteEdge', this).call(this, '/shared_accounts', params);
    }
  }, {
    key: 'getSharedAccounts',
    value: function getSharedAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/shared_accounts');
    }
  }, {
    key: 'createSharedAccount',
    value: function createSharedAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/shared_accounts', fields, params, AdsPixel, pathOverride);
    }
  }, {
    key: 'getSharedAgencies',
    value: function getSharedAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/shared_agencies');
    }
  }, {
    key: 'getStats',
    value: function getStats(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsPixelStatsResult, fields, params, fetchFirstPage, '/stats');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdsPixel.prototype.__proto__ || Object.getPrototypeOf(AdsPixel.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        automatic_matching_fields: 'automatic_matching_fields',
        can_proxy: 'can_proxy',
        code: 'code',
        config: 'config',
        creation_time: 'creation_time',
        creator: 'creator',
        data_use_setting: 'data_use_setting',
        description: 'description',
        duplicate_entries: 'duplicate_entries',
        enable_auto_assign_to_accounts: 'enable_auto_assign_to_accounts',
        enable_automatic_matching: 'enable_automatic_matching',
        event_stats: 'event_stats',
        event_time_max: 'event_time_max',
        event_time_min: 'event_time_min',
        first_party_cookie_status: 'first_party_cookie_status',
        has_1p_pixel_event: 'has_1p_pixel_event',
        id: 'id',
        is_consolidated_container: 'is_consolidated_container',
        is_created_by_business: 'is_created_by_business',
        is_crm: 'is_crm',
        is_mta_use: 'is_mta_use',
        is_restricted_use: 'is_restricted_use',
        is_unavailable: 'is_unavailable',
        last_fired_time: 'last_fired_time',
        last_upload_app: 'last_upload_app',
        last_upload_app_changed_time: 'last_upload_app_changed_time',
        match_rate_approx: 'match_rate_approx',
        matched_entries: 'matched_entries',
        name: 'name',
        owner_ad_account: 'owner_ad_account',
        owner_business: 'owner_business',
        usage: 'usage',
        user_access_expire_time: 'user_access_expire_time',
        valid_entries: 'valid_entries'
      });
    }
  }, {
    key: 'SortBy',
    get: function get() {
      return Object.freeze({
        last_fired_time: 'LAST_FIRED_TIME',
        name: 'NAME'
      });
    }
  }, {
    key: 'AutomaticMatchingFields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        ct: 'ct',
        db: 'db',
        em: 'em',
        external_id: 'external_id',
        fn: 'fn',
        ge: 'ge',
        ln: 'ln',
        ph: 'ph',
        st: 'st',
        zp: 'zp'
      });
    }
  }, {
    key: 'DataUseSetting',
    get: function get() {
      return Object.freeze({
        advertising_and_analytics: 'ADVERTISING_AND_ANALYTICS',
        analytics_only: 'ANALYTICS_ONLY',
        empty: 'EMPTY'
      });
    }
  }, {
    key: 'FirstPartyCookieStatus',
    get: function get() {
      return Object.freeze({
        empty: 'EMPTY',
        first_party_cookie_disabled: 'FIRST_PARTY_COOKIE_DISABLED',
        first_party_cookie_enabled: 'FIRST_PARTY_COOKIE_ENABLED'
      });
    }
  }, {
    key: 'PermittedTasks',
    get: function get() {
      return Object.freeze({
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        edit: 'EDIT',
        upload: 'UPLOAD'
      });
    }
  }, {
    key: 'Tasks',
    get: function get() {
      return Object.freeze({
        aa_analyze: 'AA_ANALYZE',
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        edit: 'EDIT',
        upload: 'UPLOAD'
      });
    }
  }]);
  return AdsPixel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BrandRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BrandRequest = function (_AbstractCrudObject) {
  inherits(BrandRequest, _AbstractCrudObject);

  function BrandRequest() {
    classCallCheck(this, BrandRequest);
    return possibleConstructorReturn(this, (BrandRequest.__proto__ || Object.getPrototypeOf(BrandRequest)).apply(this, arguments));
  }

  createClass(BrandRequest, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_countries: 'ad_countries',
        additional_contacts: 'additional_contacts',
        approval_level: 'approval_level',
        cells: 'cells',
        countries: 'countries',
        deny_reason: 'deny_reason',
        end_time: 'end_time',
        estimated_reach: 'estimated_reach',
        id: 'id',
        is_multicell: 'is_multicell',
        locale: 'locale',
        max_age: 'max_age',
        min_age: 'min_age',
        questions: 'questions',
        region: 'region',
        request_status: 'request_status',
        review_date: 'review_date',
        start_time: 'start_time',
        status: 'status',
        submit_date: 'submit_date',
        total_budget: 'total_budget'
      });
    }
  }]);
  return BrandRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudienceSalts
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudienceSalts = function (_AbstractCrudObject) {
  inherits(CustomAudienceSalts, _AbstractCrudObject);

  function CustomAudienceSalts() {
    classCallCheck(this, CustomAudienceSalts);
    return possibleConstructorReturn(this, (CustomAudienceSalts.__proto__ || Object.getPrototypeOf(CustomAudienceSalts)).apply(this, arguments));
  }

  createClass(CustomAudienceSalts, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        public_key: 'public_key'
      });
    }
  }]);
  return CustomAudienceSalts;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudienceSession
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudienceSession = function (_AbstractCrudObject) {
  inherits(CustomAudienceSession, _AbstractCrudObject);

  function CustomAudienceSession() {
    classCallCheck(this, CustomAudienceSession);
    return possibleConstructorReturn(this, (CustomAudienceSession.__proto__ || Object.getPrototypeOf(CustomAudienceSession)).apply(this, arguments));
  }

  createClass(CustomAudienceSession, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        end_time: 'end_time',
        num_invalid_entries: 'num_invalid_entries',
        num_matched: 'num_matched',
        num_received: 'num_received',
        progress: 'progress',
        session_id: 'session_id',
        stage: 'stage',
        start_time: 'start_time'
      });
    }
  }]);
  return CustomAudienceSession;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudiencesharedAccountInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudiencesharedAccountInfo = function (_AbstractCrudObject) {
  inherits(CustomAudiencesharedAccountInfo, _AbstractCrudObject);

  function CustomAudiencesharedAccountInfo() {
    classCallCheck(this, CustomAudiencesharedAccountInfo);
    return possibleConstructorReturn(this, (CustomAudiencesharedAccountInfo.__proto__ || Object.getPrototypeOf(CustomAudiencesharedAccountInfo)).apply(this, arguments));
  }

  createClass(CustomAudiencesharedAccountInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        account_name: 'account_name',
        business_id: 'business_id',
        business_name: 'business_name',
        sharing_status: 'sharing_status'
      });
    }
  }]);
  return CustomAudiencesharedAccountInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudience
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudience = function (_AbstractCrudObject) {
  inherits(CustomAudience, _AbstractCrudObject);

  function CustomAudience() {
    classCallCheck(this, CustomAudience);
    return possibleConstructorReturn(this, (CustomAudience.__proto__ || Object.getPrototypeOf(CustomAudience)).apply(this, arguments));
  }

  createClass(CustomAudience, [{
    key: 'deleteAdAccounts',
    value: function deleteAdAccounts() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(CustomAudience.prototype.__proto__ || Object.getPrototypeOf(CustomAudience.prototype), 'deleteEdge', this).call(this, '/adaccounts', params);
    }
  }, {
    key: 'getAdAccounts',
    value: function getAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/adaccounts');
    }
  }, {
    key: 'createAdAccount',
    value: function createAdAccount(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adaccounts', fields, params, CustomAudience, pathOverride);
    }
  }, {
    key: 'getAds',
    value: function getAds(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Ad, fields, params, fetchFirstPage, '/ads');
    }
  }, {
    key: 'getSalts',
    value: function getSalts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomAudienceSalts, fields, params, fetchFirstPage, '/salts');
    }
  }, {
    key: 'createSalt',
    value: function createSalt(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/salts', fields, params, CustomAudience, pathOverride);
    }
  }, {
    key: 'getSessions',
    value: function getSessions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomAudienceSession, fields, params, fetchFirstPage, '/sessions');
    }
  }, {
    key: 'getSharedAccountInfo',
    value: function getSharedAccountInfo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomAudiencesharedAccountInfo, fields, params, fetchFirstPage, '/shared_account_info');
    }
  }, {
    key: 'deleteUsers',
    value: function deleteUsers() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(CustomAudience.prototype.__proto__ || Object.getPrototypeOf(CustomAudience.prototype), 'deleteEdge', this).call(this, '/users', params);
    }
  }, {
    key: 'createUser',
    value: function createUser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/users', fields, params, CustomAudience, pathOverride);
    }
  }, {
    key: 'createUsersReplace',
    value: function createUsersReplace(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/usersreplace', fields, params, CustomAudience, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(CustomAudience.prototype.__proto__ || Object.getPrototypeOf(CustomAudience.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(CustomAudience.prototype.__proto__ || Object.getPrototypeOf(CustomAudience.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        approximate_count_lower_bound: 'approximate_count_lower_bound',
        approximate_count_upper_bound: 'approximate_count_upper_bound',
        customer_file_source: 'customer_file_source',
        data_source: 'data_source',
        data_source_types: 'data_source_types',
        datafile_custom_audience_uploading_status: 'datafile_custom_audience_uploading_status',
        delete_time: 'delete_time',
        delivery_status: 'delivery_status',
        description: 'description',
        excluded_custom_audiences: 'excluded_custom_audiences',
        external_event_source: 'external_event_source',
        household_audience: 'household_audience',
        id: 'id',
        included_custom_audiences: 'included_custom_audiences',
        is_household: 'is_household',
        is_snapshot: 'is_snapshot',
        is_value_based: 'is_value_based',
        lookalike_audience_ids: 'lookalike_audience_ids',
        lookalike_spec: 'lookalike_spec',
        name: 'name',
        operation_status: 'operation_status',
        opt_out_link: 'opt_out_link',
        owner_business: 'owner_business',
        page_deletion_marked_delete_time: 'page_deletion_marked_delete_time',
        permission_for_actions: 'permission_for_actions',
        pixel_id: 'pixel_id',
        regulated_audience_spec: 'regulated_audience_spec',
        retention_days: 'retention_days',
        rev_share_policy_id: 'rev_share_policy_id',
        rule: 'rule',
        rule_aggregation: 'rule_aggregation',
        rule_v2: 'rule_v2',
        seed_audience: 'seed_audience',
        sharing_status: 'sharing_status',
        subtype: 'subtype',
        time_content_updated: 'time_content_updated',
        time_created: 'time_created',
        time_updated: 'time_updated'
      });
    }
  }, {
    key: 'ClaimObjective',
    get: function get() {
      return Object.freeze({
        automotive_model: 'AUTOMOTIVE_MODEL',
        collaborative_ads: 'COLLABORATIVE_ADS',
        home_listing: 'HOME_LISTING',
        media_title: 'MEDIA_TITLE',
        product: 'PRODUCT',
        travel: 'TRAVEL',
        vehicle: 'VEHICLE',
        vehicle_offer: 'VEHICLE_OFFER'
      });
    }
  }, {
    key: 'ContentType',
    get: function get() {
      return Object.freeze({
        automotive_model: 'AUTOMOTIVE_MODEL',
        destination: 'DESTINATION',
        flight: 'FLIGHT',
        generic: 'GENERIC',
        home_listing: 'HOME_LISTING',
        hotel: 'HOTEL',
        job: 'JOB',
        local_service_business: 'LOCAL_SERVICE_BUSINESS',
        media_title: 'MEDIA_TITLE',
        offline_product: 'OFFLINE_PRODUCT',
        product: 'PRODUCT',
        vehicle: 'VEHICLE',
        vehicle_offer: 'VEHICLE_OFFER'
      });
    }
  }, {
    key: 'CustomerFileSource',
    get: function get() {
      return Object.freeze({
        both_user_and_partner_provided: 'BOTH_USER_AND_PARTNER_PROVIDED',
        partner_provided_only: 'PARTNER_PROVIDED_ONLY',
        user_provided_only: 'USER_PROVIDED_ONLY'
      });
    }
  }, {
    key: 'SubscriptionInfo',
    get: function get() {
      return Object.freeze({
        messenger: 'MESSENGER',
        whatsapp: 'WHATSAPP'
      });
    }
  }, {
    key: 'Subtype',
    get: function get() {
      return Object.freeze({
        app: 'APP',
        bag_of_accounts: 'BAG_OF_ACCOUNTS',
        bidding: 'BIDDING',
        claim: 'CLAIM',
        custom: 'CUSTOM',
        engagement: 'ENGAGEMENT',
        exclusion: 'EXCLUSION',
        fox: 'FOX',
        lookalike: 'LOOKALIKE',
        managed: 'MANAGED',
        measurement: 'MEASUREMENT',
        messenger_subscriber_list: 'MESSENGER_SUBSCRIBER_LIST',
        offline_conversion: 'OFFLINE_CONVERSION',
        partner: 'PARTNER',
        primary: 'PRIMARY',
        regulated_categories_audience: 'REGULATED_CATEGORIES_AUDIENCE',
        study_rule_audience: 'STUDY_RULE_AUDIENCE',
        subscriber_segment: 'SUBSCRIBER_SEGMENT',
        video: 'VIDEO',
        website: 'WEBSITE'
      });
    }
  }, {
    key: 'UseForProducts',
    get: function get() {
      return Object.freeze({
        ads: 'ADS',
        marketing_messages: 'MARKETING_MESSAGES'
      });
    }
  }, {
    key: 'ActionSource',
    get: function get() {
      return Object.freeze({
        physical_store: 'PHYSICAL_STORE',
        website: 'WEBSITE'
      });
    }
  }]);
  return CustomAudience;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OfflineConversionDataSet
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OfflineConversionDataSet = function (_AbstractCrudObject) {
  inherits(OfflineConversionDataSet, _AbstractCrudObject);

  function OfflineConversionDataSet() {
    classCallCheck(this, OfflineConversionDataSet);
    return possibleConstructorReturn(this, (OfflineConversionDataSet.__proto__ || Object.getPrototypeOf(OfflineConversionDataSet)).apply(this, arguments));
  }

  createClass(OfflineConversionDataSet, [{
    key: 'getAdAccounts',
    value: function getAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/adaccounts');
    }
  }, {
    key: 'getAgencies',
    value: function getAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/agencies');
    }
  }, {
    key: 'getAudiences',
    value: function getAudiences(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomAudience, fields, params, fetchFirstPage, '/audiences');
    }
  }, {
    key: 'getCustomConversions',
    value: function getCustomConversions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomConversion, fields, params, fetchFirstPage, '/customconversions');
    }
  }, {
    key: 'getServerEventsPermittedBusiness',
    value: function getServerEventsPermittedBusiness(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/server_events_permitted_business');
    }
  }, {
    key: 'getSharedAccounts',
    value: function getSharedAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/shared_accounts');
    }
  }, {
    key: 'getSharedAgencies',
    value: function getSharedAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/shared_agencies');
    }
  }, {
    key: 'getStats',
    value: function getStats(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/stats');
    }
  }, {
    key: 'getUploads',
    value: function getUploads(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OfflineConversionDataSetUpload, fields, params, fetchFirstPage, '/uploads');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        automatic_matching_fields: 'automatic_matching_fields',
        business: 'business',
        can_proxy: 'can_proxy',
        config: 'config',
        creation_time: 'creation_time',
        creator: 'creator',
        data_use_setting: 'data_use_setting',
        description: 'description',
        duplicate_entries: 'duplicate_entries',
        enable_auto_assign_to_accounts: 'enable_auto_assign_to_accounts',
        enable_automatic_matching: 'enable_automatic_matching',
        event_stats: 'event_stats',
        event_time_max: 'event_time_max',
        event_time_min: 'event_time_min',
        first_party_cookie_status: 'first_party_cookie_status',
        id: 'id',
        is_consolidated_container: 'is_consolidated_container',
        is_created_by_business: 'is_created_by_business',
        is_crm: 'is_crm',
        is_mta_use: 'is_mta_use',
        is_restricted_use: 'is_restricted_use',
        is_unavailable: 'is_unavailable',
        last_fired_time: 'last_fired_time',
        last_upload_app: 'last_upload_app',
        last_upload_app_changed_time: 'last_upload_app_changed_time',
        match_rate_approx: 'match_rate_approx',
        matched_entries: 'matched_entries',
        name: 'name',
        owner_ad_account: 'owner_ad_account',
        owner_business: 'owner_business',
        usage: 'usage',
        valid_entries: 'valid_entries'
      });
    }
  }]);
  return OfflineConversionDataSet;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PartnerStudy
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PartnerStudy = function (_AbstractCrudObject) {
  inherits(PartnerStudy, _AbstractCrudObject);

  function PartnerStudy() {
    classCallCheck(this, PartnerStudy);
    return possibleConstructorReturn(this, (PartnerStudy.__proto__ || Object.getPrototypeOf(PartnerStudy)).apply(this, arguments));
  }

  createClass(PartnerStudy, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        additional_info: 'additional_info',
        brand: 'brand',
        client_name: 'client_name',
        emails: 'emails',
        id: 'id',
        input_ids: 'input_ids',
        is_export: 'is_export',
        lift_study: 'lift_study',
        location: 'location',
        match_file_ds: 'match_file_ds',
        name: 'name',
        partner_defined_id: 'partner_defined_id',
        partner_household_graph_dataset_id: 'partner_household_graph_dataset_id',
        status: 'status',
        study_end_date: 'study_end_date',
        study_start_date: 'study_start_date',
        study_type: 'study_type',
        submit_date: 'submit_date'
      });
    }
  }]);
  return PartnerStudy;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdStudyObjective
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdStudyObjective = function (_AbstractCrudObject) {
  inherits(AdStudyObjective, _AbstractCrudObject);

  function AdStudyObjective() {
    classCallCheck(this, AdStudyObjective);
    return possibleConstructorReturn(this, (AdStudyObjective.__proto__ || Object.getPrototypeOf(AdStudyObjective)).apply(this, arguments));
  }

  createClass(AdStudyObjective, [{
    key: 'getAdsPixels',
    value: function getAdsPixels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsPixel, fields, params, fetchFirstPage, '/adspixels');
    }
  }, {
    key: 'getApplications',
    value: function getApplications(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/applications');
    }
  }, {
    key: 'getBrandRequests',
    value: function getBrandRequests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BrandRequest, fields, params, fetchFirstPage, '/brand_requests');
    }
  }, {
    key: 'getCustomConversions',
    value: function getCustomConversions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomConversion, fields, params, fetchFirstPage, '/customconversions');
    }
  }, {
    key: 'getOfflineConversionDataSets',
    value: function getOfflineConversionDataSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OfflineConversionDataSet, fields, params, fetchFirstPage, '/offline_conversion_data_sets');
    }
  }, {
    key: 'getPartnerPrivateStudies',
    value: function getPartnerPrivateStudies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/partner_private_studies');
    }
  }, {
    key: 'getPartnerStudies',
    value: function getPartnerStudies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PartnerStudy, fields, params, fetchFirstPage, '/partnerstudies');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdStudyObjective.prototype.__proto__ || Object.getPrototypeOf(AdStudyObjective.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        is_primary: 'is_primary',
        last_updated_results: 'last_updated_results',
        name: 'name',
        results: 'results',
        type: 'type'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        brand: 'BRAND',
        brandlift: 'BRANDLIFT',
        conversions: 'CONVERSIONS',
        ftl: 'FTL',
        mae: 'MAE',
        mai: 'MAI',
        mpc_conversion: 'MPC_CONVERSION',
        nonsales: 'NONSALES',
        partner: 'PARTNER',
        sales: 'SALES',
        telco: 'TELCO'
      });
    }
  }]);
  return AdStudyObjective;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdStudy
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdStudy = function (_AbstractCrudObject) {
  inherits(AdStudy, _AbstractCrudObject);

  function AdStudy() {
    classCallCheck(this, AdStudy);
    return possibleConstructorReturn(this, (AdStudy.__proto__ || Object.getPrototypeOf(AdStudy)).apply(this, arguments));
  }

  createClass(AdStudy, [{
    key: 'getCells',
    value: function getCells(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdStudyCell, fields, params, fetchFirstPage, '/cells');
    }
  }, {
    key: 'createCheckPoint',
    value: function createCheckPoint(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/checkpoint', fields, params, AdStudy, pathOverride);
    }
  }, {
    key: 'getInstances',
    value: function getInstances(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PrivateLiftStudyInstance, fields, params, fetchFirstPage, '/instances');
    }
  }, {
    key: 'createInstance',
    value: function createInstance(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/instances', fields, params, PrivateLiftStudyInstance, pathOverride);
    }
  }, {
    key: 'getObjectives',
    value: function getObjectives(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdStudyObjective, fields, params, fetchFirstPage, '/objectives');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdStudy.prototype.__proto__ || Object.getPrototypeOf(AdStudy.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdStudy.prototype.__proto__ || Object.getPrototypeOf(AdStudy.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        canceled_time: 'canceled_time',
        client_business: 'client_business',
        cooldown_start_time: 'cooldown_start_time',
        created_by: 'created_by',
        created_time: 'created_time',
        description: 'description',
        end_time: 'end_time',
        id: 'id',
        measurement_contact: 'measurement_contact',
        name: 'name',
        observation_end_time: 'observation_end_time',
        results_first_available_date: 'results_first_available_date',
        sales_contact: 'sales_contact',
        start_time: 'start_time',
        type: 'type',
        updated_by: 'updated_by',
        updated_time: 'updated_time'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        backend_ab_testing: 'BACKEND_AB_TESTING',
        continuous_lift_config: 'CONTINUOUS_LIFT_CONFIG',
        geo_lift: 'GEO_LIFT',
        lift: 'LIFT',
        split_test: 'SPLIT_TEST'
      });
    }
  }]);
  return AdStudy;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CloudGame
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CloudGame = function (_AbstractCrudObject) {
  inherits(CloudGame, _AbstractCrudObject);

  function CloudGame() {
    classCallCheck(this, CloudGame);
    return possibleConstructorReturn(this, (CloudGame.__proto__ || Object.getPrototypeOf(CloudGame)).apply(this, arguments));
  }

  createClass(CloudGame, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        owner: 'owner',
        playable_ad_file_size: 'playable_ad_file_size',
        playable_ad_orientation: 'playable_ad_orientation',
        playable_ad_package_name: 'playable_ad_package_name',
        playable_ad_reject_reason: 'playable_ad_reject_reason',
        playable_ad_status: 'playable_ad_status',
        playable_ad_upload_time: 'playable_ad_upload_time'
      });
    }
  }]);
  return CloudGame;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdImage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdImage = function (_AbstractCrudObject) {
  inherits(AdImage, _AbstractCrudObject);

  function AdImage() {
    classCallCheck(this, AdImage);
    return possibleConstructorReturn(this, (AdImage.__proto__ || Object.getPrototypeOf(AdImage)).apply(this, arguments));
  }

  createClass(AdImage, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        created_time: 'created_time',
        creatives: 'creatives',
        hash: 'hash',
        height: 'height',
        id: 'id',
        is_associated_creatives_in_adgroups: 'is_associated_creatives_in_adgroups',
        name: 'name',
        original_height: 'original_height',
        original_width: 'original_width',
        owner_business: 'owner_business',
        permalink_url: 'permalink_url',
        status: 'status',
        updated_time: 'updated_time',
        url: 'url',
        url_128: 'url_128',
        width: 'width'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        active: 'ACTIVE',
        deleted: 'DELETED',
        internal: 'INTERNAL'
      });
    }
  }]);
  return AdImage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdLabel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdLabel = function (_AbstractCrudObject) {
  inherits(AdLabel, _AbstractCrudObject);

  function AdLabel() {
    classCallCheck(this, AdLabel);
    return possibleConstructorReturn(this, (AdLabel.__proto__ || Object.getPrototypeOf(AdLabel)).apply(this, arguments));
  }

  createClass(AdLabel, [{
    key: 'getAdCreatives',
    value: function getAdCreatives(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdCreative, fields, params, fetchFirstPage, '/adcreatives');
    }
  }, {
    key: 'getAds',
    value: function getAds(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Ad, fields, params, fetchFirstPage, '/ads');
    }
  }, {
    key: 'getAdSets',
    value: function getAdSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdSet, fields, params, fetchFirstPage, '/adsets');
    }
  }, {
    key: 'getCampaigns',
    value: function getCampaigns(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Campaign, fields, params, fetchFirstPage, '/campaigns');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdLabel.prototype.__proto__ || Object.getPrototypeOf(AdLabel.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdLabel.prototype.__proto__ || Object.getPrototypeOf(AdLabel.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account: 'account',
        created_time: 'created_time',
        id: 'id',
        name: 'name',
        updated_time: 'updated_time'
      });
    }
  }]);
  return AdLabel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PlayableContent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PlayableContent = function (_AbstractCrudObject) {
  inherits(PlayableContent, _AbstractCrudObject);

  function PlayableContent() {
    classCallCheck(this, PlayableContent);
    return possibleConstructorReturn(this, (PlayableContent.__proto__ || Object.getPrototypeOf(PlayableContent)).apply(this, arguments));
  }

  createClass(PlayableContent, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        owner: 'owner'
      });
    }
  }]);
  return PlayableContent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountAdRulesHistory
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountAdRulesHistory = function (_AbstractCrudObject) {
  inherits(AdAccountAdRulesHistory, _AbstractCrudObject);

  function AdAccountAdRulesHistory() {
    classCallCheck(this, AdAccountAdRulesHistory);
    return possibleConstructorReturn(this, (AdAccountAdRulesHistory.__proto__ || Object.getPrototypeOf(AdAccountAdRulesHistory)).apply(this, arguments));
  }

  createClass(AdAccountAdRulesHistory, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        evaluation_spec: 'evaluation_spec',
        exception_code: 'exception_code',
        exception_message: 'exception_message',
        execution_spec: 'execution_spec',
        is_manual: 'is_manual',
        results: 'results',
        rule_id: 'rule_id',
        schedule_spec: 'schedule_spec',
        timestamp: 'timestamp'
      });
    }
  }, {
    key: 'Action',
    get: function get() {
      return Object.freeze({
        budget_not_redistributed: 'BUDGET_NOT_REDISTRIBUTED',
        changed_bid: 'CHANGED_BID',
        changed_budget: 'CHANGED_BUDGET',
        consolidate_asc_fragmentation: 'CONSOLIDATE_ASC_FRAGMENTATION',
        convert_asc_cp_single_instance: 'CONVERT_ASC_CP_SINGLE_INSTANCE',
        email: 'EMAIL',
        enable_advantage_campaign_budget: 'ENABLE_ADVANTAGE_CAMPAIGN_BUDGET',
        enable_advantage_plus_creative: 'ENABLE_ADVANTAGE_PLUS_CREATIVE',
        enable_advantage_plus_placements: 'ENABLE_ADVANTAGE_PLUS_PLACEMENTS',
        enable_autoflow: 'ENABLE_AUTOFLOW',
        enable_gen_uncrop: 'ENABLE_GEN_UNCROP',
        enable_landing_page_views: 'ENABLE_LANDING_PAGE_VIEWS',
        enable_music: 'ENABLE_MUSIC',
        enable_reels_placements: 'ENABLE_REELS_PLACEMENTS',
        enable_semantic_based_audience_expansion: 'ENABLE_SEMANTIC_BASED_AUDIENCE_EXPANSION',
        enable_shops_ads: 'ENABLE_SHOPS_ADS',
        endpoint_pinged: 'ENDPOINT_PINGED',
        error: 'ERROR',
        facebook_notification_sent: 'FACEBOOK_NOTIFICATION_SENT',
        message_sent: 'MESSAGE_SENT',
        not_changed: 'NOT_CHANGED',
        paused: 'PAUSED',
        unpaused: 'UNPAUSED'
      });
    }
  }, {
    key: 'EvaluationType',
    get: function get() {
      return Object.freeze({
        schedule: 'SCHEDULE',
        trigger: 'TRIGGER'
      });
    }
  }]);
  return AdAccountAdRulesHistory;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountAdVolume
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountAdVolume = function (_AbstractCrudObject) {
  inherits(AdAccountAdVolume, _AbstractCrudObject);

  function AdAccountAdVolume() {
    classCallCheck(this, AdAccountAdVolume);
    return possibleConstructorReturn(this, (AdAccountAdVolume.__proto__ || Object.getPrototypeOf(AdAccountAdVolume)).apply(this, arguments));
  }

  createClass(AdAccountAdVolume, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actor_id: 'actor_id',
        actor_name: 'actor_name',
        ad_limit_scope_business: 'ad_limit_scope_business',
        ad_limit_scope_business_manager_id: 'ad_limit_scope_business_manager_id',
        ad_limit_set_by_page_admin: 'ad_limit_set_by_page_admin',
        ads_running_or_in_review_count: 'ads_running_or_in_review_count',
        ads_running_or_in_review_count_subject_to_limit_set_by_page: 'ads_running_or_in_review_count_subject_to_limit_set_by_page',
        current_account_ads_running_or_in_review_count: 'current_account_ads_running_or_in_review_count',
        future_limit_activation_date: 'future_limit_activation_date',
        future_limit_on_ads_running_or_in_review: 'future_limit_on_ads_running_or_in_review',
        limit_on_ads_running_or_in_review: 'limit_on_ads_running_or_in_review',
        recommendations: 'recommendations'
      });
    }
  }, {
    key: 'RecommendationType',
    get: function get() {
      return Object.freeze({
        aac_creation_package: 'AAC_CREATION_PACKAGE',
        ab_test: 'AB_TEST',
        account_needs_credit: 'ACCOUNT_NEEDS_CREDIT',
        account_spend_limit: 'ACCOUNT_SPEND_LIMIT',
        account_spend_limit_duplication: 'ACCOUNT_SPEND_LIMIT_DUPLICATION',
        aco_toggle: 'ACO_TOGGLE',
        ads_reporting: 'ADS_REPORTING',
        advanced_campaign_budget: 'ADVANCED_CAMPAIGN_BUDGET',
        advantage_app_campaign: 'ADVANTAGE_APP_CAMPAIGN',
        advantage_campaign_budget_duplication: 'ADVANTAGE_CAMPAIGN_BUDGET_DUPLICATION',
        advantage_custom_audience: 'ADVANTAGE_CUSTOM_AUDIENCE',
        advantage_custom_audience_duplication: 'ADVANTAGE_CUSTOM_AUDIENCE_DUPLICATION',
        advantage_custom_audience_upsell: 'ADVANTAGE_CUSTOM_AUDIENCE_UPSELL',
        advantage_detailed_targeting: 'ADVANTAGE_DETAILED_TARGETING',
        advantage_lookalike_audience: 'ADVANTAGE_LOOKALIKE_AUDIENCE',
        advantage_lookalike_duplication: 'ADVANTAGE_LOOKALIKE_DUPLICATION',
        advantage_plus_app_campaign: 'ADVANTAGE_PLUS_APP_CAMPAIGN',
        advantage_plus_app_campaign_precreate: 'ADVANTAGE_PLUS_APP_CAMPAIGN_PRECREATE',
        advantage_plus_audience: 'ADVANTAGE_PLUS_AUDIENCE',
        advantage_plus_audience_duplication: 'ADVANTAGE_PLUS_AUDIENCE_DUPLICATION',
        advantage_plus_audience_friction: 'ADVANTAGE_PLUS_AUDIENCE_FRICTION',
        advantage_plus_audience_toggle: 'ADVANTAGE_PLUS_AUDIENCE_TOGGLE',
        advantage_plus_campaign_budget: 'ADVANTAGE_PLUS_CAMPAIGN_BUDGET',
        advantage_plus_catalog_ads: 'ADVANTAGE_PLUS_CATALOG_ADS',
        advantage_plus_creative: 'ADVANTAGE_PLUS_CREATIVE',
        advantage_plus_creative_catalog: 'ADVANTAGE_PLUS_CREATIVE_CATALOG',
        advantage_plus_creative_se: 'ADVANTAGE_PLUS_CREATIVE_SE',
        advantage_plus_placements_duplication: 'ADVANTAGE_PLUS_PLACEMENTS_DUPLICATION',
        advantage_plus_placements_friction: 'ADVANTAGE_PLUS_PLACEMENTS_FRICTION',
        advantage_plus_placements_v2_duplication: 'ADVANTAGE_PLUS_PLACEMENTS_V2_DUPLICATION',
        advantage_shopping_campaign: 'ADVANTAGE_SHOPPING_CAMPAIGN',
        advantage_shopping_campaign_fragmentation: 'ADVANTAGE_SHOPPING_CAMPAIGN_FRAGMENTATION',
        ad_lift_recall_goal: 'AD_LIFT_RECALL_GOAL',
        ad_lift_recall_goal_precreate: 'AD_LIFT_RECALL_GOAL_PRECREATE',
        ad_lift_recall_optimization_goal: 'AD_LIFT_RECALL_OPTIMIZATION_GOAL',
        ad_objective: 'AD_OBJECTIVE',
        aem_v2_ineligible: 'AEM_V2_INELIGIBLE',
        aggregated_bid_limited: 'AGGREGATED_BID_LIMITED',
        aggregated_budget_limited: 'AGGREGATED_BUDGET_LIMITED',
        aggregated_cost_limited: 'AGGREGATED_COST_LIMITED',
        aplus_c_catalog_duplication: 'APLUS_C_CATALOG_DUPLICATION',
        app_aem_v2_installation_promotion: 'APP_AEM_V2_INSTALLATION_PROMOTION',
        app_engaged_view_conversions_duplication: 'APP_ENGAGED_VIEW_CONVERSIONS_DUPLICATION',
        asc_budget_optimization: 'ASC_BUDGET_OPTIMIZATION',
        asc_creation_package: 'ASC_CREATION_PACKAGE',
        asc_fragmentation_v2: 'ASC_FRAGMENTATION_V2',
        asc_precreate: 'ASC_PRECREATE',
        aspect_ratio: 'ASPECT_RATIO',
        atleast_6_placements: 'ATLEAST_6_PLACEMENTS',
        auction_overlap: 'AUCTION_OVERLAP',
        auction_overlap_consolidation: 'AUCTION_OVERLAP_CONSOLIDATION',
        audience_expansion: 'AUDIENCE_EXPANSION',
        audience_expansion_georadius: 'AUDIENCE_EXPANSION_GEORADIUS',
        audience_expansion_lookalike: 'AUDIENCE_EXPANSION_LOOKALIKE',
        audience_expansion_retargeting: 'AUDIENCE_EXPANSION_RETARGETING',
        audience_learning_limited: 'AUDIENCE_LEARNING_LIMITED',
        autoflow_opt_in: 'AUTOFLOW_OPT_IN',
        autoflow_opt_in_fallback_duplication_flow: 'AUTOFLOW_OPT_IN_FALLBACK_DUPLICATION_FLOW',
        autoflow_opt_in_v2: 'AUTOFLOW_OPT_IN_V2',
        automatic_placements: 'AUTOMATIC_PLACEMENTS',
        automatic_placements_v2: 'AUTOMATIC_PLACEMENTS_V2',
        auto_bid: 'AUTO_BID',
        background_generation: 'BACKGROUND_GENERATION',
        blended_ads: 'BLENDED_ADS',
        blended_ads_duplication: 'BLENDED_ADS_DUPLICATION',
        blended_ads_for_shops_ads_duplication: 'BLENDED_ADS_FOR_SHOPS_ADS_DUPLICATION',
        broad_targeting: 'BROAD_TARGETING',
        budget_limited: 'BUDGET_LIMITED',
        capi: 'CAPI',
        capi_crm_guidance: 'CAPI_CRM_GUIDANCE',
        capi_performance_match_key: 'CAPI_PERFORMANCE_MATCH_KEY',
        capi_performance_match_key_v2: 'CAPI_PERFORMANCE_MATCH_KEY_V2',
        cash_rewards_opt_in: 'CASH_REWARDS_OPT_IN',
        catalog_match_rate: 'CATALOG_MATCH_RATE',
        commerce_shops_ads_duplication: 'COMMERCE_SHOPS_ADS_DUPLICATION',
        connected_sources: 'CONNECTED_SOURCES',
        connected_sources_duplication: 'CONNECTED_SOURCES_DUPLICATION',
        connect_facebook_page_to_instagram: 'CONNECT_FACEBOOK_PAGE_TO_INSTAGRAM',
        connect_facebook_page_to_whatsapp: 'CONNECT_FACEBOOK_PAGE_TO_WHATSAPP',
        conversion_lead_ads: 'CONVERSION_LEAD_ADS',
        cost_goal: 'COST_GOAL',
        cost_goal_budget_limited: 'COST_GOAL_BUDGET_LIMITED',
        cost_goal_cpa_limited: 'COST_GOAL_CPA_LIMITED',
        cost_per_result: 'COST_PER_RESULT',
        creation_package_upgrade_to_asc: 'CREATION_PACKAGE_UPGRADE_TO_ASC',
        creation_package_upgrade_to_ctx: 'CREATION_PACKAGE_UPGRADE_TO_CTX',
        creation_package_upgrade_to_tla: 'CREATION_PACKAGE_UPGRADE_TO_TLA',
        creation_package_upgrade_to_tmc: 'CREATION_PACKAGE_UPGRADE_TO_TMC',
        creative_badge: 'CREATIVE_BADGE',
        creative_diversity: 'CREATIVE_DIVERSITY',
        creative_fatigue: 'CREATIVE_FATIGUE',
        creative_fatigue_duplication: 'CREATIVE_FATIGUE_DUPLICATION',
        creative_fatigue_hourly: 'CREATIVE_FATIGUE_HOURLY',
        creative_limited: 'CREATIVE_LIMITED',
        creative_limited_duplication: 'CREATIVE_LIMITED_DUPLICATION',
        creative_limited_hourly: 'CREATIVE_LIMITED_HOURLY',
        creator_ads_pa_conversion: 'CREATOR_ADS_PA_CONVERSION',
        cta: 'CTA',
        ctx_budget_optimization: 'CTX_BUDGET_OPTIMIZATION',
        ctx_creation_package: 'CTX_CREATION_PACKAGE',
        ctx_cta_upgrade_in_duplication: 'CTX_CTA_UPGRADE_IN_DUPLICATION',
        ctx_ctmpo_upgrade: 'CTX_CTMPO_UPGRADE',
        ctx_guidance: 'CTX_GUIDANCE',
        ctx_precreate: 'CTX_PRECREATE',
        da_advantage_plus_creative_info_labels: 'DA_ADVANTAGE_PLUS_CREATIVE_INFO_LABELS',
        da_duplication_product_tags: 'DA_DUPLICATION_PRODUCT_TAGS',
        dead_link: 'DEAD_LINK',
        defragmentation_acb: 'DEFRAGMENTATION_ACB',
        defragmentation_acb_duplication: 'DEFRAGMENTATION_ACB_DUPLICATION',
        delivery_error: 'DELIVERY_ERROR',
        delivery_warning: 'DELIVERY_WARNING',
        dynamic_advantage_campaign_budget: 'DYNAMIC_ADVANTAGE_CAMPAIGN_BUDGET',
        ecosystem_bid_reduce_l1_cardinality: 'ECOSYSTEM_BID_REDUCE_L1_CARDINALITY',
        engaged_view_conversions_creation: 'ENGAGED_VIEW_CONVERSIONS_CREATION',
        evc_app_duplication_upgrade: 'EVC_APP_DUPLICATION_UPGRADE',
        evc_web_duplication_upgrade: 'EVC_WEB_DUPLICATION_UPGRADE',
        fragmentation: 'FRAGMENTATION',
        fragmentation_resolution_update: 'FRAGMENTATION_RESOLUTION_UPDATE',
        fragmentation_v2: 'FRAGMENTATION_V2',
        generative_uncrop_duplication: 'GENERATIVE_UNCROP_DUPLICATION',
        ges_test: 'GES_TEST',
        guidance_center_code_gen: 'GUIDANCE_CENTER_CODE_GEN',
        heuristic_default_duration: 'HEURISTIC_DEFAULT_DURATION',
        high_cost: 'HIGH_COST',
        historical_benchmark: 'HISTORICAL_BENCHMARK',
        ig_multi_ads: 'IG_MULTI_ADS',
        landing_page_view: 'LANDING_PAGE_VIEW',
        landing_page_view_optimization_goal: 'LANDING_PAGE_VIEW_OPTIMIZATION_GOAL',
        landing_page_view_precreate: 'LANDING_PAGE_VIEW_PRECREATE',
        lead_ads_guidance: 'LEAD_ADS_GUIDANCE',
        learning_limited: 'LEARNING_LIMITED',
        learning_pause_friction: 'LEARNING_PAUSE_FRICTION',
        learning_phase_budget_edits: 'LEARNING_PHASE_BUDGET_EDITS',
        low_budget_utilization: 'LOW_BUDGET_UTILIZATION',
        low_outcome: 'LOW_OUTCOME',
        merlin_guidance: 'MERLIN_GUIDANCE',
        messaging_events: 'MESSAGING_EVENTS',
        messaging_events_precreate: 'MESSAGING_EVENTS_PRECREATE',
        messaging_partners: 'MESSAGING_PARTNERS',
        messaging_partners_precreate: 'MESSAGING_PARTNERS_PRECREATE',
        meta_verified_ads_performance_guidance: 'META_VERIFIED_ADS_PERFORMANCE_GUIDANCE',
        missing_or_invalid_parameters: 'MISSING_OR_INVALID_PARAMETERS',
        mixed_formats: 'MIXED_FORMATS',
        mixed_pa_combine_adsets: 'MIXED_PA_COMBINE_ADSETS',
        mmt_carousel_to_video: 'MMT_CAROUSEL_TO_VIDEO',
        mobile_first_creative: 'MOBILE_FIRST_CREATIVE',
        mobile_first_video: 'MOBILE_FIRST_VIDEO',
        mr_aemv2sub_kconsolidation: 'MR_AEMV2SUB_KCONSOLIDATION',
        multi_advertiser_ads: 'MULTI_ADVERTISER_ADS',
        multi_text: 'MULTI_TEXT',
        music: 'MUSIC',
        not_applicable: 'NOT_APPLICABLE',
        no_delivery_status: 'NO_DELIVERY_STATUS',
        offsite_conversion: 'OFFSITE_CONVERSION',
        optimal_bau: 'OPTIMAL_BAU',
        outcome_forecaster_shadow_logging: 'OUTCOME_FORECASTER_SHADOW_LOGGING',
        payment_method: 'PAYMENT_METHOD',
        performant_creative_reels_opt_in: 'PERFORMANT_CREATIVE_REELS_OPT_IN',
        pfr_l1_inline_mmt: 'PFR_L1_INLINE_MMT',
        pixel_optimization_aam: 'PIXEL_OPTIMIZATION_AAM',
        pixel_optimization_aam_precreate: 'PIXEL_OPTIMIZATION_AAM_PRECREATE',
        pixel_optimization_hie: 'PIXEL_OPTIMIZATION_HIE',
        pixel_optimization_hie_precreate: 'PIXEL_OPTIMIZATION_HIE_PRECREATE',
        pixel_setup: 'PIXEL_SETUP',
        pixel_setup_precreate: 'PIXEL_SETUP_PRECREATE',
        pixel_upsell: 'PIXEL_UPSELL',
        placements_liquidity_automatic_guidance: 'PLACEMENTS_LIQUIDITY_AUTOMATIC_GUIDANCE',
        predictive_creative_limited: 'PREDICTIVE_CREATIVE_LIMITED',
        predictive_creative_limited_hourly: 'PREDICTIVE_CREATIVE_LIMITED_HOURLY',
        preparing_status: 'PREPARING_STATUS',
        purchase_optimization: 'PURCHASE_OPTIMIZATION',
        rapid_learning_limited: 'RAPID_LEARNING_LIMITED',
        rapid_learning_phase: 'RAPID_LEARNING_PHASE',
        reach_optimization_goal: 'REACH_OPTIMIZATION_GOAL',
        reach_optimization_goal_precreate: 'REACH_OPTIMIZATION_GOAL_PRECREATE',
        reels_duplication_upsell: 'REELS_DUPLICATION_UPSELL',
        reels_music_duplication: 'REELS_MUSIC_DUPLICATION',
        reels_pc_and_mobile_first_creative: 'REELS_PC_AND_MOBILE_FIRST_CREATIVE',
        reels_performant_creative: 'REELS_PERFORMANT_CREATIVE',
        reels_placement: 'REELS_PLACEMENT',
        revert: 'REVERT',
        sabr_default_duration: 'SABR_DEFAULT_DURATION',
        sales_conversion: 'SALES_CONVERSION',
        scale_good_campaign: 'SCALE_GOOD_CAMPAIGN',
        scale_good_campaign_duplication: 'SCALE_GOOD_CAMPAIGN_DUPLICATION',
        scale_good_campaign_smb: 'SCALE_GOOD_CAMPAIGN_SMB',
        scale_good_ctx_campaign: 'SCALE_GOOD_CTX_CAMPAIGN',
        semantic_based_audience_duplication: 'SEMANTIC_BASED_AUDIENCE_DUPLICATION',
        semantic_based_audience_expansion: 'SEMANTIC_BASED_AUDIENCE_EXPANSION',
        setup_pixel: 'SETUP_PIXEL',
        shops_ads: 'SHOPS_ADS',
        shops_ads_duplication: 'SHOPS_ADS_DUPLICATION',
        shops_ads_traffic_cap_settings: 'SHOPS_ADS_TRAFFIC_CAP_SETTINGS',
        shop_ads_v2: 'SHOP_ADS_V2',
        signals_growth_capi: 'SIGNALS_GROWTH_CAPI',
        signals_growth_capi_precreate: 'SIGNALS_GROWTH_CAPI_PRECREATE',
        signals_growth_capi_table: 'SIGNALS_GROWTH_CAPI_TABLE',
        signals_growth_capi_v2: 'SIGNALS_GROWTH_CAPI_V2',
        similar_advertiser_budget_recommendation: 'SIMILAR_ADVERTISER_BUDGET_RECOMMENDATION',
        six_plus_manual_placements: 'SIX_PLUS_MANUAL_PLACEMENTS',
        six_plus_placements_duplication: 'SIX_PLUS_PLACEMENTS_DUPLICATION',
        spend_limit: 'SPEND_LIMIT',
        syd_test_mode: 'SYD_TEST_MODE',
        tailored_lead_ad_campaign: 'TAILORED_LEAD_AD_CAMPAIGN',
        tailored_messages_campaign: 'TAILORED_MESSAGES_CAMPAIGN',
        tla_creation_package: 'TLA_CREATION_PACKAGE',
        top_adsets_with_ads_under_cap: 'TOP_ADSETS_WITH_ADS_UNDER_CAP',
        top_campaigns_with_ads_under_cap: 'TOP_CAMPAIGNS_WITH_ADS_UNDER_CAP',
        two_p_guidance_card_aaa: 'TWO_P_GUIDANCE_CARD_AAA',
        two_p_guidance_card_auto_placement: 'TWO_P_GUIDANCE_CARD_AUTO_PLACEMENT',
        two_p_guidance_card_cbo_off: 'TWO_P_GUIDANCE_CARD_CBO_OFF',
        two_p_guidance_card_ctm_preflight: 'TWO_P_GUIDANCE_CARD_CTM_PREFLIGHT',
        uncrop_image: 'UNCROP_IMAGE',
        uneconomical_ads_throttling: 'UNECONOMICAL_ADS_THROTTLING',
        unified_inbox: 'UNIFIED_INBOX',
        unused_budget: 'UNUSED_BUDGET',
        value_diagnostics_guidance: 'VALUE_DIAGNOSTICS_GUIDANCE',
        video_length: 'VIDEO_LENGTH',
        video_views_upsell: 'VIDEO_VIEWS_UPSELL',
        video_views_upsell_precreate: 'VIDEO_VIEWS_UPSELL_PRECREATE',
        wa_messaging_partners: 'WA_MESSAGING_PARTNERS',
        wa_messaging_partners_precreate: 'WA_MESSAGING_PARTNERS_PRECREATE',
        web_engaged_view_conversions: 'WEB_ENGAGED_VIEW_CONVERSIONS',
        zero_conversion: 'ZERO_CONVERSION',
        zero_impression: 'ZERO_IMPRESSION'
      });
    }
  }]);
  return AdAccountAdVolume;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AsyncRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AsyncRequest = function (_AbstractCrudObject) {
  inherits(AsyncRequest, _AbstractCrudObject);

  function AsyncRequest() {
    classCallCheck(this, AsyncRequest);
    return possibleConstructorReturn(this, (AsyncRequest.__proto__ || Object.getPrototypeOf(AsyncRequest)).apply(this, arguments));
  }

  createClass(AsyncRequest, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        result: 'result',
        status: 'status',
        type: 'type'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        error: 'ERROR',
        executing: 'EXECUTING',
        finished: 'FINISHED',
        initialized: 'INITIALIZED'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        async_adgroup_creation: 'ASYNC_ADGROUP_CREATION',
        batch_api: 'BATCH_API',
        drafts: 'DRAFTS'
      });
    }
  }]);
  return AsyncRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAsyncRequestSet
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAsyncRequestSet = function (_AbstractCrudObject) {
  inherits(AdAsyncRequestSet, _AbstractCrudObject);

  function AdAsyncRequestSet() {
    classCallCheck(this, AdAsyncRequestSet);
    return possibleConstructorReturn(this, (AdAsyncRequestSet.__proto__ || Object.getPrototypeOf(AdAsyncRequestSet)).apply(this, arguments));
  }

  createClass(AdAsyncRequestSet, [{
    key: 'getRequests',
    value: function getRequests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAsyncRequest, fields, params, fetchFirstPage, '/requests');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdAsyncRequestSet.prototype.__proto__ || Object.getPrototypeOf(AdAsyncRequestSet.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdAsyncRequestSet.prototype.__proto__ || Object.getPrototypeOf(AdAsyncRequestSet.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        canceled_count: 'canceled_count',
        created_time: 'created_time',
        error_count: 'error_count',
        id: 'id',
        in_progress_count: 'in_progress_count',
        initial_count: 'initial_count',
        is_completed: 'is_completed',
        name: 'name',
        notification_mode: 'notification_mode',
        notification_result: 'notification_result',
        notification_status: 'notification_status',
        notification_uri: 'notification_uri',
        owner_id: 'owner_id',
        success_count: 'success_count',
        total_count: 'total_count',
        updated_time: 'updated_time'
      });
    }
  }, {
    key: 'NotificationMode',
    get: function get() {
      return Object.freeze({
        off: 'OFF',
        on_complete: 'ON_COMPLETE'
      });
    }
  }]);
  return AdAsyncRequestSet;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudienceFunnel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudienceFunnel = function (_AbstractCrudObject) {
  inherits(AudienceFunnel, _AbstractCrudObject);

  function AudienceFunnel() {
    classCallCheck(this, AudienceFunnel);
    return possibleConstructorReturn(this, (AudienceFunnel.__proto__ || Object.getPrototypeOf(AudienceFunnel)).apply(this, arguments));
  }

  createClass(AudienceFunnel, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience_type_param_name: 'audience_type_param_name',
        audience_type_param_tags: 'audience_type_param_tags',
        custom_audience_groups_info: 'custom_audience_groups_info'
      });
    }
  }]);
  return AudienceFunnel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BroadTargetingCategories
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BroadTargetingCategories = function (_AbstractCrudObject) {
  inherits(BroadTargetingCategories, _AbstractCrudObject);

  function BroadTargetingCategories() {
    classCallCheck(this, BroadTargetingCategories);
    return possibleConstructorReturn(this, (BroadTargetingCategories.__proto__ || Object.getPrototypeOf(BroadTargetingCategories)).apply(this, arguments));
  }

  createClass(BroadTargetingCategories, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        category_description: 'category_description',
        id: 'id',
        name: 'name',
        parent_category: 'parent_category',
        path: 'path',
        size_lower_bound: 'size_lower_bound',
        size_upper_bound: 'size_upper_bound',
        source: 'source',
        type: 'type',
        type_name: 'type_name',
        untranslated_name: 'untranslated_name',
        untranslated_parent_name: 'untranslated_parent_name'
      });
    }
  }]);
  return BroadTargetingCategories;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsConversionGoal
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsConversionGoal = function (_AbstractCrudObject) {
  inherits(AdsConversionGoal, _AbstractCrudObject);

  function AdsConversionGoal() {
    classCallCheck(this, AdsConversionGoal);
    return possibleConstructorReturn(this, (AdsConversionGoal.__proto__ || Object.getPrototypeOf(AdsConversionGoal)).apply(this, arguments));
  }

  createClass(AdsConversionGoal, [{
    key: 'getConversionEvents',
    value: function getConversionEvents(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/conversion_events');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_id: 'ad_account_id',
        conversion_event_value_source: 'conversion_event_value_source',
        description: 'description',
        goal_creation_method: 'goal_creation_method',
        id: 'id',
        name: 'name',
        performance_goal: 'performance_goal',
        update_status: 'update_status'
      });
    }
  }]);
  return AdsConversionGoal;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BespokePartnerGuidanceLaser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BespokePartnerGuidanceLaser = function (_AbstractCrudObject) {
  inherits(BespokePartnerGuidanceLaser, _AbstractCrudObject);

  function BespokePartnerGuidanceLaser() {
    classCallCheck(this, BespokePartnerGuidanceLaser);
    return possibleConstructorReturn(this, (BespokePartnerGuidanceLaser.__proto__ || Object.getPrototypeOf(BespokePartnerGuidanceLaser)).apply(this, arguments));
  }

  createClass(BespokePartnerGuidanceLaser, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        campaign_group: 'campaign_group',
        cpa_improvement: 'cpa_improvement',
        guidance_type: 'guidance_type',
        id: 'id'
      });
    }
  }]);
  return BespokePartnerGuidanceLaser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudiencesTOS
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudiencesTOS = function (_AbstractCrudObject) {
  inherits(CustomAudiencesTOS, _AbstractCrudObject);

  function CustomAudiencesTOS() {
    classCallCheck(this, CustomAudiencesTOS);
    return possibleConstructorReturn(this, (CustomAudiencesTOS.__proto__ || Object.getPrototypeOf(CustomAudiencesTOS)).apply(this, arguments));
  }

  createClass(CustomAudiencesTOS, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        content: 'content',
        id: 'id',
        type: 'type'
      });
    }
  }]);
  return CustomAudiencesTOS;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountDeliveryEstimate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountDeliveryEstimate = function (_AbstractCrudObject) {
  inherits(AdAccountDeliveryEstimate, _AbstractCrudObject);

  function AdAccountDeliveryEstimate() {
    classCallCheck(this, AdAccountDeliveryEstimate);
    return possibleConstructorReturn(this, (AdAccountDeliveryEstimate.__proto__ || Object.getPrototypeOf(AdAccountDeliveryEstimate)).apply(this, arguments));
  }

  createClass(AdAccountDeliveryEstimate, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        daily_outcomes_curve: 'daily_outcomes_curve',
        estimate_dau: 'estimate_dau',
        estimate_mau_lower_bound: 'estimate_mau_lower_bound',
        estimate_mau_upper_bound: 'estimate_mau_upper_bound',
        estimate_ready: 'estimate_ready',
        targeting_optimization_types: 'targeting_optimization_types'
      });
    }
  }, {
    key: 'OptimizationGoal',
    get: function get() {
      return Object.freeze({
        ad_recall_lift: 'AD_RECALL_LIFT',
        app_installs: 'APP_INSTALLS',
        app_installs_and_offsite_conversions: 'APP_INSTALLS_AND_OFFSITE_CONVERSIONS',
        conversations: 'CONVERSATIONS',
        derived_events: 'DERIVED_EVENTS',
        engaged_users: 'ENGAGED_USERS',
        event_responses: 'EVENT_RESPONSES',
        impressions: 'IMPRESSIONS',
        in_app_value: 'IN_APP_VALUE',
        landing_page_views: 'LANDING_PAGE_VIEWS',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        meaningful_call_attempt: 'MEANINGFUL_CALL_ATTEMPT',
        messaging_appointment_conversion: 'MESSAGING_APPOINTMENT_CONVERSION',
        messaging_purchase_conversion: 'MESSAGING_PURCHASE_CONVERSION',
        none: 'NONE',
        offsite_conversions: 'OFFSITE_CONVERSIONS',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        profile_visit: 'PROFILE_VISIT',
        quality_call: 'QUALITY_CALL',
        quality_lead: 'QUALITY_LEAD',
        reach: 'REACH',
        reminders_set: 'REMINDERS_SET',
        subscribers: 'SUBSCRIBERS',
        thruplay: 'THRUPLAY',
        value: 'VALUE',
        visit_instagram_profile: 'VISIT_INSTAGRAM_PROFILE'
      });
    }
  }]);
  return AdAccountDeliveryEstimate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountDsaRecommendations
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountDsaRecommendations = function (_AbstractCrudObject) {
  inherits(AdAccountDsaRecommendations, _AbstractCrudObject);

  function AdAccountDsaRecommendations() {
    classCallCheck(this, AdAccountDsaRecommendations);
    return possibleConstructorReturn(this, (AdAccountDsaRecommendations.__proto__ || Object.getPrototypeOf(AdAccountDsaRecommendations)).apply(this, arguments));
  }

  createClass(AdAccountDsaRecommendations, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        recommendations: 'recommendations'
      });
    }
  }]);
  return AdAccountDsaRecommendations;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountIosFourteenCampaignLimits
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountIosFourteenCampaignLimits = function (_AbstractCrudObject) {
  inherits(AdAccountIosFourteenCampaignLimits, _AbstractCrudObject);

  function AdAccountIosFourteenCampaignLimits() {
    classCallCheck(this, AdAccountIosFourteenCampaignLimits);
    return possibleConstructorReturn(this, (AdAccountIosFourteenCampaignLimits.__proto__ || Object.getPrototypeOf(AdAccountIosFourteenCampaignLimits)).apply(this, arguments));
  }

  createClass(AdAccountIosFourteenCampaignLimits, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        campaign_group_limit: 'campaign_group_limit',
        campaign_group_limits_details: 'campaign_group_limits_details',
        campaign_limit: 'campaign_limit'
      });
    }
  }]);
  return AdAccountIosFourteenCampaignLimits;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountMatchedSearchApplicationsEdgeData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountMatchedSearchApplicationsEdgeData = function (_AbstractCrudObject) {
  inherits(AdAccountMatchedSearchApplicationsEdgeData, _AbstractCrudObject);

  function AdAccountMatchedSearchApplicationsEdgeData() {
    classCallCheck(this, AdAccountMatchedSearchApplicationsEdgeData);
    return possibleConstructorReturn(this, (AdAccountMatchedSearchApplicationsEdgeData.__proto__ || Object.getPrototypeOf(AdAccountMatchedSearchApplicationsEdgeData)).apply(this, arguments));
  }

  createClass(AdAccountMatchedSearchApplicationsEdgeData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        are_app_events_unavailable: 'are_app_events_unavailable',
        icon_url: 'icon_url',
        name: 'name',
        search_source_store: 'search_source_store',
        store: 'store',
        unique_id: 'unique_id',
        url: 'url'
      });
    }
  }, {
    key: 'AppStore',
    get: function get() {
      return Object.freeze({
        amazon_app_store: 'AMAZON_APP_STORE',
        apk_mirror: 'APK_MIRROR',
        apk_monk: 'APK_MONK',
        apk_pure: 'APK_PURE',
        aptoide_a1_store: 'APTOIDE_A1_STORE',
        bemobi_mobile_store: 'BEMOBI_MOBILE_STORE',
        digital_turbine_store: 'DIGITAL_TURBINE_STORE',
        does_not_exist: 'DOES_NOT_EXIST',
        fb_android_store: 'FB_ANDROID_STORE',
        fb_canvas: 'FB_CANVAS',
        fb_gameroom: 'FB_GAMEROOM',
        galaxy_store: 'GALAXY_STORE',
        google_play: 'GOOGLE_PLAY',
        instant_game: 'INSTANT_GAME',
        itunes: 'ITUNES',
        itunes_ipad: 'ITUNES_IPAD',
        neon_android_store: 'NEON_ANDROID_STORE',
        none: 'NONE',
        oculus_app_store: 'OCULUS_APP_STORE',
        oppo: 'OPPO',
        roku_store: 'ROKU_STORE',
        uptodown: 'UPTODOWN',
        vivo: 'VIVO',
        windows_10_store: 'WINDOWS_10_STORE',
        windows_store: 'WINDOWS_STORE',
        xiaomi: 'XIAOMI'
      });
    }
  }]);
  return AdAccountMatchedSearchApplicationsEdgeData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountMaxBid
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountMaxBid = function (_AbstractCrudObject) {
  inherits(AdAccountMaxBid, _AbstractCrudObject);

  function AdAccountMaxBid() {
    classCallCheck(this, AdAccountMaxBid);
    return possibleConstructorReturn(this, (AdAccountMaxBid.__proto__ || Object.getPrototypeOf(AdAccountMaxBid)).apply(this, arguments));
  }

  createClass(AdAccountMaxBid, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        max_bid: 'max_bid'
      });
    }
  }]);
  return AdAccountMaxBid;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MinimumBudget
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MinimumBudget = function (_AbstractCrudObject) {
  inherits(MinimumBudget, _AbstractCrudObject);

  function MinimumBudget() {
    classCallCheck(this, MinimumBudget);
    return possibleConstructorReturn(this, (MinimumBudget.__proto__ || Object.getPrototypeOf(MinimumBudget)).apply(this, arguments));
  }

  createClass(MinimumBudget, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        currency: 'currency',
        min_daily_budget_high_freq: 'min_daily_budget_high_freq',
        min_daily_budget_imp: 'min_daily_budget_imp',
        min_daily_budget_low_freq: 'min_daily_budget_low_freq',
        min_daily_budget_video_views: 'min_daily_budget_video_views'
      });
    }
  }]);
  return MinimumBudget;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessOwnedObjectOnBehalfOfRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessOwnedObjectOnBehalfOfRequest = function (_AbstractCrudObject) {
  inherits(BusinessOwnedObjectOnBehalfOfRequest, _AbstractCrudObject);

  function BusinessOwnedObjectOnBehalfOfRequest() {
    classCallCheck(this, BusinessOwnedObjectOnBehalfOfRequest);
    return possibleConstructorReturn(this, (BusinessOwnedObjectOnBehalfOfRequest.__proto__ || Object.getPrototypeOf(BusinessOwnedObjectOnBehalfOfRequest)).apply(this, arguments));
  }

  createClass(BusinessOwnedObjectOnBehalfOfRequest, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business_owned_object: 'business_owned_object',
        id: 'id',
        receiving_business: 'receiving_business',
        requesting_business: 'requesting_business',
        status: 'status'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        approve: 'APPROVE',
        decline: 'DECLINE',
        expired: 'EXPIRED',
        in_progress: 'IN_PROGRESS',
        pending: 'PENDING',
        pending_email_verification: 'PENDING_EMAIL_VERIFICATION',
        pending_integrity_review: 'PENDING_INTEGRITY_REVIEW'
      });
    }
  }]);
  return BusinessOwnedObjectOnBehalfOfRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WebPublisher
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WebPublisher = function (_AbstractCrudObject) {
  inherits(WebPublisher, _AbstractCrudObject);

  function WebPublisher() {
    classCallCheck(this, WebPublisher);
    return possibleConstructorReturn(this, (WebPublisher.__proto__ || Object.getPrototypeOf(WebPublisher)).apply(this, arguments));
  }

  createClass(WebPublisher, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        domain_url: 'domain_url',
        id: 'id',
        publisher_name: 'publisher_name'
      });
    }
  }]);
  return WebPublisher;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PublisherBlockList
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PublisherBlockList = function (_AbstractCrudObject) {
  inherits(PublisherBlockList, _AbstractCrudObject);

  function PublisherBlockList() {
    classCallCheck(this, PublisherBlockList);
    return possibleConstructorReturn(this, (PublisherBlockList.__proto__ || Object.getPrototypeOf(PublisherBlockList)).apply(this, arguments));
  }

  createClass(PublisherBlockList, [{
    key: 'createAppendPublisherUrl',
    value: function createAppendPublisherUrl(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/append_publisher_urls', fields, params, null, pathOverride);
    }
  }, {
    key: 'getPagedWebPublishers',
    value: function getPagedWebPublishers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(WebPublisher, fields, params, fetchFirstPage, '/paged_web_publishers');
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(PublisherBlockList.prototype.__proto__ || Object.getPrototypeOf(PublisherBlockList.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(PublisherBlockList.prototype.__proto__ || Object.getPrototypeOf(PublisherBlockList.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_publishers: 'app_publishers',
        business_owner_id: 'business_owner_id',
        id: 'id',
        is_auto_blocking_on: 'is_auto_blocking_on',
        is_eligible_at_campaign_level: 'is_eligible_at_campaign_level',
        last_update_time: 'last_update_time',
        last_update_user: 'last_update_user',
        name: 'name',
        owner_ad_account_id: 'owner_ad_account_id',
        web_publishers: 'web_publishers'
      });
    }
  }]);
  return PublisherBlockList;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountReachEstimate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountReachEstimate = function (_AbstractCrudObject) {
  inherits(AdAccountReachEstimate, _AbstractCrudObject);

  function AdAccountReachEstimate() {
    classCallCheck(this, AdAccountReachEstimate);
    return possibleConstructorReturn(this, (AdAccountReachEstimate.__proto__ || Object.getPrototypeOf(AdAccountReachEstimate)).apply(this, arguments));
  }

  createClass(AdAccountReachEstimate, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        estimate_ready: 'estimate_ready',
        users_lower_bound: 'users_lower_bound',
        users_upper_bound: 'users_upper_bound'
      });
    }
  }]);
  return AdAccountReachEstimate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReachFrequencyPrediction
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReachFrequencyPrediction = function (_AbstractCrudObject) {
  inherits(ReachFrequencyPrediction, _AbstractCrudObject);

  function ReachFrequencyPrediction() {
    classCallCheck(this, ReachFrequencyPrediction);
    return possibleConstructorReturn(this, (ReachFrequencyPrediction.__proto__ || Object.getPrototypeOf(ReachFrequencyPrediction)).apply(this, arguments));
  }

  createClass(ReachFrequencyPrediction, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        activity_status: 'activity_status',
        ad_formats: 'ad_formats',
        auction_entry_option_index: 'auction_entry_option_index',
        audience_size_lower_bound: 'audience_size_lower_bound',
        audience_size_upper_bound: 'audience_size_upper_bound',
        business_id: 'business_id',
        buying_type: 'buying_type',
        campaign_group_id: 'campaign_group_id',
        campaign_id: 'campaign_id',
        campaign_time_start: 'campaign_time_start',
        campaign_time_stop: 'campaign_time_stop',
        currency: 'currency',
        curve_budget_reach: 'curve_budget_reach',
        curve_reach: 'curve_reach',
        daily_grp_curve: 'daily_grp_curve',
        daily_impression_curve: 'daily_impression_curve',
        daily_impression_curve_map: 'daily_impression_curve_map',
        day_parting_schedule: 'day_parting_schedule',
        destination_id: 'destination_id',
        end_time: 'end_time',
        expiration_time: 'expiration_time',
        external_budget: 'external_budget',
        external_impression: 'external_impression',
        external_maximum_budget: 'external_maximum_budget',
        external_maximum_impression: 'external_maximum_impression',
        external_maximum_reach: 'external_maximum_reach',
        external_minimum_budget: 'external_minimum_budget',
        external_minimum_impression: 'external_minimum_impression',
        external_minimum_reach: 'external_minimum_reach',
        external_reach: 'external_reach',
        feed_ratio_0000: 'feed_ratio_0000',
        frequency_cap: 'frequency_cap',
        frequency_distribution_map: 'frequency_distribution_map',
        frequency_distribution_map_agg: 'frequency_distribution_map_agg',
        grp_audience_size: 'grp_audience_size',
        grp_avg_probability_map: 'grp_avg_probability_map',
        grp_country_audience_size: 'grp_country_audience_size',
        grp_curve: 'grp_curve',
        grp_dmas_audience_size: 'grp_dmas_audience_size',
        grp_filtering_threshold_00: 'grp_filtering_threshold_00',
        grp_points: 'grp_points',
        grp_ratio: 'grp_ratio',
        grp_reach_ratio: 'grp_reach_ratio',
        grp_status: 'grp_status',
        holdout_percentage: 'holdout_percentage',
        id: 'id',
        impression_curve: 'impression_curve',
        instagram_destination_id: 'instagram_destination_id',
        instream_packages: 'instream_packages',
        interval_frequency_cap: 'interval_frequency_cap',
        interval_frequency_cap_reset_period: 'interval_frequency_cap_reset_period',
        is_bonus_media: 'is_bonus_media',
        is_conversion_goal: 'is_conversion_goal',
        is_higher_average_frequency: 'is_higher_average_frequency',
        is_io: 'is_io',
        is_reserved_buying: 'is_reserved_buying',
        is_trp: 'is_trp',
        name: 'name',
        objective: 'objective',
        objective_name: 'objective_name',
        odax_objective: 'odax_objective',
        odax_objective_name: 'odax_objective_name',
        optimization_goal: 'optimization_goal',
        optimization_goal_name: 'optimization_goal_name',
        pause_periods: 'pause_periods',
        placement_breakdown: 'placement_breakdown',
        placement_breakdown_map: 'placement_breakdown_map',
        plan_name: 'plan_name',
        plan_type: 'plan_type',
        prediction_mode: 'prediction_mode',
        prediction_progress: 'prediction_progress',
        reference_id: 'reference_id',
        reservation_status: 'reservation_status',
        start_time: 'start_time',
        status: 'status',
        story_event_type: 'story_event_type',
        target_cpm: 'target_cpm',
        target_spec: 'target_spec',
        time_created: 'time_created',
        time_updated: 'time_updated',
        timezone_id: 'timezone_id',
        timezone_name: 'timezone_name',
        topline_id: 'topline_id',
        video_view_length_constraint: 'video_view_length_constraint',
        viewtag: 'viewtag'
      });
    }
  }, {
    key: 'Action',
    get: function get() {
      return Object.freeze({
        cancel: 'cancel',
        quote: 'quote',
        reserve: 'reserve'
      });
    }
  }, {
    key: 'BuyingType',
    get: function get() {
      return Object.freeze({
        auction: 'AUCTION',
        deprecated_reach_block: 'DEPRECATED_REACH_BLOCK',
        fixed_cpm: 'FIXED_CPM',
        mixed: 'MIXED',
        reachblock: 'REACHBLOCK',
        research_poll: 'RESEARCH_POLL',
        reserved: 'RESERVED'
      });
    }
  }, {
    key: 'InstreamPackages',
    get: function get() {
      return Object.freeze({
        beauty: 'BEAUTY',
        entertainment: 'ENTERTAINMENT',
        food: 'FOOD',
        normal: 'NORMAL',
        premium: 'PREMIUM',
        regular_animals_pets: 'REGULAR_ANIMALS_PETS',
        regular_food: 'REGULAR_FOOD',
        regular_games: 'REGULAR_GAMES',
        regular_politics: 'REGULAR_POLITICS',
        regular_sports: 'REGULAR_SPORTS',
        regular_style: 'REGULAR_STYLE',
        regular_tv_movies: 'REGULAR_TV_MOVIES',
        spanish: 'SPANISH',
        sports: 'SPORTS'
      });
    }
  }]);
  return ReachFrequencyPrediction;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountRecommendations
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountRecommendations = function (_AbstractCrudObject) {
  inherits(AdAccountRecommendations, _AbstractCrudObject);

  function AdAccountRecommendations() {
    classCallCheck(this, AdAccountRecommendations);
    return possibleConstructorReturn(this, (AdAccountRecommendations.__proto__ || Object.getPrototypeOf(AdAccountRecommendations)).apply(this, arguments));
  }

  createClass(AdAccountRecommendations, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        recommendations: 'recommendations'
      });
    }
  }]);
  return AdAccountRecommendations;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SavedAudience
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SavedAudience = function (_AbstractCrudObject) {
  inherits(SavedAudience, _AbstractCrudObject);

  function SavedAudience() {
    classCallCheck(this, SavedAudience);
    return possibleConstructorReturn(this, (SavedAudience.__proto__ || Object.getPrototypeOf(SavedAudience)).apply(this, arguments));
  }

  createClass(SavedAudience, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account: 'account',
        approximate_count_lower_bound: 'approximate_count_lower_bound',
        approximate_count_upper_bound: 'approximate_count_upper_bound',
        delete_time: 'delete_time',
        description: 'description',
        id: 'id',
        name: 'name',
        operation_status: 'operation_status',
        owner_business: 'owner_business',
        page_deletion_marked_delete_time: 'page_deletion_marked_delete_time',
        permission_for_actions: 'permission_for_actions',
        run_status: 'run_status',
        sentence_lines: 'sentence_lines',
        targeting: 'targeting',
        time_created: 'time_created',
        time_updated: 'time_updated'
      });
    }
  }]);
  return SavedAudience;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountSubscribedApps
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountSubscribedApps = function (_AbstractCrudObject) {
  inherits(AdAccountSubscribedApps, _AbstractCrudObject);

  function AdAccountSubscribedApps() {
    classCallCheck(this, AdAccountSubscribedApps);
    return possibleConstructorReturn(this, (AdAccountSubscribedApps.__proto__ || Object.getPrototypeOf(AdAccountSubscribedApps)).apply(this, arguments));
  }

  createClass(AdAccountSubscribedApps, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        app_name: 'app_name'
      });
    }
  }]);
  return AdAccountSubscribedApps;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountTargetingUnified
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountTargetingUnified = function (_AbstractCrudObject) {
  inherits(AdAccountTargetingUnified, _AbstractCrudObject);

  function AdAccountTargetingUnified() {
    classCallCheck(this, AdAccountTargetingUnified);
    return possibleConstructorReturn(this, (AdAccountTargetingUnified.__proto__ || Object.getPrototypeOf(AdAccountTargetingUnified)).apply(this, arguments));
  }

  createClass(AdAccountTargetingUnified, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience_size_lower_bound: 'audience_size_lower_bound',
        audience_size_upper_bound: 'audience_size_upper_bound',
        conversion_lift: 'conversion_lift',
        description: 'description',
        id: 'id',
        img: 'img',
        info: 'info',
        info_title: 'info_title',
        is_recommendation: 'is_recommendation',
        key: 'key',
        link: 'link',
        name: 'name',
        parent: 'parent',
        partner: 'partner',
        path: 'path',
        performance_rating: 'performance_rating',
        raw_name: 'raw_name',
        recommendation_model: 'recommendation_model',
        search_interest_id: 'search_interest_id',
        source: 'source',
        spend: 'spend',
        type: 'type',
        valid: 'valid'
      });
    }
  }, {
    key: 'LimitType',
    get: function get() {
      return Object.freeze({
        behaviors: 'behaviors',
        college_years: 'college_years',
        education_majors: 'education_majors',
        education_schools: 'education_schools',
        education_statuses: 'education_statuses',
        ethnic_affinity: 'ethnic_affinity',
        family_statuses: 'family_statuses',
        generation: 'generation',
        home_ownership: 'home_ownership',
        home_type: 'home_type',
        home_value: 'home_value',
        household_composition: 'household_composition',
        income: 'income',
        industries: 'industries',
        interested_in: 'interested_in',
        interests: 'interests',
        life_events: 'life_events',
        location_categories: 'location_categories',
        moms: 'moms',
        net_worth: 'net_worth',
        office_type: 'office_type',
        politics: 'politics',
        relationship_statuses: 'relationship_statuses',
        user_adclusters: 'user_adclusters',
        work_employers: 'work_employers',
        work_positions: 'work_positions'
      });
    }
  }, {
    key: 'RegulatedCategories',
    get: function get() {
      return Object.freeze({
        credit: 'CREDIT',
        employment: 'EMPLOYMENT',
        financial_products_services: 'FINANCIAL_PRODUCTS_SERVICES',
        housing: 'HOUSING',
        issues_elections_politics: 'ISSUES_ELECTIONS_POLITICS',
        none: 'NONE',
        online_gambling_and_gaming: 'ONLINE_GAMBLING_AND_GAMING'
      });
    }
  }, {
    key: 'RegulatedCountries',
    get: function get() {
      return Object.freeze({
        ad: 'AD',
        ae: 'AE',
        af: 'AF',
        ag: 'AG',
        ai: 'AI',
        al: 'AL',
        am: 'AM',
        an: 'AN',
        ao: 'AO',
        aq: 'AQ',
        ar: 'AR',
        as: 'AS',
        at: 'AT',
        au: 'AU',
        aw: 'AW',
        ax: 'AX',
        az: 'AZ',
        ba: 'BA',
        bb: 'BB',
        bd: 'BD',
        be: 'BE',
        bf: 'BF',
        bg: 'BG',
        bh: 'BH',
        bi: 'BI',
        bj: 'BJ',
        bl: 'BL',
        bm: 'BM',
        bn: 'BN',
        bo: 'BO',
        bq: 'BQ',
        br: 'BR',
        bs: 'BS',
        bt: 'BT',
        bv: 'BV',
        bw: 'BW',
        by: 'BY',
        bz: 'BZ',
        ca: 'CA',
        cc: 'CC',
        cd: 'CD',
        cf: 'CF',
        cg: 'CG',
        ch: 'CH',
        ci: 'CI',
        ck: 'CK',
        cl: 'CL',
        cm: 'CM',
        cn: 'CN',
        co: 'CO',
        cr: 'CR',
        cu: 'CU',
        cv: 'CV',
        cw: 'CW',
        cx: 'CX',
        cy: 'CY',
        cz: 'CZ',
        de: 'DE',
        dj: 'DJ',
        dk: 'DK',
        dm: 'DM',
        do: 'DO',
        dz: 'DZ',
        ec: 'EC',
        ee: 'EE',
        eg: 'EG',
        eh: 'EH',
        er: 'ER',
        es: 'ES',
        et: 'ET',
        fi: 'FI',
        fj: 'FJ',
        fk: 'FK',
        fm: 'FM',
        fo: 'FO',
        fr: 'FR',
        ga: 'GA',
        gb: 'GB',
        gd: 'GD',
        ge: 'GE',
        gf: 'GF',
        gg: 'GG',
        gh: 'GH',
        gi: 'GI',
        gl: 'GL',
        gm: 'GM',
        gn: 'GN',
        gp: 'GP',
        gq: 'GQ',
        gr: 'GR',
        gs: 'GS',
        gt: 'GT',
        gu: 'GU',
        gw: 'GW',
        gy: 'GY',
        hk: 'HK',
        hm: 'HM',
        hn: 'HN',
        hr: 'HR',
        ht: 'HT',
        hu: 'HU',
        id: 'ID',
        ie: 'IE',
        il: 'IL',
        im: 'IM',
        in: 'IN',
        io: 'IO',
        iq: 'IQ',
        ir: 'IR',
        is: 'IS',
        it: 'IT',
        je: 'JE',
        jm: 'JM',
        jo: 'JO',
        jp: 'JP',
        ke: 'KE',
        kg: 'KG',
        kh: 'KH',
        ki: 'KI',
        km: 'KM',
        kn: 'KN',
        kp: 'KP',
        kr: 'KR',
        kw: 'KW',
        ky: 'KY',
        kz: 'KZ',
        la: 'LA',
        lb: 'LB',
        lc: 'LC',
        li: 'LI',
        lk: 'LK',
        lr: 'LR',
        ls: 'LS',
        lt: 'LT',
        lu: 'LU',
        lv: 'LV',
        ly: 'LY',
        ma: 'MA',
        mc: 'MC',
        md: 'MD',
        me: 'ME',
        mf: 'MF',
        mg: 'MG',
        mh: 'MH',
        mk: 'MK',
        ml: 'ML',
        mm: 'MM',
        mn: 'MN',
        mo: 'MO',
        mp: 'MP',
        mq: 'MQ',
        mr: 'MR',
        ms: 'MS',
        mt: 'MT',
        mu: 'MU',
        mv: 'MV',
        mw: 'MW',
        mx: 'MX',
        my: 'MY',
        mz: 'MZ',
        na: 'NA',
        nc: 'NC',
        ne: 'NE',
        nf: 'NF',
        ng: 'NG',
        ni: 'NI',
        nl: 'NL',
        no: 'NO',
        np: 'NP',
        nr: 'NR',
        nu: 'NU',
        nz: 'NZ',
        om: 'OM',
        pa: 'PA',
        pe: 'PE',
        pf: 'PF',
        pg: 'PG',
        ph: 'PH',
        pk: 'PK',
        pl: 'PL',
        pm: 'PM',
        pn: 'PN',
        pr: 'PR',
        ps: 'PS',
        pt: 'PT',
        pw: 'PW',
        py: 'PY',
        qa: 'QA',
        re: 'RE',
        ro: 'RO',
        rs: 'RS',
        ru: 'RU',
        rw: 'RW',
        sa: 'SA',
        sb: 'SB',
        sc: 'SC',
        sd: 'SD',
        se: 'SE',
        sg: 'SG',
        sh: 'SH',
        si: 'SI',
        sj: 'SJ',
        sk: 'SK',
        sl: 'SL',
        sm: 'SM',
        sn: 'SN',
        so: 'SO',
        sr: 'SR',
        ss: 'SS',
        st: 'ST',
        sv: 'SV',
        sx: 'SX',
        sy: 'SY',
        sz: 'SZ',
        tc: 'TC',
        td: 'TD',
        tf: 'TF',
        tg: 'TG',
        th: 'TH',
        tj: 'TJ',
        tk: 'TK',
        tl: 'TL',
        tm: 'TM',
        tn: 'TN',
        to: 'TO',
        tr: 'TR',
        tt: 'TT',
        tv: 'TV',
        tw: 'TW',
        tz: 'TZ',
        ua: 'UA',
        ug: 'UG',
        um: 'UM',
        us: 'US',
        uy: 'UY',
        uz: 'UZ',
        va: 'VA',
        vc: 'VC',
        ve: 'VE',
        vg: 'VG',
        vi: 'VI',
        vn: 'VN',
        vu: 'VU',
        wf: 'WF',
        ws: 'WS',
        xk: 'XK',
        ye: 'YE',
        yt: 'YT',
        za: 'ZA',
        zm: 'ZM',
        zw: 'ZW'
      });
    }
  }, {
    key: 'WhitelistedTypes',
    get: function get() {
      return Object.freeze({
        adgroup_id: 'adgroup_id',
        age_max: 'age_max',
        age_min: 'age_min',
        age_range: 'age_range',
        alternate_auto_targeting_option: 'alternate_auto_targeting_option',
        app_install_state: 'app_install_state',
        audience_network_positions: 'audience_network_positions',
        behaviors: 'behaviors',
        brand_safety_content_filter_levels: 'brand_safety_content_filter_levels',
        brand_safety_content_severity_levels: 'brand_safety_content_severity_levels',
        cafe_ca_contraction_targeting_signal: 'cafe_ca_contraction_targeting_signal',
        cafe_ca_expansion_targeting_signal: 'cafe_ca_expansion_targeting_signal',
        catalog_based_targeting: 'catalog_based_targeting',
        cities: 'cities',
        city_keys: 'city_keys',
        college_years: 'college_years',
        conjunctive_user_adclusters: 'conjunctive_user_adclusters',
        connections: 'connections',
        contextual_targeting_categories: 'contextual_targeting_categories',
        countries: 'countries',
        country: 'country',
        country_groups: 'country_groups',
        custom_audiences: 'custom_audiences',
        device_platforms: 'device_platforms',
        direct_install_devices: 'direct_install_devices',
        dynamic_audience_ids: 'dynamic_audience_ids',
        education_majors: 'education_majors',
        education_schools: 'education_schools',
        education_statuses: 'education_statuses',
        effective_audience_network_positions: 'effective_audience_network_positions',
        effective_device_platforms: 'effective_device_platforms',
        effective_facebook_positions: 'effective_facebook_positions',
        effective_instagram_positions: 'effective_instagram_positions',
        effective_messenger_positions: 'effective_messenger_positions',
        effective_oculus_positions: 'effective_oculus_positions',
        effective_publisher_platforms: 'effective_publisher_platforms',
        effective_threads_positions: 'effective_threads_positions',
        effective_whatsapp_positions: 'effective_whatsapp_positions',
        engagement_specs: 'engagement_specs',
        ethnic_affinity: 'ethnic_affinity',
        exclude_previous_days: 'exclude_previous_days',
        exclude_reached_since: 'exclude_reached_since',
        excluded_brand_safety_content_types: 'excluded_brand_safety_content_types',
        excluded_connections: 'excluded_connections',
        excluded_custom_audiences: 'excluded_custom_audiences',
        excluded_dynamic_audience_ids: 'excluded_dynamic_audience_ids',
        excluded_engagement_specs: 'excluded_engagement_specs',
        excluded_geo_locations: 'excluded_geo_locations',
        excluded_mobile_device_model: 'excluded_mobile_device_model',
        excluded_product_audience_specs: 'excluded_product_audience_specs',
        excluded_publisher_categories: 'excluded_publisher_categories',
        excluded_publisher_list_ids: 'excluded_publisher_list_ids',
        excluded_user_adclusters: 'excluded_user_adclusters',
        excluded_user_device: 'excluded_user_device',
        exclusions: 'exclusions',
        expanded_implicit_custom_audiences: 'expanded_implicit_custom_audiences',
        facebook_positions: 'facebook_positions',
        family_statuses: 'family_statuses',
        fb_deal_id: 'fb_deal_id',
        flexible_spec: 'flexible_spec',
        follow_profiles: 'follow_profiles',
        follow_profiles_negative: 'follow_profiles_negative',
        format: 'format',
        friends_of_connections: 'friends_of_connections',
        gatekeepers: 'gatekeepers',
        genders: 'genders',
        generation: 'generation',
        geo_locations: 'geo_locations',
        home_ownership: 'home_ownership',
        home_type: 'home_type',
        home_value: 'home_value',
        household_composition: 'household_composition',
        id: 'id',
        income: 'income',
        industries: 'industries',
        instagram_hashtags: 'instagram_hashtags',
        instagram_positions: 'instagram_positions',
        instream_video_skippable_excluded: 'instream_video_skippable_excluded',
        instream_video_sponsorship_placements: 'instream_video_sponsorship_placements',
        interest_defaults_source: 'interest_defaults_source',
        interested_in: 'interested_in',
        interests: 'interests',
        is_instagram_destination_ad: 'is_instagram_destination_ad',
        is_whatsapp_destination_ad: 'is_whatsapp_destination_ad',
        keywords: 'keywords',
        life_events: 'life_events',
        locales: 'locales',
        location_categories: 'location_categories',
        location_cluster_ids: 'location_cluster_ids',
        location_expansion: 'location_expansion',
        marketing_message_channels: 'marketing_message_channels',
        marketing_message_targeting: 'marketing_message_targeting',
        marketplace_product_categories: 'marketplace_product_categories',
        messenger_positions: 'messenger_positions',
        mobile_device_model: 'mobile_device_model',
        moms: 'moms',
        net_worth: 'net_worth',
        oculus_positions: 'oculus_positions',
        office_type: 'office_type',
        page_types: 'page_types',
        place_page_set_ids: 'place_page_set_ids',
        political_views: 'political_views',
        politics: 'politics',
        product_audience_specs: 'product_audience_specs',
        prospecting_audience: 'prospecting_audience',
        publisher_platforms: 'publisher_platforms',
        radius: 'radius',
        region_keys: 'region_keys',
        regions: 'regions',
        relationship_statuses: 'relationship_statuses',
        rtb_flag: 'rtb_flag',
        site_category: 'site_category',
        tafe_ca_mitigation_strategy: 'tafe_ca_mitigation_strategy',
        targeting_automation: 'targeting_automation',
        targeting_optimization: 'targeting_optimization',
        targeting_relaxation_types: 'targeting_relaxation_types',
        threads_positions: 'threads_positions',
        timezones: 'timezones',
        topic: 'topic',
        trending: 'trending',
        user_adclusters: 'user_adclusters',
        user_device: 'user_device',
        user_event: 'user_event',
        user_os: 'user_os',
        user_page_threads: 'user_page_threads',
        user_page_threads_excluded: 'user_page_threads_excluded',
        whatsapp_positions: 'whatsapp_positions',
        wireless_carrier: 'wireless_carrier',
        work_employers: 'work_employers',
        work_positions: 'work_positions',
        zips: 'zips'
      });
    }
  }, {
    key: 'AppStore',
    get: function get() {
      return Object.freeze({
        amazon_app_store: 'amazon_app_store',
        apk_mirror: 'apk_mirror',
        apk_monk: 'apk_monk',
        apk_pure: 'apk_pure',
        aptoide_a1_store: 'aptoide_a1_store',
        bemobi_mobile_store: 'bemobi_mobile_store',
        digital_turbine_store: 'digital_turbine_store',
        does_not_exist: 'does_not_exist',
        fb_android_store: 'fb_android_store',
        fb_canvas: 'fb_canvas',
        fb_gameroom: 'fb_gameroom',
        galaxy_store: 'galaxy_store',
        google_play: 'google_play',
        instant_game: 'instant_game',
        itunes: 'itunes',
        itunes_ipad: 'itunes_ipad',
        neon_android_store: 'neon_android_store',
        none: 'none',
        oculus_app_store: 'oculus_app_store',
        oppo: 'oppo',
        roku_channel_store: 'roku_channel_store',
        uptodown: 'uptodown',
        vivo: 'vivo',
        windows_10_store: 'windows_10_store',
        windows_store: 'windows_store',
        xiaomi: 'xiaomi'
      });
    }
  }, {
    key: 'Objective',
    get: function get() {
      return Object.freeze({
        app_installs: 'APP_INSTALLS',
        brand_awareness: 'BRAND_AWARENESS',
        conversions: 'CONVERSIONS',
        event_responses: 'EVENT_RESPONSES',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        local_awareness: 'LOCAL_AWARENESS',
        messages: 'MESSAGES',
        offer_claims: 'OFFER_CLAIMS',
        outcome_app_promotion: 'OUTCOME_APP_PROMOTION',
        outcome_awareness: 'OUTCOME_AWARENESS',
        outcome_engagement: 'OUTCOME_ENGAGEMENT',
        outcome_leads: 'OUTCOME_LEADS',
        outcome_sales: 'OUTCOME_SALES',
        outcome_traffic: 'OUTCOME_TRAFFIC',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        product_catalog_sales: 'PRODUCT_CATALOG_SALES',
        reach: 'REACH',
        store_visits: 'STORE_VISITS',
        video_views: 'VIDEO_VIEWS'
      });
    }
  }, {
    key: 'Mode',
    get: function get() {
      return Object.freeze({
        best_performing: 'best_performing',
        recently_used: 'recently_used',
        related: 'related',
        suggestions: 'suggestions'
      });
    }
  }]);
  return AdAccountTargetingUnified;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountTrackingData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountTrackingData = function (_AbstractCrudObject) {
  inherits(AdAccountTrackingData, _AbstractCrudObject);

  function AdAccountTrackingData() {
    classCallCheck(this, AdAccountTrackingData);
    return possibleConstructorReturn(this, (AdAccountTrackingData.__proto__ || Object.getPrototypeOf(AdAccountTrackingData)).apply(this, arguments));
  }

  createClass(AdAccountTrackingData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        tracking_specs: 'tracking_specs'
      });
    }
  }]);
  return AdAccountTrackingData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountUser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountUser = function (_AbstractCrudObject) {
  inherits(AdAccountUser, _AbstractCrudObject);

  function AdAccountUser() {
    classCallCheck(this, AdAccountUser);
    return possibleConstructorReturn(this, (AdAccountUser.__proto__ || Object.getPrototypeOf(AdAccountUser)).apply(this, arguments));
  }

  createClass(AdAccountUser, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        tasks: 'tasks'
      });
    }
  }]);
  return AdAccountUser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsValueAdjustmentRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsValueAdjustmentRule = function (_AbstractCrudObject) {
  inherits(AdsValueAdjustmentRule, _AbstractCrudObject);

  function AdsValueAdjustmentRule() {
    classCallCheck(this, AdsValueAdjustmentRule);
    return possibleConstructorReturn(this, (AdsValueAdjustmentRule.__proto__ || Object.getPrototypeOf(AdsValueAdjustmentRule)).apply(this, arguments));
  }

  createClass(AdsValueAdjustmentRule, [{
    key: 'getCriterias',
    value: function getCriterias(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/criterias');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        base_value: 'base_value',
        id: 'id'
      });
    }
  }]);
  return AdsValueAdjustmentRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsValueAdjustmentRuleCollection
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsValueAdjustmentRuleCollection = function (_AbstractCrudObject) {
  inherits(AdsValueAdjustmentRuleCollection, _AbstractCrudObject);

  function AdsValueAdjustmentRuleCollection() {
    classCallCheck(this, AdsValueAdjustmentRuleCollection);
    return possibleConstructorReturn(this, (AdsValueAdjustmentRuleCollection.__proto__ || Object.getPrototypeOf(AdsValueAdjustmentRuleCollection)).apply(this, arguments));
  }

  createClass(AdsValueAdjustmentRuleCollection, [{
    key: 'getRules',
    value: function getRules(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/rules');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return AdsValueAdjustmentRuleCollection;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccount
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccount = function (_AbstractCrudObject) {
  inherits(AdAccount, _AbstractCrudObject);

  function AdAccount() {
    classCallCheck(this, AdAccount);
    return possibleConstructorReturn(this, (AdAccount.__proto__ || Object.getPrototypeOf(AdAccount)).apply(this, arguments));
  }

  createClass(AdAccount, [{
    key: 'getAccountControls',
    value: function getAccountControls(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountBusinessConstraints, fields, params, fetchFirstPage, '/account_controls');
    }
  }, {
    key: 'createAccountControl',
    value: function createAccountControl(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/account_controls', fields, params, AdAccountBusinessConstraints, pathOverride);
    }
  }, {
    key: 'getActivities',
    value: function getActivities(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdActivity, fields, params, fetchFirstPage, '/activities');
    }
  }, {
    key: 'getAdPlacePageSets',
    value: function getAdPlacePageSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdPlacePageSet, fields, params, fetchFirstPage, '/ad_place_page_sets');
    }
  }, {
    key: 'createAdPlacePageSet',
    value: function createAdPlacePageSet(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/ad_place_page_sets', fields, params, AdPlacePageSet, pathOverride);
    }
  }, {
    key: 'createAdPlacePageSetsAsync',
    value: function createAdPlacePageSetsAsync(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/ad_place_page_sets_async', fields, params, AdPlacePageSet, pathOverride);
    }
  }, {
    key: 'getAdSavedKeywords',
    value: function getAdSavedKeywords(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdSavedKeywords, fields, params, fetchFirstPage, '/ad_saved_keywords');
    }
  }, {
    key: 'getAdStudies',
    value: function getAdStudies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdStudy, fields, params, fetchFirstPage, '/ad_studies');
    }
  }, {
    key: 'getAdCloudPlayables',
    value: function getAdCloudPlayables(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CloudGame, fields, params, fetchFirstPage, '/adcloudplayables');
    }
  }, {
    key: 'getAdCreatives',
    value: function getAdCreatives(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdCreative, fields, params, fetchFirstPage, '/adcreatives');
    }
  }, {
    key: 'createAdCreative',
    value: function createAdCreative(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adcreatives', fields, params, AdCreative, pathOverride);
    }
  }, {
    key: 'getAdCreativesByLabels',
    value: function getAdCreativesByLabels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdCreative, fields, params, fetchFirstPage, '/adcreativesbylabels');
    }
  }, {
    key: 'deleteAdImages',
    value: function deleteAdImages() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdAccount.prototype.__proto__ || Object.getPrototypeOf(AdAccount.prototype), 'deleteEdge', this).call(this, '/adimages', params);
    }
  }, {
    key: 'getAdImages',
    value: function getAdImages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdImage, fields, params, fetchFirstPage, '/adimages');
    }
  }, {
    key: 'createAdImage',
    value: function createAdImage(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adimages', fields, params, AdImage, pathOverride);
    }
  }, {
    key: 'getAdLabels',
    value: function getAdLabels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdLabel, fields, params, fetchFirstPage, '/adlabels');
    }
  }, {
    key: 'createAdLabel',
    value: function createAdLabel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adlabels', fields, params, AdLabel, pathOverride);
    }
  }, {
    key: 'getAdPlayables',
    value: function getAdPlayables(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PlayableContent, fields, params, fetchFirstPage, '/adplayables');
    }
  }, {
    key: 'createAdPlayable',
    value: function createAdPlayable(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adplayables', fields, params, PlayableContent, pathOverride);
    }
  }, {
    key: 'getAdRulesHistory',
    value: function getAdRulesHistory(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountAdRulesHistory, fields, params, fetchFirstPage, '/adrules_history');
    }
  }, {
    key: 'getAdRulesLibrary',
    value: function getAdRulesLibrary(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdRule, fields, params, fetchFirstPage, '/adrules_library');
    }
  }, {
    key: 'createAdRulesLibrary',
    value: function createAdRulesLibrary(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adrules_library', fields, params, AdRule, pathOverride);
    }
  }, {
    key: 'getAds',
    value: function getAds(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Ad, fields, params, fetchFirstPage, '/ads');
    }
  }, {
    key: 'createAd',
    value: function createAd(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/ads', fields, params, Ad, pathOverride);
    }
  }, {
    key: 'getAdsReportingMmmReports',
    value: function getAdsReportingMmmReports(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsReportBuilderMMMReport, fields, params, fetchFirstPage, '/ads_reporting_mmm_reports');
    }
  }, {
    key: 'getAdsReportingMmmSchedulers',
    value: function getAdsReportingMmmSchedulers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsReportBuilderMMMReportScheduler, fields, params, fetchFirstPage, '/ads_reporting_mmm_schedulers');
    }
  }, {
    key: 'getAdsVolume',
    value: function getAdsVolume(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountAdVolume, fields, params, fetchFirstPage, '/ads_volume');
    }
  }, {
    key: 'getAdsByLabels',
    value: function getAdsByLabels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Ad, fields, params, fetchFirstPage, '/adsbylabels');
    }
  }, {
    key: 'getAdSets',
    value: function getAdSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdSet, fields, params, fetchFirstPage, '/adsets');
    }
  }, {
    key: 'createAdSet',
    value: function createAdSet(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adsets', fields, params, AdSet, pathOverride);
    }
  }, {
    key: 'getAdSetsByLabels',
    value: function getAdSetsByLabels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdSet, fields, params, fetchFirstPage, '/adsetsbylabels');
    }
  }, {
    key: 'getAdsPixels',
    value: function getAdsPixels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsPixel, fields, params, fetchFirstPage, '/adspixels');
    }
  }, {
    key: 'createAdsPixel',
    value: function createAdsPixel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adspixels', fields, params, AdsPixel, pathOverride);
    }
  }, {
    key: 'getAdvertisableApplications',
    value: function getAdvertisableApplications(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/advertisable_applications');
    }
  }, {
    key: 'deleteAdVideos',
    value: function deleteAdVideos() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdAccount.prototype.__proto__ || Object.getPrototypeOf(AdAccount.prototype), 'deleteEdge', this).call(this, '/advideos', params);
    }
  }, {
    key: 'getAdVideos',
    value: function getAdVideos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdVideo, fields, params, fetchFirstPage, '/advideos');
    }
  }, {
    key: 'createAdVideo',
    value: function createAdVideo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/advideos', fields, params, AdVideo, pathOverride);
    }
  }, {
    key: 'getAffectedAdSets',
    value: function getAffectedAdSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdSet, fields, params, fetchFirstPage, '/affectedadsets');
    }
  }, {
    key: 'deleteAgencies',
    value: function deleteAgencies() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdAccount.prototype.__proto__ || Object.getPrototypeOf(AdAccount.prototype), 'deleteEdge', this).call(this, '/agencies', params);
    }
  }, {
    key: 'getAgencies',
    value: function getAgencies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Business, fields, params, fetchFirstPage, '/agencies');
    }
  }, {
    key: 'createAgency',
    value: function createAgency(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/agencies', fields, params, AdAccount, pathOverride);
    }
  }, {
    key: 'getApplications',
    value: function getApplications(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Application, fields, params, fetchFirstPage, '/applications');
    }
  }, {
    key: 'deleteAssignedUsers',
    value: function deleteAssignedUsers() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdAccount.prototype.__proto__ || Object.getPrototypeOf(AdAccount.prototype), 'deleteEdge', this).call(this, '/assigned_users', params);
    }
  }, {
    key: 'getAssignedUsers',
    value: function getAssignedUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AssignedUser, fields, params, fetchFirstPage, '/assigned_users');
    }
  }, {
    key: 'createAssignedUser',
    value: function createAssignedUser(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/assigned_users', fields, params, AdAccount, pathOverride);
    }
  }, {
    key: 'createAsyncBatchRequest',
    value: function createAsyncBatchRequest(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/async_batch_requests', fields, params, Campaign, pathOverride);
    }
  }, {
    key: 'getAsyncRequests',
    value: function getAsyncRequests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AsyncRequest, fields, params, fetchFirstPage, '/async_requests');
    }
  }, {
    key: 'getAsyncAdRequestSets',
    value: function getAsyncAdRequestSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAsyncRequestSet, fields, params, fetchFirstPage, '/asyncadrequestsets');
    }
  }, {
    key: 'createAsyncAdRequestSet',
    value: function createAsyncAdRequestSet(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/asyncadrequestsets', fields, params, AdAsyncRequestSet, pathOverride);
    }
  }, {
    key: 'getAudienceFunnel',
    value: function getAudienceFunnel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AudienceFunnel, fields, params, fetchFirstPage, '/audience_funnel');
    }
  }, {
    key: 'createBlockListDraft',
    value: function createBlockListDraft(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/block_list_drafts', fields, params, AdAccount, pathOverride);
    }
  }, {
    key: 'createBrandSafetyContentFilterLevel',
    value: function createBrandSafetyContentFilterLevel(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/brand_safety_content_filter_levels', fields, params, AdAccount, pathOverride);
    }
  }, {
    key: 'getBroadTargetingCategories',
    value: function getBroadTargetingCategories(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BroadTargetingCategories, fields, params, fetchFirstPage, '/broadtargetingcategories');
    }
  }, {
    key: 'getBusinessProjects',
    value: function getBusinessProjects(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessProject, fields, params, fetchFirstPage, '/businessprojects');
    }
  }, {
    key: 'deleteCampaigns',
    value: function deleteCampaigns() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdAccount.prototype.__proto__ || Object.getPrototypeOf(AdAccount.prototype), 'deleteEdge', this).call(this, '/campaigns', params);
    }
  }, {
    key: 'getCampaigns',
    value: function getCampaigns(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Campaign, fields, params, fetchFirstPage, '/campaigns');
    }
  }, {
    key: 'createCampaign',
    value: function createCampaign(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/campaigns', fields, params, Campaign, pathOverride);
    }
  }, {
    key: 'getCampaignsByLabels',
    value: function getCampaignsByLabels(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Campaign, fields, params, fetchFirstPage, '/campaignsbylabels');
    }
  }, {
    key: 'getConnectedInstagramAccounts',
    value: function getConnectedInstagramAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGUser, fields, params, fetchFirstPage, '/connected_instagram_accounts');
    }
  }, {
    key: 'getConnectedInstagramAccountsWithIabp',
    value: function getConnectedInstagramAccountsWithIabp(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramUser, fields, params, fetchFirstPage, '/connected_instagram_accounts_with_iabp');
    }
  }, {
    key: 'getConversionGoals',
    value: function getConversionGoals(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsConversionGoal, fields, params, fetchFirstPage, '/conversion_goals');
    }
  }, {
    key: 'getCpaGuidance',
    value: function getCpaGuidance(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BespokePartnerGuidanceLaser, fields, params, fetchFirstPage, '/cpa_guidance');
    }
  }, {
    key: 'getCustomAudiences',
    value: function getCustomAudiences(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomAudience, fields, params, fetchFirstPage, '/customaudiences');
    }
  }, {
    key: 'createCustomAudience',
    value: function createCustomAudience(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/customaudiences', fields, params, CustomAudience, pathOverride);
    }
  }, {
    key: 'getCustomAudiencesTos',
    value: function getCustomAudiencesTos(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomAudiencesTOS, fields, params, fetchFirstPage, '/customaudiencestos');
    }
  }, {
    key: 'createCustomAudiencesTo',
    value: function createCustomAudiencesTo(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/customaudiencestos', fields, params, AdAccount, pathOverride);
    }
  }, {
    key: 'getCustomConversions',
    value: function getCustomConversions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CustomConversion, fields, params, fetchFirstPage, '/customconversions');
    }
  }, {
    key: 'createCustomConversion',
    value: function createCustomConversion(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/customconversions', fields, params, CustomConversion, pathOverride);
    }
  }, {
    key: 'getDeliveryEstimate',
    value: function getDeliveryEstimate(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountDeliveryEstimate, fields, params, fetchFirstPage, '/delivery_estimate');
    }
  }, {
    key: 'getDeprecatedTargetingAdSets',
    value: function getDeprecatedTargetingAdSets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdSet, fields, params, fetchFirstPage, '/deprecatedtargetingadsets');
    }
  }, {
    key: 'getDsaRecommendations',
    value: function getDsaRecommendations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountDsaRecommendations, fields, params, fetchFirstPage, '/dsa_recommendations');
    }
  }, {
    key: 'getGeneratePreviews',
    value: function getGeneratePreviews(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdPreview, fields, params, fetchFirstPage, '/generatepreviews');
    }
  }, {
    key: 'getImpactingAdStudies',
    value: function getImpactingAdStudies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdStudy, fields, params, fetchFirstPage, '/impacting_ad_studies');
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsInsights, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'getInsightsAsync',
    value: function getInsightsAsync(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/insights', fields, params, AdReportRun, pathOverride);
    }
  }, {
    key: 'getInstagramAccounts',
    value: function getInstagramAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramUser, fields, params, fetchFirstPage, '/instagram_accounts');
    }
  }, {
    key: 'getIosFourteenCampaignLimits',
    value: function getIosFourteenCampaignLimits(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountIosFourteenCampaignLimits, fields, params, fetchFirstPage, '/ios_fourteen_campaign_limits');
    }
  }, {
    key: 'createManagedPartnerAd',
    value: function createManagedPartnerAd(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/managed_partner_ads', fields, params, null, pathOverride);
    }
  }, {
    key: 'getMatchedSearchApplications',
    value: function getMatchedSearchApplications(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountMatchedSearchApplicationsEdgeData, fields, params, fetchFirstPage, '/matched_search_applications');
    }
  }, {
    key: 'getMaxBid',
    value: function getMaxBid(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountMaxBid, fields, params, fetchFirstPage, '/max_bid');
    }
  }, {
    key: 'getMinimumBudgets',
    value: function getMinimumBudgets(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MinimumBudget, fields, params, fetchFirstPage, '/minimum_budgets');
    }
  }, {
    key: 'getOnBehalfRequests',
    value: function getOnBehalfRequests(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(BusinessOwnedObjectOnBehalfOfRequest, fields, params, fetchFirstPage, '/onbehalf_requests');
    }
  }, {
    key: 'createProductAudience',
    value: function createProductAudience(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/product_audiences', fields, params, CustomAudience, pathOverride);
    }
  }, {
    key: 'getPromotePages',
    value: function getPromotePages(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Page, fields, params, fetchFirstPage, '/promote_pages');
    }
  }, {
    key: 'getPublisherBlockLists',
    value: function getPublisherBlockLists(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(PublisherBlockList, fields, params, fetchFirstPage, '/publisher_block_lists');
    }
  }, {
    key: 'createPublisherBlockList',
    value: function createPublisherBlockList(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/publisher_block_lists', fields, params, PublisherBlockList, pathOverride);
    }
  }, {
    key: 'getReachEstimate',
    value: function getReachEstimate(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountReachEstimate, fields, params, fetchFirstPage, '/reachestimate');
    }
  }, {
    key: 'getReachFrequencyPredictions',
    value: function getReachFrequencyPredictions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ReachFrequencyPrediction, fields, params, fetchFirstPage, '/reachfrequencypredictions');
    }
  }, {
    key: 'createReachFrequencyPrediction',
    value: function createReachFrequencyPrediction(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/reachfrequencypredictions', fields, params, ReachFrequencyPrediction, pathOverride);
    }
  }, {
    key: 'getRecommendations',
    value: function getRecommendations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountRecommendations, fields, params, fetchFirstPage, '/recommendations');
    }
  }, {
    key: 'createRecommendation',
    value: function createRecommendation(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/recommendations', fields, params, AdAccountRecommendations, pathOverride);
    }
  }, {
    key: 'getSavedAudiences',
    value: function getSavedAudiences(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(SavedAudience, fields, params, fetchFirstPage, '/saved_audiences');
    }
  }, {
    key: 'deleteSubscribedApps',
    value: function deleteSubscribedApps() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdAccount.prototype.__proto__ || Object.getPrototypeOf(AdAccount.prototype), 'deleteEdge', this).call(this, '/subscribed_apps', params);
    }
  }, {
    key: 'getSubscribedApps',
    value: function getSubscribedApps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountSubscribedApps, fields, params, fetchFirstPage, '/subscribed_apps');
    }
  }, {
    key: 'createSubscribedApp',
    value: function createSubscribedApp(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/subscribed_apps', fields, params, AdAccountSubscribedApps, pathOverride);
    }
  }, {
    key: 'getTargetingBrowse',
    value: function getTargetingBrowse(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountTargetingUnified, fields, params, fetchFirstPage, '/targetingbrowse');
    }
  }, {
    key: 'getTargetingSearch',
    value: function getTargetingSearch(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountTargetingUnified, fields, params, fetchFirstPage, '/targetingsearch');
    }
  }, {
    key: 'getTargetingSentenceLines',
    value: function getTargetingSentenceLines(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(TargetingSentenceLine, fields, params, fetchFirstPage, '/targetingsentencelines');
    }
  }, {
    key: 'getTargetingSuggestions',
    value: function getTargetingSuggestions(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountTargetingUnified, fields, params, fetchFirstPage, '/targetingsuggestions');
    }
  }, {
    key: 'getTargetingValidATIOn',
    value: function getTargetingValidATIOn(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountTargetingUnified, fields, params, fetchFirstPage, '/targetingvalidation');
    }
  }, {
    key: 'getTracking',
    value: function getTracking(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountTrackingData, fields, params, fetchFirstPage, '/tracking');
    }
  }, {
    key: 'createTracking',
    value: function createTracking(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/tracking', fields, params, AdAccount, pathOverride);
    }
  }, {
    key: 'getUsers',
    value: function getUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccountUser, fields, params, fetchFirstPage, '/users');
    }
  }, {
    key: 'deleteUsersOfAnyAudience',
    value: function deleteUsersOfAnyAudience() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(AdAccount.prototype.__proto__ || Object.getPrototypeOf(AdAccount.prototype), 'deleteEdge', this).call(this, '/usersofanyaudience', params);
    }
  }, {
    key: 'getValueAdjustmentRules',
    value: function getValueAdjustmentRules(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsValueAdjustmentRule, fields, params, fetchFirstPage, '/value_adjustment_rules');
    }
  }, {
    key: 'getValueRuleSet',
    value: function getValueRuleSet(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdsValueAdjustmentRuleCollection, fields, params, fetchFirstPage, '/value_rule_set');
    }
  }, {
    key: 'getVideoAds',
    value: function getVideoAds(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdVideo, fields, params, fetchFirstPage, '/video_ads');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(AdAccount.prototype.__proto__ || Object.getPrototypeOf(AdAccount.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        account_status: 'account_status',
        ad_account_promotable_objects: 'ad_account_promotable_objects',
        age: 'age',
        agency_client_declaration: 'agency_client_declaration',
        all_capabilities: 'all_capabilities',
        amount_spent: 'amount_spent',
        attribution_spec: 'attribution_spec',
        balance: 'balance',
        brand_safety_content_filter_levels: 'brand_safety_content_filter_levels',
        business: 'business',
        business_city: 'business_city',
        business_country_code: 'business_country_code',
        business_name: 'business_name',
        business_state: 'business_state',
        business_street: 'business_street',
        business_street2: 'business_street2',
        business_zip: 'business_zip',
        can_create_brand_lift_study: 'can_create_brand_lift_study',
        capabilities: 'capabilities',
        created_time: 'created_time',
        currency: 'currency',
        custom_audience_info: 'custom_audience_info',
        default_dsa_beneficiary: 'default_dsa_beneficiary',
        default_dsa_payor: 'default_dsa_payor',
        disable_reason: 'disable_reason',
        end_advertiser: 'end_advertiser',
        end_advertiser_name: 'end_advertiser_name',
        existing_customers: 'existing_customers',
        extended_credit_invoice_group: 'extended_credit_invoice_group',
        failed_delivery_checks: 'failed_delivery_checks',
        fb_entity: 'fb_entity',
        funding_source: 'funding_source',
        funding_source_details: 'funding_source_details',
        has_migrated_permissions: 'has_migrated_permissions',
        has_page_authorized_adaccount: 'has_page_authorized_adaccount',
        id: 'id',
        io_number: 'io_number',
        is_attribution_spec_system_default: 'is_attribution_spec_system_default',
        is_direct_deals_enabled: 'is_direct_deals_enabled',
        is_in_3ds_authorization_enabled_market: 'is_in_3ds_authorization_enabled_market',
        is_notifications_enabled: 'is_notifications_enabled',
        is_personal: 'is_personal',
        is_prepay_account: 'is_prepay_account',
        is_tax_id_required: 'is_tax_id_required',
        liable_address: 'liable_address',
        line_numbers: 'line_numbers',
        media_agency: 'media_agency',
        min_campaign_group_spend_cap: 'min_campaign_group_spend_cap',
        min_daily_budget: 'min_daily_budget',
        name: 'name',
        offsite_pixels_tos_accepted: 'offsite_pixels_tos_accepted',
        owner: 'owner',
        owner_business: 'owner_business',
        partner: 'partner',
        rf_spec: 'rf_spec',
        send_bill_to_address: 'send_bill_to_address',
        show_checkout_experience: 'show_checkout_experience',
        sold_to_address: 'sold_to_address',
        spend_cap: 'spend_cap',
        tax_id: 'tax_id',
        tax_id_status: 'tax_id_status',
        tax_id_type: 'tax_id_type',
        timezone_id: 'timezone_id',
        timezone_name: 'timezone_name',
        timezone_offset_hours_utc: 'timezone_offset_hours_utc',
        tos_accepted: 'tos_accepted',
        user_access_expire_time: 'user_access_expire_time',
        user_tasks: 'user_tasks',
        user_tos_accepted: 'user_tos_accepted',
        viewable_business: 'viewable_business'
      });
    }
  }, {
    key: 'Currency',
    get: function get() {
      return Object.freeze({
        aed: 'AED',
        ars: 'ARS',
        aud: 'AUD',
        bdt: 'BDT',
        bob: 'BOB',
        brl: 'BRL',
        cad: 'CAD',
        chf: 'CHF',
        clp: 'CLP',
        cny: 'CNY',
        cop: 'COP',
        crc: 'CRC',
        czk: 'CZK',
        dkk: 'DKK',
        dzd: 'DZD',
        egp: 'EGP',
        eur: 'EUR',
        gbp: 'GBP',
        gtq: 'GTQ',
        hkd: 'HKD',
        hnl: 'HNL',
        huf: 'HUF',
        idr: 'IDR',
        ils: 'ILS',
        inr: 'INR',
        isk: 'ISK',
        jpy: 'JPY',
        kes: 'KES',
        krw: 'KRW',
        lkr: 'LKR',
        mop: 'MOP',
        mxn: 'MXN',
        myr: 'MYR',
        ngn: 'NGN',
        nio: 'NIO',
        nok: 'NOK',
        nzd: 'NZD',
        pen: 'PEN',
        php: 'PHP',
        pkr: 'PKR',
        pln: 'PLN',
        pyg: 'PYG',
        qar: 'QAR',
        ron: 'RON',
        sar: 'SAR',
        sek: 'SEK',
        sgd: 'SGD',
        thb: 'THB',
        try: 'TRY',
        twd: 'TWD',
        uah: 'UAH',
        usd: 'USD',
        uyu: 'UYU',
        vnd: 'VND',
        zar: 'ZAR'
      });
    }
  }, {
    key: 'PermittedTasks',
    get: function get() {
      return Object.freeze({
        aa_analyze: 'AA_ANALYZE',
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        draft: 'DRAFT',
        manage: 'MANAGE'
      });
    }
  }, {
    key: 'Tasks',
    get: function get() {
      return Object.freeze({
        aa_analyze: 'AA_ANALYZE',
        advertise: 'ADVERTISE',
        analyze: 'ANALYZE',
        draft: 'DRAFT',
        manage: 'MANAGE'
      });
    }
  }, {
    key: 'BrandSafetyContentFilterLevels',
    get: function get() {
      return Object.freeze({
        an_relaxed: 'AN_RELAXED',
        an_standard: 'AN_STANDARD',
        an_strict: 'AN_STRICT',
        facebook_relaxed: 'FACEBOOK_RELAXED',
        facebook_standard: 'FACEBOOK_STANDARD',
        facebook_strict: 'FACEBOOK_STRICT',
        feed_dnm: 'FEED_DNM',
        feed_relaxed: 'FEED_RELAXED',
        feed_standard: 'FEED_STANDARD',
        feed_strict: 'FEED_STRICT',
        uninitialized: 'UNINITIALIZED',
        unknown: 'UNKNOWN'
      });
    }
  }, {
    key: 'ClaimObjective',
    get: function get() {
      return Object.freeze({
        automotive_model: 'AUTOMOTIVE_MODEL',
        collaborative_ads: 'COLLABORATIVE_ADS',
        home_listing: 'HOME_LISTING',
        media_title: 'MEDIA_TITLE',
        product: 'PRODUCT',
        travel: 'TRAVEL',
        vehicle: 'VEHICLE',
        vehicle_offer: 'VEHICLE_OFFER'
      });
    }
  }, {
    key: 'ContentType',
    get: function get() {
      return Object.freeze({
        automotive_model: 'AUTOMOTIVE_MODEL',
        destination: 'DESTINATION',
        flight: 'FLIGHT',
        generic: 'GENERIC',
        home_listing: 'HOME_LISTING',
        hotel: 'HOTEL',
        job: 'JOB',
        local_service_business: 'LOCAL_SERVICE_BUSINESS',
        media_title: 'MEDIA_TITLE',
        offline_product: 'OFFLINE_PRODUCT',
        product: 'PRODUCT',
        vehicle: 'VEHICLE',
        vehicle_offer: 'VEHICLE_OFFER'
      });
    }
  }, {
    key: 'Subtype',
    get: function get() {
      return Object.freeze({
        app: 'APP',
        bag_of_accounts: 'BAG_OF_ACCOUNTS',
        bidding: 'BIDDING',
        claim: 'CLAIM',
        custom: 'CUSTOM',
        engagement: 'ENGAGEMENT',
        exclusion: 'EXCLUSION',
        fox: 'FOX',
        lookalike: 'LOOKALIKE',
        managed: 'MANAGED',
        measurement: 'MEASUREMENT',
        messenger_subscriber_list: 'MESSENGER_SUBSCRIBER_LIST',
        offline_conversion: 'OFFLINE_CONVERSION',
        partner: 'PARTNER',
        primary: 'PRIMARY',
        regulated_categories_audience: 'REGULATED_CATEGORIES_AUDIENCE',
        study_rule_audience: 'STUDY_RULE_AUDIENCE',
        subscriber_segment: 'SUBSCRIBER_SEGMENT',
        video: 'VIDEO',
        website: 'WEBSITE'
      });
    }
  }, {
    key: 'ActionSource',
    get: function get() {
      return Object.freeze({
        physical_store: 'PHYSICAL_STORE',
        website: 'WEBSITE'
      });
    }
  }]);
  return AdAccount;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountAAACompatibleAdObjects
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountAAACompatibleAdObjects = function (_AbstractCrudObject) {
  inherits(AdAccountAAACompatibleAdObjects, _AbstractCrudObject);

  function AdAccountAAACompatibleAdObjects() {
    classCallCheck(this, AdAccountAAACompatibleAdObjects);
    return possibleConstructorReturn(this, (AdAccountAAACompatibleAdObjects.__proto__ || Object.getPrototypeOf(AdAccountAAACompatibleAdObjects)).apply(this, arguments));
  }

  createClass(AdAccountAAACompatibleAdObjects, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adgroup_ids: 'adgroup_ids',
        campaign_group_ids: 'campaign_group_ids',
        campaign_ids: 'campaign_ids'
      });
    }
  }]);
  return AdAccountAAACompatibleAdObjects;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountAAASimilarCampaigns
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountAAASimilarCampaigns = function (_AbstractCrudObject) {
  inherits(AdAccountAAASimilarCampaigns, _AbstractCrudObject);

  function AdAccountAAASimilarCampaigns() {
    classCallCheck(this, AdAccountAAASimilarCampaigns);
    return possibleConstructorReturn(this, (AdAccountAAASimilarCampaigns.__proto__ || Object.getPrototypeOf(AdAccountAAASimilarCampaigns)).apply(this, arguments));
  }

  createClass(AdAccountAAASimilarCampaigns, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        similar_campaign_limit: 'similar_campaign_limit',
        similar_campaigns_info: 'similar_campaigns_info',
        used_campaign_slots: 'used_campaign_slots'
      });
    }
  }]);
  return AdAccountAAASimilarCampaigns;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountASLSchedule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountASLSchedule = function (_AbstractCrudObject) {
  inherits(AdAccountASLSchedule, _AbstractCrudObject);

  function AdAccountASLSchedule() {
    classCallCheck(this, AdAccountASLSchedule);
    return possibleConstructorReturn(this, (AdAccountASLSchedule.__proto__ || Object.getPrototypeOf(AdAccountASLSchedule)).apply(this, arguments));
  }

  createClass(AdAccountASLSchedule, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account: 'ad_account',
        id: 'id',
        time_created: 'time_created',
        time_updated: 'time_updated'
      });
    }
  }]);
  return AdAccountASLSchedule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountAdLimitsInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountAdLimitsInsights = function (_AbstractCrudObject) {
  inherits(AdAccountAdLimitsInsights, _AbstractCrudObject);

  function AdAccountAdLimitsInsights() {
    classCallCheck(this, AdAccountAdLimitsInsights);
    return possibleConstructorReturn(this, (AdAccountAdLimitsInsights.__proto__ || Object.getPrototypeOf(AdAccountAdLimitsInsights)).apply(this, arguments));
  }

  createClass(AdAccountAdLimitsInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        date_start: 'date_start',
        date_stop: 'date_stop'
      });
    }
  }]);
  return AdAccountAdLimitsInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountAdRulesCountByType
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountAdRulesCountByType = function (_AbstractCrudObject) {
  inherits(AdAccountAdRulesCountByType, _AbstractCrudObject);

  function AdAccountAdRulesCountByType() {
    classCallCheck(this, AdAccountAdRulesCountByType);
    return possibleConstructorReturn(this, (AdAccountAdRulesCountByType.__proto__ || Object.getPrototypeOf(AdAccountAdRulesCountByType)).apply(this, arguments));
  }

  createClass(AdAccountAdRulesCountByType, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        count: 'count',
        evaluation_type: 'evaluation_type'
      });
    }
  }]);
  return AdAccountAdRulesCountByType;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountAdsRecommendedAudios
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountAdsRecommendedAudios = function (_AbstractCrudObject) {
  inherits(AdAccountAdsRecommendedAudios, _AbstractCrudObject);

  function AdAccountAdsRecommendedAudios() {
    classCallCheck(this, AdAccountAdsRecommendedAudios);
    return possibleConstructorReturn(this, (AdAccountAdsRecommendedAudios.__proto__ || Object.getPrototypeOf(AdAccountAdsRecommendedAudios)).apply(this, arguments));
  }

  createClass(AdAccountAdsRecommendedAudios, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audio_assets: 'audio_assets'
      });
    }
  }]);
  return AdAccountAdsRecommendedAudios;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountAllPaymentMethods
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountAllPaymentMethods = function (_AbstractCrudObject) {
  inherits(AdAccountAllPaymentMethods, _AbstractCrudObject);

  function AdAccountAllPaymentMethods() {
    classCallCheck(this, AdAccountAllPaymentMethods);
    return possibleConstructorReturn(this, (AdAccountAllPaymentMethods.__proto__ || Object.getPrototypeOf(AdAccountAllPaymentMethods)).apply(this, arguments));
  }

  createClass(AdAccountAllPaymentMethods, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return AdAccountAllPaymentMethods;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountAppSetupRequirements
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountAppSetupRequirements = function (_AbstractCrudObject) {
  inherits(AdAccountAppSetupRequirements, _AbstractCrudObject);

  function AdAccountAppSetupRequirements() {
    classCallCheck(this, AdAccountAppSetupRequirements);
    return possibleConstructorReturn(this, (AdAccountAppSetupRequirements.__proto__ || Object.getPrototypeOf(AdAccountAppSetupRequirements)).apply(this, arguments));
  }

  createClass(AdAccountAppSetupRequirements, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return AdAccountAppSetupRequirements;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountBankInfoList
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountBankInfoList = function (_AbstractCrudObject) {
  inherits(AdAccountBankInfoList, _AbstractCrudObject);

  function AdAccountBankInfoList() {
    classCallCheck(this, AdAccountBankInfoList);
    return possibleConstructorReturn(this, (AdAccountBankInfoList.__proto__ || Object.getPrototypeOf(AdAccountBankInfoList)).apply(this, arguments));
  }

  createClass(AdAccountBankInfoList, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        banks: 'banks'
      });
    }
  }]);
  return AdAccountBankInfoList;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountBillingDatePreference
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountBillingDatePreference = function (_AbstractCrudObject) {
  inherits(AdAccountBillingDatePreference, _AbstractCrudObject);

  function AdAccountBillingDatePreference() {
    classCallCheck(this, AdAccountBillingDatePreference);
    return possibleConstructorReturn(this, (AdAccountBillingDatePreference.__proto__ || Object.getPrototypeOf(AdAccountBillingDatePreference)).apply(this, arguments));
  }

  createClass(AdAccountBillingDatePreference, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account: 'ad_account',
        day_of_month: 'day_of_month',
        id: 'id',
        next_bill_date: 'next_bill_date',
        time_created: 'time_created',
        time_effective: 'time_effective'
      });
    }
  }]);
  return AdAccountBillingDatePreference;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountCampaignAttributionOptionInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountCampaignAttributionOptionInfo = function (_AbstractCrudObject) {
  inherits(AdAccountCampaignAttributionOptionInfo, _AbstractCrudObject);

  function AdAccountCampaignAttributionOptionInfo() {
    classCallCheck(this, AdAccountCampaignAttributionOptionInfo);
    return possibleConstructorReturn(this, (AdAccountCampaignAttributionOptionInfo.__proto__ || Object.getPrototypeOf(AdAccountCampaignAttributionOptionInfo)).apply(this, arguments));
  }

  createClass(AdAccountCampaignAttributionOptionInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_eligible: 'is_eligible',
        value: 'value'
      });
    }
  }]);
  return AdAccountCampaignAttributionOptionInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountCreationRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountCreationRequest = function (_AbstractCrudObject) {
  inherits(AdAccountCreationRequest, _AbstractCrudObject);

  function AdAccountCreationRequest() {
    classCallCheck(this, AdAccountCreationRequest);
    return possibleConstructorReturn(this, (AdAccountCreationRequest.__proto__ || Object.getPrototypeOf(AdAccountCreationRequest)).apply(this, arguments));
  }

  createClass(AdAccountCreationRequest, [{
    key: 'getAdAccounts',
    value: function getAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/adaccounts');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_accounts_currency: 'ad_accounts_currency',
        ad_accounts_info: 'ad_accounts_info',
        additional_comment: 'additional_comment',
        address_in_chinese: 'address_in_chinese',
        address_in_english: 'address_in_english',
        address_in_local_language: 'address_in_local_language',
        advertiser_business: 'advertiser_business',
        appeal_reason: 'appeal_reason',
        business: 'business',
        business_registration_id: 'business_registration_id',
        chinese_legal_entity_name: 'chinese_legal_entity_name',
        contact: 'contact',
        creator: 'creator',
        credit_card_id: 'credit_card_id',
        disapproval_reasons: 'disapproval_reasons',
        english_legal_entity_name: 'english_legal_entity_name',
        extended_credit_id: 'extended_credit_id',
        id: 'id',
        is_smb: 'is_smb',
        is_test: 'is_test',
        legal_entity_name_in_local_language: 'legal_entity_name_in_local_language',
        oe_request_id: 'oe_request_id',
        official_website_url: 'official_website_url',
        planning_agency_business: 'planning_agency_business',
        planning_agency_business_id: 'planning_agency_business_id',
        promotable_app_ids: 'promotable_app_ids',
        promotable_page_ids: 'promotable_page_ids',
        promotable_urls: 'promotable_urls',
        request_change_reasons: 'request_change_reasons',
        status: 'status',
        subvertical: 'subvertical',
        subvertical_v2: 'subvertical_v2',
        time_created: 'time_created',
        vertical: 'vertical',
        vertical_v2: 'vertical_v2'
      });
    }
  }]);
  return AdAccountCreationRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountCustomAudienceLimits
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountCustomAudienceLimits = function (_AbstractCrudObject) {
  inherits(AdAccountCustomAudienceLimits, _AbstractCrudObject);

  function AdAccountCustomAudienceLimits() {
    classCallCheck(this, AdAccountCustomAudienceLimits);
    return possibleConstructorReturn(this, (AdAccountCustomAudienceLimits.__proto__ || Object.getPrototypeOf(AdAccountCustomAudienceLimits)).apply(this, arguments));
  }

  createClass(AdAccountCustomAudienceLimits, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience_update_quota_in_total: 'audience_update_quota_in_total',
        audience_update_quota_left: 'audience_update_quota_left',
        has_hit_audience_update_limit: 'has_hit_audience_update_limit',
        next_audience_update_available_time: 'next_audience_update_available_time',
        rate_limit_reset_time: 'rate_limit_reset_time'
      });
    }
  }]);
  return AdAccountCustomAudienceLimits;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountDefaultDestination
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountDefaultDestination = function (_AbstractCrudObject) {
  inherits(AdAccountDefaultDestination, _AbstractCrudObject);

  function AdAccountDefaultDestination() {
    classCallCheck(this, AdAccountDefaultDestination);
    return possibleConstructorReturn(this, (AdAccountDefaultDestination.__proto__ || Object.getPrototypeOf(AdAccountDefaultDestination)).apply(this, arguments));
  }

  createClass(AdAccountDefaultDestination, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        destination_id: 'destination_id',
        destination_url: 'destination_url'
      });
    }
  }]);
  return AdAccountDefaultDestination;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountDefaultObjective
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountDefaultObjective = function (_AbstractCrudObject) {
  inherits(AdAccountDefaultObjective, _AbstractCrudObject);

  function AdAccountDefaultObjective() {
    classCallCheck(this, AdAccountDefaultObjective);
    return possibleConstructorReturn(this, (AdAccountDefaultObjective.__proto__ || Object.getPrototypeOf(AdAccountDefaultObjective)).apply(this, arguments));
  }

  createClass(AdAccountDefaultObjective, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        default_objective_for_user: 'default_objective_for_user',
        objective_for_level: 'objective_for_level'
      });
    }
  }, {
    key: 'DefaultObjectiveForUser',
    get: function get() {
      return Object.freeze({
        app_installs: 'APP_INSTALLS',
        brand_awareness: 'BRAND_AWARENESS',
        event_responses: 'EVENT_RESPONSES',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        local_awareness: 'LOCAL_AWARENESS',
        messages: 'MESSAGES',
        offer_claims: 'OFFER_CLAIMS',
        outcome_app_promotion: 'OUTCOME_APP_PROMOTION',
        outcome_awareness: 'OUTCOME_AWARENESS',
        outcome_engagement: 'OUTCOME_ENGAGEMENT',
        outcome_leads: 'OUTCOME_LEADS',
        outcome_sales: 'OUTCOME_SALES',
        outcome_traffic: 'OUTCOME_TRAFFIC',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        product_catalog_sales: 'PRODUCT_CATALOG_SALES',
        reach: 'REACH',
        store_visits: 'STORE_VISITS',
        video_views: 'VIDEO_VIEWS',
        website_conversions: 'WEBSITE_CONVERSIONS'
      });
    }
  }, {
    key: 'ObjectiveForLevel',
    get: function get() {
      return Object.freeze({
        app_installs: 'APP_INSTALLS',
        brand_awareness: 'BRAND_AWARENESS',
        event_responses: 'EVENT_RESPONSES',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        local_awareness: 'LOCAL_AWARENESS',
        messages: 'MESSAGES',
        offer_claims: 'OFFER_CLAIMS',
        outcome_app_promotion: 'OUTCOME_APP_PROMOTION',
        outcome_awareness: 'OUTCOME_AWARENESS',
        outcome_engagement: 'OUTCOME_ENGAGEMENT',
        outcome_leads: 'OUTCOME_LEADS',
        outcome_sales: 'OUTCOME_SALES',
        outcome_traffic: 'OUTCOME_TRAFFIC',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        product_catalog_sales: 'PRODUCT_CATALOG_SALES',
        reach: 'REACH',
        store_visits: 'STORE_VISITS',
        video_views: 'VIDEO_VIEWS',
        website_conversions: 'WEBSITE_CONVERSIONS'
      });
    }
  }]);
  return AdAccountDefaultObjective;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountLiveVideoAdvertiser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountLiveVideoAdvertiser = function (_AbstractCrudObject) {
  inherits(AdAccountLiveVideoAdvertiser, _AbstractCrudObject);

  function AdAccountLiveVideoAdvertiser() {
    classCallCheck(this, AdAccountLiveVideoAdvertiser);
    return possibleConstructorReturn(this, (AdAccountLiveVideoAdvertiser.__proto__ || Object.getPrototypeOf(AdAccountLiveVideoAdvertiser)).apply(this, arguments));
  }

  createClass(AdAccountLiveVideoAdvertiser, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_lva_toggle_on: 'is_lva_toggle_on',
        lva_default_budget: 'lva_default_budget',
        should_show_lva_toggle: 'should_show_lva_toggle'
      });
    }
  }]);
  return AdAccountLiveVideoAdvertiser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountOptimizationGoalsAEMv2Eligibility
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountOptimizationGoalsAEMv2Eligibility = function (_AbstractCrudObject) {
  inherits(AdAccountOptimizationGoalsAEMv2Eligibility, _AbstractCrudObject);

  function AdAccountOptimizationGoalsAEMv2Eligibility() {
    classCallCheck(this, AdAccountOptimizationGoalsAEMv2Eligibility);
    return possibleConstructorReturn(this, (AdAccountOptimizationGoalsAEMv2Eligibility.__proto__ || Object.getPrototypeOf(AdAccountOptimizationGoalsAEMv2Eligibility)).apply(this, arguments));
  }

  createClass(AdAccountOptimizationGoalsAEMv2Eligibility, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_disabled: 'is_disabled',
        optimization_goal: 'optimization_goal'
      });
    }
  }, {
    key: 'OptimizationGoal',
    get: function get() {
      return Object.freeze({
        ad_recall_lift: 'AD_RECALL_LIFT',
        app_installs: 'APP_INSTALLS',
        app_installs_and_offsite_conversions: 'APP_INSTALLS_AND_OFFSITE_CONVERSIONS',
        conversations: 'CONVERSATIONS',
        derived_events: 'DERIVED_EVENTS',
        engaged_users: 'ENGAGED_USERS',
        event_responses: 'EVENT_RESPONSES',
        impressions: 'IMPRESSIONS',
        in_app_value: 'IN_APP_VALUE',
        landing_page_views: 'LANDING_PAGE_VIEWS',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        meaningful_call_attempt: 'MEANINGFUL_CALL_ATTEMPT',
        messaging_appointment_conversion: 'MESSAGING_APPOINTMENT_CONVERSION',
        messaging_purchase_conversion: 'MESSAGING_PURCHASE_CONVERSION',
        none: 'NONE',
        offsite_conversions: 'OFFSITE_CONVERSIONS',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        profile_visit: 'PROFILE_VISIT',
        quality_call: 'QUALITY_CALL',
        quality_lead: 'QUALITY_LEAD',
        reach: 'REACH',
        reminders_set: 'REMINDERS_SET',
        subscribers: 'SUBSCRIBERS',
        thruplay: 'THRUPLAY',
        value: 'VALUE',
        visit_instagram_profile: 'VISIT_INSTAGRAM_PROFILE'
      });
    }
  }]);
  return AdAccountOptimizationGoalsAEMv2Eligibility;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountPaymentDetails
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountPaymentDetails = function (_AbstractCrudObject) {
  inherits(AdAccountPaymentDetails, _AbstractCrudObject);

  function AdAccountPaymentDetails() {
    classCallCheck(this, AdAccountPaymentDetails);
    return possibleConstructorReturn(this, (AdAccountPaymentDetails.__proto__ || Object.getPrototypeOf(AdAccountPaymentDetails)).apply(this, arguments));
  }

  createClass(AdAccountPaymentDetails, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount: 'amount',
        create_date: 'create_date',
        id: 'id',
        last_action_status: 'last_action_status',
        metadata: 'metadata',
        payment_details_id: 'payment_details_id'
      });
    }
  }]);
  return AdAccountPaymentDetails;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountPaymentOptions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountPaymentOptions = function (_AbstractCrudObject) {
  inherits(AdAccountPaymentOptions, _AbstractCrudObject);

  function AdAccountPaymentOptions() {
    classCallCheck(this, AdAccountPaymentOptions);
    return possibleConstructorReturn(this, (AdAccountPaymentOptions.__proto__ || Object.getPrototypeOf(AdAccountPaymentOptions)).apply(this, arguments));
  }

  createClass(AdAccountPaymentOptions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        available_altpay_options: 'available_altpay_options',
        available_card_types: 'available_card_types',
        available_payment_options: 'available_payment_options',
        existing_payment_methods: 'existing_payment_methods'
      });
    }
  }]);
  return AdAccountPaymentOptions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountPrepayDetails
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountPrepayDetails = function (_AbstractCrudObject) {
  inherits(AdAccountPrepayDetails, _AbstractCrudObject);

  function AdAccountPrepayDetails() {
    classCallCheck(this, AdAccountPrepayDetails);
    return possibleConstructorReturn(this, (AdAccountPrepayDetails.__proto__ || Object.getPrototypeOf(AdAccountPrepayDetails)).apply(this, arguments));
  }

  createClass(AdAccountPrepayDetails, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        default_funding_amount: 'default_funding_amount',
        max_acceptable_amount: 'max_acceptable_amount',
        min_acceptable_amount: 'min_acceptable_amount',
        should_collect_business_details: 'should_collect_business_details'
      });
    }
  }]);
  return AdAccountPrepayDetails;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountPromotableObjects
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountPromotableObjects = function (_AbstractCrudObject) {
  inherits(AdAccountPromotableObjects, _AbstractCrudObject);

  function AdAccountPromotableObjects() {
    classCallCheck(this, AdAccountPromotableObjects);
    return possibleConstructorReturn(this, (AdAccountPromotableObjects.__proto__ || Object.getPrototypeOf(AdAccountPromotableObjects)).apply(this, arguments));
  }

  createClass(AdAccountPromotableObjects, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        promotable_app_ids: 'promotable_app_ids',
        promotable_page_ids: 'promotable_page_ids',
        promotable_urls: 'promotable_urls'
      });
    }
  }]);
  return AdAccountPromotableObjects;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountPromotionProgressBar
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountPromotionProgressBar = function (_AbstractCrudObject) {
  inherits(AdAccountPromotionProgressBar, _AbstractCrudObject);

  function AdAccountPromotionProgressBar() {
    classCallCheck(this, AdAccountPromotionProgressBar);
    return possibleConstructorReturn(this, (AdAccountPromotionProgressBar.__proto__ || Object.getPrototypeOf(AdAccountPromotionProgressBar)).apply(this, arguments));
  }

  createClass(AdAccountPromotionProgressBar, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adaccount_permission: 'adaccount_permission',
        coupon_currency: 'coupon_currency',
        coupon_value: 'coupon_value',
        expiration_time: 'expiration_time',
        progress_completed: 'progress_completed',
        promotion_type: 'promotion_type',
        spend_requirement_in_cent: 'spend_requirement_in_cent',
        spend_since_enrollment: 'spend_since_enrollment'
      });
    }
  }]);
  return AdAccountPromotionProgressBar;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountRecommendedCamapaignBudget
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountRecommendedCamapaignBudget = function (_AbstractCrudObject) {
  inherits(AdAccountRecommendedCamapaignBudget, _AbstractCrudObject);

  function AdAccountRecommendedCamapaignBudget() {
    classCallCheck(this, AdAccountRecommendedCamapaignBudget);
    return possibleConstructorReturn(this, (AdAccountRecommendedCamapaignBudget.__proto__ || Object.getPrototypeOf(AdAccountRecommendedCamapaignBudget)).apply(this, arguments));
  }

  createClass(AdAccountRecommendedCamapaignBudget, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        daily: 'daily',
        lifetime: 'lifetime',
        objective: 'objective'
      });
    }
  }]);
  return AdAccountRecommendedCamapaignBudget;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountRelatedIcoStudy
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountRelatedIcoStudy = function (_AbstractCrudObject) {
  inherits(AdAccountRelatedIcoStudy, _AbstractCrudObject);

  function AdAccountRelatedIcoStudy() {
    classCallCheck(this, AdAccountRelatedIcoStudy);
    return possibleConstructorReturn(this, (AdAccountRelatedIcoStudy.__proto__ || Object.getPrototypeOf(AdAccountRelatedIcoStudy)).apply(this, arguments));
  }

  createClass(AdAccountRelatedIcoStudy, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return AdAccountRelatedIcoStudy;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountSmartSuggestedAds
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountSmartSuggestedAds = function (_AbstractCrudObject) {
  inherits(AdAccountSmartSuggestedAds, _AbstractCrudObject);

  function AdAccountSmartSuggestedAds() {
    classCallCheck(this, AdAccountSmartSuggestedAds);
    return possibleConstructorReturn(this, (AdAccountSmartSuggestedAds.__proto__ || Object.getPrototypeOf(AdAccountSmartSuggestedAds)).apply(this, arguments));
  }

  createClass(AdAccountSmartSuggestedAds, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_creative_spec: 'ad_creative_spec',
        description: 'description',
        guidance_spec: 'guidance_spec',
        thumbnail_url: 'thumbnail_url'
      });
    }
  }]);
  return AdAccountSmartSuggestedAds;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountSpendLimit
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountSpendLimit = function (_AbstractCrudObject) {
  inherits(AdAccountSpendLimit, _AbstractCrudObject);

  function AdAccountSpendLimit() {
    classCallCheck(this, AdAccountSpendLimit);
    return possibleConstructorReturn(this, (AdAccountSpendLimit.__proto__ || Object.getPrototypeOf(AdAccountSpendLimit)).apply(this, arguments));
  }

  createClass(AdAccountSpendLimit, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount_spent: 'amount_spent',
        group_id: 'group_id',
        limit_id: 'limit_id',
        limit_value: 'limit_value',
        time_created: 'time_created',
        time_start: 'time_start',
        time_stop: 'time_stop'
      });
    }
  }]);
  return AdAccountSpendLimit;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountSubsidyAmountDetails
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountSubsidyAmountDetails = function (_AbstractCrudObject) {
  inherits(AdAccountSubsidyAmountDetails, _AbstractCrudObject);

  function AdAccountSubsidyAmountDetails() {
    classCallCheck(this, AdAccountSubsidyAmountDetails);
    return possibleConstructorReturn(this, (AdAccountSubsidyAmountDetails.__proto__ || Object.getPrototypeOf(AdAccountSubsidyAmountDetails)).apply(this, arguments));
  }

  createClass(AdAccountSubsidyAmountDetails, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        entered_amount: 'entered_amount',
        fee_amount: 'fee_amount',
        total_amount: 'total_amount'
      });
    }
  }]);
  return AdAccountSubsidyAmountDetails;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountSuggestedTag
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountSuggestedTag = function (_AbstractCrudObject) {
  inherits(AdAccountSuggestedTag, _AbstractCrudObject);

  function AdAccountSuggestedTag() {
    classCallCheck(this, AdAccountSuggestedTag);
    return possibleConstructorReturn(this, (AdAccountSuggestedTag.__proto__ || Object.getPrototypeOf(AdAccountSuggestedTag)).apply(this, arguments));
  }

  createClass(AdAccountSuggestedTag, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        product_id: 'product_id',
        x: 'x',
        y: 'y'
      });
    }
  }]);
  return AdAccountSuggestedTag;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountURLForAssetExtraction
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountURLForAssetExtraction = function (_AbstractCrudObject) {
  inherits(AdAccountURLForAssetExtraction, _AbstractCrudObject);

  function AdAccountURLForAssetExtraction() {
    classCallCheck(this, AdAccountURLForAssetExtraction);
    return possibleConstructorReturn(this, (AdAccountURLForAssetExtraction.__proto__ || Object.getPrototypeOf(AdAccountURLForAssetExtraction)).apply(this, arguments));
  }

  createClass(AdAccountURLForAssetExtraction, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        source_type: 'source_type',
        source_url: 'source_url'
      });
    }
  }]);
  return AdAccountURLForAssetExtraction;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountUserPermissions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountUserPermissions = function (_AbstractCrudObject) {
  inherits(AdAccountUserPermissions, _AbstractCrudObject);

  function AdAccountUserPermissions() {
    classCallCheck(this, AdAccountUserPermissions);
    return possibleConstructorReturn(this, (AdAccountUserPermissions.__proto__ || Object.getPrototypeOf(AdAccountUserPermissions)).apply(this, arguments));
  }

  createClass(AdAccountUserPermissions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        business_persona: 'business_persona',
        created_by: 'created_by',
        created_time: 'created_time',
        email: 'email',
        status: 'status',
        tasks: 'tasks',
        updated_by: 'updated_by',
        updated_time: 'updated_time',
        user: 'user'
      });
    }
  }]);
  return AdAccountUserPermissions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountUserSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountUserSettings = function (_AbstractCrudObject) {
  inherits(AdAccountUserSettings, _AbstractCrudObject);

  function AdAccountUserSettings() {
    classCallCheck(this, AdAccountUserSettings);
    return possibleConstructorReturn(this, (AdAccountUserSettings.__proto__ || Object.getPrototypeOf(AdAccountUserSettings)).apply(this, arguments));
  }

  createClass(AdAccountUserSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        acf_should_opt_out_video_adjustments: 'acf_should_opt_out_video_adjustments',
        aco_sticky_settings: 'aco_sticky_settings',
        ad_account: 'ad_account',
        ad_object_export_format: 'ad_object_export_format',
        auto_review_video_caption: 'auto_review_video_caption',
        campaign_overview_columns: 'campaign_overview_columns',
        column_suggestion_status: 'column_suggestion_status',
        default_account_overview_agegender_metrics: 'default_account_overview_agegender_metrics',
        default_account_overview_location_metrics: 'default_account_overview_location_metrics',
        default_account_overview_metrics: 'default_account_overview_metrics',
        default_account_overview_time_metrics: 'default_account_overview_time_metrics',
        default_builtin_column_preset: 'default_builtin_column_preset',
        default_nam_time_range: 'default_nam_time_range',
        draft_mode_enabled: 'draft_mode_enabled',
        export_deleted_items_with_delivery: 'export_deleted_items_with_delivery',
        export_summary_row: 'export_summary_row',
        has_seen_groups_column_flexing_experience: 'has_seen_groups_column_flexing_experience',
        has_seen_instagram_column_flexing_experience: 'has_seen_instagram_column_flexing_experience',
        has_seen_leads_column_flexing_experience: 'has_seen_leads_column_flexing_experience',
        has_seen_shops_ads_metrics_onboarding_tour: 'has_seen_shops_ads_metrics_onboarding_tour',
        has_seen_shops_column_flexing_experience: 'has_seen_shops_column_flexing_experience',
        hidden_optimization_tips: 'hidden_optimization_tips',
        id: 'id',
        is_3p_auth_setting_set: 'is_3p_auth_setting_set',
        is_text_variation_nux_close: 'is_text_variation_nux_close',
        last_used_columns: 'last_used_columns',
        last_used_pe_filters: 'last_used_pe_filters',
        last_used_website_urls: 'last_used_website_urls',
        outlier_preferences: 'outlier_preferences',
        pinned_ad_object_ids: 'pinned_ad_object_ids',
        rb_export_format: 'rb_export_format',
        rb_export_raw_data: 'rb_export_raw_data',
        rb_export_summary_row: 'rb_export_summary_row',
        saip_advertiser_setup_optimisation_guidance_overall_state: 'saip_advertiser_setup_optimisation_guidance_overall_state',
        saip_advertiser_setup_optimisation_guidance_state: 'saip_advertiser_setup_optimisation_guidance_state',
        shops_ads_metrics_onboarding_tour_close_count: 'shops_ads_metrics_onboarding_tour_close_count',
        shops_ads_metrics_onboarding_tour_last_action_time: 'shops_ads_metrics_onboarding_tour_last_action_time',
        should_default_image_auto_crop: 'should_default_image_auto_crop',
        should_default_image_auto_crop_for_tail: 'should_default_image_auto_crop_for_tail',
        should_default_image_auto_crop_optimization: 'should_default_image_auto_crop_optimization',
        should_default_image_dof_toggle: 'should_default_image_dof_toggle',
        should_default_image_lpp_ads_to_square: 'should_default_image_lpp_ads_to_square',
        should_default_instagram_profile_card_optimization: 'should_default_instagram_profile_card_optimization',
        should_default_text_swapping_optimization: 'should_default_text_swapping_optimization',
        should_logout_of_3p_sourcing: 'should_logout_of_3p_sourcing',
        show_archived_data: 'show_archived_data',
        show_text_variation_nux_tooltip: 'show_text_variation_nux_tooltip',
        syd_campaign_trends_activemetric: 'syd_campaign_trends_activemetric',
        syd_campaign_trends_attribution: 'syd_campaign_trends_attribution',
        syd_campaign_trends_metrics: 'syd_campaign_trends_metrics',
        syd_campaign_trends_objective: 'syd_campaign_trends_objective',
        syd_campaign_trends_time_range: 'syd_campaign_trends_time_range',
        syd_landing_page_opt_in_status: 'syd_landing_page_opt_in_status',
        text_variations_opt_in_type: 'text_variations_opt_in_type',
        user: 'user'
      });
    }
  }, {
    key: 'SydCampaignTrendsObjective',
    get: function get() {
      return Object.freeze({
        app_installs: 'APP_INSTALLS',
        brand_awareness: 'BRAND_AWARENESS',
        event_responses: 'EVENT_RESPONSES',
        lead_generation: 'LEAD_GENERATION',
        link_clicks: 'LINK_CLICKS',
        local_awareness: 'LOCAL_AWARENESS',
        messages: 'MESSAGES',
        offer_claims: 'OFFER_CLAIMS',
        outcome_app_promotion: 'OUTCOME_APP_PROMOTION',
        outcome_awareness: 'OUTCOME_AWARENESS',
        outcome_engagement: 'OUTCOME_ENGAGEMENT',
        outcome_leads: 'OUTCOME_LEADS',
        outcome_sales: 'OUTCOME_SALES',
        outcome_traffic: 'OUTCOME_TRAFFIC',
        page_likes: 'PAGE_LIKES',
        post_engagement: 'POST_ENGAGEMENT',
        product_catalog_sales: 'PRODUCT_CATALOG_SALES',
        reach: 'REACH',
        store_visits: 'STORE_VISITS',
        video_views: 'VIDEO_VIEWS',
        website_conversions: 'WEBSITE_CONVERSIONS'
      });
    }
  }]);
  return AdAccountUserSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAccountYouthAdsAdvertiser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAccountYouthAdsAdvertiser = function (_AbstractCrudObject) {
  inherits(AdAccountYouthAdsAdvertiser, _AbstractCrudObject);

  function AdAccountYouthAdsAdvertiser() {
    classCallCheck(this, AdAccountYouthAdsAdvertiser);
    return possibleConstructorReturn(this, (AdAccountYouthAdsAdvertiser.__proto__ || Object.getPrototypeOf(AdAccountYouthAdsAdvertiser)).apply(this, arguments));
  }

  createClass(AdAccountYouthAdsAdvertiser, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_youth_ads_advertiser: 'is_youth_ads_advertiser'
      });
    }
  }]);
  return AdAccountYouthAdsAdvertiser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetBody
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetBody = function (_AbstractCrudObject) {
  inherits(AdAssetBody, _AbstractCrudObject);

  function AdAssetBody() {
    classCallCheck(this, AdAssetBody);
    return possibleConstructorReturn(this, (AdAssetBody.__proto__ || Object.getPrototypeOf(AdAssetBody)).apply(this, arguments));
  }

  createClass(AdAssetBody, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        text: 'text',
        url_tags: 'url_tags'
      });
    }
  }]);
  return AdAssetBody;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetCallToActionType
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetCallToActionType = function (_AbstractCrudObject) {
  inherits(AdAssetCallToActionType, _AbstractCrudObject);

  function AdAssetCallToActionType() {
    classCallCheck(this, AdAssetCallToActionType);
    return possibleConstructorReturn(this, (AdAssetCallToActionType.__proto__ || Object.getPrototypeOf(AdAssetCallToActionType)).apply(this, arguments));
  }

  createClass(AdAssetCallToActionType, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return AdAssetCallToActionType;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetCustomizationRuleCustomizationSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetCustomizationRuleCustomizationSpec = function (_AbstractCrudObject) {
  inherits(AdAssetCustomizationRuleCustomizationSpec, _AbstractCrudObject);

  function AdAssetCustomizationRuleCustomizationSpec() {
    classCallCheck(this, AdAssetCustomizationRuleCustomizationSpec);
    return possibleConstructorReturn(this, (AdAssetCustomizationRuleCustomizationSpec.__proto__ || Object.getPrototypeOf(AdAssetCustomizationRuleCustomizationSpec)).apply(this, arguments));
  }

  createClass(AdAssetCustomizationRuleCustomizationSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        age_max: 'age_max',
        age_min: 'age_min',
        audience_network_positions: 'audience_network_positions',
        device_platforms: 'device_platforms',
        facebook_positions: 'facebook_positions',
        geo_locations: 'geo_locations',
        instagram_positions: 'instagram_positions',
        locales: 'locales',
        messenger_positions: 'messenger_positions',
        publisher_platforms: 'publisher_platforms'
      });
    }
  }, {
    key: 'DevicePlatforms',
    get: function get() {
      return Object.freeze({
        desktop: 'desktop',
        mobile: 'mobile'
      });
    }
  }]);
  return AdAssetCustomizationRuleCustomizationSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetDescription
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetDescription = function (_AbstractCrudObject) {
  inherits(AdAssetDescription, _AbstractCrudObject);

  function AdAssetDescription() {
    classCallCheck(this, AdAssetDescription);
    return possibleConstructorReturn(this, (AdAssetDescription.__proto__ || Object.getPrototypeOf(AdAssetDescription)).apply(this, arguments));
  }

  createClass(AdAssetDescription, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        text: 'text',
        url_tags: 'url_tags'
      });
    }
  }]);
  return AdAssetDescription;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedAdditionalData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedAdditionalData = function (_AbstractCrudObject) {
  inherits(AdAssetFeedAdditionalData, _AbstractCrudObject);

  function AdAssetFeedAdditionalData() {
    classCallCheck(this, AdAssetFeedAdditionalData);
    return possibleConstructorReturn(this, (AdAssetFeedAdditionalData.__proto__ || Object.getPrototypeOf(AdAssetFeedAdditionalData)).apply(this, arguments));
  }

  createClass(AdAssetFeedAdditionalData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        automated_product_tags: 'automated_product_tags',
        brand_page_id: 'brand_page_id',
        is_click_to_message: 'is_click_to_message',
        multi_share_end_card: 'multi_share_end_card',
        page_welcome_message: 'page_welcome_message',
        partner_app_welcome_message_flow_id: 'partner_app_welcome_message_flow_id'
      });
    }
  }]);
  return AdAssetFeedAdditionalData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedAdditionalDataPageNudgeMessage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedAdditionalDataPageNudgeMessage = function (_AbstractCrudObject) {
  inherits(AdAssetFeedAdditionalDataPageNudgeMessage, _AbstractCrudObject);

  function AdAssetFeedAdditionalDataPageNudgeMessage() {
    classCallCheck(this, AdAssetFeedAdditionalDataPageNudgeMessage);
    return possibleConstructorReturn(this, (AdAssetFeedAdditionalDataPageNudgeMessage.__proto__ || Object.getPrototypeOf(AdAssetFeedAdditionalDataPageNudgeMessage)).apply(this, arguments));
  }

  createClass(AdAssetFeedAdditionalDataPageNudgeMessage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        enabled: 'enabled',
        quick_replies: 'quick_replies',
        text: 'text'
      });
    }
  }]);
  return AdAssetFeedAdditionalDataPageNudgeMessage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpec = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpec, _AbstractCrudObject);

  function AdAssetFeedSpec() {
    classCallCheck(this, AdAssetFeedSpec);
    return possibleConstructorReturn(this, (AdAssetFeedSpec.__proto__ || Object.getPrototypeOf(AdAssetFeedSpec)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_formats: 'ad_formats',
        additional_data: 'additional_data',
        app_product_page_id: 'app_product_page_id',
        asset_customization_rules: 'asset_customization_rules',
        autotranslate: 'autotranslate',
        bodies: 'bodies',
        call_ads_configuration: 'call_ads_configuration',
        call_to_action_types: 'call_to_action_types',
        call_to_actions: 'call_to_actions',
        captions: 'captions',
        carousels: 'carousels',
        descriptions: 'descriptions',
        events: 'events',
        groups: 'groups',
        images: 'images',
        link_urls: 'link_urls',
        message_extensions: 'message_extensions',
        onsite_destinations: 'onsite_destinations',
        optimization_type: 'optimization_type',
        promotional_metadata: 'promotional_metadata',
        reasons_to_shop: 'reasons_to_shop',
        shops_bundle: 'shops_bundle',
        titles: 'titles',
        upcoming_events: 'upcoming_events',
        videos: 'videos'
      });
    }
  }, {
    key: 'CallToActionTypes',
    get: function get() {
      return Object.freeze({
        add_to_cart: 'ADD_TO_CART',
        apply_now: 'APPLY_NOW',
        ask_about_services: 'ASK_ABOUT_SERVICES',
        ask_for_more_info: 'ASK_FOR_MORE_INFO',
        audio_call: 'AUDIO_CALL',
        book_a_consultation: 'BOOK_A_CONSULTATION',
        book_now: 'BOOK_NOW',
        book_travel: 'BOOK_TRAVEL',
        buy: 'BUY',
        buy_now: 'BUY_NOW',
        buy_tickets: 'BUY_TICKETS',
        buy_via_message: 'BUY_VIA_MESSAGE',
        call: 'CALL',
        call_me: 'CALL_ME',
        call_now: 'CALL_NOW',
        chat_with_us: 'CHAT_WITH_US',
        confirm: 'CONFIRM',
        contact: 'CONTACT',
        contact_us: 'CONTACT_US',
        donate: 'DONATE',
        donate_now: 'DONATE_NOW',
        download: 'DOWNLOAD',
        event_rsvp: 'EVENT_RSVP',
        find_a_group: 'FIND_A_GROUP',
        find_your_groups: 'FIND_YOUR_GROUPS',
        follow_news_storyline: 'FOLLOW_NEWS_STORYLINE',
        follow_page: 'FOLLOW_PAGE',
        follow_user: 'FOLLOW_USER',
        get_a_quote: 'GET_A_QUOTE',
        get_directions: 'GET_DIRECTIONS',
        get_offer: 'GET_OFFER',
        get_offer_view: 'GET_OFFER_VIEW',
        get_promotions: 'GET_PROMOTIONS',
        get_quote: 'GET_QUOTE',
        get_showtimes: 'GET_SHOWTIMES',
        get_started: 'GET_STARTED',
        inquire_now: 'INQUIRE_NOW',
        install_app: 'INSTALL_APP',
        install_mobile_app: 'INSTALL_MOBILE_APP',
        join_channel: 'JOIN_CHANNEL',
        learn_more: 'LEARN_MORE',
        like_page: 'LIKE_PAGE',
        listen_music: 'LISTEN_MUSIC',
        listen_now: 'LISTEN_NOW',
        make_an_appointment: 'MAKE_AN_APPOINTMENT',
        message_page: 'MESSAGE_PAGE',
        mobile_download: 'MOBILE_DOWNLOAD',
        no_button: 'NO_BUTTON',
        open_instant_app: 'OPEN_INSTANT_APP',
        open_link: 'OPEN_LINK',
        order_now: 'ORDER_NOW',
        pay_to_access: 'PAY_TO_ACCESS',
        play_game: 'PLAY_GAME',
        play_game_on_facebook: 'PLAY_GAME_ON_FACEBOOK',
        purchase_gift_cards: 'PURCHASE_GIFT_CARDS',
        raise_money: 'RAISE_MONEY',
        record_now: 'RECORD_NOW',
        refer_friends: 'REFER_FRIENDS',
        request_time: 'REQUEST_TIME',
        say_thanks: 'SAY_THANKS',
        see_more: 'SEE_MORE',
        sell_now: 'SELL_NOW',
        send_a_gift: 'SEND_A_GIFT',
        send_gift_money: 'SEND_GIFT_MONEY',
        send_updates: 'SEND_UPDATES',
        share: 'SHARE',
        shop_now: 'SHOP_NOW',
        sign_up: 'SIGN_UP',
        sotto_subscribe: 'SOTTO_SUBSCRIBE',
        start_order: 'START_ORDER',
        subscribe: 'SUBSCRIBE',
        swipe_up_product: 'SWIPE_UP_PRODUCT',
        swipe_up_shop: 'SWIPE_UP_SHOP',
        update_app: 'UPDATE_APP',
        use_app: 'USE_APP',
        use_mobile_app: 'USE_MOBILE_APP',
        video_annotation: 'VIDEO_ANNOTATION',
        video_call: 'VIDEO_CALL',
        view_channel: 'VIEW_CHANNEL',
        view_product: 'VIEW_PRODUCT',
        visit_pages_feed: 'VISIT_PAGES_FEED',
        watch_more: 'WATCH_MORE',
        watch_video: 'WATCH_VIDEO',
        whatsapp_message: 'WHATSAPP_MESSAGE',
        woodhenge_support: 'WOODHENGE_SUPPORT'
      });
    }
  }]);
  return AdAssetFeedSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecAssetCustomizationRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecAssetCustomizationRule = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecAssetCustomizationRule, _AbstractCrudObject);

  function AdAssetFeedSpecAssetCustomizationRule() {
    classCallCheck(this, AdAssetFeedSpecAssetCustomizationRule);
    return possibleConstructorReturn(this, (AdAssetFeedSpecAssetCustomizationRule.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecAssetCustomizationRule)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecAssetCustomizationRule, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        body_label: 'body_label',
        call_to_action_label: 'call_to_action_label',
        call_to_action_type_label: 'call_to_action_type_label',
        caption_label: 'caption_label',
        carousel_label: 'carousel_label',
        customization_spec: 'customization_spec',
        description_label: 'description_label',
        image_label: 'image_label',
        is_default: 'is_default',
        link_url_label: 'link_url_label',
        priority: 'priority',
        title_label: 'title_label',
        video_label: 'video_label'
      });
    }
  }]);
  return AdAssetFeedSpecAssetCustomizationRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecAssetLabel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecAssetLabel = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecAssetLabel, _AbstractCrudObject);

  function AdAssetFeedSpecAssetLabel() {
    classCallCheck(this, AdAssetFeedSpecAssetLabel);
    return possibleConstructorReturn(this, (AdAssetFeedSpecAssetLabel.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecAssetLabel)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecAssetLabel, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return AdAssetFeedSpecAssetLabel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecBody
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecBody = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecBody, _AbstractCrudObject);

  function AdAssetFeedSpecBody() {
    classCallCheck(this, AdAssetFeedSpecBody);
    return possibleConstructorReturn(this, (AdAssetFeedSpecBody.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecBody)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecBody, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adlabels: 'adlabels',
        text: 'text',
        url_tags: 'url_tags'
      });
    }
  }]);
  return AdAssetFeedSpecBody;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecCallToAction
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecCallToAction = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecCallToAction, _AbstractCrudObject);

  function AdAssetFeedSpecCallToAction() {
    classCallCheck(this, AdAssetFeedSpecCallToAction);
    return possibleConstructorReturn(this, (AdAssetFeedSpecCallToAction.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecCallToAction)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecCallToAction, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adlabels: 'adlabels',
        type: 'type',
        value: 'value'
      });
    }
  }]);
  return AdAssetFeedSpecCallToAction;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecCaption
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecCaption = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecCaption, _AbstractCrudObject);

  function AdAssetFeedSpecCaption() {
    classCallCheck(this, AdAssetFeedSpecCaption);
    return possibleConstructorReturn(this, (AdAssetFeedSpecCaption.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecCaption)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecCaption, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adlabels: 'adlabels',
        text: 'text',
        url_tags: 'url_tags'
      });
    }
  }]);
  return AdAssetFeedSpecCaption;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecCarousel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecCarousel = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecCarousel, _AbstractCrudObject);

  function AdAssetFeedSpecCarousel() {
    classCallCheck(this, AdAssetFeedSpecCarousel);
    return possibleConstructorReturn(this, (AdAssetFeedSpecCarousel.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecCarousel)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecCarousel, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adlabels: 'adlabels',
        child_attachments: 'child_attachments',
        multi_share_end_card: 'multi_share_end_card',
        multi_share_optimized: 'multi_share_optimized'
      });
    }
  }]);
  return AdAssetFeedSpecCarousel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecCarouselChildAttachment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecCarouselChildAttachment = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecCarouselChildAttachment, _AbstractCrudObject);

  function AdAssetFeedSpecCarouselChildAttachment() {
    classCallCheck(this, AdAssetFeedSpecCarouselChildAttachment);
    return possibleConstructorReturn(this, (AdAssetFeedSpecCarouselChildAttachment.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecCarouselChildAttachment)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecCarouselChildAttachment, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        body_label: 'body_label',
        call_to_action_type_label: 'call_to_action_type_label',
        caption_label: 'caption_label',
        description_label: 'description_label',
        image_label: 'image_label',
        link_url_label: 'link_url_label',
        phone_data_ids_label: 'phone_data_ids_label',
        static_card: 'static_card',
        title_label: 'title_label',
        video_label: 'video_label'
      });
    }
  }]);
  return AdAssetFeedSpecCarouselChildAttachment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecDescription
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecDescription = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecDescription, _AbstractCrudObject);

  function AdAssetFeedSpecDescription() {
    classCallCheck(this, AdAssetFeedSpecDescription);
    return possibleConstructorReturn(this, (AdAssetFeedSpecDescription.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecDescription)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecDescription, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adlabels: 'adlabels',
        text: 'text',
        url_tags: 'url_tags'
      });
    }
  }]);
  return AdAssetFeedSpecDescription;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecEvents
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecEvents = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecEvents, _AbstractCrudObject);

  function AdAssetFeedSpecEvents() {
    classCallCheck(this, AdAssetFeedSpecEvents);
    return possibleConstructorReturn(this, (AdAssetFeedSpecEvents.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecEvents)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecEvents, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return AdAssetFeedSpecEvents;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecGroupRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecGroupRule = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecGroupRule, _AbstractCrudObject);

  function AdAssetFeedSpecGroupRule() {
    classCallCheck(this, AdAssetFeedSpecGroupRule);
    return possibleConstructorReturn(this, (AdAssetFeedSpecGroupRule.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecGroupRule)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecGroupRule, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        body_label: 'body_label',
        caption_label: 'caption_label',
        description_label: 'description_label',
        image_label: 'image_label',
        link_url_label: 'link_url_label',
        title_label: 'title_label',
        video_label: 'video_label'
      });
    }
  }]);
  return AdAssetFeedSpecGroupRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecImage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecImage = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecImage, _AbstractCrudObject);

  function AdAssetFeedSpecImage() {
    classCallCheck(this, AdAssetFeedSpecImage);
    return possibleConstructorReturn(this, (AdAssetFeedSpecImage.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecImage)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecImage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adlabels: 'adlabels',
        hash: 'hash',
        image_crops: 'image_crops',
        url: 'url',
        url_tags: 'url_tags'
      });
    }
  }]);
  return AdAssetFeedSpecImage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecLinkURL
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecLinkURL = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecLinkURL, _AbstractCrudObject);

  function AdAssetFeedSpecLinkURL() {
    classCallCheck(this, AdAssetFeedSpecLinkURL);
    return possibleConstructorReturn(this, (AdAssetFeedSpecLinkURL.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecLinkURL)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecLinkURL, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adlabels: 'adlabels',
        carousel_see_more_url: 'carousel_see_more_url',
        deeplink_url: 'deeplink_url',
        display_url: 'display_url',
        url_tags: 'url_tags',
        website_url: 'website_url'
      });
    }
  }]);
  return AdAssetFeedSpecLinkURL;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecTitle
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecTitle = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecTitle, _AbstractCrudObject);

  function AdAssetFeedSpecTitle() {
    classCallCheck(this, AdAssetFeedSpecTitle);
    return possibleConstructorReturn(this, (AdAssetFeedSpecTitle.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecTitle)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecTitle, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adlabels: 'adlabels',
        text: 'text',
        url_tags: 'url_tags'
      });
    }
  }]);
  return AdAssetFeedSpecTitle;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetFeedSpecVideo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetFeedSpecVideo = function (_AbstractCrudObject) {
  inherits(AdAssetFeedSpecVideo, _AbstractCrudObject);

  function AdAssetFeedSpecVideo() {
    classCallCheck(this, AdAssetFeedSpecVideo);
    return possibleConstructorReturn(this, (AdAssetFeedSpecVideo.__proto__ || Object.getPrototypeOf(AdAssetFeedSpecVideo)).apply(this, arguments));
  }

  createClass(AdAssetFeedSpecVideo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adlabels: 'adlabels',
        caption_ids: 'caption_ids',
        thumbnail_hash: 'thumbnail_hash',
        thumbnail_url: 'thumbnail_url',
        url_tags: 'url_tags',
        video_id: 'video_id'
      });
    }
  }]);
  return AdAssetFeedSpecVideo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetImage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetImage = function (_AbstractCrudObject) {
  inherits(AdAssetImage, _AbstractCrudObject);

  function AdAssetImage() {
    classCallCheck(this, AdAssetImage);
    return possibleConstructorReturn(this, (AdAssetImage.__proto__ || Object.getPrototypeOf(AdAssetImage)).apply(this, arguments));
  }

  createClass(AdAssetImage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        hash: 'hash',
        id: 'id',
        image_crops: 'image_crops',
        name: 'name',
        tag: 'tag',
        url: 'url',
        url_tags: 'url_tags'
      });
    }
  }]);
  return AdAssetImage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetLinkURL
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetLinkURL = function (_AbstractCrudObject) {
  inherits(AdAssetLinkURL, _AbstractCrudObject);

  function AdAssetLinkURL() {
    classCallCheck(this, AdAssetLinkURL);
    return possibleConstructorReturn(this, (AdAssetLinkURL.__proto__ || Object.getPrototypeOf(AdAssetLinkURL)).apply(this, arguments));
  }

  createClass(AdAssetLinkURL, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        android_deeplink_url: 'android_deeplink_url',
        carousel_see_more_url: 'carousel_see_more_url',
        deeplink_url: 'deeplink_url',
        display_url: 'display_url',
        id: 'id',
        ipad_deeplink_url: 'ipad_deeplink_url',
        iphone_deeplink_url: 'iphone_deeplink_url',
        url_tags: 'url_tags',
        website_url: 'website_url'
      });
    }
  }]);
  return AdAssetLinkURL;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetMessageExtensions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetMessageExtensions = function (_AbstractCrudObject) {
  inherits(AdAssetMessageExtensions, _AbstractCrudObject);

  function AdAssetMessageExtensions() {
    classCallCheck(this, AdAssetMessageExtensions);
    return possibleConstructorReturn(this, (AdAssetMessageExtensions.__proto__ || Object.getPrototypeOf(AdAssetMessageExtensions)).apply(this, arguments));
  }

  createClass(AdAssetMessageExtensions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        type: 'type'
      });
    }
  }]);
  return AdAssetMessageExtensions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetOnsiteDestinations
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetOnsiteDestinations = function (_AbstractCrudObject) {
  inherits(AdAssetOnsiteDestinations, _AbstractCrudObject);

  function AdAssetOnsiteDestinations() {
    classCallCheck(this, AdAssetOnsiteDestinations);
    return possibleConstructorReturn(this, (AdAssetOnsiteDestinations.__proto__ || Object.getPrototypeOf(AdAssetOnsiteDestinations)).apply(this, arguments));
  }

  createClass(AdAssetOnsiteDestinations, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        auto_optimization: 'auto_optimization',
        details_page_product_id: 'details_page_product_id',
        shop_collection_product_set_id: 'shop_collection_product_set_id',
        storefront_shop_id: 'storefront_shop_id'
      });
    }
  }]);
  return AdAssetOnsiteDestinations;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetTargetRuleTargeting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetTargetRuleTargeting = function (_AbstractCrudObject) {
  inherits(AdAssetTargetRuleTargeting, _AbstractCrudObject);

  function AdAssetTargetRuleTargeting() {
    classCallCheck(this, AdAssetTargetRuleTargeting);
    return possibleConstructorReturn(this, (AdAssetTargetRuleTargeting.__proto__ || Object.getPrototypeOf(AdAssetTargetRuleTargeting)).apply(this, arguments));
  }

  createClass(AdAssetTargetRuleTargeting, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        age_max: 'age_max',
        age_min: 'age_min',
        audience_network_positions: 'audience_network_positions',
        device_platforms: 'device_platforms',
        facebook_positions: 'facebook_positions',
        geo_locations: 'geo_locations',
        instagram_positions: 'instagram_positions',
        publisher_platforms: 'publisher_platforms'
      });
    }
  }, {
    key: 'DevicePlatforms',
    get: function get() {
      return Object.freeze({
        desktop: 'desktop',
        mobile: 'mobile'
      });
    }
  }]);
  return AdAssetTargetRuleTargeting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetTitle
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetTitle = function (_AbstractCrudObject) {
  inherits(AdAssetTitle, _AbstractCrudObject);

  function AdAssetTitle() {
    classCallCheck(this, AdAssetTitle);
    return possibleConstructorReturn(this, (AdAssetTitle.__proto__ || Object.getPrototypeOf(AdAssetTitle)).apply(this, arguments));
  }

  createClass(AdAssetTitle, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        text: 'text',
        url_tags: 'url_tags'
      });
    }
  }]);
  return AdAssetTitle;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAssetVideo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAssetVideo = function (_AbstractCrudObject) {
  inherits(AdAssetVideo, _AbstractCrudObject);

  function AdAssetVideo() {
    classCallCheck(this, AdAssetVideo);
    return possibleConstructorReturn(this, (AdAssetVideo.__proto__ || Object.getPrototypeOf(AdAssetVideo)).apply(this, arguments));
  }

  createClass(AdAssetVideo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        caption_ids: 'caption_ids',
        id: 'id',
        source_image_url: 'source_image_url',
        tag: 'tag',
        thumbnail_hash: 'thumbnail_hash',
        thumbnail_source: 'thumbnail_source',
        thumbnail_url: 'thumbnail_url',
        url: 'url',
        url_tags: 'url_tags',
        video_id: 'video_id',
        video_name: 'video_name'
      });
    }
  }]);
  return AdAssetVideo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdAsyncRequestSetNotificationResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdAsyncRequestSetNotificationResult = function (_AbstractCrudObject) {
  inherits(AdAsyncRequestSetNotificationResult, _AbstractCrudObject);

  function AdAsyncRequestSetNotificationResult() {
    classCallCheck(this, AdAsyncRequestSetNotificationResult);
    return possibleConstructorReturn(this, (AdAsyncRequestSetNotificationResult.__proto__ || Object.getPrototypeOf(AdAsyncRequestSetNotificationResult)).apply(this, arguments));
  }

  createClass(AdAsyncRequestSetNotificationResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        response: 'response',
        status: 'status'
      });
    }
  }]);
  return AdAsyncRequestSetNotificationResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdBidAdjustments
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdBidAdjustments = function (_AbstractCrudObject) {
  inherits(AdBidAdjustments, _AbstractCrudObject);

  function AdBidAdjustments() {
    classCallCheck(this, AdBidAdjustments);
    return possibleConstructorReturn(this, (AdBidAdjustments.__proto__ || Object.getPrototypeOf(AdBidAdjustments)).apply(this, arguments));
  }

  createClass(AdBidAdjustments, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        age_range: 'age_range',
        page_types: 'page_types',
        user_groups: 'user_groups'
      });
    }
  }]);
  return AdBidAdjustments;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignBidConstraint
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignBidConstraint = function (_AbstractCrudObject) {
  inherits(AdCampaignBidConstraint, _AbstractCrudObject);

  function AdCampaignBidConstraint() {
    classCallCheck(this, AdCampaignBidConstraint);
    return possibleConstructorReturn(this, (AdCampaignBidConstraint.__proto__ || Object.getPrototypeOf(AdCampaignBidConstraint)).apply(this, arguments));
  }

  createClass(AdCampaignBidConstraint, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        roas_average_floor: 'roas_average_floor'
      });
    }
  }]);
  return AdCampaignBidConstraint;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignConversionValueExpressionSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignConversionValueExpressionSpec = function (_AbstractCrudObject) {
  inherits(AdCampaignConversionValueExpressionSpec, _AbstractCrudObject);

  function AdCampaignConversionValueExpressionSpec() {
    classCallCheck(this, AdCampaignConversionValueExpressionSpec);
    return possibleConstructorReturn(this, (AdCampaignConversionValueExpressionSpec.__proto__ || Object.getPrototypeOf(AdCampaignConversionValueExpressionSpec)).apply(this, arguments));
  }

  createClass(AdCampaignConversionValueExpressionSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adjustment_sign: 'adjustment_sign',
        adjustment_weight: 'adjustment_weight',
        destination_type: 'destination_type'
      });
    }
  }]);
  return AdCampaignConversionValueExpressionSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignDeliveryStats
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignDeliveryStats = function (_AbstractCrudObject) {
  inherits(AdCampaignDeliveryStats, _AbstractCrudObject);

  function AdCampaignDeliveryStats() {
    classCallCheck(this, AdCampaignDeliveryStats);
    return possibleConstructorReturn(this, (AdCampaignDeliveryStats.__proto__ || Object.getPrototypeOf(AdCampaignDeliveryStats)).apply(this, arguments));
  }

  createClass(AdCampaignDeliveryStats, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        bid_recommendation: 'bid_recommendation',
        current_average_cost: 'current_average_cost',
        last_significant_edit_ts: 'last_significant_edit_ts',
        learning_stage_exit_info: 'learning_stage_exit_info',
        learning_stage_info: 'learning_stage_info',
        unsupported_features: 'unsupported_features'
      });
    }
  }]);
  return AdCampaignDeliveryStats;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignDeliveryStatsUnsupportedReasons
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignDeliveryStatsUnsupportedReasons = function (_AbstractCrudObject) {
  inherits(AdCampaignDeliveryStatsUnsupportedReasons, _AbstractCrudObject);

  function AdCampaignDeliveryStatsUnsupportedReasons() {
    classCallCheck(this, AdCampaignDeliveryStatsUnsupportedReasons);
    return possibleConstructorReturn(this, (AdCampaignDeliveryStatsUnsupportedReasons.__proto__ || Object.getPrototypeOf(AdCampaignDeliveryStatsUnsupportedReasons)).apply(this, arguments));
  }

  createClass(AdCampaignDeliveryStatsUnsupportedReasons, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        reason_data: 'reason_data',
        reason_type: 'reason_type'
      });
    }
  }]);
  return AdCampaignDeliveryStatsUnsupportedReasons;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignFrequencyControlSpecs
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignFrequencyControlSpecs = function (_AbstractCrudObject) {
  inherits(AdCampaignFrequencyControlSpecs, _AbstractCrudObject);

  function AdCampaignFrequencyControlSpecs() {
    classCallCheck(this, AdCampaignFrequencyControlSpecs);
    return possibleConstructorReturn(this, (AdCampaignFrequencyControlSpecs.__proto__ || Object.getPrototypeOf(AdCampaignFrequencyControlSpecs)).apply(this, arguments));
  }

  createClass(AdCampaignFrequencyControlSpecs, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        event: 'event',
        interval_days: 'interval_days',
        max_frequency: 'max_frequency'
      });
    }
  }]);
  return AdCampaignFrequencyControlSpecs;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignGroupIncrementalConversionOptimizationConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignGroupIncrementalConversionOptimizationConfig = function (_AbstractCrudObject) {
  inherits(AdCampaignGroupIncrementalConversionOptimizationConfig, _AbstractCrudObject);

  function AdCampaignGroupIncrementalConversionOptimizationConfig() {
    classCallCheck(this, AdCampaignGroupIncrementalConversionOptimizationConfig);
    return possibleConstructorReturn(this, (AdCampaignGroupIncrementalConversionOptimizationConfig.__proto__ || Object.getPrototypeOf(AdCampaignGroupIncrementalConversionOptimizationConfig)).apply(this, arguments));
  }

  createClass(AdCampaignGroupIncrementalConversionOptimizationConfig, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action_type: 'action_type',
        ad_study_end_time: 'ad_study_end_time',
        ad_study_id: 'ad_study_id',
        ad_study_name: 'ad_study_name',
        ad_study_start_time: 'ad_study_start_time',
        cell_id: 'cell_id',
        cell_name: 'cell_name',
        holdout_size: 'holdout_size',
        ico_type: 'ico_type',
        objectives: 'objectives'
      });
    }
  }]);
  return AdCampaignGroupIncrementalConversionOptimizationConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignGroupMetricsMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignGroupMetricsMetadata = function (_AbstractCrudObject) {
  inherits(AdCampaignGroupMetricsMetadata, _AbstractCrudObject);

  function AdCampaignGroupMetricsMetadata() {
    classCallCheck(this, AdCampaignGroupMetricsMetadata);
    return possibleConstructorReturn(this, (AdCampaignGroupMetricsMetadata.__proto__ || Object.getPrototypeOf(AdCampaignGroupMetricsMetadata)).apply(this, arguments));
  }

  createClass(AdCampaignGroupMetricsMetadata, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        budget_optimization: 'budget_optimization',
        duplication_flow_tips: 'duplication_flow_tips'
      });
    }
  }]);
  return AdCampaignGroupMetricsMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignGroupStats
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignGroupStats = function (_AbstractCrudObject) {
  inherits(AdCampaignGroupStats, _AbstractCrudObject);

  function AdCampaignGroupStats() {
    classCallCheck(this, AdCampaignGroupStats);
    return possibleConstructorReturn(this, (AdCampaignGroupStats.__proto__ || Object.getPrototypeOf(AdCampaignGroupStats)).apply(this, arguments));
  }

  createClass(AdCampaignGroupStats, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actions: 'actions',
        campaign_group_id: 'campaign_group_id',
        clicks: 'clicks',
        end_time: 'end_time',
        impressions: 'impressions',
        inline_actions: 'inline_actions',
        social_clicks: 'social_clicks',
        social_impressions: 'social_impressions',
        social_spent: 'social_spent',
        social_unique_clicks: 'social_unique_clicks',
        social_unique_impressions: 'social_unique_impressions',
        spent: 'spent',
        start_time: 'start_time',
        unique_clicks: 'unique_clicks',
        unique_impressions: 'unique_impressions'
      });
    }
  }]);
  return AdCampaignGroupStats;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignGroupStructureTree
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignGroupStructureTree = function (_AbstractCrudObject) {
  inherits(AdCampaignGroupStructureTree, _AbstractCrudObject);

  function AdCampaignGroupStructureTree() {
    classCallCheck(this, AdCampaignGroupStructureTree);
    return possibleConstructorReturn(this, (AdCampaignGroupStructureTree.__proto__ || Object.getPrototypeOf(AdCampaignGroupStructureTree)).apply(this, arguments));
  }

  createClass(AdCampaignGroupStructureTree, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        children: 'children',
        id: 'id',
        name: 'name',
        time_updated: 'time_updated'
      });
    }
  }]);
  return AdCampaignGroupStructureTree;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignIssuesInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignIssuesInfo = function (_AbstractCrudObject) {
  inherits(AdCampaignIssuesInfo, _AbstractCrudObject);

  function AdCampaignIssuesInfo() {
    classCallCheck(this, AdCampaignIssuesInfo);
    return possibleConstructorReturn(this, (AdCampaignIssuesInfo.__proto__ || Object.getPrototypeOf(AdCampaignIssuesInfo)).apply(this, arguments));
  }

  createClass(AdCampaignIssuesInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        error_code: 'error_code',
        error_message: 'error_message',
        error_summary: 'error_summary',
        error_type: 'error_type',
        level: 'level'
      });
    }
  }]);
  return AdCampaignIssuesInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignLearningStageInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignLearningStageInfo = function (_AbstractCrudObject) {
  inherits(AdCampaignLearningStageInfo, _AbstractCrudObject);

  function AdCampaignLearningStageInfo() {
    classCallCheck(this, AdCampaignLearningStageInfo);
    return possibleConstructorReturn(this, (AdCampaignLearningStageInfo.__proto__ || Object.getPrototypeOf(AdCampaignLearningStageInfo)).apply(this, arguments));
  }

  createClass(AdCampaignLearningStageInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        attribution_windows: 'attribution_windows',
        conversions: 'conversions',
        last_sig_edit_ts: 'last_sig_edit_ts',
        status: 'status'
      });
    }
  }]);
  return AdCampaignLearningStageInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignMetricsMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignMetricsMetadata = function (_AbstractCrudObject) {
  inherits(AdCampaignMetricsMetadata, _AbstractCrudObject);

  function AdCampaignMetricsMetadata() {
    classCallCheck(this, AdCampaignMetricsMetadata);
    return possibleConstructorReturn(this, (AdCampaignMetricsMetadata.__proto__ || Object.getPrototypeOf(AdCampaignMetricsMetadata)).apply(this, arguments));
  }

  createClass(AdCampaignMetricsMetadata, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        boosted_component_optimization: 'boosted_component_optimization',
        creation_flow_tips: 'creation_flow_tips',
        default_opted_in_placements: 'default_opted_in_placements',
        delivery_growth_optimizations: 'delivery_growth_optimizations',
        duplication_flow_tips: 'duplication_flow_tips',
        edit_flow_tips: 'edit_flow_tips'
      });
    }
  }]);
  return AdCampaignMetricsMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignMultiAds
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignMultiAds = function (_AbstractCrudObject) {
  inherits(AdCampaignMultiAds, _AbstractCrudObject);

  function AdCampaignMultiAds() {
    classCallCheck(this, AdCampaignMultiAds);
    return possibleConstructorReturn(this, (AdCampaignMultiAds.__proto__ || Object.getPrototypeOf(AdCampaignMultiAds)).apply(this, arguments));
  }

  createClass(AdCampaignMultiAds, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        enroll_status: 'enroll_status',
        source_type: 'source_type'
      });
    }
  }]);
  return AdCampaignMultiAds;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignOptimizationEvent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignOptimizationEvent = function (_AbstractCrudObject) {
  inherits(AdCampaignOptimizationEvent, _AbstractCrudObject);

  function AdCampaignOptimizationEvent() {
    classCallCheck(this, AdCampaignOptimizationEvent);
    return possibleConstructorReturn(this, (AdCampaignOptimizationEvent.__proto__ || Object.getPrototypeOf(AdCampaignOptimizationEvent)).apply(this, arguments));
  }

  createClass(AdCampaignOptimizationEvent, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        custom_conversion_id: 'custom_conversion_id',
        event_sequence: 'event_sequence',
        event_type: 'event_type'
      });
    }
  }]);
  return AdCampaignOptimizationEvent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignPacedBidInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignPacedBidInfo = function (_AbstractCrudObject) {
  inherits(AdCampaignPacedBidInfo, _AbstractCrudObject);

  function AdCampaignPacedBidInfo() {
    classCallCheck(this, AdCampaignPacedBidInfo);
    return possibleConstructorReturn(this, (AdCampaignPacedBidInfo.__proto__ || Object.getPrototypeOf(AdCampaignPacedBidInfo)).apply(this, arguments));
  }

  createClass(AdCampaignPacedBidInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        bidding_status: 'bidding_status'
      });
    }
  }]);
  return AdCampaignPacedBidInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCampaignStats
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCampaignStats = function (_AbstractCrudObject) {
  inherits(AdCampaignStats, _AbstractCrudObject);

  function AdCampaignStats() {
    classCallCheck(this, AdCampaignStats);
    return possibleConstructorReturn(this, (AdCampaignStats.__proto__ || Object.getPrototypeOf(AdCampaignStats)).apply(this, arguments));
  }

  createClass(AdCampaignStats, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        actions: 'actions',
        adgroup_id: 'adgroup_id',
        campaign_id: 'campaign_id',
        campaign_ids: 'campaign_ids',
        clicks: 'clicks',
        end_time: 'end_time',
        id: 'id',
        impressions: 'impressions',
        inline_actions: 'inline_actions',
        io_number: 'io_number',
        is_completed: 'is_completed',
        line_number: 'line_number',
        newsfeed_position: 'newsfeed_position',
        social_clicks: 'social_clicks',
        social_impressions: 'social_impressions',
        social_spent: 'social_spent',
        social_unique_clicks: 'social_unique_clicks',
        social_unique_impressions: 'social_unique_impressions',
        spent: 'spent',
        start_time: 'start_time',
        topline_id: 'topline_id',
        unique_clicks: 'unique_clicks',
        unique_impressions: 'unique_impressions'
      });
    }
  }]);
  return AdCampaignStats;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdColumnSizes
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdColumnSizes = function (_AbstractCrudObject) {
  inherits(AdColumnSizes, _AbstractCrudObject);

  function AdColumnSizes() {
    classCallCheck(this, AdColumnSizes);
    return possibleConstructorReturn(this, (AdColumnSizes.__proto__ || Object.getPrototypeOf(AdColumnSizes)).apply(this, arguments));
  }

  createClass(AdColumnSizes, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        admarket_account: 'admarket_account',
        app_id: 'app_id',
        columns: 'columns',
        id: 'id',
        owner: 'owner',
        page: 'page',
        report: 'report',
        tab: 'tab',
        view: 'view'
      });
    }
  }]);
  return AdColumnSizes;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdContract
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdContract = function (_AbstractCrudObject) {
  inherits(AdContract, _AbstractCrudObject);

  function AdContract() {
    classCallCheck(this, AdContract);
    return possibleConstructorReturn(this, (AdContract.__proto__ || Object.getPrototypeOf(AdContract)).apply(this, arguments));
  }

  createClass(AdContract, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        account_mgr_fbid: 'account_mgr_fbid',
        account_mgr_name: 'account_mgr_name',
        adops_person_name: 'adops_person_name',
        advertiser_address_fbid: 'advertiser_address_fbid',
        advertiser_fbid: 'advertiser_fbid',
        advertiser_name: 'advertiser_name',
        agency_discount: 'agency_discount',
        agency_name: 'agency_name',
        bill_to_address_fbid: 'bill_to_address_fbid',
        bill_to_fbid: 'bill_to_fbid',
        campaign_name: 'campaign_name',
        created_by: 'created_by',
        created_date: 'created_date',
        customer_io: 'customer_io',
        io_number: 'io_number',
        io_terms: 'io_terms',
        io_type: 'io_type',
        last_updated_by: 'last_updated_by',
        last_updated_date: 'last_updated_date',
        max_end_date: 'max_end_date',
        mdc_fbid: 'mdc_fbid',
        media_plan_number: 'media_plan_number',
        min_start_date: 'min_start_date',
        msa_contract: 'msa_contract',
        payment_terms: 'payment_terms',
        rev_hold_flag: 'rev_hold_flag',
        rev_hold_released_by: 'rev_hold_released_by',
        rev_hold_released_on: 'rev_hold_released_on',
        salesrep_fbid: 'salesrep_fbid',
        salesrep_name: 'salesrep_name',
        sold_to_address_fbid: 'sold_to_address_fbid',
        sold_to_fbid: 'sold_to_fbid',
        status: 'status',
        subvertical: 'subvertical',
        thirdparty_billed: 'thirdparty_billed',
        thirdparty_uid: 'thirdparty_uid',
        thirdparty_url: 'thirdparty_url',
        vat_country: 'vat_country',
        version: 'version',
        vertical: 'vertical'
      });
    }
  }]);
  return AdContract;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdConversionValues
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdConversionValues = function (_AbstractCrudObject) {
  inherits(AdConversionValues, _AbstractCrudObject);

  function AdConversionValues() {
    classCallCheck(this, AdConversionValues);
    return possibleConstructorReturn(this, (AdConversionValues.__proto__ || Object.getPrototypeOf(AdConversionValues)).apply(this, arguments));
  }

  createClass(AdConversionValues, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adgroup_id: 'adgroup_id',
        campaign_id: 'campaign_id',
        values: 'values'
      });
    }
  }]);
  return AdConversionValues;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdConversions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdConversions = function (_AbstractCrudObject) {
  inherits(AdConversions, _AbstractCrudObject);

  function AdConversions() {
    classCallCheck(this, AdConversions);
    return possibleConstructorReturn(this, (AdConversions.__proto__ || Object.getPrototypeOf(AdConversions)).apply(this, arguments));
  }

  createClass(AdConversions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        adgroup_id: 'adgroup_id',
        campaign_id: 'campaign_id',
        values: 'values'
      });
    }
  }]);
  return AdConversions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreationPackageConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreationPackageConfig = function (_AbstractCrudObject) {
  inherits(AdCreationPackageConfig, _AbstractCrudObject);

  function AdCreationPackageConfig() {
    classCallCheck(this, AdCreationPackageConfig);
    return possibleConstructorReturn(this, (AdCreationPackageConfig.__proto__ || Object.getPrototypeOf(AdCreationPackageConfig)).apply(this, arguments));
  }

  createClass(AdCreationPackageConfig, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        api_version: 'api_version',
        id: 'id',
        is_eligible_for_default_opt_in: 'is_eligible_for_default_opt_in',
        objective: 'objective',
        package_id: 'package_id',
        status: 'status'
      });
    }
  }]);
  return AdCreationPackageConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeAdDisclaimer
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeAdDisclaimer = function (_AbstractCrudObject) {
  inherits(AdCreativeAdDisclaimer, _AbstractCrudObject);

  function AdCreativeAdDisclaimer() {
    classCallCheck(this, AdCreativeAdDisclaimer);
    return possibleConstructorReturn(this, (AdCreativeAdDisclaimer.__proto__ || Object.getPrototypeOf(AdCreativeAdDisclaimer)).apply(this, arguments));
  }

  createClass(AdCreativeAdDisclaimer, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        text: 'text',
        title: 'title',
        url: 'url'
      });
    }
  }]);
  return AdCreativeAdDisclaimer;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeAssetGroupsSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeAssetGroupsSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeAssetGroupsSpec, _AbstractCrudObject);

  function AdCreativeAssetGroupsSpec() {
    classCallCheck(this, AdCreativeAssetGroupsSpec);
    return possibleConstructorReturn(this, (AdCreativeAssetGroupsSpec.__proto__ || Object.getPrototypeOf(AdCreativeAssetGroupsSpec)).apply(this, arguments));
  }

  createClass(AdCreativeAssetGroupsSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        groups: 'groups',
        origin: 'origin'
      });
    }
  }]);
  return AdCreativeAssetGroupsSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeBrandedContentAds
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeBrandedContentAds = function (_AbstractCrudObject) {
  inherits(AdCreativeBrandedContentAds, _AbstractCrudObject);

  function AdCreativeBrandedContentAds() {
    classCallCheck(this, AdCreativeBrandedContentAds);
    return possibleConstructorReturn(this, (AdCreativeBrandedContentAds.__proto__ || Object.getPrototypeOf(AdCreativeBrandedContentAds)).apply(this, arguments));
  }

  createClass(AdCreativeBrandedContentAds, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_format: 'ad_format',
        content_search_input: 'content_search_input',
        creator_ad_permission_type: 'creator_ad_permission_type',
        facebook_boost_post_access_token: 'facebook_boost_post_access_token',
        instagram_boost_post_access_token: 'instagram_boost_post_access_token',
        is_mca_internal: 'is_mca_internal',
        parent_source_facebook_post_id: 'parent_source_facebook_post_id',
        parent_source_instagram_media_id: 'parent_source_instagram_media_id',
        partners: 'partners',
        product_set_partner_selection_status: 'product_set_partner_selection_status',
        promoted_page_id: 'promoted_page_id',
        testimonial: 'testimonial',
        ui_version: 'ui_version'
      });
    }
  }]);
  return AdCreativeBrandedContentAds;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeBrandedContentAdsPartners
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeBrandedContentAdsPartners = function (_AbstractCrudObject) {
  inherits(AdCreativeBrandedContentAdsPartners, _AbstractCrudObject);

  function AdCreativeBrandedContentAdsPartners() {
    classCallCheck(this, AdCreativeBrandedContentAdsPartners);
    return possibleConstructorReturn(this, (AdCreativeBrandedContentAdsPartners.__proto__ || Object.getPrototypeOf(AdCreativeBrandedContentAdsPartners)).apply(this, arguments));
  }

  createClass(AdCreativeBrandedContentAdsPartners, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        fb_page_id: 'fb_page_id',
        has_create_ads_access: 'has_create_ads_access',
        identity_type: 'identity_type',
        ig_asset_id: 'ig_asset_id',
        ig_user_id: 'ig_user_id'
      });
    }
  }]);
  return AdCreativeBrandedContentAdsPartners;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeCollectionThumbnailInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeCollectionThumbnailInfo = function (_AbstractCrudObject) {
  inherits(AdCreativeCollectionThumbnailInfo, _AbstractCrudObject);

  function AdCreativeCollectionThumbnailInfo() {
    classCallCheck(this, AdCreativeCollectionThumbnailInfo);
    return possibleConstructorReturn(this, (AdCreativeCollectionThumbnailInfo.__proto__ || Object.getPrototypeOf(AdCreativeCollectionThumbnailInfo)).apply(this, arguments));
  }

  createClass(AdCreativeCollectionThumbnailInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        element_child_index: 'element_child_index',
        element_crops: 'element_crops',
        element_id: 'element_id'
      });
    }
  }]);
  return AdCreativeCollectionThumbnailInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeContextualMultiAds
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeContextualMultiAds = function (_AbstractCrudObject) {
  inherits(AdCreativeContextualMultiAds, _AbstractCrudObject);

  function AdCreativeContextualMultiAds() {
    classCallCheck(this, AdCreativeContextualMultiAds);
    return possibleConstructorReturn(this, (AdCreativeContextualMultiAds.__proto__ || Object.getPrototypeOf(AdCreativeContextualMultiAds)).apply(this, arguments));
  }

  createClass(AdCreativeContextualMultiAds, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        enroll_status: 'enroll_status'
      });
    }
  }]);
  return AdCreativeContextualMultiAds;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeDegreesOfFreedomSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeDegreesOfFreedomSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeDegreesOfFreedomSpec, _AbstractCrudObject);

  function AdCreativeDegreesOfFreedomSpec() {
    classCallCheck(this, AdCreativeDegreesOfFreedomSpec);
    return possibleConstructorReturn(this, (AdCreativeDegreesOfFreedomSpec.__proto__ || Object.getPrototypeOf(AdCreativeDegreesOfFreedomSpec)).apply(this, arguments));
  }

  createClass(AdCreativeDegreesOfFreedomSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_handle_type: 'ad_handle_type',
        creative_features_spec: 'creative_features_spec',
        degrees_of_freedom_type: 'degrees_of_freedom_type',
        image_transformation_types: 'image_transformation_types',
        multi_media_transformation_type: 'multi_media_transformation_type',
        stories_transformation_types: 'stories_transformation_types',
        text_transformation_types: 'text_transformation_types',
        video_transformation_types: 'video_transformation_types'
      });
    }
  }]);
  return AdCreativeDegreesOfFreedomSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeDestinationSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeDestinationSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeDestinationSpec, _AbstractCrudObject);

  function AdCreativeDestinationSpec() {
    classCallCheck(this, AdCreativeDestinationSpec);
    return possibleConstructorReturn(this, (AdCreativeDestinationSpec.__proto__ || Object.getPrototypeOf(AdCreativeDestinationSpec)).apply(this, arguments));
  }

  createClass(AdCreativeDestinationSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        destination_type: 'destination_type'
      });
    }
  }]);
  return AdCreativeDestinationSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeFacebookBrandedContent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeFacebookBrandedContent = function (_AbstractCrudObject) {
  inherits(AdCreativeFacebookBrandedContent, _AbstractCrudObject);

  function AdCreativeFacebookBrandedContent() {
    classCallCheck(this, AdCreativeFacebookBrandedContent);
    return possibleConstructorReturn(this, (AdCreativeFacebookBrandedContent.__proto__ || Object.getPrototypeOf(AdCreativeFacebookBrandedContent)).apply(this, arguments));
  }

  createClass(AdCreativeFacebookBrandedContent, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        shared_to_sponsor_status: 'shared_to_sponsor_status',
        sponsor_page_id: 'sponsor_page_id',
        sponsor_relationship: 'sponsor_relationship'
      });
    }
  }]);
  return AdCreativeFacebookBrandedContent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeFeatureActionMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeFeatureActionMetadata = function (_AbstractCrudObject) {
  inherits(AdCreativeFeatureActionMetadata, _AbstractCrudObject);

  function AdCreativeFeatureActionMetadata() {
    classCallCheck(this, AdCreativeFeatureActionMetadata);
    return possibleConstructorReturn(this, (AdCreativeFeatureActionMetadata.__proto__ || Object.getPrototypeOf(AdCreativeFeatureActionMetadata)).apply(this, arguments));
  }

  createClass(AdCreativeFeatureActionMetadata, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        type: 'type'
      });
    }
  }]);
  return AdCreativeFeatureActionMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeFeatureCustomizations
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeFeatureCustomizations = function (_AbstractCrudObject) {
  inherits(AdCreativeFeatureCustomizations, _AbstractCrudObject);

  function AdCreativeFeatureCustomizations() {
    classCallCheck(this, AdCreativeFeatureCustomizations);
    return possibleConstructorReturn(this, (AdCreativeFeatureCustomizations.__proto__ || Object.getPrototypeOf(AdCreativeFeatureCustomizations)).apply(this, arguments));
  }

  createClass(AdCreativeFeatureCustomizations, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        showcase_card_display: 'showcase_card_display'
      });
    }
  }]);
  return AdCreativeFeatureCustomizations;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeFeatureDetails
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeFeatureDetails = function (_AbstractCrudObject) {
  inherits(AdCreativeFeatureDetails, _AbstractCrudObject);

  function AdCreativeFeatureDetails() {
    classCallCheck(this, AdCreativeFeatureDetails);
    return possibleConstructorReturn(this, (AdCreativeFeatureDetails.__proto__ || Object.getPrototypeOf(AdCreativeFeatureDetails)).apply(this, arguments));
  }

  createClass(AdCreativeFeatureDetails, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        customizations: 'customizations',
        enroll_status: 'enroll_status'
      });
    }
  }]);
  return AdCreativeFeatureDetails;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeFeaturesSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeFeaturesSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeFeaturesSpec, _AbstractCrudObject);

  function AdCreativeFeaturesSpec() {
    classCallCheck(this, AdCreativeFeaturesSpec);
    return possibleConstructorReturn(this, (AdCreativeFeaturesSpec.__proto__ || Object.getPrototypeOf(AdCreativeFeaturesSpec)).apply(this, arguments));
  }

  createClass(AdCreativeFeaturesSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adapt_to_placement: 'adapt_to_placement',
        add_text_overlay: 'add_text_overlay',
        ads_with_benefits: 'ads_with_benefits',
        advantage_plus_creative: 'advantage_plus_creative',
        app_highlights: 'app_highlights',
        audio: 'audio',
        carousel_to_video: 'carousel_to_video',
        catalog_feed_tag: 'catalog_feed_tag',
        customize_product_recommendation: 'customize_product_recommendation',
        cv_transformation: 'cv_transformation',
        description_automation: 'description_automation',
        dha_optimization: 'dha_optimization',
        dynamic_partner_content: 'dynamic_partner_content',
        enhance_cta: 'enhance_cta',
        fb_feed_tag: 'fb_feed_tag',
        fb_reels_tag: 'fb_reels_tag',
        fb_story_tag: 'fb_story_tag',
        feed_caption_optimization: 'feed_caption_optimization',
        ig_feed_tag: 'ig_feed_tag',
        ig_glados_feed: 'ig_glados_feed',
        ig_reels_tag: 'ig_reels_tag',
        ig_stream_tag: 'ig_stream_tag',
        image_animation: 'image_animation',
        image_auto_crop: 'image_auto_crop',
        image_background_gen: 'image_background_gen',
        image_brightness_and_contrast: 'image_brightness_and_contrast',
        image_enhancement: 'image_enhancement',
        image_templates: 'image_templates',
        image_touchups: 'image_touchups',
        image_uncrop: 'image_uncrop',
        inline_comment: 'inline_comment',
        local_store_extension: 'local_store_extension',
        media_liquidity_animated_image: 'media_liquidity_animated_image',
        media_order: 'media_order',
        media_type_automation: 'media_type_automation',
        pac_relaxation: 'pac_relaxation',
        product_extensions: 'product_extensions',
        product_metadata_automation: 'product_metadata_automation',
        product_tags: 'product_tags',
        profile_card: 'profile_card',
        site_extensions: 'site_extensions',
        standard_enhancements: 'standard_enhancements',
        standard_enhancements_catalog: 'standard_enhancements_catalog',
        text_generation: 'text_generation',
        text_optimizations: 'text_optimizations',
        video_auto_crop: 'video_auto_crop',
        video_filtering: 'video_filtering',
        video_highlight: 'video_highlight',
        video_uncrop: 'video_uncrop'
      });
    }
  }]);
  return AdCreativeFeaturesSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeGenerativeAssetSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeGenerativeAssetSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeGenerativeAssetSpec, _AbstractCrudObject);

  function AdCreativeGenerativeAssetSpec() {
    classCallCheck(this, AdCreativeGenerativeAssetSpec);
    return possibleConstructorReturn(this, (AdCreativeGenerativeAssetSpec.__proto__ || Object.getPrototypeOf(AdCreativeGenerativeAssetSpec)).apply(this, arguments));
  }

  createClass(AdCreativeGenerativeAssetSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return AdCreativeGenerativeAssetSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeHouseShopsAdsSellerContent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeHouseShopsAdsSellerContent = function (_AbstractCrudObject) {
  inherits(AdCreativeHouseShopsAdsSellerContent, _AbstractCrudObject);

  function AdCreativeHouseShopsAdsSellerContent() {
    classCallCheck(this, AdCreativeHouseShopsAdsSellerContent);
    return possibleConstructorReturn(this, (AdCreativeHouseShopsAdsSellerContent.__proto__ || Object.getPrototypeOf(AdCreativeHouseShopsAdsSellerContent)).apply(this, arguments));
  }

  createClass(AdCreativeHouseShopsAdsSellerContent, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return AdCreativeHouseShopsAdsSellerContent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeImageDataMediaElements
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeImageDataMediaElements = function (_AbstractCrudObject) {
  inherits(AdCreativeImageDataMediaElements, _AbstractCrudObject);

  function AdCreativeImageDataMediaElements() {
    classCallCheck(this, AdCreativeImageDataMediaElements);
    return possibleConstructorReturn(this, (AdCreativeImageDataMediaElements.__proto__ || Object.getPrototypeOf(AdCreativeImageDataMediaElements)).apply(this, arguments));
  }

  createClass(AdCreativeImageDataMediaElements, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        element_id: 'element_id',
        element_type: 'element_type',
        x: 'x',
        y: 'y'
      });
    }
  }]);
  return AdCreativeImageDataMediaElements;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeInstagramBrandedContent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeInstagramBrandedContent = function (_AbstractCrudObject) {
  inherits(AdCreativeInstagramBrandedContent, _AbstractCrudObject);

  function AdCreativeInstagramBrandedContent() {
    classCallCheck(this, AdCreativeInstagramBrandedContent);
    return possibleConstructorReturn(this, (AdCreativeInstagramBrandedContent.__proto__ || Object.getPrototypeOf(AdCreativeInstagramBrandedContent)).apply(this, arguments));
  }

  createClass(AdCreativeInstagramBrandedContent, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        sponsor_id: 'sponsor_id'
      });
    }
  }]);
  return AdCreativeInstagramBrandedContent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeInteractiveComponentsSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeInteractiveComponentsSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeInteractiveComponentsSpec, _AbstractCrudObject);

  function AdCreativeInteractiveComponentsSpec() {
    classCallCheck(this, AdCreativeInteractiveComponentsSpec);
    return possibleConstructorReturn(this, (AdCreativeInteractiveComponentsSpec.__proto__ || Object.getPrototypeOf(AdCreativeInteractiveComponentsSpec)).apply(this, arguments));
  }

  createClass(AdCreativeInteractiveComponentsSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        child_attachments: 'child_attachments',
        components: 'components'
      });
    }
  }]);
  return AdCreativeInteractiveComponentsSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkData = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkData, _AbstractCrudObject);

  function AdCreativeLinkData() {
    classCallCheck(this, AdCreativeLinkData);
    return possibleConstructorReturn(this, (AdCreativeLinkData.__proto__ || Object.getPrototypeOf(AdCreativeLinkData)).apply(this, arguments));
  }

  createClass(AdCreativeLinkData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_context: 'ad_context',
        additional_image_index: 'additional_image_index',
        app_link_spec: 'app_link_spec',
        attachment_style: 'attachment_style',
        automated_product_tags: 'automated_product_tags',
        branded_content_shared_to_sponsor_status: 'branded_content_shared_to_sponsor_status',
        branded_content_sponsor_page_id: 'branded_content_sponsor_page_id',
        call_to_action: 'call_to_action',
        caption: 'caption',
        child_attachments: 'child_attachments',
        collection_thumbnails: 'collection_thumbnails',
        customization_rules_spec: 'customization_rules_spec',
        description: 'description',
        event_id: 'event_id',
        force_single_link: 'force_single_link',
        format_option: 'format_option',
        image_crops: 'image_crops',
        image_hash: 'image_hash',
        image_layer_specs: 'image_layer_specs',
        image_overlay_spec: 'image_overlay_spec',
        link: 'link',
        message: 'message',
        multi_share_end_card: 'multi_share_end_card',
        multi_share_optimized: 'multi_share_optimized',
        name: 'name',
        offer_id: 'offer_id',
        page_welcome_message: 'page_welcome_message',
        picture: 'picture',
        post_click_configuration: 'post_click_configuration',
        preferred_image_tags: 'preferred_image_tags',
        preferred_video_tags: 'preferred_video_tags',
        retailer_item_ids: 'retailer_item_ids',
        show_multiple_images: 'show_multiple_images',
        static_fallback_spec: 'static_fallback_spec',
        use_flexible_image_aspect_ratio: 'use_flexible_image_aspect_ratio'
      });
    }
  }, {
    key: 'FormatOption',
    get: function get() {
      return Object.freeze({
        carousel_ar_effects: 'carousel_ar_effects',
        carousel_images_multi_items: 'carousel_images_multi_items',
        carousel_images_single_item: 'carousel_images_single_item',
        carousel_slideshows: 'carousel_slideshows',
        collection_video: 'collection_video',
        single_image: 'single_image'
      });
    }
  }]);
  return AdCreativeLinkData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataAppLinkSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataAppLinkSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataAppLinkSpec, _AbstractCrudObject);

  function AdCreativeLinkDataAppLinkSpec() {
    classCallCheck(this, AdCreativeLinkDataAppLinkSpec);
    return possibleConstructorReturn(this, (AdCreativeLinkDataAppLinkSpec.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataAppLinkSpec)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataAppLinkSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        android: 'android',
        ios: 'ios',
        ipad: 'ipad',
        iphone: 'iphone'
      });
    }
  }]);
  return AdCreativeLinkDataAppLinkSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataCallToAction
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataCallToAction = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataCallToAction, _AbstractCrudObject);

  function AdCreativeLinkDataCallToAction() {
    classCallCheck(this, AdCreativeLinkDataCallToAction);
    return possibleConstructorReturn(this, (AdCreativeLinkDataCallToAction.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataCallToAction)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataCallToAction, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        type: 'type',
        value: 'value'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        add_to_cart: 'ADD_TO_CART',
        apply_now: 'APPLY_NOW',
        ask_about_services: 'ASK_ABOUT_SERVICES',
        ask_for_more_info: 'ASK_FOR_MORE_INFO',
        audio_call: 'AUDIO_CALL',
        book_a_consultation: 'BOOK_A_CONSULTATION',
        book_now: 'BOOK_NOW',
        book_travel: 'BOOK_TRAVEL',
        buy: 'BUY',
        buy_now: 'BUY_NOW',
        buy_tickets: 'BUY_TICKETS',
        buy_via_message: 'BUY_VIA_MESSAGE',
        call: 'CALL',
        call_me: 'CALL_ME',
        call_now: 'CALL_NOW',
        chat_with_us: 'CHAT_WITH_US',
        confirm: 'CONFIRM',
        contact: 'CONTACT',
        contact_us: 'CONTACT_US',
        donate: 'DONATE',
        donate_now: 'DONATE_NOW',
        download: 'DOWNLOAD',
        event_rsvp: 'EVENT_RSVP',
        find_a_group: 'FIND_A_GROUP',
        find_your_groups: 'FIND_YOUR_GROUPS',
        follow_news_storyline: 'FOLLOW_NEWS_STORYLINE',
        follow_page: 'FOLLOW_PAGE',
        follow_user: 'FOLLOW_USER',
        get_a_quote: 'GET_A_QUOTE',
        get_directions: 'GET_DIRECTIONS',
        get_offer: 'GET_OFFER',
        get_offer_view: 'GET_OFFER_VIEW',
        get_promotions: 'GET_PROMOTIONS',
        get_quote: 'GET_QUOTE',
        get_showtimes: 'GET_SHOWTIMES',
        get_started: 'GET_STARTED',
        inquire_now: 'INQUIRE_NOW',
        install_app: 'INSTALL_APP',
        install_mobile_app: 'INSTALL_MOBILE_APP',
        join_channel: 'JOIN_CHANNEL',
        learn_more: 'LEARN_MORE',
        like_page: 'LIKE_PAGE',
        listen_music: 'LISTEN_MUSIC',
        listen_now: 'LISTEN_NOW',
        make_an_appointment: 'MAKE_AN_APPOINTMENT',
        message_page: 'MESSAGE_PAGE',
        mobile_download: 'MOBILE_DOWNLOAD',
        no_button: 'NO_BUTTON',
        open_instant_app: 'OPEN_INSTANT_APP',
        open_link: 'OPEN_LINK',
        order_now: 'ORDER_NOW',
        pay_to_access: 'PAY_TO_ACCESS',
        play_game: 'PLAY_GAME',
        play_game_on_facebook: 'PLAY_GAME_ON_FACEBOOK',
        purchase_gift_cards: 'PURCHASE_GIFT_CARDS',
        raise_money: 'RAISE_MONEY',
        record_now: 'RECORD_NOW',
        refer_friends: 'REFER_FRIENDS',
        request_time: 'REQUEST_TIME',
        say_thanks: 'SAY_THANKS',
        see_more: 'SEE_MORE',
        sell_now: 'SELL_NOW',
        send_a_gift: 'SEND_A_GIFT',
        send_gift_money: 'SEND_GIFT_MONEY',
        send_updates: 'SEND_UPDATES',
        share: 'SHARE',
        shop_now: 'SHOP_NOW',
        sign_up: 'SIGN_UP',
        sotto_subscribe: 'SOTTO_SUBSCRIBE',
        start_order: 'START_ORDER',
        subscribe: 'SUBSCRIBE',
        swipe_up_product: 'SWIPE_UP_PRODUCT',
        swipe_up_shop: 'SWIPE_UP_SHOP',
        update_app: 'UPDATE_APP',
        use_app: 'USE_APP',
        use_mobile_app: 'USE_MOBILE_APP',
        video_annotation: 'VIDEO_ANNOTATION',
        video_call: 'VIDEO_CALL',
        view_channel: 'VIEW_CHANNEL',
        view_product: 'VIEW_PRODUCT',
        visit_pages_feed: 'VISIT_PAGES_FEED',
        watch_more: 'WATCH_MORE',
        watch_video: 'WATCH_VIDEO',
        whatsapp_message: 'WHATSAPP_MESSAGE',
        woodhenge_support: 'WOODHENGE_SUPPORT'
      });
    }
  }]);
  return AdCreativeLinkDataCallToAction;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataCallToActionValue
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataCallToActionValue = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataCallToActionValue, _AbstractCrudObject);

  function AdCreativeLinkDataCallToActionValue() {
    classCallCheck(this, AdCreativeLinkDataCallToActionValue);
    return possibleConstructorReturn(this, (AdCreativeLinkDataCallToActionValue.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataCallToActionValue)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataCallToActionValue, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_destination: 'app_destination',
        app_link: 'app_link',
        application: 'application',
        event_id: 'event_id',
        lead_gen_form_id: 'lead_gen_form_id',
        link: 'link',
        link_caption: 'link_caption',
        link_format: 'link_format',
        object_store_urls: 'object_store_urls',
        page: 'page',
        product_link: 'product_link',
        whatsapp_number: 'whatsapp_number'
      });
    }
  }]);
  return AdCreativeLinkDataCallToActionValue;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataChildAttachment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataChildAttachment = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataChildAttachment, _AbstractCrudObject);

  function AdCreativeLinkDataChildAttachment() {
    classCallCheck(this, AdCreativeLinkDataChildAttachment);
    return possibleConstructorReturn(this, (AdCreativeLinkDataChildAttachment.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataChildAttachment)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataChildAttachment, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        call_to_action: 'call_to_action',
        caption: 'caption',
        description: 'description',
        image_crops: 'image_crops',
        image_hash: 'image_hash',
        link: 'link',
        name: 'name',
        picture: 'picture',
        place_data: 'place_data',
        static_card: 'static_card',
        video_id: 'video_id'
      });
    }
  }]);
  return AdCreativeLinkDataChildAttachment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataCustomOverlaySpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataCustomOverlaySpec = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataCustomOverlaySpec, _AbstractCrudObject);

  function AdCreativeLinkDataCustomOverlaySpec() {
    classCallCheck(this, AdCreativeLinkDataCustomOverlaySpec);
    return possibleConstructorReturn(this, (AdCreativeLinkDataCustomOverlaySpec.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataCustomOverlaySpec)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataCustomOverlaySpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        background_color: 'background_color',
        float_with_margin: 'float_with_margin',
        font: 'font',
        option: 'option',
        position: 'position',
        render_with_icon: 'render_with_icon',
        template: 'template',
        text_color: 'text_color'
      });
    }
  }, {
    key: 'BackgroundColor',
    get: function get() {
      return Object.freeze({
        background_000000: 'background_000000',
        background_0090ff: 'background_0090ff',
        background_00af4c: 'background_00af4c',
        background_595959: 'background_595959',
        background_755dde: 'background_755dde',
        background_e50900: 'background_e50900',
        background_f23474: 'background_f23474',
        background_f78400: 'background_f78400',
        background_ffffff: 'background_ffffff'
      });
    }
  }, {
    key: 'Font',
    get: function get() {
      return Object.freeze({
        droid_serif_regular: 'droid_serif_regular',
        lato_regular: 'lato_regular',
        noto_sans_regular: 'noto_sans_regular',
        nunito_sans_bold: 'nunito_sans_bold',
        open_sans_bold: 'open_sans_bold',
        pt_serif_bold: 'pt_serif_bold',
        roboto_condensed_regular: 'roboto_condensed_regular',
        roboto_medium: 'roboto_medium'
      });
    }
  }, {
    key: 'Option',
    get: function get() {
      return Object.freeze({
        bank_transfer: 'bank_transfer',
        boleto: 'boleto',
        cash_on_delivery: 'cash_on_delivery',
        discount_with_boleto: 'discount_with_boleto',
        fast_delivery: 'fast_delivery',
        free_shipping: 'free_shipping',
        home_delivery: 'home_delivery',
        inventory: 'inventory',
        pay_at_hotel: 'pay_at_hotel',
        pay_on_arrival: 'pay_on_arrival'
      });
    }
  }, {
    key: 'Position',
    get: function get() {
      return Object.freeze({
        bottom_left: 'bottom_left',
        bottom_right: 'bottom_right',
        top_left: 'top_left',
        top_right: 'top_right'
      });
    }
  }, {
    key: 'Template',
    get: function get() {
      return Object.freeze({
        pill_with_text: 'pill_with_text'
      });
    }
  }, {
    key: 'TextColor',
    get: function get() {
      return Object.freeze({
        text_000000: 'text_000000',
        text_007ad0: 'text_007ad0',
        text_009c2a: 'text_009c2a',
        text_646464: 'text_646464',
        text_755dde: 'text_755dde',
        text_c91b00: 'text_c91b00',
        text_f23474: 'text_f23474',
        text_f78400: 'text_f78400',
        text_ffffff: 'text_ffffff'
      });
    }
  }]);
  return AdCreativeLinkDataCustomOverlaySpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataImageLayerSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataImageLayerSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataImageLayerSpec, _AbstractCrudObject);

  function AdCreativeLinkDataImageLayerSpec() {
    classCallCheck(this, AdCreativeLinkDataImageLayerSpec);
    return possibleConstructorReturn(this, (AdCreativeLinkDataImageLayerSpec.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataImageLayerSpec)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataImageLayerSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        blending_mode: 'blending_mode',
        content: 'content',
        frame_auto_show_enroll_status: 'frame_auto_show_enroll_status',
        frame_image_hash: 'frame_image_hash',
        frame_source: 'frame_source',
        image_source: 'image_source',
        layer_type: 'layer_type',
        opacity: 'opacity',
        overlay_position: 'overlay_position',
        overlay_shape: 'overlay_shape',
        scale: 'scale',
        shape_color: 'shape_color',
        text_color: 'text_color',
        text_font: 'text_font'
      });
    }
  }, {
    key: 'BlendingMode',
    get: function get() {
      return Object.freeze({
        lighten: 'lighten',
        multiply: 'multiply',
        normal: 'normal'
      });
    }
  }, {
    key: 'FrameSource',
    get: function get() {
      return Object.freeze({
        custom: 'custom'
      });
    }
  }, {
    key: 'ImageSource',
    get: function get() {
      return Object.freeze({
        catalog: 'catalog'
      });
    }
  }, {
    key: 'LayerType',
    get: function get() {
      return Object.freeze({
        frame_overlay: 'frame_overlay',
        image: 'image',
        text_overlay: 'text_overlay'
      });
    }
  }, {
    key: 'OverlayPosition',
    get: function get() {
      return Object.freeze({
        bottom: 'bottom',
        bottom_left: 'bottom_left',
        bottom_right: 'bottom_right',
        center: 'center',
        left: 'left',
        right: 'right',
        top: 'top',
        top_left: 'top_left',
        top_right: 'top_right'
      });
    }
  }, {
    key: 'OverlayShape',
    get: function get() {
      return Object.freeze({
        circle: 'circle',
        none: 'none',
        pill: 'pill',
        rectangle: 'rectangle',
        triangle: 'triangle'
      });
    }
  }, {
    key: 'TextFont',
    get: function get() {
      return Object.freeze({
        droid_serif_regular: 'droid_serif_regular',
        lato_regular: 'lato_regular',
        noto_sans_regular: 'noto_sans_regular',
        nunito_sans_bold: 'nunito_sans_bold',
        open_sans_bold: 'open_sans_bold',
        open_sans_condensed_bold: 'open_sans_condensed_bold',
        pt_serif_bold: 'pt_serif_bold',
        roboto_condensed_regular: 'roboto_condensed_regular',
        roboto_medium: 'roboto_medium'
      });
    }
  }]);
  return AdCreativeLinkDataImageLayerSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataImageOverlaySpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataImageOverlaySpec = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataImageOverlaySpec, _AbstractCrudObject);

  function AdCreativeLinkDataImageOverlaySpec() {
    classCallCheck(this, AdCreativeLinkDataImageOverlaySpec);
    return possibleConstructorReturn(this, (AdCreativeLinkDataImageOverlaySpec.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataImageOverlaySpec)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataImageOverlaySpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        custom_text_type: 'custom_text_type',
        float_with_margin: 'float_with_margin',
        overlay_template: 'overlay_template',
        position: 'position',
        text_font: 'text_font',
        text_template_tags: 'text_template_tags',
        text_type: 'text_type',
        theme_color: 'theme_color'
      });
    }
  }, {
    key: 'CustomTextType',
    get: function get() {
      return Object.freeze({
        free_shipping: 'free_shipping',
        popular: 'popular'
      });
    }
  }, {
    key: 'OverlayTemplate',
    get: function get() {
      return Object.freeze({
        circle_with_text: 'circle_with_text',
        pill_with_text: 'pill_with_text',
        triangle_with_text: 'triangle_with_text'
      });
    }
  }, {
    key: 'Position',
    get: function get() {
      return Object.freeze({
        bottom_left: 'bottom_left',
        bottom_right: 'bottom_right',
        top_left: 'top_left',
        top_right: 'top_right'
      });
    }
  }, {
    key: 'TextFont',
    get: function get() {
      return Object.freeze({
        droid_serif_regular: 'droid_serif_regular',
        dynads_hybrid_bold: 'dynads_hybrid_bold',
        lato_regular: 'lato_regular',
        noto_sans_regular: 'noto_sans_regular',
        nunito_sans_bold: 'nunito_sans_bold',
        open_sans_bold: 'open_sans_bold',
        open_sans_condensed_bold: 'open_sans_condensed_bold',
        pt_serif_bold: 'pt_serif_bold',
        roboto_condensed_regular: 'roboto_condensed_regular',
        roboto_medium: 'roboto_medium'
      });
    }
  }, {
    key: 'TextType',
    get: function get() {
      return Object.freeze({
        automated_personalize: 'automated_personalize',
        custom: 'custom',
        disclaimer: 'disclaimer',
        from_price: 'from_price',
        guest_rating: 'guest_rating',
        percentage_off: 'percentage_off',
        price: 'price',
        star_rating: 'star_rating',
        strikethrough_price: 'strikethrough_price',
        sustainable: 'sustainable'
      });
    }
  }, {
    key: 'ThemeColor',
    get: function get() {
      return Object.freeze({
        background_000000_text_ffffff: 'background_000000_text_ffffff',
        background_0090ff_text_ffffff: 'background_0090ff_text_ffffff',
        background_00af4c_text_ffffff: 'background_00af4c_text_ffffff',
        background_595959_text_ffffff: 'background_595959_text_ffffff',
        background_755dde_text_ffffff: 'background_755dde_text_ffffff',
        background_e50900_text_ffffff: 'background_e50900_text_ffffff',
        background_f23474_text_ffffff: 'background_f23474_text_ffffff',
        background_f78400_text_ffffff: 'background_f78400_text_ffffff',
        background_ffffff_text_000000: 'background_ffffff_text_000000',
        background_ffffff_text_007ad0: 'background_ffffff_text_007ad0',
        background_ffffff_text_009c2a: 'background_ffffff_text_009c2a',
        background_ffffff_text_646464: 'background_ffffff_text_646464',
        background_ffffff_text_755dde: 'background_ffffff_text_755dde',
        background_ffffff_text_c91b00: 'background_ffffff_text_c91b00',
        background_ffffff_text_f23474: 'background_ffffff_text_f23474',
        background_ffffff_text_f78400: 'background_ffffff_text_f78400'
      });
    }
  }]);
  return AdCreativeLinkDataImageOverlaySpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataMoment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataMoment = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataMoment, _AbstractCrudObject);

  function AdCreativeLinkDataMoment() {
    classCallCheck(this, AdCreativeLinkDataMoment);
    return possibleConstructorReturn(this, (AdCreativeLinkDataMoment.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataMoment)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataMoment, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        type: 'type'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        fb_live_shopping: 'FB_LIVE_SHOPPING',
        ig_live_shopping: 'IG_LIVE_SHOPPING'
      });
    }
  }]);
  return AdCreativeLinkDataMoment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataSponsorshipInfoSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataSponsorshipInfoSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataSponsorshipInfoSpec, _AbstractCrudObject);

  function AdCreativeLinkDataSponsorshipInfoSpec() {
    classCallCheck(this, AdCreativeLinkDataSponsorshipInfoSpec);
    return possibleConstructorReturn(this, (AdCreativeLinkDataSponsorshipInfoSpec.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataSponsorshipInfoSpec)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataSponsorshipInfoSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        sponsor_image_url: 'sponsor_image_url',
        sponsor_name: 'sponsor_name'
      });
    }
  }]);
  return AdCreativeLinkDataSponsorshipInfoSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeLinkDataTemplateVideoSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeLinkDataTemplateVideoSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeLinkDataTemplateVideoSpec, _AbstractCrudObject);

  function AdCreativeLinkDataTemplateVideoSpec() {
    classCallCheck(this, AdCreativeLinkDataTemplateVideoSpec);
    return possibleConstructorReturn(this, (AdCreativeLinkDataTemplateVideoSpec.__proto__ || Object.getPrototypeOf(AdCreativeLinkDataTemplateVideoSpec)).apply(this, arguments));
  }

  createClass(AdCreativeLinkDataTemplateVideoSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        categorization_criteria: 'categorization_criteria',
        customization: 'customization',
        template_id: 'template_id'
      });
    }
  }]);
  return AdCreativeLinkDataTemplateVideoSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeMarketingMessageStructuredSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeMarketingMessageStructuredSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeMarketingMessageStructuredSpec, _AbstractCrudObject);

  function AdCreativeMarketingMessageStructuredSpec() {
    classCallCheck(this, AdCreativeMarketingMessageStructuredSpec);
    return possibleConstructorReturn(this, (AdCreativeMarketingMessageStructuredSpec.__proto__ || Object.getPrototypeOf(AdCreativeMarketingMessageStructuredSpec)).apply(this, arguments));
  }

  createClass(AdCreativeMarketingMessageStructuredSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        buttons: 'buttons',
        footer: 'footer',
        greeting: 'greeting',
        is_optimized_text: 'is_optimized_text',
        language: 'language',
        referenced_adgroup_id: 'referenced_adgroup_id',
        whats_app_business_phone_number_id: 'whats_app_business_phone_number_id'
      });
    }
  }]);
  return AdCreativeMarketingMessageStructuredSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeObjectStorySpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeObjectStorySpec = function (_AbstractCrudObject) {
  inherits(AdCreativeObjectStorySpec, _AbstractCrudObject);

  function AdCreativeObjectStorySpec() {
    classCallCheck(this, AdCreativeObjectStorySpec);
    return possibleConstructorReturn(this, (AdCreativeObjectStorySpec.__proto__ || Object.getPrototypeOf(AdCreativeObjectStorySpec)).apply(this, arguments));
  }

  createClass(AdCreativeObjectStorySpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        instagram_actor_id: 'instagram_actor_id',
        link_data: 'link_data',
        page_id: 'page_id',
        photo_data: 'photo_data',
        product_data: 'product_data',
        template_data: 'template_data',
        text_data: 'text_data',
        threads_user_id: 'threads_user_id',
        video_data: 'video_data'
      });
    }
  }]);
  return AdCreativeObjectStorySpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeOmnichannelLinkSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeOmnichannelLinkSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeOmnichannelLinkSpec, _AbstractCrudObject);

  function AdCreativeOmnichannelLinkSpec() {
    classCallCheck(this, AdCreativeOmnichannelLinkSpec);
    return possibleConstructorReturn(this, (AdCreativeOmnichannelLinkSpec.__proto__ || Object.getPrototypeOf(AdCreativeOmnichannelLinkSpec)).apply(this, arguments));
  }

  createClass(AdCreativeOmnichannelLinkSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app: 'app',
        web: 'web'
      });
    }
  }]);
  return AdCreativeOmnichannelLinkSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativePhotoData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativePhotoData = function (_AbstractCrudObject) {
  inherits(AdCreativePhotoData, _AbstractCrudObject);

  function AdCreativePhotoData() {
    classCallCheck(this, AdCreativePhotoData);
    return possibleConstructorReturn(this, (AdCreativePhotoData.__proto__ || Object.getPrototypeOf(AdCreativePhotoData)).apply(this, arguments));
  }

  createClass(AdCreativePhotoData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        branded_content_shared_to_sponsor_status: 'branded_content_shared_to_sponsor_status',
        branded_content_sponsor_page_id: 'branded_content_sponsor_page_id',
        caption: 'caption',
        image_hash: 'image_hash',
        page_welcome_message: 'page_welcome_message',
        url: 'url'
      });
    }
  }]);
  return AdCreativePhotoData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativePhotoDataMediaElements
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativePhotoDataMediaElements = function (_AbstractCrudObject) {
  inherits(AdCreativePhotoDataMediaElements, _AbstractCrudObject);

  function AdCreativePhotoDataMediaElements() {
    classCallCheck(this, AdCreativePhotoDataMediaElements);
    return possibleConstructorReturn(this, (AdCreativePhotoDataMediaElements.__proto__ || Object.getPrototypeOf(AdCreativePhotoDataMediaElements)).apply(this, arguments));
  }

  createClass(AdCreativePhotoDataMediaElements, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        element_id: 'element_id',
        element_type: 'element_type',
        x: 'x',
        y: 'y'
      });
    }
  }]);
  return AdCreativePhotoDataMediaElements;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativePlaceData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativePlaceData = function (_AbstractCrudObject) {
  inherits(AdCreativePlaceData, _AbstractCrudObject);

  function AdCreativePlaceData() {
    classCallCheck(this, AdCreativePlaceData);
    return possibleConstructorReturn(this, (AdCreativePlaceData.__proto__ || Object.getPrototypeOf(AdCreativePlaceData)).apply(this, arguments));
  }

  createClass(AdCreativePlaceData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        address_string: 'address_string',
        label: 'label',
        latitude: 'latitude',
        location_source_id: 'location_source_id',
        longitude: 'longitude',
        type: 'type'
      });
    }
  }]);
  return AdCreativePlaceData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativePlatformCustomization
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativePlatformCustomization = function (_AbstractCrudObject) {
  inherits(AdCreativePlatformCustomization, _AbstractCrudObject);

  function AdCreativePlatformCustomization() {
    classCallCheck(this, AdCreativePlatformCustomization);
    return possibleConstructorReturn(this, (AdCreativePlatformCustomization.__proto__ || Object.getPrototypeOf(AdCreativePlatformCustomization)).apply(this, arguments));
  }

  createClass(AdCreativePlatformCustomization, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        instagram: 'instagram'
      });
    }
  }]);
  return AdCreativePlatformCustomization;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativePortraitCustomizations
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativePortraitCustomizations = function (_AbstractCrudObject) {
  inherits(AdCreativePortraitCustomizations, _AbstractCrudObject);

  function AdCreativePortraitCustomizations() {
    classCallCheck(this, AdCreativePortraitCustomizations);
    return possibleConstructorReturn(this, (AdCreativePortraitCustomizations.__proto__ || Object.getPrototypeOf(AdCreativePortraitCustomizations)).apply(this, arguments));
  }

  createClass(AdCreativePortraitCustomizations, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        carousel_delivery_mode: 'carousel_delivery_mode',
        specifications: 'specifications'
      });
    }
  }]);
  return AdCreativePortraitCustomizations;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativePostClickConfiguration
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativePostClickConfiguration = function (_AbstractCrudObject) {
  inherits(AdCreativePostClickConfiguration, _AbstractCrudObject);

  function AdCreativePostClickConfiguration() {
    classCallCheck(this, AdCreativePostClickConfiguration);
    return possibleConstructorReturn(this, (AdCreativePostClickConfiguration.__proto__ || Object.getPrototypeOf(AdCreativePostClickConfiguration)).apply(this, arguments));
  }

  createClass(AdCreativePostClickConfiguration, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        post_click_item_description: 'post_click_item_description',
        post_click_item_headline: 'post_click_item_headline'
      });
    }
  }]);
  return AdCreativePostClickConfiguration;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeProductData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeProductData = function (_AbstractCrudObject) {
  inherits(AdCreativeProductData, _AbstractCrudObject);

  function AdCreativeProductData() {
    classCallCheck(this, AdCreativeProductData);
    return possibleConstructorReturn(this, (AdCreativeProductData.__proto__ || Object.getPrototypeOf(AdCreativeProductData)).apply(this, arguments));
  }

  createClass(AdCreativeProductData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        product_id: 'product_id',
        product_source: 'product_source'
      });
    }
  }]);
  return AdCreativeProductData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativePromotionMetadataSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativePromotionMetadataSpec = function (_AbstractCrudObject) {
  inherits(AdCreativePromotionMetadataSpec, _AbstractCrudObject);

  function AdCreativePromotionMetadataSpec() {
    classCallCheck(this, AdCreativePromotionMetadataSpec);
    return possibleConstructorReturn(this, (AdCreativePromotionMetadataSpec.__proto__ || Object.getPrototypeOf(AdCreativePromotionMetadataSpec)).apply(this, arguments));
  }

  createClass(AdCreativePromotionMetadataSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        end_date: 'end_date',
        id: 'id',
        promotion_source: 'promotion_source',
        promotion_type: 'promotion_type',
        promotion_value: 'promotion_value',
        required_code: 'required_code',
        start_date: 'start_date'
      });
    }
  }]);
  return AdCreativePromotionMetadataSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeRecommenderSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeRecommenderSettings = function (_AbstractCrudObject) {
  inherits(AdCreativeRecommenderSettings, _AbstractCrudObject);

  function AdCreativeRecommenderSettings() {
    classCallCheck(this, AdCreativeRecommenderSettings);
    return possibleConstructorReturn(this, (AdCreativeRecommenderSettings.__proto__ || Object.getPrototypeOf(AdCreativeRecommenderSettings)).apply(this, arguments));
  }

  createClass(AdCreativeRecommenderSettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        preferred_events: 'preferred_events',
        product_sales_channel: 'product_sales_channel'
      });
    }
  }]);
  return AdCreativeRecommenderSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeRegionalRegulationDisclaimer
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeRegionalRegulationDisclaimer = function (_AbstractCrudObject) {
  inherits(AdCreativeRegionalRegulationDisclaimer, _AbstractCrudObject);

  function AdCreativeRegionalRegulationDisclaimer() {
    classCallCheck(this, AdCreativeRegionalRegulationDisclaimer);
    return possibleConstructorReturn(this, (AdCreativeRegionalRegulationDisclaimer.__proto__ || Object.getPrototypeOf(AdCreativeRegionalRegulationDisclaimer)).apply(this, arguments));
  }

  createClass(AdCreativeRegionalRegulationDisclaimer, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return AdCreativeRegionalRegulationDisclaimer;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeRewardInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeRewardInfo = function (_AbstractCrudObject) {
  inherits(AdCreativeRewardInfo, _AbstractCrudObject);

  function AdCreativeRewardInfo() {
    classCallCheck(this, AdCreativeRewardInfo);
    return possibleConstructorReturn(this, (AdCreativeRewardInfo.__proto__ || Object.getPrototypeOf(AdCreativeRewardInfo)).apply(this, arguments));
  }

  createClass(AdCreativeRewardInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        reward_offer_id: 'reward_offer_id',
        reward_program_id: 'reward_program_id'
      });
    }
  }]);
  return AdCreativeRewardInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeShopSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeShopSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeShopSpec, _AbstractCrudObject);

  function AdCreativeShopSpec() {
    classCallCheck(this, AdCreativeShopSpec);
    return possibleConstructorReturn(this, (AdCreativeShopSpec.__proto__ || Object.getPrototypeOf(AdCreativeShopSpec)).apply(this, arguments));
  }

  createClass(AdCreativeShopSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        collection_id: 'collection_id',
        landing_view: 'landing_view',
        shop_id: 'shop_id'
      });
    }
  }]);
  return AdCreativeShopSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeSiteLinksSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeSiteLinksSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeSiteLinksSpec, _AbstractCrudObject);

  function AdCreativeSiteLinksSpec() {
    classCallCheck(this, AdCreativeSiteLinksSpec);
    return possibleConstructorReturn(this, (AdCreativeSiteLinksSpec.__proto__ || Object.getPrototypeOf(AdCreativeSiteLinksSpec)).apply(this, arguments));
  }

  createClass(AdCreativeSiteLinksSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        site_link_image_hash: 'site_link_image_hash',
        site_link_image_url: 'site_link_image_url',
        site_link_recommendation_type: 'site_link_recommendation_type',
        site_link_title: 'site_link_title',
        site_link_url: 'site_link_url'
      });
    }
  }]);
  return AdCreativeSiteLinksSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeSourcingSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeSourcingSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeSourcingSpec, _AbstractCrudObject);

  function AdCreativeSourcingSpec() {
    classCallCheck(this, AdCreativeSourcingSpec);
    return possibleConstructorReturn(this, (AdCreativeSourcingSpec.__proto__ || Object.getPrototypeOf(AdCreativeSourcingSpec)).apply(this, arguments));
  }

  createClass(AdCreativeSourcingSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        associated_product_set_id: 'associated_product_set_id',
        enable_social_feedback_preservation: 'enable_social_feedback_preservation',
        promotion_metadata_spec: 'promotion_metadata_spec',
        site_links_spec: 'site_links_spec',
        source_url: 'source_url'
      });
    }
  }]);
  return AdCreativeSourcingSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeStaticFallbackSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeStaticFallbackSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeStaticFallbackSpec, _AbstractCrudObject);

  function AdCreativeStaticFallbackSpec() {
    classCallCheck(this, AdCreativeStaticFallbackSpec);
    return possibleConstructorReturn(this, (AdCreativeStaticFallbackSpec.__proto__ || Object.getPrototypeOf(AdCreativeStaticFallbackSpec)).apply(this, arguments));
  }

  createClass(AdCreativeStaticFallbackSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        call_to_action: 'call_to_action',
        description: 'description',
        image_hash: 'image_hash',
        link: 'link',
        message: 'message',
        name: 'name'
      });
    }
  }]);
  return AdCreativeStaticFallbackSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeTemplateURLSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeTemplateURLSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeTemplateURLSpec, _AbstractCrudObject);

  function AdCreativeTemplateURLSpec() {
    classCallCheck(this, AdCreativeTemplateURLSpec);
    return possibleConstructorReturn(this, (AdCreativeTemplateURLSpec.__proto__ || Object.getPrototypeOf(AdCreativeTemplateURLSpec)).apply(this, arguments));
  }

  createClass(AdCreativeTemplateURLSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        android: 'android',
        config: 'config',
        ios: 'ios',
        ipad: 'ipad',
        iphone: 'iphone',
        web: 'web',
        windows_phone: 'windows_phone'
      });
    }
  }]);
  return AdCreativeTemplateURLSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeTextData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeTextData = function (_AbstractCrudObject) {
  inherits(AdCreativeTextData, _AbstractCrudObject);

  function AdCreativeTextData() {
    classCallCheck(this, AdCreativeTextData);
    return possibleConstructorReturn(this, (AdCreativeTextData.__proto__ || Object.getPrototypeOf(AdCreativeTextData)).apply(this, arguments));
  }

  createClass(AdCreativeTextData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        message: 'message'
      });
    }
  }]);
  return AdCreativeTextData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeVideoData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeVideoData = function (_AbstractCrudObject) {
  inherits(AdCreativeVideoData, _AbstractCrudObject);

  function AdCreativeVideoData() {
    classCallCheck(this, AdCreativeVideoData);
    return possibleConstructorReturn(this, (AdCreativeVideoData.__proto__ || Object.getPrototypeOf(AdCreativeVideoData)).apply(this, arguments));
  }

  createClass(AdCreativeVideoData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        additional_image_index: 'additional_image_index',
        branded_content_shared_to_sponsor_status: 'branded_content_shared_to_sponsor_status',
        branded_content_sponsor_page_id: 'branded_content_sponsor_page_id',
        call_to_action: 'call_to_action',
        collection_thumbnails: 'collection_thumbnails',
        customization_rules_spec: 'customization_rules_spec',
        image_hash: 'image_hash',
        image_url: 'image_url',
        link_description: 'link_description',
        message: 'message',
        offer_id: 'offer_id',
        page_welcome_message: 'page_welcome_message',
        post_click_configuration: 'post_click_configuration',
        retailer_item_ids: 'retailer_item_ids',
        targeting: 'targeting',
        title: 'title',
        video_id: 'video_id'
      });
    }
  }]);
  return AdCreativeVideoData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeVideoDataCustomOverlaySpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeVideoDataCustomOverlaySpec = function (_AbstractCrudObject) {
  inherits(AdCreativeVideoDataCustomOverlaySpec, _AbstractCrudObject);

  function AdCreativeVideoDataCustomOverlaySpec() {
    classCallCheck(this, AdCreativeVideoDataCustomOverlaySpec);
    return possibleConstructorReturn(this, (AdCreativeVideoDataCustomOverlaySpec.__proto__ || Object.getPrototypeOf(AdCreativeVideoDataCustomOverlaySpec)).apply(this, arguments));
  }

  createClass(AdCreativeVideoDataCustomOverlaySpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        background_color: 'background_color',
        background_opacity: 'background_opacity',
        duration: 'duration',
        float_with_margin: 'float_with_margin',
        full_width: 'full_width',
        option: 'option',
        position: 'position',
        start: 'start',
        template: 'template',
        text_color: 'text_color'
      });
    }
  }, {
    key: 'BackgroundOpacity',
    get: function get() {
      return Object.freeze({
        half: 'half',
        solid: 'solid'
      });
    }
  }, {
    key: 'Option',
    get: function get() {
      return Object.freeze({
        bank_transfer: 'bank_transfer',
        boleto: 'boleto',
        cash_on_delivery: 'cash_on_delivery',
        discount_with_boleto: 'discount_with_boleto',
        fast_delivery: 'fast_delivery',
        free_shipping: 'free_shipping',
        home_delivery: 'home_delivery',
        inventory: 'inventory',
        pay_at_hotel: 'pay_at_hotel',
        pay_on_arrival: 'pay_on_arrival'
      });
    }
  }, {
    key: 'Position',
    get: function get() {
      return Object.freeze({
        middle_center: 'middle_center',
        middle_left: 'middle_left',
        middle_right: 'middle_right',
        top_center: 'top_center',
        top_left: 'top_left',
        top_right: 'top_right'
      });
    }
  }, {
    key: 'Template',
    get: function get() {
      return Object.freeze({
        rectangle_with_text: 'rectangle_with_text'
      });
    }
  }]);
  return AdCreativeVideoDataCustomOverlaySpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeVideoDataMediaElements
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeVideoDataMediaElements = function (_AbstractCrudObject) {
  inherits(AdCreativeVideoDataMediaElements, _AbstractCrudObject);

  function AdCreativeVideoDataMediaElements() {
    classCallCheck(this, AdCreativeVideoDataMediaElements);
    return possibleConstructorReturn(this, (AdCreativeVideoDataMediaElements.__proto__ || Object.getPrototypeOf(AdCreativeVideoDataMediaElements)).apply(this, arguments));
  }

  createClass(AdCreativeVideoDataMediaElements, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        element_id: 'element_id',
        element_type: 'element_type'
      });
    }
  }]);
  return AdCreativeVideoDataMediaElements;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCreativeWhatsAppChannelSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCreativeWhatsAppChannelSpec = function (_AbstractCrudObject) {
  inherits(AdCreativeWhatsAppChannelSpec, _AbstractCrudObject);

  function AdCreativeWhatsAppChannelSpec() {
    classCallCheck(this, AdCreativeWhatsAppChannelSpec);
    return possibleConstructorReturn(this, (AdCreativeWhatsAppChannelSpec.__proto__ || Object.getPrototypeOf(AdCreativeWhatsAppChannelSpec)).apply(this, arguments));
  }

  createClass(AdCreativeWhatsAppChannelSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        channel_id: 'channel_id',
        channel_url: 'channel_url'
      });
    }
  }]);
  return AdCreativeWhatsAppChannelSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCustomDerivedMetrics
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCustomDerivedMetrics = function (_AbstractCrudObject) {
  inherits(AdCustomDerivedMetrics, _AbstractCrudObject);

  function AdCustomDerivedMetrics() {
    classCallCheck(this, AdCustomDerivedMetrics);
    return possibleConstructorReturn(this, (AdCustomDerivedMetrics.__proto__ || Object.getPrototypeOf(AdCustomDerivedMetrics)).apply(this, arguments));
  }

  createClass(AdCustomDerivedMetrics, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_id: 'ad_account_id',
        business: 'business',
        creation_time: 'creation_time',
        creator: 'creator',
        custom_derived_metric_type: 'custom_derived_metric_type',
        deletion_time: 'deletion_time',
        deletor: 'deletor',
        description: 'description',
        format_type: 'format_type',
        formula: 'formula',
        has_attribution_windows: 'has_attribution_windows',
        has_inline_attribution_window: 'has_inline_attribution_window',
        id: 'id',
        name: 'name',
        permission: 'permission',
        saved_report_id: 'saved_report_id',
        scope: 'scope'
      });
    }
  }]);
  return AdCustomDerivedMetrics;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdCustomizationRuleSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdCustomizationRuleSpec = function (_AbstractCrudObject) {
  inherits(AdCustomizationRuleSpec, _AbstractCrudObject);

  function AdCustomizationRuleSpec() {
    classCallCheck(this, AdCustomizationRuleSpec);
    return possibleConstructorReturn(this, (AdCustomizationRuleSpec.__proto__ || Object.getPrototypeOf(AdCustomizationRuleSpec)).apply(this, arguments));
  }

  createClass(AdCustomizationRuleSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        caption: 'caption',
        customization_spec: 'customization_spec',
        description: 'description',
        image_hash: 'image_hash',
        link: 'link',
        message: 'message',
        name: 'name',
        priority: 'priority',
        template_url_spec: 'template_url_spec',
        video_id: 'video_id'
      });
    }
  }]);
  return AdCustomizationRuleSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdDefaultValues
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdDefaultValues = function (_AbstractCrudObject) {
  inherits(AdDefaultValues, _AbstractCrudObject);

  function AdDefaultValues() {
    classCallCheck(this, AdDefaultValues);
    return possibleConstructorReturn(this, (AdDefaultValues.__proto__ || Object.getPrototypeOf(AdDefaultValues)).apply(this, arguments));
  }

  createClass(AdDefaultValues, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        campaign_group: 'campaign_group'
      });
    }
  }]);
  return AdDefaultValues;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdDraft
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdDraft = function (_AbstractCrudObject) {
  inherits(AdDraft, _AbstractCrudObject);

  function AdDraft() {
    classCallCheck(this, AdDraft);
    return possibleConstructorReturn(this, (AdDraft.__proto__ || Object.getPrototypeOf(AdDraft)).apply(this, arguments));
  }

  createClass(AdDraft, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        api_version: 'api_version',
        async_request_set: 'async_request_set',
        author_id: 'author_id',
        created_by: 'created_by',
        draft_version: 'draft_version',
        id: 'id',
        is_active: 'is_active',
        name: 'name',
        ownership_type: 'ownership_type',
        publish_status: 'publish_status',
        state: 'state',
        summary: 'summary',
        time_created: 'time_created',
        time_updated: 'time_updated'
      });
    }
  }]);
  return AdDraft;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdDynamicCreative
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdDynamicCreative = function (_AbstractCrudObject) {
  inherits(AdDynamicCreative, _AbstractCrudObject);

  function AdDynamicCreative() {
    classCallCheck(this, AdDynamicCreative);
    return possibleConstructorReturn(this, (AdDynamicCreative.__proto__ || Object.getPrototypeOf(AdDynamicCreative)).apply(this, arguments));
  }

  createClass(AdDynamicCreative, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        preview_url: 'preview_url'
      });
    }
  }]);
  return AdDynamicCreative;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdEntityTargetSpend
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdEntityTargetSpend = function (_AbstractCrudObject) {
  inherits(AdEntityTargetSpend, _AbstractCrudObject);

  function AdEntityTargetSpend() {
    classCallCheck(this, AdEntityTargetSpend);
    return possibleConstructorReturn(this, (AdEntityTargetSpend.__proto__ || Object.getPrototypeOf(AdEntityTargetSpend)).apply(this, arguments));
  }

  createClass(AdEntityTargetSpend, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount: 'amount',
        has_error: 'has_error',
        is_accurate: 'is_accurate',
        is_prorated: 'is_prorated',
        is_updating: 'is_updating'
      });
    }
  }]);
  return AdEntityTargetSpend;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdExportPreset
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdExportPreset = function (_AbstractCrudObject) {
  inherits(AdExportPreset, _AbstractCrudObject);

  function AdExportPreset() {
    classCallCheck(this, AdExportPreset);
    return possibleConstructorReturn(this, (AdExportPreset.__proto__ || Object.getPrototypeOf(AdExportPreset)).apply(this, arguments));
  }

  createClass(AdExportPreset, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        created_time: 'created_time',
        fields: 'fields',
        id: 'id',
        name: 'name',
        owner: 'owner',
        updated_time: 'updated_time'
      });
    }
  }]);
  return AdExportPreset;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdKeywordStats
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdKeywordStats = function (_AbstractCrudObject) {
  inherits(AdKeywordStats, _AbstractCrudObject);

  function AdKeywordStats() {
    classCallCheck(this, AdKeywordStats);
    return possibleConstructorReturn(this, (AdKeywordStats.__proto__ || Object.getPrototypeOf(AdKeywordStats)).apply(this, arguments));
  }

  createClass(AdKeywordStats, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actions: 'actions',
        clicks: 'clicks',
        cost_per_total_action: 'cost_per_total_action',
        cost_per_unique_click: 'cost_per_unique_click',
        cpc: 'cpc',
        cpm: 'cpm',
        cpp: 'cpp',
        ctr: 'ctr',
        frequency: 'frequency',
        id: 'id',
        impressions: 'impressions',
        name: 'name',
        reach: 'reach',
        spend: 'spend',
        total_actions: 'total_actions',
        total_unique_actions: 'total_unique_actions',
        unique_actions: 'unique_actions',
        unique_clicks: 'unique_clicks',
        unique_ctr: 'unique_ctr',
        unique_impressions: 'unique_impressions'
      });
    }
  }]);
  return AdKeywordStats;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdKeywords
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdKeywords = function (_AbstractCrudObject) {
  inherits(AdKeywords, _AbstractCrudObject);

  function AdKeywords() {
    classCallCheck(this, AdKeywords);
    return possibleConstructorReturn(this, (AdKeywords.__proto__ || Object.getPrototypeOf(AdKeywords)).apply(this, arguments));
  }

  createClass(AdKeywords, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        brands: 'brands',
        product_categories: 'product_categories',
        product_names: 'product_names',
        search_terms: 'search_terms'
      });
    }
  }]);
  return AdKeywords;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdKpiShift
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdKpiShift = function (_AbstractCrudObject) {
  inherits(AdKpiShift, _AbstractCrudObject);

  function AdKpiShift() {
    classCallCheck(this, AdKpiShift);
    return possibleConstructorReturn(this, (AdKpiShift.__proto__ || Object.getPrototypeOf(AdKpiShift)).apply(this, arguments));
  }

  createClass(AdKpiShift, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_set: 'ad_set',
        cost_per_result_shift: 'cost_per_result_shift',
        enough_effective_days: 'enough_effective_days',
        result_indicator: 'result_indicator',
        result_shift: 'result_shift',
        spend_shift: 'spend_shift'
      });
    }
  }]);
  return AdKpiShift;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdLightAdgroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdLightAdgroup = function (_AbstractCrudObject) {
  inherits(AdLightAdgroup, _AbstractCrudObject);

  function AdLightAdgroup() {
    classCallCheck(this, AdLightAdgroup);
    return possibleConstructorReturn(this, (AdLightAdgroup.__proto__ || Object.getPrototypeOf(AdLightAdgroup)).apply(this, arguments));
  }

  createClass(AdLightAdgroup, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adset_id: 'adset_id',
        id: 'id'
      });
    }
  }]);
  return AdLightAdgroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdLightCampaign
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdLightCampaign = function (_AbstractCrudObject) {
  inherits(AdLightCampaign, _AbstractCrudObject);

  function AdLightCampaign() {
    classCallCheck(this, AdLightCampaign);
    return possibleConstructorReturn(this, (AdLightCampaign.__proto__ || Object.getPrototypeOf(AdLightCampaign)).apply(this, arguments));
  }

  createClass(AdLightCampaign, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        campaign_id: 'campaign_id',
        id: 'id'
      });
    }
  }]);
  return AdLightCampaign;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdLightCampaignGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdLightCampaignGroup = function (_AbstractCrudObject) {
  inherits(AdLightCampaignGroup, _AbstractCrudObject);

  function AdLightCampaignGroup() {
    classCallCheck(this, AdLightCampaignGroup);
    return possibleConstructorReturn(this, (AdLightCampaignGroup.__proto__ || Object.getPrototypeOf(AdLightCampaignGroup)).apply(this, arguments));
  }

  createClass(AdLightCampaignGroup, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return AdLightCampaignGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdLimitSetting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdLimitSetting = function (_AbstractCrudObject) {
  inherits(AdLimitSetting, _AbstractCrudObject);

  function AdLimitSetting() {
    classCallCheck(this, AdLimitSetting);
    return possibleConstructorReturn(this, (AdLimitSetting.__proto__ || Object.getPrototypeOf(AdLimitSetting)).apply(this, arguments));
  }

  createClass(AdLimitSetting, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        limit_allocation_by_page_advertisers: 'limit_allocation_by_page_advertisers'
      });
    }
  }]);
  return AdLimitSetting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdLimitsEnforcementData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdLimitsEnforcementData = function (_AbstractCrudObject) {
  inherits(AdLimitsEnforcementData, _AbstractCrudObject);

  function AdLimitsEnforcementData() {
    classCallCheck(this, AdLimitsEnforcementData);
    return possibleConstructorReturn(this, (AdLimitsEnforcementData.__proto__ || Object.getPrototypeOf(AdLimitsEnforcementData)).apply(this, arguments));
  }

  createClass(AdLimitsEnforcementData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_limit_on_page: 'ad_limit_on_page',
        ad_limit_on_scope: 'ad_limit_on_scope',
        ad_volume_on_page: 'ad_volume_on_page',
        ad_volume_on_scope: 'ad_volume_on_scope',
        is_admin: 'is_admin',
        page_name: 'page_name'
      });
    }
  }]);
  return AdLimitsEnforcementData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdMonetizationProperty
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdMonetizationProperty = function (_AbstractCrudObject) {
  inherits(AdMonetizationProperty, _AbstractCrudObject);

  function AdMonetizationProperty() {
    classCallCheck(this, AdMonetizationProperty);
    return possibleConstructorReturn(this, (AdMonetizationProperty.__proto__ || Object.getPrototypeOf(AdMonetizationProperty)).apply(this, arguments));
  }

  createClass(AdMonetizationProperty, [{
    key: 'getAdNetworkAnalytics',
    value: function getAdNetworkAnalytics(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdNetworkAnalyticsSyncQueryResult, fields, params, fetchFirstPage, '/adnetworkanalytics');
    }
  }, {
    key: 'createAdNetworkAnalytic',
    value: function createAdNetworkAnalytic(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/adnetworkanalytics', fields, params, AdMonetizationProperty, pathOverride);
    }
  }, {
    key: 'getAdNetworkAnalyticsResults',
    value: function getAdNetworkAnalyticsResults(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdNetworkAnalyticsAsyncQueryResult, fields, params, fetchFirstPage, '/adnetworkanalytics_results');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        owner_business: 'owner_business',
        id: 'id'
      });
    }
  }]);
  return AdMonetizationProperty;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdNetworkAnalyticsAsyncQueryExport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdNetworkAnalyticsAsyncQueryExport = function (_AbstractCrudObject) {
  inherits(AdNetworkAnalyticsAsyncQueryExport, _AbstractCrudObject);

  function AdNetworkAnalyticsAsyncQueryExport() {
    classCallCheck(this, AdNetworkAnalyticsAsyncQueryExport);
    return possibleConstructorReturn(this, (AdNetworkAnalyticsAsyncQueryExport.__proto__ || Object.getPrototypeOf(AdNetworkAnalyticsAsyncQueryExport)).apply(this, arguments));
  }

  createClass(AdNetworkAnalyticsAsyncQueryExport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        error: 'error',
        export_link: 'export_link',
        query_id: 'query_id',
        status: 'status'
      });
    }
  }]);
  return AdNetworkAnalyticsAsyncQueryExport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdPlacePageSetMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdPlacePageSetMetadata = function (_AbstractCrudObject) {
  inherits(AdPlacePageSetMetadata, _AbstractCrudObject);

  function AdPlacePageSetMetadata() {
    classCallCheck(this, AdPlacePageSetMetadata);
    return possibleConstructorReturn(this, (AdPlacePageSetMetadata.__proto__ || Object.getPrototypeOf(AdPlacePageSetMetadata)).apply(this, arguments));
  }

  createClass(AdPlacePageSetMetadata, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience: 'audience',
        custom: 'custom',
        extra_data: 'extra_data',
        fixed_radius: 'fixed_radius'
      });
    }
  }]);
  return AdPlacePageSetMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdPromotedObject
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdPromotedObject = function (_AbstractCrudObject) {
  inherits(AdPromotedObject, _AbstractCrudObject);

  function AdPromotedObject() {
    classCallCheck(this, AdPromotedObject);
    return possibleConstructorReturn(this, (AdPromotedObject.__proto__ || Object.getPrototypeOf(AdPromotedObject)).apply(this, arguments));
  }

  createClass(AdPromotedObject, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        application_id: 'application_id',
        boosted_product_set_id: 'boosted_product_set_id',
        conversion_goal_id: 'conversion_goal_id',
        custom_conversion_id: 'custom_conversion_id',
        custom_event_str: 'custom_event_str',
        custom_event_type: 'custom_event_type',
        event_id: 'event_id',
        fundraiser_campaign_id: 'fundraiser_campaign_id',
        lead_ads_form_event_source_type: 'lead_ads_form_event_source_type',
        mcme_conversion_id: 'mcme_conversion_id',
        object_store_url: 'object_store_url',
        offer_id: 'offer_id',
        offline_conversion_data_set_id: 'offline_conversion_data_set_id',
        offsite_conversion_event_id: 'offsite_conversion_event_id',
        omnichannel_object: 'omnichannel_object',
        page_id: 'page_id',
        pixel_aggregation_rule: 'pixel_aggregation_rule',
        pixel_id: 'pixel_id',
        pixel_rule: 'pixel_rule',
        place_page_set: 'place_page_set',
        place_page_set_id: 'place_page_set_id',
        product_catalog_id: 'product_catalog_id',
        product_item_id: 'product_item_id',
        product_set: 'product_set',
        product_set_id: 'product_set_id',
        retention_days: 'retention_days',
        value_semantic_type: 'value_semantic_type',
        variation: 'variation',
        whatsapp_phone_number: 'whatsapp_phone_number'
      });
    }
  }, {
    key: 'CustomEventType',
    get: function get() {
      return Object.freeze({
        achievement_unlocked: 'ACHIEVEMENT_UNLOCKED',
        add_payment_info: 'ADD_PAYMENT_INFO',
        add_to_cart: 'ADD_TO_CART',
        add_to_wishlist: 'ADD_TO_WISHLIST',
        ad_impression: 'AD_IMPRESSION',
        complete_registration: 'COMPLETE_REGISTRATION',
        contact: 'CONTACT',
        content_view: 'CONTENT_VIEW',
        customize_product: 'CUSTOMIZE_PRODUCT',
        d2_retention: 'D2_RETENTION',
        d7_retention: 'D7_RETENTION',
        donate: 'DONATE',
        find_location: 'FIND_LOCATION',
        initiated_checkout: 'INITIATED_CHECKOUT',
        lead: 'LEAD',
        level_achieved: 'LEVEL_ACHIEVED',
        listing_interaction: 'LISTING_INTERACTION',
        messaging_conversation_started_7d: 'MESSAGING_CONVERSATION_STARTED_7D',
        other: 'OTHER',
        purchase: 'PURCHASE',
        rate: 'RATE',
        schedule: 'SCHEDULE',
        search: 'SEARCH',
        service_booking_request: 'SERVICE_BOOKING_REQUEST',
        spent_credits: 'SPENT_CREDITS',
        start_trial: 'START_TRIAL',
        submit_application: 'SUBMIT_APPLICATION',
        subscribe: 'SUBSCRIBE',
        tutorial_completion: 'TUTORIAL_COMPLETION'
      });
    }
  }]);
  return AdPromotedObject;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdProposal
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdProposal = function (_AbstractCrudObject) {
  inherits(AdProposal, _AbstractCrudObject);

  function AdProposal() {
    classCallCheck(this, AdProposal);
    return possibleConstructorReturn(this, (AdProposal.__proto__ || Object.getPrototypeOf(AdProposal)).apply(this, arguments));
  }

  createClass(AdProposal, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_proposal_type_name: 'ad_proposal_type_name',
        adaccount: 'adaccount',
        creation_time: 'creation_time',
        creator: 'creator',
        delivery_interface: 'delivery_interface',
        expiration_time: 'expiration_time',
        has_conflict: 'has_conflict',
        id: 'id',
        kpi_metric: 'kpi_metric',
        message: 'message',
        name: 'name',
        proposal_dts_template: 'proposal_dts_template',
        proposal_template_name: 'proposal_template_name',
        recommendation: 'recommendation',
        review_time: 'review_time',
        reviewed_by: 'reviewed_by',
        send_time: 'send_time',
        status: 'status',
        use_testing: 'use_testing'
      });
    }
  }]);
  return AdProposal;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRecommendation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRecommendation = function (_AbstractCrudObject) {
  inherits(AdRecommendation, _AbstractCrudObject);

  function AdRecommendation() {
    classCallCheck(this, AdRecommendation);
    return possibleConstructorReturn(this, (AdRecommendation.__proto__ || Object.getPrototypeOf(AdRecommendation)).apply(this, arguments));
  }

  createClass(AdRecommendation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        blame_field: 'blame_field',
        code: 'code',
        confidence: 'confidence',
        importance: 'importance',
        message: 'message',
        recommendation_data: 'recommendation_data',
        title: 'title',
        value: 'value'
      });
    }
  }, {
    key: 'Confidence',
    get: function get() {
      return Object.freeze({
        high: 'HIGH',
        low: 'LOW',
        medium: 'MEDIUM'
      });
    }
  }, {
    key: 'Importance',
    get: function get() {
      return Object.freeze({
        high: 'HIGH',
        low: 'LOW',
        medium: 'MEDIUM'
      });
    }
  }]);
  return AdRecommendation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRecommendationData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRecommendationData = function (_AbstractCrudObject) {
  inherits(AdRecommendationData, _AbstractCrudObject);

  function AdRecommendationData() {
    classCallCheck(this, AdRecommendationData);
    return possibleConstructorReturn(this, (AdRecommendationData.__proto__ || Object.getPrototypeOf(AdRecommendationData)).apply(this, arguments));
  }

  createClass(AdRecommendationData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        link: 'link'
      });
    }
  }]);
  return AdRecommendationData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleEvaluationSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleEvaluationSpec = function (_AbstractCrudObject) {
  inherits(AdRuleEvaluationSpec, _AbstractCrudObject);

  function AdRuleEvaluationSpec() {
    classCallCheck(this, AdRuleEvaluationSpec);
    return possibleConstructorReturn(this, (AdRuleEvaluationSpec.__proto__ || Object.getPrototypeOf(AdRuleEvaluationSpec)).apply(this, arguments));
  }

  createClass(AdRuleEvaluationSpec, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        evaluation_type: 'evaluation_type',
        filters: 'filters',
        trigger: 'trigger',
        id: 'id'
      });
    }
  }, {
    key: 'EvaluationType',
    get: function get() {
      return Object.freeze({
        schedule: 'SCHEDULE',
        trigger: 'TRIGGER'
      });
    }
  }]);
  return AdRuleEvaluationSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleExecutionOptions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleExecutionOptions = function (_AbstractCrudObject) {
  inherits(AdRuleExecutionOptions, _AbstractCrudObject);

  function AdRuleExecutionOptions() {
    classCallCheck(this, AdRuleExecutionOptions);
    return possibleConstructorReturn(this, (AdRuleExecutionOptions.__proto__ || Object.getPrototypeOf(AdRuleExecutionOptions)).apply(this, arguments));
  }

  createClass(AdRuleExecutionOptions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        field: 'field',
        operator: 'operator',
        value: 'value'
      });
    }
  }, {
    key: 'Operator',
    get: function get() {
      return Object.freeze({
        equal: 'EQUAL',
        in: 'IN'
      });
    }
  }]);
  return AdRuleExecutionOptions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleExecutionSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleExecutionSpec = function (_AbstractCrudObject) {
  inherits(AdRuleExecutionSpec, _AbstractCrudObject);

  function AdRuleExecutionSpec() {
    classCallCheck(this, AdRuleExecutionSpec);
    return possibleConstructorReturn(this, (AdRuleExecutionSpec.__proto__ || Object.getPrototypeOf(AdRuleExecutionSpec)).apply(this, arguments));
  }

  createClass(AdRuleExecutionSpec, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        execution_options: 'execution_options',
        execution_type: 'execution_type',
        id: 'id'
      });
    }
  }, {
    key: 'ExecutionType',
    get: function get() {
      return Object.freeze({
        add_interest_relaxation: 'ADD_INTEREST_RELAXATION',
        add_questionnaire_interests: 'ADD_QUESTIONNAIRE_INTERESTS',
        ad_recommendation_apply: 'AD_RECOMMENDATION_APPLY',
        audience_consolidation: 'AUDIENCE_CONSOLIDATION',
        audience_consolidation_ask_first: 'AUDIENCE_CONSOLIDATION_ASK_FIRST',
        change_bid: 'CHANGE_BID',
        change_budget: 'CHANGE_BUDGET',
        change_campaign_budget: 'CHANGE_CAMPAIGN_BUDGET',
        dco: 'DCO',
        increase_radius: 'INCREASE_RADIUS',
        notification: 'NOTIFICATION',
        pause: 'PAUSE',
        ping_endpoint: 'PING_ENDPOINT',
        rebalance_budget: 'REBALANCE_BUDGET',
        rotate: 'ROTATE',
        unpause: 'UNPAUSE',
        update_creative: 'UPDATE_CREATIVE',
        update_lax_budget: 'UPDATE_LAX_BUDGET',
        update_lax_duration: 'UPDATE_LAX_DURATION'
      });
    }
  }]);
  return AdRuleExecutionSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleFilters
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleFilters = function (_AbstractCrudObject) {
  inherits(AdRuleFilters, _AbstractCrudObject);

  function AdRuleFilters() {
    classCallCheck(this, AdRuleFilters);
    return possibleConstructorReturn(this, (AdRuleFilters.__proto__ || Object.getPrototypeOf(AdRuleFilters)).apply(this, arguments));
  }

  createClass(AdRuleFilters, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        field: 'field',
        operator: 'operator',
        value: 'value'
      });
    }
  }, {
    key: 'Operator',
    get: function get() {
      return Object.freeze({
        all: 'ALL',
        any: 'ANY',
        contain: 'CONTAIN',
        equal: 'EQUAL',
        greater_than: 'GREATER_THAN',
        in: 'IN',
        in_range: 'IN_RANGE',
        less_than: 'LESS_THAN',
        none: 'NONE',
        not_contain: 'NOT_CONTAIN',
        not_equal: 'NOT_EQUAL',
        not_in: 'NOT_IN',
        not_in_range: 'NOT_IN_RANGE'
      });
    }
  }]);
  return AdRuleFilters;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleHistoryResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleHistoryResult = function (_AbstractCrudObject) {
  inherits(AdRuleHistoryResult, _AbstractCrudObject);

  function AdRuleHistoryResult() {
    classCallCheck(this, AdRuleHistoryResult);
    return possibleConstructorReturn(this, (AdRuleHistoryResult.__proto__ || Object.getPrototypeOf(AdRuleHistoryResult)).apply(this, arguments));
  }

  createClass(AdRuleHistoryResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actions: 'actions',
        object_id: 'object_id',
        object_type: 'object_type'
      });
    }
  }, {
    key: 'ObjectType',
    get: function get() {
      return Object.freeze({
        ad: 'AD',
        adset: 'ADSET',
        campaign: 'CAMPAIGN'
      });
    }
  }]);
  return AdRuleHistoryResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleHistoryResultAction
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleHistoryResultAction = function (_AbstractCrudObject) {
  inherits(AdRuleHistoryResultAction, _AbstractCrudObject);

  function AdRuleHistoryResultAction() {
    classCallCheck(this, AdRuleHistoryResultAction);
    return possibleConstructorReturn(this, (AdRuleHistoryResultAction.__proto__ || Object.getPrototypeOf(AdRuleHistoryResultAction)).apply(this, arguments));
  }

  createClass(AdRuleHistoryResultAction, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action: 'action',
        field: 'field',
        new_value: 'new_value',
        old_value: 'old_value'
      });
    }
  }]);
  return AdRuleHistoryResultAction;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleSchedule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleSchedule = function (_AbstractCrudObject) {
  inherits(AdRuleSchedule, _AbstractCrudObject);

  function AdRuleSchedule() {
    classCallCheck(this, AdRuleSchedule);
    return possibleConstructorReturn(this, (AdRuleSchedule.__proto__ || Object.getPrototypeOf(AdRuleSchedule)).apply(this, arguments));
  }

  createClass(AdRuleSchedule, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        days: 'days',
        end_minute: 'end_minute',
        start_minute: 'start_minute'
      });
    }
  }]);
  return AdRuleSchedule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleScheduleSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleScheduleSpec = function (_AbstractCrudObject) {
  inherits(AdRuleScheduleSpec, _AbstractCrudObject);

  function AdRuleScheduleSpec() {
    classCallCheck(this, AdRuleScheduleSpec);
    return possibleConstructorReturn(this, (AdRuleScheduleSpec.__proto__ || Object.getPrototypeOf(AdRuleScheduleSpec)).apply(this, arguments));
  }

  createClass(AdRuleScheduleSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        schedule: 'schedule',
        schedule_type: 'schedule_type'
      });
    }
  }]);
  return AdRuleScheduleSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdRuleTrigger
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdRuleTrigger = function (_AbstractCrudObject) {
  inherits(AdRuleTrigger, _AbstractCrudObject);

  function AdRuleTrigger() {
    classCallCheck(this, AdRuleTrigger);
    return possibleConstructorReturn(this, (AdRuleTrigger.__proto__ || Object.getPrototypeOf(AdRuleTrigger)).apply(this, arguments));
  }

  createClass(AdRuleTrigger, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        field: 'field',
        operator: 'operator',
        type: 'type',
        value: 'value'
      });
    }
  }, {
    key: 'Operator',
    get: function get() {
      return Object.freeze({
        all: 'ALL',
        any: 'ANY',
        contain: 'CONTAIN',
        equal: 'EQUAL',
        greater_than: 'GREATER_THAN',
        in: 'IN',
        in_range: 'IN_RANGE',
        less_than: 'LESS_THAN',
        none: 'NONE',
        not_contain: 'NOT_CONTAIN',
        not_equal: 'NOT_EQUAL',
        not_in: 'NOT_IN',
        not_in_range: 'NOT_IN_RANGE'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        delivery_insights_change: 'DELIVERY_INSIGHTS_CHANGE',
        metadata_creation: 'METADATA_CREATION',
        metadata_update: 'METADATA_UPDATE',
        stats_change: 'STATS_CHANGE',
        stats_milestone: 'STATS_MILESTONE'
      });
    }
  }]);
  return AdRuleTrigger;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdSavedLocation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdSavedLocation = function (_AbstractCrudObject) {
  inherits(AdSavedLocation, _AbstractCrudObject);

  function AdSavedLocation() {
    classCallCheck(this, AdSavedLocation);
    return possibleConstructorReturn(this, (AdSavedLocation.__proto__ || Object.getPrototypeOf(AdSavedLocation)).apply(this, arguments));
  }

  createClass(AdSavedLocation, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        cities: 'cities',
        countries: 'countries',
        country_groups: 'country_groups',
        custom_locations: 'custom_locations',
        geo_markets: 'geo_markets',
        id: 'id',
        location_sentences: 'location_sentences',
        name: 'name',
        regions: 'regions',
        zips: 'zips'
      });
    }
  }]);
  return AdSavedLocation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdSavedReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdSavedReport = function (_AbstractCrudObject) {
  inherits(AdSavedReport, _AbstractCrudObject);

  function AdSavedReport() {
    classCallCheck(this, AdSavedReport);
    return possibleConstructorReturn(this, (AdSavedReport.__proto__ || Object.getPrototypeOf(AdSavedReport)).apply(this, arguments));
  }

  createClass(AdSavedReport, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_owner: 'app_owner',
        breakdowns: 'breakdowns',
        builtin_column_set: 'builtin_column_set',
        creation_source: 'creation_source',
        date_interval: 'date_interval',
        date_preset: 'date_preset',
        format_version: 'format_version',
        id: 'id',
        insights_section: 'insights_section',
        is_shared_unread: 'is_shared_unread',
        level: 'level',
        name: 'name',
        normalized_filter: 'normalized_filter',
        sort: 'sort',
        user_attribution_windows: 'user_attribution_windows',
        user_columns: 'user_columns',
        user_filter: 'user_filter',
        user_owner: 'user_owner'
      });
    }
  }]);
  return AdSavedReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdStudyObjectiveID
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdStudyObjectiveID = function (_AbstractCrudObject) {
  inherits(AdStudyObjectiveID, _AbstractCrudObject);

  function AdStudyObjectiveID() {
    classCallCheck(this, AdStudyObjectiveID);
    return possibleConstructorReturn(this, (AdStudyObjectiveID.__proto__ || Object.getPrototypeOf(AdStudyObjectiveID)).apply(this, arguments));
  }

  createClass(AdStudyObjectiveID, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        event_names: 'event_names',
        id: 'id',
        type: 'type'
      });
    }
  }]);
  return AdStudyObjectiveID;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdStudyObjectiveOffsiteDatasets
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdStudyObjectiveOffsiteDatasets = function (_AbstractCrudObject) {
  inherits(AdStudyObjectiveOffsiteDatasets, _AbstractCrudObject);

  function AdStudyObjectiveOffsiteDatasets() {
    classCallCheck(this, AdStudyObjectiveOffsiteDatasets);
    return possibleConstructorReturn(this, (AdStudyObjectiveOffsiteDatasets.__proto__ || Object.getPrototypeOf(AdStudyObjectiveOffsiteDatasets)).apply(this, arguments));
  }

  createClass(AdStudyObjectiveOffsiteDatasets, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        event_names: 'event_names',
        id: 'id'
      });
    }
  }]);
  return AdStudyObjectiveOffsiteDatasets;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdTopline
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdTopline = function (_AbstractCrudObject) {
  inherits(AdTopline, _AbstractCrudObject);

  function AdTopline() {
    classCallCheck(this, AdTopline);
    return possibleConstructorReturn(this, (AdTopline.__proto__ || Object.getPrototypeOf(AdTopline)).apply(this, arguments));
  }

  createClass(AdTopline, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        client_approval_date: 'client_approval_date',
        created_by: 'created_by',
        created_date: 'created_date',
        description: 'description',
        flight_end_date: 'flight_end_date',
        flight_start_date: 'flight_start_date',
        func_cap_amount: 'func_cap_amount',
        func_cap_amount_with_offset: 'func_cap_amount_with_offset',
        func_line_amount: 'func_line_amount',
        func_line_amount_with_offset: 'func_line_amount_with_offset',
        func_price: 'func_price',
        func_price_with_offset: 'func_price_with_offset',
        gender: 'gender',
        id: 'id',
        impressions: 'impressions',
        io_number: 'io_number',
        is_bonus_line: 'is_bonus_line',
        keywords: 'keywords',
        last_updated_by: 'last_updated_by',
        last_updated_date: 'last_updated_date',
        line_number: 'line_number',
        line_position: 'line_position',
        line_type: 'line_type',
        location: 'location',
        max_age: 'max_age',
        max_budget: 'max_budget',
        min_age: 'min_age',
        price_per_trp: 'price_per_trp',
        product_type: 'product_type',
        rev_assurance_approval_date: 'rev_assurance_approval_date',
        targets: 'targets',
        trp_updated_time: 'trp_updated_time',
        trp_value: 'trp_value',
        uom: 'uom'
      });
    }
  }]);
  return AdTopline;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdToplineDetail
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdToplineDetail = function (_AbstractCrudObject) {
  inherits(AdToplineDetail, _AbstractCrudObject);

  function AdToplineDetail() {
    classCallCheck(this, AdToplineDetail);
    return possibleConstructorReturn(this, (AdToplineDetail.__proto__ || Object.getPrototypeOf(AdToplineDetail)).apply(this, arguments));
  }

  createClass(AdToplineDetail, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        active_status: 'active_status',
        ad_account_id: 'ad_account_id',
        flight_end_date: 'flight_end_date',
        flight_start_date: 'flight_start_date',
        id: 'id',
        io_number: 'io_number',
        line_number: 'line_number',
        price: 'price',
        quantity: 'quantity',
        sf_detail_line_id: 'sf_detail_line_id',
        subline_id: 'subline_id',
        targets: 'targets',
        time_created: 'time_created',
        time_updated: 'time_updated'
      });
    }
  }]);
  return AdToplineDetail;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdVolume
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdVolume = function (_AbstractCrudObject) {
  inherits(AdVolume, _AbstractCrudObject);

  function AdVolume() {
    classCallCheck(this, AdVolume);
    return possibleConstructorReturn(this, (AdVolume.__proto__ || Object.getPrototypeOf(AdVolume)).apply(this, arguments));
  }

  createClass(AdVolume, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_volume_break_down: 'ad_volume_break_down',
        ads_running_or_in_review_count: 'ads_running_or_in_review_count',
        future_limit_activation_date: 'future_limit_activation_date',
        future_limit_on_ads_running_or_in_review: 'future_limit_on_ads_running_or_in_review',
        individual_accounts_ad_volume: 'individual_accounts_ad_volume',
        is_gpa_page: 'is_gpa_page',
        limit_on_ads_running_or_in_review: 'limit_on_ads_running_or_in_review',
        owning_business_ad_volume: 'owning_business_ad_volume',
        partner_business_ad_volume: 'partner_business_ad_volume',
        user_role: 'user_role'
      });
    }
  }]);
  return AdVolume;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdgroupFacebookFeedback
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdgroupFacebookFeedback = function (_AbstractCrudObject) {
  inherits(AdgroupFacebookFeedback, _AbstractCrudObject);

  function AdgroupFacebookFeedback() {
    classCallCheck(this, AdgroupFacebookFeedback);
    return possibleConstructorReturn(this, (AdgroupFacebookFeedback.__proto__ || Object.getPrototypeOf(AdgroupFacebookFeedback)).apply(this, arguments));
  }

  createClass(AdgroupFacebookFeedback, [{
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Comment, fields, params, fetchFirstPage, '/comments');
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        preview: 'preview'
      });
    }
  }]);
  return AdgroupFacebookFeedback;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdgroupIssuesInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdgroupIssuesInfo = function (_AbstractCrudObject) {
  inherits(AdgroupIssuesInfo, _AbstractCrudObject);

  function AdgroupIssuesInfo() {
    classCallCheck(this, AdgroupIssuesInfo);
    return possibleConstructorReturn(this, (AdgroupIssuesInfo.__proto__ || Object.getPrototypeOf(AdgroupIssuesInfo)).apply(this, arguments));
  }

  createClass(AdgroupIssuesInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        error_code: 'error_code',
        error_message: 'error_message',
        error_summary: 'error_summary',
        error_type: 'error_type',
        level: 'level'
      });
    }
  }]);
  return AdgroupIssuesInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdgroupMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdgroupMetadata = function (_AbstractCrudObject) {
  inherits(AdgroupMetadata, _AbstractCrudObject);

  function AdgroupMetadata() {
    classCallCheck(this, AdgroupMetadata);
    return possibleConstructorReturn(this, (AdgroupMetadata.__proto__ || Object.getPrototypeOf(AdgroupMetadata)).apply(this, arguments));
  }

  createClass(AdgroupMetadata, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_standard_enhancements_edit_source: 'ad_standard_enhancements_edit_source',
        adgroup_creation_source: 'adgroup_creation_source',
        adgroup_edit_source: 'adgroup_edit_source',
        carousel_style: 'carousel_style',
        carousel_with_static_card_style: 'carousel_with_static_card_style'
      });
    }
  }]);
  return AdgroupMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdgroupPlacementSpecificReviewFeedback
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdgroupPlacementSpecificReviewFeedback = function (_AbstractCrudObject) {
  inherits(AdgroupPlacementSpecificReviewFeedback, _AbstractCrudObject);

  function AdgroupPlacementSpecificReviewFeedback() {
    classCallCheck(this, AdgroupPlacementSpecificReviewFeedback);
    return possibleConstructorReturn(this, (AdgroupPlacementSpecificReviewFeedback.__proto__ || Object.getPrototypeOf(AdgroupPlacementSpecificReviewFeedback)).apply(this, arguments));
  }

  createClass(AdgroupPlacementSpecificReviewFeedback, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_admin: 'account_admin',
        ad: 'ad',
        ads_conversion_experiences: 'ads_conversion_experiences',
        b2c: 'b2c',
        b2c_commerce_unified: 'b2c_commerce_unified',
        bsg: 'bsg',
        city_community: 'city_community',
        commerce: 'commerce',
        compromise: 'compromise',
        daily_deals: 'daily_deals',
        daily_deals_legacy: 'daily_deals_legacy',
        dpa: 'dpa',
        dri_copyright: 'dri_copyright',
        dri_counterfeit: 'dri_counterfeit',
        facebook: 'facebook',
        facebook_pages_live_shopping: 'facebook_pages_live_shopping',
        independent_work: 'independent_work',
        instagram: 'instagram',
        instagram_shop: 'instagram_shop',
        job_search: 'job_search',
        lead_gen_honeypot: 'lead_gen_honeypot',
        marketplace: 'marketplace',
        marketplace_home_rentals: 'marketplace_home_rentals',
        marketplace_home_sales: 'marketplace_home_sales',
        marketplace_motors: 'marketplace_motors',
        marketplace_shops: 'marketplace_shops',
        max_review_placements: 'max_review_placements',
        neighborhoods: 'neighborhoods',
        page_admin: 'page_admin',
        product: 'product',
        product_service: 'product_service',
        profile: 'profile',
        seller: 'seller',
        shops: 'shops',
        traffic_quality: 'traffic_quality',
        unified_commerce_content: 'unified_commerce_content',
        whatsapp: 'whatsapp'
      });
    }
  }]);
  return AdgroupPlacementSpecificReviewFeedback;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdgroupReviewFeedback
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdgroupReviewFeedback = function (_AbstractCrudObject) {
  inherits(AdgroupReviewFeedback, _AbstractCrudObject);

  function AdgroupReviewFeedback() {
    classCallCheck(this, AdgroupReviewFeedback);
    return possibleConstructorReturn(this, (AdgroupReviewFeedback.__proto__ || Object.getPrototypeOf(AdgroupReviewFeedback)).apply(this, arguments));
  }

  createClass(AdgroupReviewFeedback, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        global: 'global',
        placement_specific: 'placement_specific'
      });
    }
  }]);
  return AdgroupReviewFeedback;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdjacentContentDeliveryReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdjacentContentDeliveryReport = function (_AbstractCrudObject) {
  inherits(AdjacentContentDeliveryReport, _AbstractCrudObject);

  function AdjacentContentDeliveryReport() {
    classCallCheck(this, AdjacentContentDeliveryReport);
    return possibleConstructorReturn(this, (AdjacentContentDeliveryReport.__proto__ || Object.getPrototypeOf(AdjacentContentDeliveryReport)).apply(this, arguments));
  }

  createClass(AdjacentContentDeliveryReport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_id: 'ad_id',
        content: 'content',
        impression_id: 'impression_id'
      });
    }
  }]);
  return AdjacentContentDeliveryReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsActionStats
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsActionStats = function (_AbstractCrudObject) {
  inherits(AdsActionStats, _AbstractCrudObject);

  function AdsActionStats() {
    classCallCheck(this, AdsActionStats);
    return possibleConstructorReturn(this, (AdsActionStats.__proto__ || Object.getPrototypeOf(AdsActionStats)).apply(this, arguments));
  }

  createClass(AdsActionStats, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        value_1d_click: '1d_click',
        value_1d_click_all_conversions: '1d_click_all_conversions',
        value_1d_click_first_conversion: '1d_click_first_conversion',
        value_1d_ev: '1d_ev',
        value_1d_ev_all_conversions: '1d_ev_all_conversions',
        value_1d_ev_first_conversion: '1d_ev_first_conversion',
        value_1d_view: '1d_view',
        value_1d_view_all_conversions: '1d_view_all_conversions',
        value_1d_view_first_conversion: '1d_view_first_conversion',
        value_28d_click: '28d_click',
        value_28d_click_all_conversions: '28d_click_all_conversions',
        value_28d_click_first_conversion: '28d_click_first_conversion',
        value_28d_view: '28d_view',
        value_28d_view_all_conversions: '28d_view_all_conversions',
        value_28d_view_first_conversion: '28d_view_first_conversion',
        value_7d_click: '7d_click',
        value_7d_click_all_conversions: '7d_click_all_conversions',
        value_7d_click_first_conversion: '7d_click_first_conversion',
        value_7d_view: '7d_view',
        value_7d_view_all_conversions: '7d_view_all_conversions',
        value_7d_view_first_conversion: '7d_view_first_conversion',
        action_brand: 'action_brand',
        action_canvas_component_id: 'action_canvas_component_id',
        action_canvas_component_name: 'action_canvas_component_name',
        action_carousel_card_id: 'action_carousel_card_id',
        action_carousel_card_name: 'action_carousel_card_name',
        action_category: 'action_category',
        action_converted_product_id: 'action_converted_product_id',
        action_destination: 'action_destination',
        action_device: 'action_device',
        action_event_channel: 'action_event_channel',
        action_link_click_destination: 'action_link_click_destination',
        action_location_code: 'action_location_code',
        action_reaction: 'action_reaction',
        action_target_id: 'action_target_id',
        action_type: 'action_type',
        action_video_asset_id: 'action_video_asset_id',
        action_video_sound: 'action_video_sound',
        action_video_type: 'action_video_type',
        dda: 'dda',
        inline: 'inline',
        interactive_component_sticker_id: 'interactive_component_sticker_id',
        interactive_component_sticker_response: 'interactive_component_sticker_response',
        skan_click: 'skan_click',
        skan_click_second_postback: 'skan_click_second_postback',
        skan_click_third_postback: 'skan_click_third_postback',
        skan_view: 'skan_view',
        skan_view_second_postback: 'skan_view_second_postback',
        skan_view_third_postback: 'skan_view_third_postback',
        value: 'value'
      });
    }
  }]);
  return AdsActionStats;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsAnomalyDetection
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsAnomalyDetection = function (_AbstractCrudObject) {
  inherits(AdsAnomalyDetection, _AbstractCrudObject);

  function AdsAnomalyDetection() {
    classCallCheck(this, AdsAnomalyDetection);
    return possibleConstructorReturn(this, (AdsAnomalyDetection.__proto__ || Object.getPrototypeOf(AdsAnomalyDetection)).apply(this, arguments));
  }

  createClass(AdsAnomalyDetection, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        anomaly_data: 'anomaly_data',
        day: 'day'
      });
    }
  }]);
  return AdsAnomalyDetection;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsCreationSavedState
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsCreationSavedState = function (_AbstractCrudObject) {
  inherits(AdsCreationSavedState, _AbstractCrudObject);

  function AdsCreationSavedState() {
    classCallCheck(this, AdsCreationSavedState);
    return possibleConstructorReturn(this, (AdsCreationSavedState.__proto__ || Object.getPrototypeOf(AdsCreationSavedState)).apply(this, arguments));
  }

  createClass(AdsCreationSavedState, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account: 'ad_account',
        id: 'id',
        serialized_store_data: 'serialized_store_data',
        time_updated: 'time_updated',
        user: 'user'
      });
    }
  }]);
  return AdsCreationSavedState;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsCustomPivotsPreview
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsCustomPivotsPreview = function (_AbstractCrudObject) {
  inherits(AdsCustomPivotsPreview, _AbstractCrudObject);

  function AdsCustomPivotsPreview() {
    classCallCheck(this, AdsCustomPivotsPreview);
    return possibleConstructorReturn(this, (AdsCustomPivotsPreview.__proto__ || Object.getPrototypeOf(AdsCustomPivotsPreview)).apply(this, arguments));
  }

  createClass(AdsCustomPivotsPreview, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        account_name: 'account_name',
        ad_id: 'ad_id',
        ad_name: 'ad_name',
        adset_id: 'adset_id',
        adset_name: 'adset_name',
        campaign_id: 'campaign_id',
        campaign_name: 'campaign_name',
        custom_breakdown: 'custom_breakdown'
      });
    }
  }]);
  return AdsCustomPivotsPreview;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsDataPartner
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsDataPartner = function (_AbstractCrudObject) {
  inherits(AdsDataPartner, _AbstractCrudObject);

  function AdsDataPartner() {
    classCallCheck(this, AdsDataPartner);
    return possibleConstructorReturn(this, (AdsDataPartner.__proto__ || Object.getPrototypeOf(AdsDataPartner)).apply(this, arguments));
  }

  createClass(AdsDataPartner, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        rev_share_policies: 'rev_share_policies'
      });
    }
  }]);
  return AdsDataPartner;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsGuidanceQEExposure
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsGuidanceQEExposure = function (_AbstractCrudObject) {
  inherits(AdsGuidanceQEExposure, _AbstractCrudObject);

  function AdsGuidanceQEExposure() {
    classCallCheck(this, AdsGuidanceQEExposure);
    return possibleConstructorReturn(this, (AdsGuidanceQEExposure.__proto__ || Object.getPrototypeOf(AdsGuidanceQEExposure)).apply(this, arguments));
  }

  createClass(AdsGuidanceQEExposure, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_exposed: 'account_exposed'
      });
    }
  }]);
  return AdsGuidanceQEExposure;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsHistogramStats
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsHistogramStats = function (_AbstractCrudObject) {
  inherits(AdsHistogramStats, _AbstractCrudObject);

  function AdsHistogramStats() {
    classCallCheck(this, AdsHistogramStats);
    return possibleConstructorReturn(this, (AdsHistogramStats.__proto__ || Object.getPrototypeOf(AdsHistogramStats)).apply(this, arguments));
  }

  createClass(AdsHistogramStats, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        value_1d_click: '1d_click',
        value_1d_click_all_conversions: '1d_click_all_conversions',
        value_1d_click_first_conversion: '1d_click_first_conversion',
        value_1d_ev: '1d_ev',
        value_1d_ev_all_conversions: '1d_ev_all_conversions',
        value_1d_ev_first_conversion: '1d_ev_first_conversion',
        value_1d_view: '1d_view',
        value_1d_view_all_conversions: '1d_view_all_conversions',
        value_1d_view_first_conversion: '1d_view_first_conversion',
        value_28d_click: '28d_click',
        value_28d_click_all_conversions: '28d_click_all_conversions',
        value_28d_click_first_conversion: '28d_click_first_conversion',
        value_28d_view: '28d_view',
        value_28d_view_all_conversions: '28d_view_all_conversions',
        value_28d_view_first_conversion: '28d_view_first_conversion',
        value_7d_click: '7d_click',
        value_7d_click_all_conversions: '7d_click_all_conversions',
        value_7d_click_first_conversion: '7d_click_first_conversion',
        value_7d_view: '7d_view',
        value_7d_view_all_conversions: '7d_view_all_conversions',
        value_7d_view_first_conversion: '7d_view_first_conversion',
        action_brand: 'action_brand',
        action_canvas_component_id: 'action_canvas_component_id',
        action_canvas_component_name: 'action_canvas_component_name',
        action_carousel_card_id: 'action_carousel_card_id',
        action_carousel_card_name: 'action_carousel_card_name',
        action_category: 'action_category',
        action_converted_product_id: 'action_converted_product_id',
        action_destination: 'action_destination',
        action_device: 'action_device',
        action_event_channel: 'action_event_channel',
        action_link_click_destination: 'action_link_click_destination',
        action_location_code: 'action_location_code',
        action_reaction: 'action_reaction',
        action_target_id: 'action_target_id',
        action_type: 'action_type',
        action_video_asset_id: 'action_video_asset_id',
        action_video_sound: 'action_video_sound',
        action_video_type: 'action_video_type',
        dda: 'dda',
        inline: 'inline',
        interactive_component_sticker_id: 'interactive_component_sticker_id',
        interactive_component_sticker_response: 'interactive_component_sticker_response',
        skan_click: 'skan_click',
        skan_click_second_postback: 'skan_click_second_postback',
        skan_click_third_postback: 'skan_click_third_postback',
        skan_view: 'skan_view',
        skan_view_second_postback: 'skan_view_second_postback',
        skan_view_third_postback: 'skan_view_third_postback',
        value: 'value'
      });
    }
  }]);
  return AdsHistogramStats;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsImageCrops
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsImageCrops = function (_AbstractCrudObject) {
  inherits(AdsImageCrops, _AbstractCrudObject);

  function AdsImageCrops() {
    classCallCheck(this, AdsImageCrops);
    return possibleConstructorReturn(this, (AdsImageCrops.__proto__ || Object.getPrototypeOf(AdsImageCrops)).apply(this, arguments));
  }

  createClass(AdsImageCrops, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        value_100x100: '100x100',
        value_100x72: '100x72',
        value_191x100: '191x100',
        value_400x150: '400x150',
        value_400x500: '400x500',
        value_600x360: '600x360',
        value_90x160: '90x160'
      });
    }
  }]);
  return AdsImageCrops;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsNamingTemplate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsNamingTemplate = function (_AbstractCrudObject) {
  inherits(AdsNamingTemplate, _AbstractCrudObject);

  function AdsNamingTemplate() {
    classCallCheck(this, AdsNamingTemplate);
    return possibleConstructorReturn(this, (AdsNamingTemplate.__proto__ || Object.getPrototypeOf(AdsNamingTemplate)).apply(this, arguments));
  }

  createClass(AdsNamingTemplate, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        api_fields: 'api_fields',
        api_version: 'api_version',
        field_order: 'field_order',
        id: 'id',
        level: 'level',
        separator: 'separator',
        template_version: 'template_version',
        user_defined_fields: 'user_defined_fields',
        value_separator: 'value_separator'
      });
    }
  }, {
    key: 'Level',
    get: function get() {
      return Object.freeze({
        adgroup: 'ADGROUP',
        ad_account: 'AD_ACCOUNT',
        campaign: 'CAMPAIGN',
        campaign_group: 'CAMPAIGN_GROUP',
        opportunities: 'OPPORTUNITIES',
        privacy_info_center: 'PRIVACY_INFO_CENTER',
        topline: 'TOPLINE',
        unique_adcreative: 'UNIQUE_ADCREATIVE'
      });
    }
  }]);
  return AdsNamingTemplate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsOptimalDeliveryGrowthOpportunity
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsOptimalDeliveryGrowthOpportunity = function (_AbstractCrudObject) {
  inherits(AdsOptimalDeliveryGrowthOpportunity, _AbstractCrudObject);

  function AdsOptimalDeliveryGrowthOpportunity() {
    classCallCheck(this, AdsOptimalDeliveryGrowthOpportunity);
    return possibleConstructorReturn(this, (AdsOptimalDeliveryGrowthOpportunity.__proto__ || Object.getPrototypeOf(AdsOptimalDeliveryGrowthOpportunity)).apply(this, arguments));
  }

  createClass(AdsOptimalDeliveryGrowthOpportunity, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        child_metadata: 'child_metadata',
        metadata: 'metadata',
        optimization_type: 'optimization_type'
      });
    }
  }]);
  return AdsOptimalDeliveryGrowthOpportunity;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPaymentCycle
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPaymentCycle = function (_AbstractCrudObject) {
  inherits(AdsPaymentCycle, _AbstractCrudObject);

  function AdsPaymentCycle() {
    classCallCheck(this, AdsPaymentCycle);
    return possibleConstructorReturn(this, (AdsPaymentCycle.__proto__ || Object.getPrototypeOf(AdsPaymentCycle)).apply(this, arguments));
  }

  createClass(AdsPaymentCycle, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        created_time: 'created_time',
        multiplier: 'multiplier',
        requested_threshold_amount: 'requested_threshold_amount',
        threshold_amount: 'threshold_amount',
        updated_time: 'updated_time'
      });
    }
  }]);
  return AdsPaymentCycle;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPivotRules
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPivotRules = function (_AbstractCrudObject) {
  inherits(AdsPivotRules, _AbstractCrudObject);

  function AdsPivotRules() {
    classCallCheck(this, AdsPivotRules);
    return possibleConstructorReturn(this, (AdsPivotRules.__proto__ || Object.getPrototypeOf(AdsPivotRules)).apply(this, arguments));
  }

  createClass(AdsPivotRules, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        creator: 'creator',
        description: 'description',
        id: 'id',
        name: 'name',
        permission: 'permission',
        rules: 'rules',
        scope: 'scope',
        update_by: 'update_by',
        update_time: 'update_time'
      });
    }
  }]);
  return AdsPivotRules;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelCAPISetupQuality
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelCAPISetupQuality = function (_AbstractCrudObject) {
  inherits(AdsPixelCAPISetupQuality, _AbstractCrudObject);

  function AdsPixelCAPISetupQuality() {
    classCallCheck(this, AdsPixelCAPISetupQuality);
    return possibleConstructorReturn(this, (AdsPixelCAPISetupQuality.__proto__ || Object.getPrototypeOf(AdsPixelCAPISetupQuality)).apply(this, arguments));
  }

  createClass(AdsPixelCAPISetupQuality, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        event_match_quality: 'event_match_quality',
        event_name: 'event_name'
      });
    }
  }]);
  return AdsPixelCAPISetupQuality;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelCapabilityOverride
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelCapabilityOverride = function (_AbstractCrudObject) {
  inherits(AdsPixelCapabilityOverride, _AbstractCrudObject);

  function AdsPixelCapabilityOverride() {
    classCallCheck(this, AdsPixelCapabilityOverride);
    return possibleConstructorReturn(this, (AdsPixelCapabilityOverride.__proto__ || Object.getPrototypeOf(AdsPixelCapabilityOverride)).apply(this, arguments));
  }

  createClass(AdsPixelCapabilityOverride, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        capability: 'capability',
        id: 'id',
        override_value: 'override_value',
        reason: 'reason'
      });
    }
  }]);
  return AdsPixelCapabilityOverride;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelDeliveryRecommendations
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelDeliveryRecommendations = function (_AbstractCrudObject) {
  inherits(AdsPixelDeliveryRecommendations, _AbstractCrudObject);

  function AdsPixelDeliveryRecommendations() {
    classCallCheck(this, AdsPixelDeliveryRecommendations);
    return possibleConstructorReturn(this, (AdsPixelDeliveryRecommendations.__proto__ || Object.getPrototypeOf(AdsPixelDeliveryRecommendations)).apply(this, arguments));
  }

  createClass(AdsPixelDeliveryRecommendations, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        custom_event_type: 'custom_event_type',
        optimization_goal: 'optimization_goal'
      });
    }
  }]);
  return AdsPixelDeliveryRecommendations;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelDomainControlRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelDomainControlRule = function (_AbstractCrudObject) {
  inherits(AdsPixelDomainControlRule, _AbstractCrudObject);

  function AdsPixelDomainControlRule() {
    classCallCheck(this, AdsPixelDomainControlRule);
    return possibleConstructorReturn(this, (AdsPixelDomainControlRule.__proto__ || Object.getPrototypeOf(AdsPixelDomainControlRule)).apply(this, arguments));
  }

  createClass(AdsPixelDomainControlRule, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        domain_list: 'domain_list',
        type: 'type'
      });
    }
  }]);
  return AdsPixelDomainControlRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelDomainLastFiredTime
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelDomainLastFiredTime = function (_AbstractCrudObject) {
  inherits(AdsPixelDomainLastFiredTime, _AbstractCrudObject);

  function AdsPixelDomainLastFiredTime() {
    classCallCheck(this, AdsPixelDomainLastFiredTime);
    return possibleConstructorReturn(this, (AdsPixelDomainLastFiredTime.__proto__ || Object.getPrototypeOf(AdsPixelDomainLastFiredTime)).apply(this, arguments));
  }

  createClass(AdsPixelDomainLastFiredTime, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        domain_name: 'domain_name',
        last_fired_time: 'last_fired_time'
      });
    }
  }]);
  return AdsPixelDomainLastFiredTime;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelEventLastFiredTime
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelEventLastFiredTime = function (_AbstractCrudObject) {
  inherits(AdsPixelEventLastFiredTime, _AbstractCrudObject);

  function AdsPixelEventLastFiredTime() {
    classCallCheck(this, AdsPixelEventLastFiredTime);
    return possibleConstructorReturn(this, (AdsPixelEventLastFiredTime.__proto__ || Object.getPrototypeOf(AdsPixelEventLastFiredTime)).apply(this, arguments));
  }

  createClass(AdsPixelEventLastFiredTime, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        event: 'event',
        last_fired_time: 'last_fired_time'
      });
    }
  }]);
  return AdsPixelEventLastFiredTime;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelEventPrediction
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelEventPrediction = function (_AbstractCrudObject) {
  inherits(AdsPixelEventPrediction, _AbstractCrudObject);

  function AdsPixelEventPrediction() {
    classCallCheck(this, AdsPixelEventPrediction);
    return possibleConstructorReturn(this, (AdsPixelEventPrediction.__proto__ || Object.getPrototypeOf(AdsPixelEventPrediction)).apply(this, arguments));
  }

  createClass(AdsPixelEventPrediction, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        dismissed: 'dismissed',
        event_type: 'event_type',
        rule: 'rule'
      });
    }
  }]);
  return AdsPixelEventPrediction;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelEventSuggestionRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelEventSuggestionRule = function (_AbstractCrudObject) {
  inherits(AdsPixelEventSuggestionRule, _AbstractCrudObject);

  function AdsPixelEventSuggestionRule() {
    classCallCheck(this, AdsPixelEventSuggestionRule);
    return possibleConstructorReturn(this, (AdsPixelEventSuggestionRule.__proto__ || Object.getPrototypeOf(AdsPixelEventSuggestionRule)).apply(this, arguments));
  }

  createClass(AdsPixelEventSuggestionRule, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        value_7d_volume: '7d_volume',
        dismissed: 'dismissed',
        end_time: 'end_time',
        event_type: 'event_type',
        rank: 'rank',
        rule: 'rule',
        sample_urls: 'sample_urls',
        start_time: 'start_time'
      });
    }
  }]);
  return AdsPixelEventSuggestionRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelItemPrice
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelItemPrice = function (_AbstractCrudObject) {
  inherits(AdsPixelItemPrice, _AbstractCrudObject);

  function AdsPixelItemPrice() {
    classCallCheck(this, AdsPixelItemPrice);
    return possibleConstructorReturn(this, (AdsPixelItemPrice.__proto__ || Object.getPrototypeOf(AdsPixelItemPrice)).apply(this, arguments));
  }

  createClass(AdsPixelItemPrice, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        date: 'date',
        item_price_coverage: 'item_price_coverage'
      });
    }
  }]);
  return AdsPixelItemPrice;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelMicrodataStats
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelMicrodataStats = function (_AbstractCrudObject) {
  inherits(AdsPixelMicrodataStats, _AbstractCrudObject);

  function AdsPixelMicrodataStats() {
    classCallCheck(this, AdsPixelMicrodataStats);
    return possibleConstructorReturn(this, (AdsPixelMicrodataStats.__proto__ || Object.getPrototypeOf(AdsPixelMicrodataStats)).apply(this, arguments));
  }

  createClass(AdsPixelMicrodataStats, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        allowed_domains: 'allowed_domains',
        errors_stats_for_time_ranges: 'errors_stats_for_time_ranges',
        has_valid_events: 'has_valid_events',
        suggested_allowed_domains_count_max: 'suggested_allowed_domains_count_max',
        suggested_trusted_domains: 'suggested_trusted_domains'
      });
    }
  }]);
  return AdsPixelMicrodataStats;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelRawFiresResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelRawFiresResult = function (_AbstractCrudObject) {
  inherits(AdsPixelRawFiresResult, _AbstractCrudObject);

  function AdsPixelRawFiresResult() {
    classCallCheck(this, AdsPixelRawFiresResult);
    return possibleConstructorReturn(this, (AdsPixelRawFiresResult.__proto__ || Object.getPrototypeOf(AdsPixelRawFiresResult)).apply(this, arguments));
  }

  createClass(AdsPixelRawFiresResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        data_json: 'data_json',
        device_type: 'device_type',
        event: 'event',
        event_detection_method: 'event_detection_method',
        event_src: 'event_src',
        placed_url: 'placed_url',
        timestamp: 'timestamp',
        user_pii_keys: 'user_pii_keys'
      });
    }
  }]);
  return AdsPixelRawFiresResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelRealTimeEventLogResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelRealTimeEventLogResult = function (_AbstractCrudObject) {
  inherits(AdsPixelRealTimeEventLogResult, _AbstractCrudObject);

  function AdsPixelRealTimeEventLogResult() {
    classCallCheck(this, AdsPixelRealTimeEventLogResult);
    return possibleConstructorReturn(this, (AdsPixelRealTimeEventLogResult.__proto__ || Object.getPrototypeOf(AdsPixelRealTimeEventLogResult)).apply(this, arguments));
  }

  createClass(AdsPixelRealTimeEventLogResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        data_json: 'data_json',
        dedup_data: 'dedup_data',
        device_type: 'device_type',
        domain_control_rule_rejection: 'domain_control_rule_rejection',
        event: 'event',
        event_detection_method: 'event_detection_method',
        in_iframe: 'in_iframe',
        matched_rule_conditions: 'matched_rule_conditions',
        resolved_link: 'resolved_link',
        source_rule_condition: 'source_rule_condition',
        timestamp: 'timestamp',
        trace_id: 'trace_id',
        url: 'url'
      });
    }
  }]);
  return AdsPixelRealTimeEventLogResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelRecentEventsResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelRecentEventsResult = function (_AbstractCrudObject) {
  inherits(AdsPixelRecentEventsResult, _AbstractCrudObject);

  function AdsPixelRecentEventsResult() {
    classCallCheck(this, AdsPixelRecentEventsResult);
    return possibleConstructorReturn(this, (AdsPixelRecentEventsResult.__proto__ || Object.getPrototypeOf(AdsPixelRecentEventsResult)).apply(this, arguments));
  }

  createClass(AdsPixelRecentEventsResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        count: 'count',
        event: 'event'
      });
    }
  }]);
  return AdsPixelRecentEventsResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelSignalsIWLFeedbackNux
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelSignalsIWLFeedbackNux = function (_AbstractCrudObject) {
  inherits(AdsPixelSignalsIWLFeedbackNux, _AbstractCrudObject);

  function AdsPixelSignalsIWLFeedbackNux() {
    classCallCheck(this, AdsPixelSignalsIWLFeedbackNux);
    return possibleConstructorReturn(this, (AdsPixelSignalsIWLFeedbackNux.__proto__ || Object.getPrototypeOf(AdsPixelSignalsIWLFeedbackNux)).apply(this, arguments));
  }

  createClass(AdsPixelSignalsIWLFeedbackNux, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        should_ask_to_rate: 'should_ask_to_rate'
      });
    }
  }]);
  return AdsPixelSignalsIWLFeedbackNux;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelSignalsIWLNux
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelSignalsIWLNux = function (_AbstractCrudObject) {
  inherits(AdsPixelSignalsIWLNux, _AbstractCrudObject);

  function AdsPixelSignalsIWLNux() {
    classCallCheck(this, AdsPixelSignalsIWLNux);
    return possibleConstructorReturn(this, (AdsPixelSignalsIWLNux.__proto__ || Object.getPrototypeOf(AdsPixelSignalsIWLNux)).apply(this, arguments));
  }

  createClass(AdsPixelSignalsIWLNux, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        background_color: 'background_color',
        content: 'content',
        content_color: 'content_color',
        content_size: 'content_size',
        img_url: 'img_url'
      });
    }
  }]);
  return AdsPixelSignalsIWLNux;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsPixelStats
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsPixelStats = function (_AbstractCrudObject) {
  inherits(AdsPixelStats, _AbstractCrudObject);

  function AdsPixelStats() {
    classCallCheck(this, AdsPixelStats);
    return possibleConstructorReturn(this, (AdsPixelStats.__proto__ || Object.getPrototypeOf(AdsPixelStats)).apply(this, arguments));
  }

  createClass(AdsPixelStats, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        count: 'count',
        diagnostics_hourly_last_timestamp: 'diagnostics_hourly_last_timestamp',
        event: 'event',
        value: 'value'
      });
    }
  }]);
  return AdsPixelStats;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsQuickViews
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsQuickViews = function (_AbstractCrudObject) {
  inherits(AdsQuickViews, _AbstractCrudObject);

  function AdsQuickViews() {
    classCallCheck(this, AdsQuickViews);
    return possibleConstructorReturn(this, (AdsQuickViews.__proto__ || Object.getPrototypeOf(AdsQuickViews)).apply(this, arguments));
  }

  createClass(AdsQuickViews, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        attribution_windows: 'attribution_windows',
        breakdowns: 'breakdowns',
        column_fields: 'column_fields',
        description: 'description',
        id: 'id',
        name: 'name',
        permission: 'permission',
        sort: 'sort'
      });
    }
  }]);
  return AdsQuickViews;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsReportBuilder
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsReportBuilder = function (_AbstractCrudObject) {
  inherits(AdsReportBuilder, _AbstractCrudObject);

  function AdsReportBuilder() {
    classCallCheck(this, AdsReportBuilder);
    return possibleConstructorReturn(this, (AdsReportBuilder.__proto__ || Object.getPrototypeOf(AdsReportBuilder)).apply(this, arguments));
  }

  createClass(AdsReportBuilder, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        headers: 'headers',
        rows: 'rows',
        skan_readiness_status: 'skan_readiness_status'
      });
    }
  }]);
  return AdsReportBuilder;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsReportBuilderExportCore
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsReportBuilderExportCore = function (_AbstractCrudObject) {
  inherits(AdsReportBuilderExportCore, _AbstractCrudObject);

  function AdsReportBuilderExportCore() {
    classCallCheck(this, AdsReportBuilderExportCore);
    return possibleConstructorReturn(this, (AdsReportBuilderExportCore.__proto__ || Object.getPrototypeOf(AdsReportBuilderExportCore)).apply(this, arguments));
  }

  createClass(AdsReportBuilderExportCore, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        async_percent_completion: 'async_percent_completion',
        async_report_url: 'async_report_url',
        async_status: 'async_status',
        client_creation_value: 'client_creation_value',
        expiry_time: 'expiry_time',
        export_download_time: 'export_download_time',
        export_format: 'export_format',
        export_name: 'export_name',
        export_type: 'export_type',
        has_seen: 'has_seen',
        id: 'id',
        is_sharing: 'is_sharing',
        link_sharing_expiration_time: 'link_sharing_expiration_time',
        link_sharing_uri: 'link_sharing_uri',
        time_completed: 'time_completed',
        time_start: 'time_start'
      });
    }
  }]);
  return AdsReportBuilderExportCore;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsReportBuilderSavedReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsReportBuilderSavedReport = function (_AbstractCrudObject) {
  inherits(AdsReportBuilderSavedReport, _AbstractCrudObject);

  function AdsReportBuilderSavedReport() {
    classCallCheck(this, AdsReportBuilderSavedReport);
    return possibleConstructorReturn(this, (AdsReportBuilderSavedReport.__proto__ || Object.getPrototypeOf(AdsReportBuilderSavedReport)).apply(this, arguments));
  }

  createClass(AdsReportBuilderSavedReport, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action_report_time: 'action_report_time',
        ad_account_id: 'ad_account_id',
        attribution_windows: 'attribution_windows',
        comparison_date_interval: 'comparison_date_interval',
        creation_source: 'creation_source',
        creation_time: 'creation_time',
        currency: 'currency',
        date_interval: 'date_interval',
        date_preset: 'date_preset',
        default_attribution_windows: 'default_attribution_windows',
        dimension_groups: 'dimension_groups',
        dimensions: 'dimensions',
        filtering: 'filtering',
        formatting: 'formatting',
        id: 'id',
        last_access_by: 'last_access_by',
        last_access_time: 'last_access_time',
        last_report_snapshot_id: 'last_report_snapshot_id',
        last_report_snapshot_time: 'last_report_snapshot_time',
        last_shared_report_expiration: 'last_shared_report_expiration',
        limit: 'limit',
        locked_dimensions: 'locked_dimensions',
        metrics: 'metrics',
        report_name: 'report_name',
        report_snapshot_async_percent_completion: 'report_snapshot_async_percent_completion',
        report_snapshot_async_status: 'report_snapshot_async_status',
        schedule_frequency: 'schedule_frequency',
        scope: 'scope',
        show_deprecate_aw_banner: 'show_deprecate_aw_banner',
        sorting: 'sorting',
        start_date: 'start_date',
        status: 'status',
        subscribers: 'subscribers',
        update_by: 'update_by',
        update_time: 'update_time',
        user: 'user',
        user_dimensions: 'user_dimensions',
        user_metrics: 'user_metrics',
        view_type: 'view_type'
      });
    }
  }]);
  return AdsReportBuilderSavedReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsSegments
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsSegments = function (_AbstractCrudObject) {
  inherits(AdsSegments, _AbstractCrudObject);

  function AdsSegments() {
    classCallCheck(this, AdsSegments);
    return possibleConstructorReturn(this, (AdsSegments.__proto__ || Object.getPrototypeOf(AdsSegments)).apply(this, arguments));
  }

  createClass(AdsSegments, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        daily_audience_size: 'daily_audience_size',
        daily_impressions: 'daily_impressions',
        description: 'description',
        id: 'id',
        name: 'name',
        path: 'path',
        popularity: 'popularity',
        projected_cpm: 'projected_cpm',
        projected_daily_revenue: 'projected_daily_revenue'
      });
    }
  }]);
  return AdsSegments;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsSignalDiagnosticIssue
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsSignalDiagnosticIssue = function (_AbstractCrudObject) {
  inherits(AdsSignalDiagnosticIssue, _AbstractCrudObject);

  function AdsSignalDiagnosticIssue() {
    classCallCheck(this, AdsSignalDiagnosticIssue);
    return possibleConstructorReturn(this, (AdsSignalDiagnosticIssue.__proto__ || Object.getPrototypeOf(AdsSignalDiagnosticIssue)).apply(this, arguments));
  }

  createClass(AdsSignalDiagnosticIssue, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        data_source_id: 'data_source_id',
        data_source_type: 'data_source_type',
        diagnostic_type: 'diagnostic_type',
        event_name: 'event_name',
        traffic_anomaly_drop_percentage: 'traffic_anomaly_drop_percentage',
        traffic_anomaly_drop_timestamp: 'traffic_anomaly_drop_timestamp'
      });
    }
  }]);
  return AdsSignalDiagnosticIssue;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsStartYourDayWidget
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsStartYourDayWidget = function (_AbstractCrudObject) {
  inherits(AdsStartYourDayWidget, _AbstractCrudObject);

  function AdsStartYourDayWidget() {
    classCallCheck(this, AdsStartYourDayWidget);
    return possibleConstructorReturn(this, (AdsStartYourDayWidget.__proto__ || Object.getPrototypeOf(AdsStartYourDayWidget)).apply(this, arguments));
  }

  createClass(AdsStartYourDayWidget, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        widget_id: 'widget_id'
      });
    }
  }]);
  return AdsStartYourDayWidget;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsTabular
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsTabular = function (_AbstractCrudObject) {
  inherits(AdsTabular, _AbstractCrudObject);

  function AdsTabular() {
    classCallCheck(this, AdsTabular);
    return possibleConstructorReturn(this, (AdsTabular.__proto__ || Object.getPrototypeOf(AdsTabular)).apply(this, arguments));
  }

  createClass(AdsTabular, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        rows: 'rows'
      });
    }
  }]);
  return AdsTabular;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsTargetingInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsTargetingInsights = function (_AbstractCrudObject) {
  inherits(AdsTargetingInsights, _AbstractCrudObject);

  function AdsTargetingInsights() {
    classCallCheck(this, AdsTargetingInsights);
    return possibleConstructorReturn(this, (AdsTargetingInsights.__proto__ || Object.getPrototypeOf(AdsTargetingInsights)).apply(this, arguments));
  }

  createClass(AdsTargetingInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience_size: 'audience_size',
        clicks: 'clicks',
        conversion_cost: 'conversion_cost',
        conversions: 'conversions',
        description: 'description',
        id: 'id',
        impressions: 'impressions',
        name: 'name',
        revenue: 'revenue',
        spend: 'spend',
        type: 'type'
      });
    }
  }]);
  return AdsTargetingInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsTextSuggestions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsTextSuggestions = function (_AbstractCrudObject) {
  inherits(AdsTextSuggestions, _AbstractCrudObject);

  function AdsTextSuggestions() {
    classCallCheck(this, AdsTextSuggestions);
    return possibleConstructorReturn(this, (AdsTextSuggestions.__proto__ || Object.getPrototypeOf(AdsTextSuggestions)).apply(this, arguments));
  }

  createClass(AdsTextSuggestions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_id: 'ad_account_id',
        bodies: 'bodies',
        descriptions: 'descriptions',
        inactive_session_tally: 'inactive_session_tally',
        long: 'long',
        short: 'short',
        titles: 'titles'
      });
    }
  }]);
  return AdsTextSuggestions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdsUserSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdsUserSettings = function (_AbstractCrudObject) {
  inherits(AdsUserSettings, _AbstractCrudObject);

  function AdsUserSettings() {
    classCallCheck(this, AdsUserSettings);
    return possibleConstructorReturn(this, (AdsUserSettings.__proto__ || Object.getPrototypeOf(AdsUserSettings)).apply(this, arguments));
  }

  createClass(AdsUserSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        a_plus_c_survey_seen: 'a_plus_c_survey_seen',
        add_overlays_opt_in_status: 'add_overlays_opt_in_status',
        adgroup_name_template: 'adgroup_name_template',
        ads_cs_catalog_opt_out_timestamp: 'ads_cs_catalog_opt_out_timestamp',
        ads_tool_visits: 'ads_tool_visits',
        aplusc_carousel_cda_opt_in_status: 'aplusc_carousel_cda_opt_in_status',
        aplusc_carousel_inline_comment_opt_in_status: 'aplusc_carousel_inline_comment_opt_in_status',
        aplusc_epa_opt_in_status: 'aplusc_epa_opt_in_status',
        aplusc_opt_out_friction: 'aplusc_opt_out_friction',
        autoflow_lite_opt_in_status: 'autoflow_lite_opt_in_status',
        autoflow_lite_should_opt_in: 'autoflow_lite_should_opt_in',
        blended_ads_creation_defaulting_opt_in_status: 'blended_ads_creation_defaulting_opt_in_status',
        blended_ads_creation_defaulting_opt_out_campaign_group_ids: 'blended_ads_creation_defaulting_opt_out_campaign_group_ids',
        bookmarked_pages: 'bookmarked_pages',
        campaign_group_name_template: 'campaign_group_name_template',
        campaign_name_template: 'campaign_name_template',
        carousel_to_video_opt_in_status: 'carousel_to_video_opt_in_status',
        connected_sources_catalog_opt_in_status: 'connected_sources_catalog_opt_in_status',
        default_creation_mode: 'default_creation_mode',
        export_format_default: 'export_format_default',
        focus_mode_default: 'focus_mode_default',
        gen_ai_alpha_test_status: 'gen_ai_alpha_test_status',
        id: 'id',
        image_background_generation_opt_in_status: 'image_background_generation_opt_in_status',
        image_expansion_opt_in_status: 'image_expansion_opt_in_status',
        is_ads_ai_consented: 'is_ads_ai_consented',
        is_cbo_default_on: 'is_cbo_default_on',
        is_se_removal_guidance_dismissed: 'is_se_removal_guidance_dismissed',
        last_used_post_format: 'last_used_post_format',
        last_visited_time: 'last_visited_time',
        music_on_reels_opt_in: 'music_on_reels_opt_in',
        muted_cbo_midflight_education_messages: 'muted_cbo_midflight_education_messages',
        onsite_destination_optimization_opt_in: 'onsite_destination_optimization_opt_in',
        open_tabs: 'open_tabs',
        previously_seen_recommendations: 'previously_seen_recommendations',
        product_extensions_opt_in: 'product_extensions_opt_in',
        selected_ad_account: 'selected_ad_account',
        selected_comparison_timerange: 'selected_comparison_timerange',
        selected_metric_cic: 'selected_metric_cic',
        selected_metrics_cic: 'selected_metrics_cic',
        selected_page: 'selected_page',
        selected_page_section: 'selected_page_section',
        selected_power_editor_pane: 'selected_power_editor_pane',
        selected_stat_range: 'selected_stat_range',
        should_export_filter_empty_cols: 'should_export_filter_empty_cols',
        should_export_rows_without_unsupported_feature: 'should_export_rows_without_unsupported_feature',
        should_not_auto_expand_tree_table: 'should_not_auto_expand_tree_table',
        should_not_show_cbo_campaign_toggle_off_confirmation_message: 'should_not_show_cbo_campaign_toggle_off_confirmation_message',
        should_not_show_publish_message_on_editor_close: 'should_not_show_publish_message_on_editor_close',
        show_original_videos_opt_in: 'show_original_videos_opt_in',
        static_ad_product_extensions_opt_in: 'static_ad_product_extensions_opt_in',
        sticky_setting_after_default_on: 'sticky_setting_after_default_on',
        syd_campaign_trends_metric: 'syd_campaign_trends_metric',
        total_coupon_syd_dismissals: 'total_coupon_syd_dismissals',
        total_coupon_upsell_dismissals: 'total_coupon_upsell_dismissals',
        url_prefill_removal_timestamp: 'url_prefill_removal_timestamp',
        use_pe_create_flow: 'use_pe_create_flow',
        use_stepper_primary_entry: 'use_stepper_primary_entry',
        user: 'user'
      });
    }
  }]);
  return AdsUserSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdvAInstance
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdvAInstance = function (_AbstractCrudObject) {
  inherits(AdvAInstance, _AbstractCrudObject);

  function AdvAInstance() {
    classCallCheck(this, AdvAInstance);
    return possibleConstructorReturn(this, (AdvAInstance.__proto__ || Object.getPrototypeOf(AdvAInstance)).apply(this, arguments));
  }

  createClass(AdvAInstance, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        instance_type: 'instance_type',
        name: 'name',
        owner_business: 'owner_business'
      });
    }
  }]);
  return AdvAInstance;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AdvertiserVerificationStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AdvertiserVerificationStatus = function (_AbstractCrudObject) {
  inherits(AdvertiserVerificationStatus, _AbstractCrudObject);

  function AdvertiserVerificationStatus() {
    classCallCheck(this, AdvertiserVerificationStatus);
    return possibleConstructorReturn(this, (AdvertiserVerificationStatus.__proto__ || Object.getPrototypeOf(AdvertiserVerificationStatus)).apply(this, arguments));
  }

  createClass(AdvertiserVerificationStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        banner_type: 'banner_type',
        grace_period_ends_at: 'grace_period_ends_at',
        ufac_redirect_uri: 'ufac_redirect_uri',
        verification_status: 'verification_status'
      });
    }
  }]);
  return AdvertiserVerificationStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AgeRange
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AgeRange = function (_AbstractCrudObject) {
  inherits(AgeRange, _AbstractCrudObject);

  function AgeRange() {
    classCallCheck(this, AgeRange);
    return possibleConstructorReturn(this, (AgeRange.__proto__ || Object.getPrototypeOf(AgeRange)).apply(this, arguments));
  }

  createClass(AgeRange, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        max: 'max',
        min: 'min'
      });
    }
  }]);
  return AgeRange;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AgencyClientDeclaration
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AgencyClientDeclaration = function (_AbstractCrudObject) {
  inherits(AgencyClientDeclaration, _AbstractCrudObject);

  function AgencyClientDeclaration() {
    classCallCheck(this, AgencyClientDeclaration);
    return possibleConstructorReturn(this, (AgencyClientDeclaration.__proto__ || Object.getPrototypeOf(AgencyClientDeclaration)).apply(this, arguments));
  }

  createClass(AgencyClientDeclaration, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        agency_representing_client: 'agency_representing_client',
        client_based_in_france: 'client_based_in_france',
        client_city: 'client_city',
        client_country_code: 'client_country_code',
        client_email_address: 'client_email_address',
        client_name: 'client_name',
        client_postal_code: 'client_postal_code',
        client_province: 'client_province',
        client_street: 'client_street',
        client_street2: 'client_street2',
        has_written_mandate_from_advertiser: 'has_written_mandate_from_advertiser',
        is_client_paying_invoices: 'is_client_paying_invoices'
      });
    }
  }]);
  return AgencyClientDeclaration;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AnalyticsCohortQueryResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AnalyticsCohortQueryResult = function (_AbstractCrudObject) {
  inherits(AnalyticsCohortQueryResult, _AbstractCrudObject);

  function AnalyticsCohortQueryResult() {
    classCallCheck(this, AnalyticsCohortQueryResult);
    return possibleConstructorReturn(this, (AnalyticsCohortQueryResult.__proto__ || Object.getPrototypeOf(AnalyticsCohortQueryResult)).apply(this, arguments));
  }

  createClass(AnalyticsCohortQueryResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        data: 'data',
        error: 'error',
        query_id: 'query_id',
        status: 'status'
      });
    }
  }]);
  return AnalyticsCohortQueryResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AnalyticsConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AnalyticsConfig = function (_AbstractCrudObject) {
  inherits(AnalyticsConfig, _AbstractCrudObject);

  function AnalyticsConfig() {
    classCallCheck(this, AnalyticsConfig);
    return possibleConstructorReturn(this, (AnalyticsConfig.__proto__ || Object.getPrototypeOf(AnalyticsConfig)).apply(this, arguments));
  }

  createClass(AnalyticsConfig, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        analytics_access_for_authorized_ad_account: 'analytics_access_for_authorized_ad_account',
        breakdowns_config: 'breakdowns_config',
        builtin_fields_config: 'builtin_fields_config',
        deprecated_events_config: 'deprecated_events_config',
        events_config: 'events_config',
        ios_purchase_validation_secret: 'ios_purchase_validation_secret',
        is_any_role_able_to_see_restricted_insights: 'is_any_role_able_to_see_restricted_insights',
        is_implicit_purchase_logging_on_android_supported: 'is_implicit_purchase_logging_on_android_supported',
        is_implicit_purchase_logging_on_ios_supported: 'is_implicit_purchase_logging_on_ios_supported',
        is_track_ios_app_uninstall_supported: 'is_track_ios_app_uninstall_supported',
        journey_backfill_status: 'journey_backfill_status',
        journey_conversion_events: 'journey_conversion_events',
        journey_enabled: 'journey_enabled',
        journey_impacting_change_time: 'journey_impacting_change_time',
        journey_timeout: 'journey_timeout',
        latest_sdk_versions: 'latest_sdk_versions',
        log_android_implicit_purchase_events: 'log_android_implicit_purchase_events',
        log_automatic_analytics_events: 'log_automatic_analytics_events',
        log_implicit_purchase_events: 'log_implicit_purchase_events',
        prev_journey_conversion_events: 'prev_journey_conversion_events',
        query_approximation_accuracy_level: 'query_approximation_accuracy_level',
        query_currency: 'query_currency',
        query_timezone: 'query_timezone',
        recent_events_update_time: 'recent_events_update_time',
        session_timeout_interval: 'session_timeout_interval',
        track_ios_app_uninstall: 'track_ios_app_uninstall'
      });
    }
  }]);
  return AnalyticsConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AnalyticsEntityUserConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AnalyticsEntityUserConfig = function (_AbstractCrudObject) {
  inherits(AnalyticsEntityUserConfig, _AbstractCrudObject);

  function AnalyticsEntityUserConfig() {
    classCallCheck(this, AnalyticsEntityUserConfig);
    return possibleConstructorReturn(this, (AnalyticsEntityUserConfig.__proto__ || Object.getPrototypeOf(AnalyticsEntityUserConfig)).apply(this, arguments));
  }

  createClass(AnalyticsEntityUserConfig, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        dismissed_notices: 'dismissed_notices'
      });
    }
  }]);
  return AnalyticsEntityUserConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AnalyticsFunnelQueryResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AnalyticsFunnelQueryResult = function (_AbstractCrudObject) {
  inherits(AnalyticsFunnelQueryResult, _AbstractCrudObject);

  function AnalyticsFunnelQueryResult() {
    classCallCheck(this, AnalyticsFunnelQueryResult);
    return possibleConstructorReturn(this, (AnalyticsFunnelQueryResult.__proto__ || Object.getPrototypeOf(AnalyticsFunnelQueryResult)).apply(this, arguments));
  }

  createClass(AnalyticsFunnelQueryResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        data: 'data',
        error: 'error',
        query_id: 'query_id',
        status: 'status'
      });
    }
  }]);
  return AnalyticsFunnelQueryResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AnalyticsPlatformMetricsConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AnalyticsPlatformMetricsConfig = function (_AbstractCrudObject) {
  inherits(AnalyticsPlatformMetricsConfig, _AbstractCrudObject);

  function AnalyticsPlatformMetricsConfig() {
    classCallCheck(this, AnalyticsPlatformMetricsConfig);
    return possibleConstructorReturn(this, (AnalyticsPlatformMetricsConfig.__proto__ || Object.getPrototypeOf(AnalyticsPlatformMetricsConfig)).apply(this, arguments));
  }

  createClass(AnalyticsPlatformMetricsConfig, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        has_a2u: 'has_a2u',
        has_api_calls: 'has_api_calls',
        has_app_invites: 'has_app_invites',
        has_fb_login: 'has_fb_login',
        has_game_requests: 'has_game_requests',
        has_payments: 'has_payments',
        has_referrals: 'has_referrals',
        has_stories: 'has_stories',
        has_structured_requests: 'has_structured_requests'
      });
    }
  }]);
  return AnalyticsPlatformMetricsConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AnalyticsQueryResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AnalyticsQueryResult = function (_AbstractCrudObject) {
  inherits(AnalyticsQueryResult, _AbstractCrudObject);

  function AnalyticsQueryResult() {
    classCallCheck(this, AnalyticsQueryResult);
    return possibleConstructorReturn(this, (AnalyticsQueryResult.__proto__ || Object.getPrototypeOf(AnalyticsQueryResult)).apply(this, arguments));
  }

  createClass(AnalyticsQueryResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        columns: 'columns',
        datapoints: 'datapoints',
        error: 'error',
        query_id: 'query_id',
        status: 'status'
      });
    }
  }]);
  return AnalyticsQueryResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AnalyticsSegment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AnalyticsSegment = function (_AbstractCrudObject) {
  inherits(AnalyticsSegment, _AbstractCrudObject);

  function AnalyticsSegment() {
    classCallCheck(this, AnalyticsSegment);
    return possibleConstructorReturn(this, (AnalyticsSegment.__proto__ || Object.getPrototypeOf(AnalyticsSegment)).apply(this, arguments));
  }

  createClass(AnalyticsSegment, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        custom_audience_ineligiblity_reasons: 'custom_audience_ineligiblity_reasons',
        description: 'description',
        estimated_custom_audience_size: 'estimated_custom_audience_size',
        event_info_rules: 'event_info_rules',
        event_rules: 'event_rules',
        filter_set: 'filter_set',
        has_demographic_rules: 'has_demographic_rules',
        id: 'id',
        is_all_user: 'is_all_user',
        is_eligible_for_push_campaign: 'is_eligible_for_push_campaign',
        is_internal: 'is_internal',
        name: 'name',
        percentile_rules: 'percentile_rules',
        time_last_seen: 'time_last_seen',
        time_last_updated: 'time_last_updated',
        user_property_rules: 'user_property_rules',
        web_param_rules: 'web_param_rules'
      });
    }
  }]);
  return AnalyticsSegment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AnalyticsUserConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AnalyticsUserConfig = function (_AbstractCrudObject) {
  inherits(AnalyticsUserConfig, _AbstractCrudObject);

  function AnalyticsUserConfig() {
    classCallCheck(this, AnalyticsUserConfig);
    return possibleConstructorReturn(this, (AnalyticsUserConfig.__proto__ || Object.getPrototypeOf(AnalyticsUserConfig)).apply(this, arguments));
  }

  createClass(AnalyticsUserConfig, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        demo_app_nux_config: 'demo_app_nux_config',
        flags: 'flags',
        id: 'id'
      });
    }
  }]);
  return AnalyticsUserConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AndroidAppLink
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AndroidAppLink = function (_AbstractCrudObject) {
  inherits(AndroidAppLink, _AbstractCrudObject);

  function AndroidAppLink() {
    classCallCheck(this, AndroidAppLink);
    return possibleConstructorReturn(this, (AndroidAppLink.__proto__ || Object.getPrototypeOf(AndroidAppLink)).apply(this, arguments));
  }

  createClass(AndroidAppLink, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_name: 'app_name',
        class: 'class',
        package: 'package',
        url: 'url'
      });
    }
  }]);
  return AndroidAppLink;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AppEventConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AppEventConfig = function (_AbstractCrudObject) {
  inherits(AppEventConfig, _AbstractCrudObject);

  function AppEventConfig() {
    classCallCheck(this, AppEventConfig);
    return possibleConstructorReturn(this, (AppEventConfig.__proto__ || Object.getPrototypeOf(AppEventConfig)).apply(this, arguments));
  }

  createClass(AppEventConfig, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        breakdowns_config: 'breakdowns_config',
        builtin_fields_config: 'builtin_fields_config',
        deprecated_events_config: 'deprecated_events_config',
        events_config: 'events_config',
        id: 'id',
        ios_purchase_validation_secret: 'ios_purchase_validation_secret',
        is_any_role_able_to_see_restricted_insights: 'is_any_role_able_to_see_restricted_insights',
        is_implicit_purchase_logging_on_android_supported: 'is_implicit_purchase_logging_on_android_supported',
        is_implicit_purchase_logging_on_ios_supported: 'is_implicit_purchase_logging_on_ios_supported',
        is_track_android_app_uninstall_supported: 'is_track_android_app_uninstall_supported',
        is_track_ios_app_uninstall_supported: 'is_track_ios_app_uninstall_supported',
        journey_backfill_status: 'journey_backfill_status',
        journey_conversion_events: 'journey_conversion_events',
        journey_enabled: 'journey_enabled',
        journey_timeout: 'journey_timeout',
        latest_sdk_versions: 'latest_sdk_versions',
        log_android_implicit_purchase_events: 'log_android_implicit_purchase_events',
        log_automatic_analytics_events: 'log_automatic_analytics_events',
        log_implicit_purchase_events: 'log_implicit_purchase_events',
        prev_journey_conversion_events: 'prev_journey_conversion_events',
        query_approximation_accuracy_level: 'query_approximation_accuracy_level',
        query_currency: 'query_currency',
        query_timezone: 'query_timezone',
        recent_events_update_time: 'recent_events_update_time',
        session_timeout_interval: 'session_timeout_interval',
        track_android_app_uninstall: 'track_android_app_uninstall',
        track_ios_app_uninstall: 'track_ios_app_uninstall'
      });
    }
  }]);
  return AppEventConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AppLinks
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AppLinks = function (_AbstractCrudObject) {
  inherits(AppLinks, _AbstractCrudObject);

  function AppLinks() {
    classCallCheck(this, AppLinks);
    return possibleConstructorReturn(this, (AppLinks.__proto__ || Object.getPrototypeOf(AppLinks)).apply(this, arguments));
  }

  createClass(AppLinks, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        android: 'android',
        id: 'id',
        ios: 'ios',
        ipad: 'ipad',
        iphone: 'iphone',
        web: 'web',
        windows: 'windows',
        windows_phone: 'windows_phone',
        windows_universal: 'windows_universal'
      });
    }
  }]);
  return AppLinks;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AppOptimizedCustomEvents
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AppOptimizedCustomEvents = function (_AbstractCrudObject) {
  inherits(AppOptimizedCustomEvents, _AbstractCrudObject);

  function AppOptimizedCustomEvents() {
    classCallCheck(this, AppOptimizedCustomEvents);
    return possibleConstructorReturn(this, (AppOptimizedCustomEvents.__proto__ || Object.getPrototypeOf(AppOptimizedCustomEvents)).apply(this, arguments));
  }

  createClass(AppOptimizedCustomEvents, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        app_name: 'app_name',
        event_names: 'event_names'
      });
    }
  }]);
  return AppOptimizedCustomEvents;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AppPublisher
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AppPublisher = function (_AbstractCrudObject) {
  inherits(AppPublisher, _AbstractCrudObject);

  function AppPublisher() {
    classCallCheck(this, AppPublisher);
    return possibleConstructorReturn(this, (AppPublisher.__proto__ || Object.getPrototypeOf(AppPublisher)).apply(this, arguments));
  }

  createClass(AppPublisher, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        content_id: 'content_id',
        icon_url: 'icon_url',
        id: 'id',
        name: 'name',
        platform: 'platform',
        store_name: 'store_name',
        store_url: 'store_url'
      });
    }
  }]);
  return AppPublisher;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AsyncSession
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AsyncSession = function (_AbstractCrudObject) {
  inherits(AsyncSession, _AbstractCrudObject);

  function AsyncSession() {
    classCallCheck(this, AsyncSession);
    return possibleConstructorReturn(this, (AsyncSession.__proto__ || Object.getPrototypeOf(AsyncSession)).apply(this, arguments));
  }

  createClass(AsyncSession, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app: 'app',
        complete_time: 'complete_time',
        error_code: 'error_code',
        exception: 'exception',
        id: 'id',
        method: 'method',
        name: 'name',
        page: 'page',
        percent_completed: 'percent_completed',
        platform_version: 'platform_version',
        result: 'result',
        start_time: 'start_time',
        status: 'status',
        uri: 'uri',
        user: 'user'
      });
    }
  }]);
  return AsyncSession;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AttributionSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AttributionSpec = function (_AbstractCrudObject) {
  inherits(AttributionSpec, _AbstractCrudObject);

  function AttributionSpec() {
    classCallCheck(this, AttributionSpec);
    return possibleConstructorReturn(this, (AttributionSpec.__proto__ || Object.getPrototypeOf(AttributionSpec)).apply(this, arguments));
  }

  createClass(AttributionSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        event_type: 'event_type',
        window_days: 'window_days'
      });
    }
  }]);
  return AttributionSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudienceOverlap
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudienceOverlap = function (_AbstractCrudObject) {
  inherits(AudienceOverlap, _AbstractCrudObject);

  function AudienceOverlap() {
    classCallCheck(this, AudienceOverlap);
    return possibleConstructorReturn(this, (AudienceOverlap.__proto__ || Object.getPrototypeOf(AudienceOverlap)).apply(this, arguments));
  }

  createClass(AudienceOverlap, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        estimated_reach: 'estimated_reach',
        id: 'id',
        name: 'name',
        overlap: 'overlap'
      });
    }
  }]);
  return AudienceOverlap;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudiencePermission
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudiencePermission = function (_AbstractCrudObject) {
  inherits(AudiencePermission, _AbstractCrudObject);

  function AudiencePermission() {
    classCallCheck(this, AudiencePermission);
    return possibleConstructorReturn(this, (AudiencePermission.__proto__ || Object.getPrototypeOf(AudiencePermission)).apply(this, arguments));
  }

  createClass(AudiencePermission, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience: 'audience',
        share_account_id: 'share_account_id',
        share_account_name: 'share_account_name'
      });
    }
  }]);
  return AudiencePermission;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudiencePermissionForActions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudiencePermissionForActions = function (_AbstractCrudObject) {
  inherits(AudiencePermissionForActions, _AbstractCrudObject);

  function AudiencePermissionForActions() {
    classCallCheck(this, AudiencePermissionForActions);
    return possibleConstructorReturn(this, (AudiencePermissionForActions.__proto__ || Object.getPrototypeOf(AudiencePermissionForActions)).apply(this, arguments));
  }

  createClass(AudiencePermissionForActions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_edit: 'can_edit',
        can_see_insight: 'can_see_insight',
        can_share: 'can_share',
        subtype_supports_lookalike: 'subtype_supports_lookalike',
        supports_recipient_lookalike: 'supports_recipient_lookalike'
      });
    }
  }]);
  return AudiencePermissionForActions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudienceSharingAccountValid
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudienceSharingAccountValid = function (_AbstractCrudObject) {
  inherits(AudienceSharingAccountValid, _AbstractCrudObject);

  function AudienceSharingAccountValid() {
    classCallCheck(this, AudienceSharingAccountValid);
    return possibleConstructorReturn(this, (AudienceSharingAccountValid.__proto__ || Object.getPrototypeOf(AudienceSharingAccountValid)).apply(this, arguments));
  }

  createClass(AudienceSharingAccountValid, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        account_type: 'account_type',
        business_id: 'business_id',
        business_name: 'business_name',
        can_ad_account_use_lookalike_container: 'can_ad_account_use_lookalike_container',
        sharing_agreement_status: 'sharing_agreement_status'
      });
    }
  }]);
  return AudienceSharingAccountValid;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudienceSharingRecipientAccounts
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudienceSharingRecipientAccounts = function (_AbstractCrudObject) {
  inherits(AudienceSharingRecipientAccounts, _AbstractCrudObject);

  function AudienceSharingRecipientAccounts() {
    classCallCheck(this, AudienceSharingRecipientAccounts);
    return possibleConstructorReturn(this, (AudienceSharingRecipientAccounts.__proto__ || Object.getPrototypeOf(AudienceSharingRecipientAccounts)).apply(this, arguments));
  }

  createClass(AudienceSharingRecipientAccounts, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        account_name: 'account_name',
        account_type: 'account_type',
        business_id: 'business_id',
        business_name: 'business_name',
        can_ad_account_use_lookalike_container: 'can_ad_account_use_lookalike_container',
        sharing_agreement_status: 'sharing_agreement_status'
      });
    }
  }]);
  return AudienceSharingRecipientAccounts;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudioAsset
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudioAsset = function (_AbstractCrudObject) {
  inherits(AudioAsset, _AbstractCrudObject);

  function AudioAsset() {
    classCallCheck(this, AudioAsset);
    return possibleConstructorReturn(this, (AudioAsset.__proto__ || Object.getPrototypeOf(AudioAsset)).apply(this, arguments));
  }

  createClass(AudioAsset, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        all_ddex_featured_artists: 'all_ddex_featured_artists',
        all_ddex_main_artists: 'all_ddex_main_artists',
        audio_cluster_id: 'audio_cluster_id',
        cover_image_source: 'cover_image_source',
        display_artist: 'display_artist',
        download_hd_url: 'download_hd_url',
        download_sd_url: 'download_sd_url',
        duration_in_ms: 'duration_in_ms',
        freeform_genre: 'freeform_genre',
        grid: 'grid',
        id: 'id',
        is_test: 'is_test',
        original_release_date: 'original_release_date',
        owner: 'owner',
        parental_warning_type: 'parental_warning_type',
        subtitle: 'subtitle',
        title: 'title',
        title_with_featured_artists: 'title_with_featured_artists',
        upc: 'upc'
      });
    }
  }]);
  return AudioAsset;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudioCopyright
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudioCopyright = function (_AbstractCrudObject) {
  inherits(AudioCopyright, _AbstractCrudObject);

  function AudioCopyright() {
    classCallCheck(this, AudioCopyright);
    return possibleConstructorReturn(this, (AudioCopyright.__proto__ || Object.getPrototypeOf(AudioCopyright)).apply(this, arguments));
  }

  createClass(AudioCopyright, [{
    key: 'getUpdateRecords',
    value: function getUpdateRecords(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(MediaCopyrightUpdateRecord, fields, params, fetchFirstPage, '/update_records');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        displayed_matches_count: 'displayed_matches_count',
        id: 'id',
        in_conflict: 'in_conflict',
        isrc: 'isrc',
        match_rule: 'match_rule',
        ownership_countries: 'ownership_countries',
        ownership_details: 'ownership_details',
        reference_file_status: 'reference_file_status',
        ridge_monitoring_status: 'ridge_monitoring_status',
        tags: 'tags',
        update_time: 'update_time',
        whitelisted_fb_users: 'whitelisted_fb_users',
        whitelisted_ig_users: 'whitelisted_ig_users'
      });
    }
  }]);
  return AudioCopyright;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudioIsrc
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudioIsrc = function (_AbstractCrudObject) {
  inherits(AudioIsrc, _AbstractCrudObject);

  function AudioIsrc() {
    classCallCheck(this, AudioIsrc);
    return possibleConstructorReturn(this, (AudioIsrc.__proto__ || Object.getPrototypeOf(AudioIsrc)).apply(this, arguments));
  }

  createClass(AudioIsrc, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        all_kg_featured_artists: 'all_kg_featured_artists',
        all_kg_main_artists: 'all_kg_main_artists',
        artist_profile_picture_url: 'artist_profile_picture_url',
        id: 'id',
        isrc: 'isrc',
        publishing_rights_data: 'publishing_rights_data',
        top_searchable_artist_id: 'top_searchable_artist_id',
        top_searchable_artist_name: 'top_searchable_artist_name',
        top_searchable_artist_profile_pic_url: 'top_searchable_artist_profile_pic_url'
      });
    }
  }]);
  return AudioIsrc;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudioRelease
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudioRelease = function (_AbstractCrudObject) {
  inherits(AudioRelease, _AbstractCrudObject);

  function AudioRelease() {
    classCallCheck(this, AudioRelease);
    return possibleConstructorReturn(this, (AudioRelease.__proto__ || Object.getPrototypeOf(AudioRelease)).apply(this, arguments));
  }

  createClass(AudioRelease, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        album_title: 'album_title',
        asset_availability_status: 'asset_availability_status',
        audio_availability_status: 'audio_availability_status',
        audio_release_image_uri: 'audio_release_image_uri',
        created_time: 'created_time',
        displayed_artist: 'displayed_artist',
        ean: 'ean',
        genre: 'genre',
        grid: 'grid',
        id: 'id',
        isrc: 'isrc',
        label_name: 'label_name',
        original_release_date: 'original_release_date',
        parental_warning_type: 'parental_warning_type',
        proprietary_id: 'proprietary_id',
        upc: 'upc'
      });
    }
  }]);
  return AudioRelease;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AudioVisualReferenceMatch
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AudioVisualReferenceMatch = function (_AbstractCrudObject) {
  inherits(AudioVisualReferenceMatch, _AbstractCrudObject);

  function AudioVisualReferenceMatch() {
    classCallCheck(this, AudioVisualReferenceMatch);
    return possibleConstructorReturn(this, (AudioVisualReferenceMatch.__proto__ || Object.getPrototypeOf(AudioVisualReferenceMatch)).apply(this, arguments));
  }

  createClass(AudioVisualReferenceMatch, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audio_conflicting_segments: 'audio_conflicting_segments',
        audio_current_conflict_resolved_segments: 'audio_current_conflict_resolved_segments',
        audio_segment_resolution_history: 'audio_segment_resolution_history',
        conflict_type: 'conflict_type',
        conflicting_countries: 'conflicting_countries',
        country_resolution_history: 'country_resolution_history',
        creation_time: 'creation_time',
        current_conflict_resolved_countries: 'current_conflict_resolved_countries',
        displayed_match_state: 'displayed_match_state',
        dispute_form_data_entries_with_translations: 'dispute_form_data_entries_with_translations',
        expiration_time: 'expiration_time',
        id: 'id',
        is_disputable: 'is_disputable',
        match_state: 'match_state',
        matched_overlap_percentage: 'matched_overlap_percentage',
        matched_owner_match_duration_in_sec: 'matched_owner_match_duration_in_sec',
        matched_reference_owner: 'matched_reference_owner',
        modification_history: 'modification_history',
        num_matches_on_matched_side: 'num_matches_on_matched_side',
        num_matches_on_ref_side: 'num_matches_on_ref_side',
        ref_owner_match_duration_in_sec: 'ref_owner_match_duration_in_sec',
        reference_overlap_percentage: 'reference_overlap_percentage',
        reference_owner: 'reference_owner',
        rejection_form_data_entries_with_translations: 'rejection_form_data_entries_with_translations',
        resolution_details: 'resolution_details',
        resolution_reason: 'resolution_reason',
        update_time: 'update_time',
        views_on_matched_side: 'views_on_matched_side',
        visual_conflicting_segments: 'visual_conflicting_segments',
        visual_current_conflict_resolved_segments: 'visual_current_conflict_resolved_segments',
        visual_segment_resolution_history: 'visual_segment_resolution_history'
      });
    }
  }]);
  return AudioVisualReferenceMatch;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AuthLink
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AuthLink = function (_AbstractCrudObject) {
  inherits(AuthLink, _AbstractCrudObject);

  function AuthLink() {
    classCallCheck(this, AuthLink);
    return possibleConstructorReturn(this, (AuthLink.__proto__ || Object.getPrototypeOf(AuthLink)).apply(this, arguments));
  }

  createClass(AuthLink, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        link: 'link'
      });
    }
  }]);
  return AuthLink;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * AvatarProfilePicture
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var AvatarProfilePicture = function (_AbstractCrudObject) {
  inherits(AvatarProfilePicture, _AbstractCrudObject);

  function AvatarProfilePicture() {
    classCallCheck(this, AvatarProfilePicture);
    return possibleConstructorReturn(this, (AvatarProfilePicture.__proto__ || Object.getPrototypeOf(AvatarProfilePicture)).apply(this, arguments));
  }

  createClass(AvatarProfilePicture, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        url: 'url'
      });
    }
  }]);
  return AvatarProfilePicture;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BAPIDomain
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BAPIDomain = function (_AbstractCrudObject) {
  inherits(BAPIDomain, _AbstractCrudObject);

  function BAPIDomain() {
    classCallCheck(this, BAPIDomain);
    return possibleConstructorReturn(this, (BAPIDomain.__proto__ || Object.getPrototypeOf(BAPIDomain)).apply(this, arguments));
  }

  createClass(BAPIDomain, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        domain: 'domain',
        in_cool_down_until: 'in_cool_down_until',
        is_eligible_for_vo: 'is_eligible_for_vo',
        is_in_cool_down: 'is_in_cool_down'
      });
    }
  }]);
  return BAPIDomain;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BCPCampaign
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BCPCampaign = function (_AbstractCrudObject) {
  inherits(BCPCampaign, _AbstractCrudObject);

  function BCPCampaign() {
    classCallCheck(this, BCPCampaign);
    return possibleConstructorReturn(this, (BCPCampaign.__proto__ || Object.getPrototypeOf(BCPCampaign)).apply(this, arguments));
  }

  createClass(BCPCampaign, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ads_permission_required: 'ads_permission_required',
        application_deadline: 'application_deadline',
        campaign_goal: 'campaign_goal',
        campaign_goal_other: 'campaign_goal_other',
        content_delivery_deadline: 'content_delivery_deadline',
        content_delivery_start_date: 'content_delivery_start_date',
        content_requirements: 'content_requirements',
        content_requirements_description: 'content_requirements_description',
        currency: 'currency',
        deal_negotiation_type: 'deal_negotiation_type',
        description: 'description',
        has_free_product: 'has_free_product',
        id: 'id',
        name: 'name',
        payment_amount_for_ads: 'payment_amount_for_ads',
        payment_amount_for_content: 'payment_amount_for_content',
        payment_description: 'payment_description'
      });
    }
  }]);
  return BCPCampaign;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BidSchedule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BidSchedule = function (_AbstractCrudObject) {
  inherits(BidSchedule, _AbstractCrudObject);

  function BidSchedule() {
    classCallCheck(this, BidSchedule);
    return possibleConstructorReturn(this, (BidSchedule.__proto__ || Object.getPrototypeOf(BidSchedule)).apply(this, arguments));
  }

  createClass(BidSchedule, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_object_id: 'ad_object_id',
        bid_recurrence_type: 'bid_recurrence_type',
        bid_timezone: 'bid_timezone',
        bid_value: 'bid_value',
        id: 'id',
        status: 'status',
        time_end: 'time_end',
        time_start: 'time_start'
      });
    }
  }]);
  return BidSchedule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BizInboxOffsiteEmailAccount
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BizInboxOffsiteEmailAccount = function (_AbstractCrudObject) {
  inherits(BizInboxOffsiteEmailAccount, _AbstractCrudObject);

  function BizInboxOffsiteEmailAccount() {
    classCallCheck(this, BizInboxOffsiteEmailAccount);
    return possibleConstructorReturn(this, (BizInboxOffsiteEmailAccount.__proto__ || Object.getPrototypeOf(BizInboxOffsiteEmailAccount)).apply(this, arguments));
  }

  createClass(BizInboxOffsiteEmailAccount, [{
    key: 'getAssignedUsers',
    value: function getAssignedUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AssignedUser, fields, params, fetchFirstPage, '/assigned_users');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        email_address: 'email_address',
        id: 'id'
      });
    }
  }]);
  return BizInboxOffsiteEmailAccount;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BlindPig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BlindPig = function (_AbstractCrudObject) {
  inherits(BlindPig, _AbstractCrudObject);

  function BlindPig() {
    classCallCheck(this, BlindPig);
    return possibleConstructorReturn(this, (BlindPig.__proto__ || Object.getPrototypeOf(BlindPig)).apply(this, arguments));
  }

  createClass(BlindPig, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return BlindPig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BlockedUserInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BlockedUserInfo = function (_AbstractCrudObject) {
  inherits(BlockedUserInfo, _AbstractCrudObject);

  function BlockedUserInfo() {
    classCallCheck(this, BlockedUserInfo);
    return possibleConstructorReturn(this, (BlockedUserInfo.__proto__ || Object.getPrototypeOf(BlockedUserInfo)).apply(this, arguments));
  }

  createClass(BlockedUserInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        block_time: 'block_time',
        block_type: 'block_type',
        fbid: 'fbid',
        name: 'name',
        username: 'username'
      });
    }
  }]);
  return BlockedUserInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BrandSafetyBlockListUsage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BrandSafetyBlockListUsage = function (_AbstractCrudObject) {
  inherits(BrandSafetyBlockListUsage, _AbstractCrudObject);

  function BrandSafetyBlockListUsage() {
    classCallCheck(this, BrandSafetyBlockListUsage);
    return possibleConstructorReturn(this, (BrandSafetyBlockListUsage.__proto__ || Object.getPrototypeOf(BrandSafetyBlockListUsage)).apply(this, arguments));
  }

  createClass(BrandSafetyBlockListUsage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        current_usage: 'current_usage',
        new_usage: 'new_usage',
        platform: 'platform',
        position: 'position',
        threshold: 'threshold'
      });
    }
  }]);
  return BrandSafetyBlockListUsage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BrandSafetyCampaignConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BrandSafetyCampaignConfig = function (_AbstractCrudObject) {
  inherits(BrandSafetyCampaignConfig, _AbstractCrudObject);

  function BrandSafetyCampaignConfig() {
    classCallCheck(this, BrandSafetyCampaignConfig);
    return possibleConstructorReturn(this, (BrandSafetyCampaignConfig.__proto__ || Object.getPrototypeOf(BrandSafetyCampaignConfig)).apply(this, arguments));
  }

  createClass(BrandSafetyCampaignConfig, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        comment_moderation_filter: 'comment_moderation_filter'
      });
    }
  }]);
  return BrandSafetyCampaignConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BrandSafetyDownloadable
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BrandSafetyDownloadable = function (_AbstractCrudObject) {
  inherits(BrandSafetyDownloadable, _AbstractCrudObject);

  function BrandSafetyDownloadable() {
    classCallCheck(this, BrandSafetyDownloadable);
    return possibleConstructorReturn(this, (BrandSafetyDownloadable.__proto__ || Object.getPrototypeOf(BrandSafetyDownloadable)).apply(this, arguments));
  }

  createClass(BrandSafetyDownloadable, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_context_id: 'account_context_id',
        async_job_percent_complete: 'async_job_percent_complete',
        async_job_status: 'async_job_status',
        file_name: 'file_name',
        id: 'id',
        request_surface: 'request_surface',
        url: 'url'
      });
    }
  }]);
  return BrandSafetyDownloadable;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BrandedContentAdError
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BrandedContentAdError = function (_AbstractCrudObject) {
  inherits(BrandedContentAdError, _AbstractCrudObject);

  function BrandedContentAdError() {
    classCallCheck(this, BrandedContentAdError);
    return possibleConstructorReturn(this, (BrandedContentAdError.__proto__ || Object.getPrototypeOf(BrandedContentAdError)).apply(this, arguments));
  }

  createClass(BrandedContentAdError, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        blame_field_spec: 'blame_field_spec',
        error_code: 'error_code',
        error_description: 'error_description',
        error_message: 'error_message',
        error_placement: 'error_placement',
        error_severity: 'error_severity',
        help_center_id: 'help_center_id'
      });
    }
  }]);
  return BrandedContentAdError;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BrandedContentEligibleSponsorIDs
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BrandedContentEligibleSponsorIDs = function (_AbstractCrudObject) {
  inherits(BrandedContentEligibleSponsorIDs, _AbstractCrudObject);

  function BrandedContentEligibleSponsorIDs() {
    classCallCheck(this, BrandedContentEligibleSponsorIDs);
    return possibleConstructorReturn(this, (BrandedContentEligibleSponsorIDs.__proto__ || Object.getPrototypeOf(BrandedContentEligibleSponsorIDs)).apply(this, arguments));
  }

  createClass(BrandedContentEligibleSponsorIDs, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        fb_page: 'fb_page',
        ig_account_v2: 'ig_account_v2',
        ig_approval_needed: 'ig_approval_needed'
      });
    }
  }]);
  return BrandedContentEligibleSponsorIDs;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessAdsReportingReportSpecs
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessAdsReportingReportSpecs = function (_AbstractCrudObject) {
  inherits(BusinessAdsReportingReportSpecs, _AbstractCrudObject);

  function BusinessAdsReportingReportSpecs() {
    classCallCheck(this, BusinessAdsReportingReportSpecs);
    return possibleConstructorReturn(this, (BusinessAdsReportingReportSpecs.__proto__ || Object.getPrototypeOf(BusinessAdsReportingReportSpecs)).apply(this, arguments));
  }

  createClass(BusinessAdsReportingReportSpecs, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action_report_time: 'action_report_time',
        ad_account_id: 'ad_account_id',
        ad_account_ids: 'ad_account_ids',
        ad_accounts: 'ad_accounts',
        attribution_windows: 'attribution_windows',
        business: 'business',
        business_asset_group: 'business_asset_group',
        comparison_date_interval: 'comparison_date_interval',
        creation_source: 'creation_source',
        creation_time: 'creation_time',
        currency: 'currency',
        date_preset: 'date_preset',
        default_attribution_windows: 'default_attribution_windows',
        filtering: 'filtering',
        formatting: 'formatting',
        id: 'id',
        last_access_by: 'last_access_by',
        last_access_time: 'last_access_time',
        last_report_snapshot_id: 'last_report_snapshot_id',
        last_report_snapshot_time: 'last_report_snapshot_time',
        last_shared_report_expiration: 'last_shared_report_expiration',
        limit: 'limit',
        locked_dimensions: 'locked_dimensions',
        report_name: 'report_name',
        report_snapshot_async_percent_completion: 'report_snapshot_async_percent_completion',
        report_snapshot_async_status: 'report_snapshot_async_status',
        schedule_frequency: 'schedule_frequency',
        scope: 'scope',
        show_deprecate_aw_banner: 'show_deprecate_aw_banner',
        sorting: 'sorting',
        start_date: 'start_date',
        status: 'status',
        subscribers: 'subscribers',
        update_by: 'update_by',
        update_time: 'update_time',
        user: 'user',
        user_dimensions: 'user_dimensions',
        user_metrics: 'user_metrics',
        view_type: 'view_type'
      });
    }
  }]);
  return BusinessAdsReportingReportSpecs;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessAdvertisableApplicationsResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessAdvertisableApplicationsResult = function (_AbstractCrudObject) {
  inherits(BusinessAdvertisableApplicationsResult, _AbstractCrudObject);

  function BusinessAdvertisableApplicationsResult() {
    classCallCheck(this, BusinessAdvertisableApplicationsResult);
    return possibleConstructorReturn(this, (BusinessAdvertisableApplicationsResult.__proto__ || Object.getPrototypeOf(BusinessAdvertisableApplicationsResult)).apply(this, arguments));
  }

  createClass(BusinessAdvertisableApplicationsResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        are_app_events_unavailable: 'are_app_events_unavailable',
        business: 'business',
        has_insight_permission: 'has_insight_permission',
        id: 'id',
        name: 'name',
        photo_url: 'photo_url'
      });
    }
  }]);
  return BusinessAdvertisableApplicationsResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessAgreement
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessAgreement = function (_AbstractCrudObject) {
  inherits(BusinessAgreement, _AbstractCrudObject);

  function BusinessAgreement() {
    classCallCheck(this, BusinessAgreement);
    return possibleConstructorReturn(this, (BusinessAgreement.__proto__ || Object.getPrototypeOf(BusinessAgreement)).apply(this, arguments));
  }

  createClass(BusinessAgreement, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(BusinessAgreement.prototype.__proto__ || Object.getPrototypeOf(BusinessAgreement.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        request_status: 'request_status'
      });
    }
  }, {
    key: 'RequestStatus',
    get: function get() {
      return Object.freeze({
        approve: 'APPROVE',
        decline: 'DECLINE',
        expired: 'EXPIRED',
        in_progress: 'IN_PROGRESS',
        pending: 'PENDING',
        pending_email_verification: 'PENDING_EMAIL_VERIFICATION',
        pending_integrity_review: 'PENDING_INTEGRITY_REVIEW'
      });
    }
  }]);
  return BusinessAgreement;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessCreative
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessCreative = function (_AbstractCrudObject) {
  inherits(BusinessCreative, _AbstractCrudObject);

  function BusinessCreative() {
    classCallCheck(this, BusinessCreative);
    return possibleConstructorReturn(this, (BusinessCreative.__proto__ || Object.getPrototypeOf(BusinessCreative)).apply(this, arguments));
  }

  createClass(BusinessCreative, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        duration: 'duration',
        hash: 'hash',
        height: 'height',
        id: 'id',
        name: 'name',
        thumbnail: 'thumbnail',
        type: 'type',
        url: 'url',
        video_id: 'video_id',
        width: 'width'
      });
    }
  }]);
  return BusinessCreative;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessCreativeInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessCreativeInsights = function (_AbstractCrudObject) {
  inherits(BusinessCreativeInsights, _AbstractCrudObject);

  function BusinessCreativeInsights() {
    classCallCheck(this, BusinessCreativeInsights);
    return possibleConstructorReturn(this, (BusinessCreativeInsights.__proto__ || Object.getPrototypeOf(BusinessCreativeInsights)).apply(this, arguments));
  }

  createClass(BusinessCreativeInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actions: 'actions',
        age: 'age',
        country: 'country',
        date_end: 'date_end',
        date_start: 'date_start',
        device_platform: 'device_platform',
        gender: 'gender',
        impressions: 'impressions',
        inline_link_clicks: 'inline_link_clicks',
        objective: 'objective',
        optimization_goal: 'optimization_goal',
        platform_position: 'platform_position',
        publisher_platform: 'publisher_platform',
        quality_ranking: 'quality_ranking',
        video_play_actions: 'video_play_actions',
        video_thruplay_watched_actions: 'video_thruplay_watched_actions'
      });
    }
  }]);
  return BusinessCreativeInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessFranchiseConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessFranchiseConfig = function (_AbstractCrudObject) {
  inherits(BusinessFranchiseConfig, _AbstractCrudObject);

  function BusinessFranchiseConfig() {
    classCallCheck(this, BusinessFranchiseConfig);
    return possibleConstructorReturn(this, (BusinessFranchiseConfig.__proto__ || Object.getPrototypeOf(BusinessFranchiseConfig)).apply(this, arguments));
  }

  createClass(BusinessFranchiseConfig, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        active_partner_count: 'active_partner_count',
        agency_business: 'agency_business',
        agency_business_asset_group: 'agency_business_asset_group',
        brand_name: 'brand_name',
        business: 'business',
        business_vertical: 'business_vertical',
        id: 'id',
        partner_count: 'partner_count',
        pending_agency_business: 'pending_agency_business',
        program_count: 'program_count',
        shared_business_asset_group: 'shared_business_asset_group',
        shared_creative_folder_count: 'shared_creative_folder_count',
        shared_custom_audience_count: 'shared_custom_audience_count'
      });
    }
  }]);
  return BusinessFranchiseConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessImageTBusinessFolderPathItem
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessImageTBusinessFolderPathItem = function (_AbstractCrudObject) {
  inherits(BusinessImageTBusinessFolderPathItem, _AbstractCrudObject);

  function BusinessImageTBusinessFolderPathItem() {
    classCallCheck(this, BusinessImageTBusinessFolderPathItem);
    return possibleConstructorReturn(this, (BusinessImageTBusinessFolderPathItem.__proto__ || Object.getPrototypeOf(BusinessImageTBusinessFolderPathItem)).apply(this, arguments));
  }

  createClass(BusinessImageTBusinessFolderPathItem, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        parent_folder_id: 'parent_folder_id',
        type: 'type'
      });
    }
  }]);
  return BusinessImageTBusinessFolderPathItem;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessManagedPartnerEligibility
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessManagedPartnerEligibility = function (_AbstractCrudObject) {
  inherits(BusinessManagedPartnerEligibility, _AbstractCrudObject);

  function BusinessManagedPartnerEligibility() {
    classCallCheck(this, BusinessManagedPartnerEligibility);
    return possibleConstructorReturn(this, (BusinessManagedPartnerEligibility.__proto__ || Object.getPrototypeOf(BusinessManagedPartnerEligibility)).apply(this, arguments));
  }

  createClass(BusinessManagedPartnerEligibility, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_eligible: 'is_eligible',
        reason_code: 'reason_code',
        reason_description: 'reason_description'
      });
    }
  }]);
  return BusinessManagedPartnerEligibility;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessMediaAdPlacementValidationResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessMediaAdPlacementValidationResult = function (_AbstractCrudObject) {
  inherits(BusinessMediaAdPlacementValidationResult, _AbstractCrudObject);

  function BusinessMediaAdPlacementValidationResult() {
    classCallCheck(this, BusinessMediaAdPlacementValidationResult);
    return possibleConstructorReturn(this, (BusinessMediaAdPlacementValidationResult.__proto__ || Object.getPrototypeOf(BusinessMediaAdPlacementValidationResult)).apply(this, arguments));
  }

  createClass(BusinessMediaAdPlacementValidationResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_placement: 'ad_placement',
        ad_placement_label: 'ad_placement_label',
        error_messages: 'error_messages',
        is_valid: 'is_valid'
      });
    }
  }]);
  return BusinessMediaAdPlacementValidationResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessObject
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessObject = function (_AbstractCrudObject) {
  inherits(BusinessObject, _AbstractCrudObject);

  function BusinessObject() {
    classCallCheck(this, BusinessObject);
    return possibleConstructorReturn(this, (BusinessObject.__proto__ || Object.getPrototypeOf(BusinessObject)).apply(this, arguments));
  }

  createClass(BusinessObject, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        asset: 'asset',
        asset_type: 'asset_type',
        id: 'id',
        name: 'name',
        picture: 'picture'
      });
    }
  }]);
  return BusinessObject;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessObjectTransferOwnershipAgreement
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessObjectTransferOwnershipAgreement = function (_AbstractCrudObject) {
  inherits(BusinessObjectTransferOwnershipAgreement, _AbstractCrudObject);

  function BusinessObjectTransferOwnershipAgreement() {
    classCallCheck(this, BusinessObjectTransferOwnershipAgreement);
    return possibleConstructorReturn(this, (BusinessObjectTransferOwnershipAgreement.__proto__ || Object.getPrototypeOf(BusinessObjectTransferOwnershipAgreement)).apply(this, arguments));
  }

  createClass(BusinessObjectTransferOwnershipAgreement, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        receiving_business: 'receiving_business',
        requesting_business: 'requesting_business',
        status: 'status'
      });
    }
  }]);
  return BusinessObjectTransferOwnershipAgreement;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessPartnerPremiumOptions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessPartnerPremiumOptions = function (_AbstractCrudObject) {
  inherits(BusinessPartnerPremiumOptions, _AbstractCrudObject);

  function BusinessPartnerPremiumOptions() {
    classCallCheck(this, BusinessPartnerPremiumOptions);
    return possibleConstructorReturn(this, (BusinessPartnerPremiumOptions.__proto__ || Object.getPrototypeOf(BusinessPartnerPremiumOptions)).apply(this, arguments));
  }

  createClass(BusinessPartnerPremiumOptions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        enable_basket_insight: 'enable_basket_insight',
        enable_extended_audience_retargeting: 'enable_extended_audience_retargeting',
        retailer_custom_audience_config: 'retailer_custom_audience_config'
      });
    }
  }]);
  return BusinessPartnerPremiumOptions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessProductCatalogTOS
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessProductCatalogTOS = function (_AbstractCrudObject) {
  inherits(BusinessProductCatalogTOS, _AbstractCrudObject);

  function BusinessProductCatalogTOS() {
    classCallCheck(this, BusinessProductCatalogTOS);
    return possibleConstructorReturn(this, (BusinessProductCatalogTOS.__proto__ || Object.getPrototypeOf(BusinessProductCatalogTOS)).apply(this, arguments));
  }

  createClass(BusinessProductCatalogTOS, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        accepted: 'accepted',
        content: 'content'
      });
    }
  }]);
  return BusinessProductCatalogTOS;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessRequest = function (_AbstractCrudObject) {
  inherits(BusinessRequest, _AbstractCrudObject);

  function BusinessRequest() {
    classCallCheck(this, BusinessRequest);
    return possibleConstructorReturn(this, (BusinessRequest.__proto__ || Object.getPrototypeOf(BusinessRequest)).apply(this, arguments));
  }

  createClass(BusinessRequest, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        accessor: 'accessor',
        creation_time: 'creation_time',
        id: 'id',
        object_id: 'object_id',
        object_type: 'object_type',
        permitted_tasks: 'permitted_tasks',
        request_status: 'request_status',
        request_type: 'request_type',
        requestor: 'requestor'
      });
    }
  }]);
  return BusinessRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessSettingLogsData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessSettingLogsData = function (_AbstractCrudObject) {
  inherits(BusinessSettingLogsData, _AbstractCrudObject);

  function BusinessSettingLogsData() {
    classCallCheck(this, BusinessSettingLogsData);
    return possibleConstructorReturn(this, (BusinessSettingLogsData.__proto__ || Object.getPrototypeOf(BusinessSettingLogsData)).apply(this, arguments));
  }

  createClass(BusinessSettingLogsData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actor: 'actor',
        event_object: 'event_object',
        event_time: 'event_time',
        event_type: 'event_type',
        extra_data: 'extra_data'
      });
    }
  }]);
  return BusinessSettingLogsData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessTag
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessTag = function (_AbstractCrudObject) {
  inherits(BusinessTag, _AbstractCrudObject);

  function BusinessTag() {
    classCallCheck(this, BusinessTag);
    return possibleConstructorReturn(this, (BusinessTag.__proto__ || Object.getPrototypeOf(BusinessTag)).apply(this, arguments));
  }

  createClass(BusinessTag, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return BusinessTag;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessTrafficAnalysisReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessTrafficAnalysisReport = function (_AbstractCrudObject) {
  inherits(BusinessTrafficAnalysisReport, _AbstractCrudObject);

  function BusinessTrafficAnalysisReport() {
    classCallCheck(this, BusinessTrafficAnalysisReport);
    return possibleConstructorReturn(this, (BusinessTrafficAnalysisReport.__proto__ || Object.getPrototypeOf(BusinessTrafficAnalysisReport)).apply(this, arguments));
  }

  createClass(BusinessTrafficAnalysisReport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience_location: 'audience_location',
        event_category: 'event_category',
        traffic_analysis_impressions: 'traffic_analysis_impressions'
      });
    }
  }]);
  return BusinessTrafficAnalysisReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessVideo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessVideo = function (_AbstractCrudObject) {
  inherits(BusinessVideo, _AbstractCrudObject);

  function BusinessVideo() {
    classCallCheck(this, BusinessVideo);
    return possibleConstructorReturn(this, (BusinessVideo.__proto__ || Object.getPrototypeOf(BusinessVideo)).apply(this, arguments));
  }

  createClass(BusinessVideo, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        id: 'id',
        media_library_url: 'media_library_url',
        name: 'name',
        video: 'video'
      });
    }
  }]);
  return BusinessVideo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * BusinessVideoTBusinessFolderPathItem
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var BusinessVideoTBusinessFolderPathItem = function (_AbstractCrudObject) {
  inherits(BusinessVideoTBusinessFolderPathItem, _AbstractCrudObject);

  function BusinessVideoTBusinessFolderPathItem() {
    classCallCheck(this, BusinessVideoTBusinessFolderPathItem);
    return possibleConstructorReturn(this, (BusinessVideoTBusinessFolderPathItem.__proto__ || Object.getPrototypeOf(BusinessVideoTBusinessFolderPathItem)).apply(this, arguments));
  }

  createClass(BusinessVideoTBusinessFolderPathItem, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        parent_folder_id: 'parent_folder_id',
        type: 'type'
      });
    }
  }]);
  return BusinessVideoTBusinessFolderPathItem;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CASSSetupOfflineEventSetProgress
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CASSSetupOfflineEventSetProgress = function (_AbstractCrudObject) {
  inherits(CASSSetupOfflineEventSetProgress, _AbstractCrudObject);

  function CASSSetupOfflineEventSetProgress() {
    classCallCheck(this, CASSSetupOfflineEventSetProgress);
    return possibleConstructorReturn(this, (CASSSetupOfflineEventSetProgress.__proto__ || Object.getPrototypeOf(CASSSetupOfflineEventSetProgress)).apply(this, arguments));
  }

  createClass(CASSSetupOfflineEventSetProgress, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return CASSSetupOfflineEventSetProgress;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CPASAdCreationTemplate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CPASAdCreationTemplate = function (_AbstractCrudObject) {
  inherits(CPASAdCreationTemplate, _AbstractCrudObject);

  function CPASAdCreationTemplate() {
    classCallCheck(this, CPASAdCreationTemplate);
    return possibleConstructorReturn(this, (CPASAdCreationTemplate.__proto__ || Object.getPrototypeOf(CPASAdCreationTemplate)).apply(this, arguments));
  }

  createClass(CPASAdCreationTemplate, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        id: 'id',
        is_unused_template: 'is_unused_template',
        name: 'name',
        optimization_goal: 'optimization_goal',
        targeting_type: 'targeting_type',
        template_type: 'template_type'
      });
    }
  }]);
  return CPASAdCreationTemplate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CPASParentCatalogSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CPASParentCatalogSettings = function (_AbstractCrudObject) {
  inherits(CPASParentCatalogSettings, _AbstractCrudObject);

  function CPASParentCatalogSettings() {
    classCallCheck(this, CPASParentCatalogSettings);
    return possibleConstructorReturn(this, (CPASParentCatalogSettings.__proto__ || Object.getPrototypeOf(CPASParentCatalogSettings)).apply(this, arguments));
  }

  createClass(CPASParentCatalogSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        attribution_windows: 'attribution_windows',
        default_currency: 'default_currency',
        disable_use_as_parent_catalog: 'disable_use_as_parent_catalog',
        id: 'id'
      });
    }
  }]);
  return CPASParentCatalogSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CPASSetup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CPASSetup = function (_AbstractCrudObject) {
  inherits(CPASSetup, _AbstractCrudObject);

  function CPASSetup() {
    classCallCheck(this, CPASSetup);
    return possibleConstructorReturn(this, (CPASSetup.__proto__ || Object.getPrototypeOf(CPASSetup)).apply(this, arguments));
  }

  createClass(CPASSetup, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return CPASSetup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CPASSetupPageStructureProgress
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CPASSetupPageStructureProgress = function (_AbstractCrudObject) {
  inherits(CPASSetupPageStructureProgress, _AbstractCrudObject);

  function CPASSetupPageStructureProgress() {
    classCallCheck(this, CPASSetupPageStructureProgress);
    return possibleConstructorReturn(this, (CPASSetupPageStructureProgress.__proto__ || Object.getPrototypeOf(CPASSetupPageStructureProgress)).apply(this, arguments));
  }

  createClass(CPASSetupPageStructureProgress, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        issues: 'issues',
        name: 'name'
      });
    }
  }]);
  return CPASSetupPageStructureProgress;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CRMAddress
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CRMAddress = function (_AbstractCrudObject) {
  inherits(CRMAddress, _AbstractCrudObject);

  function CRMAddress() {
    classCallCheck(this, CRMAddress);
    return possibleConstructorReturn(this, (CRMAddress.__proto__ || Object.getPrototypeOf(CRMAddress)).apply(this, arguments));
  }

  createClass(CRMAddress, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        city: 'city',
        cnpj_tax_id: 'cnpj_tax_id',
        country: 'country',
        id: 'id',
        postal_code: 'postal_code',
        registration_label: 'registration_label',
        registration_number: 'registration_number',
        state: 'state',
        street1: 'street1',
        street2: 'street2',
        street3: 'street3',
        street4: 'street4',
        validation_status: 'validation_status',
        vat_tax_id: 'vat_tax_id'
      });
    }
  }]);
  return CRMAddress;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CTWAWhatsAppNumbersInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CTWAWhatsAppNumbersInfo = function (_AbstractCrudObject) {
  inherits(CTWAWhatsAppNumbersInfo, _AbstractCrudObject);

  function CTWAWhatsAppNumbersInfo() {
    classCallCheck(this, CTWAWhatsAppNumbersInfo);
    return possibleConstructorReturn(this, (CTWAWhatsAppNumbersInfo.__proto__ || Object.getPrototypeOf(CTWAWhatsAppNumbersInfo)).apply(this, arguments));
  }

  createClass(CTWAWhatsAppNumbersInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_manage_wa_flows: 'can_manage_wa_flows',
        formatted_whatsapp_number: 'formatted_whatsapp_number',
        is_business_number: 'is_business_number',
        number_country_prefix: 'number_country_prefix',
        page_whatsapp_number_id: 'page_whatsapp_number_id',
        waba_id: 'waba_id',
        whatsapp_number: 'whatsapp_number',
        whatsapp_smb_device: 'whatsapp_smb_device'
      });
    }
  }]);
  return CTWAWhatsAppNumbersInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CalibratorExistingRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CalibratorExistingRule = function (_AbstractCrudObject) {
  inherits(CalibratorExistingRule, _AbstractCrudObject);

  function CalibratorExistingRule() {
    classCallCheck(this, CalibratorExistingRule);
    return possibleConstructorReturn(this, (CalibratorExistingRule.__proto__ || Object.getPrototypeOf(CalibratorExistingRule)).apply(this, arguments));
  }

  createClass(CalibratorExistingRule, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        value_7d_volume: '7d_volume',
        creation_source: 'creation_source',
        creation_time: 'creation_time',
        creator: 'creator',
        event_type: 'event_type',
        id: 'id',
        rule: 'rule',
        rule_type: 'rule_type',
        sample_urls: 'sample_urls',
        status: 'status',
        transforms: 'transforms'
      });
    }
  }]);
  return CalibratorExistingRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CallAdsPhoneData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CallAdsPhoneData = function (_AbstractCrudObject) {
  inherits(CallAdsPhoneData, _AbstractCrudObject);

  function CallAdsPhoneData() {
    classCallCheck(this, CallAdsPhoneData);
    return possibleConstructorReturn(this, (CallAdsPhoneData.__proto__ || Object.getPrototypeOf(CallAdsPhoneData)).apply(this, arguments));
  }

  createClass(CallAdsPhoneData, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        call_ads_phone_data_use_case: 'call_ads_phone_data_use_case',
        callback_variant: 'callback_variant',
        destination_website_url: 'destination_website_url',
        id: 'id',
        page: 'page',
        phone_number: 'phone_number'
      });
    }
  }]);
  return CallAdsPhoneData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CampaignActionsData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CampaignActionsData = function (_AbstractCrudObject) {
  inherits(CampaignActionsData, _AbstractCrudObject);

  function CampaignActionsData() {
    classCallCheck(this, CampaignActionsData);
    return possibleConstructorReturn(this, (CampaignActionsData.__proto__ || Object.getPrototypeOf(CampaignActionsData)).apply(this, arguments));
  }

  createClass(CampaignActionsData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return CampaignActionsData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CampaignGroupBrandConfiguration
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CampaignGroupBrandConfiguration = function (_AbstractCrudObject) {
  inherits(CampaignGroupBrandConfiguration, _AbstractCrudObject);

  function CampaignGroupBrandConfiguration() {
    classCallCheck(this, CampaignGroupBrandConfiguration);
    return possibleConstructorReturn(this, (CampaignGroupBrandConfiguration.__proto__ || Object.getPrototypeOf(CampaignGroupBrandConfiguration)).apply(this, arguments));
  }

  createClass(CampaignGroupBrandConfiguration, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        brand_product_name: 'brand_product_name',
        locale: 'locale',
        vertical: 'vertical'
      });
    }
  }]);
  return CampaignGroupBrandConfiguration;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CampaignGroupCollaborativeAdsPartnerInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CampaignGroupCollaborativeAdsPartnerInfo = function (_AbstractCrudObject) {
  inherits(CampaignGroupCollaborativeAdsPartnerInfo, _AbstractCrudObject);

  function CampaignGroupCollaborativeAdsPartnerInfo() {
    classCallCheck(this, CampaignGroupCollaborativeAdsPartnerInfo);
    return possibleConstructorReturn(this, (CampaignGroupCollaborativeAdsPartnerInfo.__proto__ || Object.getPrototypeOf(CampaignGroupCollaborativeAdsPartnerInfo)).apply(this, arguments));
  }

  createClass(CampaignGroupCollaborativeAdsPartnerInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return CampaignGroupCollaborativeAdsPartnerInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CanvasAdSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CanvasAdSettings = function (_AbstractCrudObject) {
  inherits(CanvasAdSettings, _AbstractCrudObject);

  function CanvasAdSettings() {
    classCallCheck(this, CanvasAdSettings);
    return possibleConstructorReturn(this, (CanvasAdSettings.__proto__ || Object.getPrototypeOf(CanvasAdSettings)).apply(this, arguments));
  }

  createClass(CanvasAdSettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_canvas_collection_eligible: 'is_canvas_collection_eligible',
        lead_form_created_time: 'lead_form_created_time',
        lead_form_name: 'lead_form_name',
        lead_gen_form_id: 'lead_gen_form_id',
        leads_count: 'leads_count',
        product_set_id: 'product_set_id',
        use_retailer_item_ids: 'use_retailer_item_ids'
      });
    }
  }]);
  return CanvasAdSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CanvasCollectionThumbnail
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CanvasCollectionThumbnail = function (_AbstractCrudObject) {
  inherits(CanvasCollectionThumbnail, _AbstractCrudObject);

  function CanvasCollectionThumbnail() {
    classCallCheck(this, CanvasCollectionThumbnail);
    return possibleConstructorReturn(this, (CanvasCollectionThumbnail.__proto__ || Object.getPrototypeOf(CanvasCollectionThumbnail)).apply(this, arguments));
  }

  createClass(CanvasCollectionThumbnail, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        element_child_index: 'element_child_index',
        element_id: 'element_id',
        photo: 'photo'
      });
    }
  }]);
  return CanvasCollectionThumbnail;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CanvasDynamicSetting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CanvasDynamicSetting = function (_AbstractCrudObject) {
  inherits(CanvasDynamicSetting, _AbstractCrudObject);

  function CanvasDynamicSetting() {
    classCallCheck(this, CanvasDynamicSetting);
    return possibleConstructorReturn(this, (CanvasDynamicSetting.__proto__ || Object.getPrototypeOf(CanvasDynamicSetting)).apply(this, arguments));
  }

  createClass(CanvasDynamicSetting, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        child_documents: 'child_documents',
        product_set_id: 'product_set_id',
        id: 'id'
      });
    }
  }]);
  return CanvasDynamicSetting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CanvasTemplate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CanvasTemplate = function (_AbstractCrudObject) {
  inherits(CanvasTemplate, _AbstractCrudObject);

  function CanvasTemplate() {
    classCallCheck(this, CanvasTemplate);
    return possibleConstructorReturn(this, (CanvasTemplate.__proto__ || Object.getPrototypeOf(CanvasTemplate)).apply(this, arguments));
  }

  createClass(CanvasTemplate, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        channels: 'channels',
        description: 'description',
        document: 'document',
        id: 'id',
        is_multi_tab_supportable: 'is_multi_tab_supportable',
        is_new: 'is_new',
        name: 'name',
        objectives: 'objectives',
        owner_id: 'owner_id',
        required_capabilities: 'required_capabilities',
        snapshot_photo: 'snapshot_photo',
        status: 'status',
        sub_verticals: 'sub_verticals',
        verticals: 'verticals'
      });
    }
  }]);
  return CanvasTemplate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogBasedTargeting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogBasedTargeting = function (_AbstractCrudObject) {
  inherits(CatalogBasedTargeting, _AbstractCrudObject);

  function CatalogBasedTargeting() {
    classCallCheck(this, CatalogBasedTargeting);
    return possibleConstructorReturn(this, (CatalogBasedTargeting.__proto__ || Object.getPrototypeOf(CatalogBasedTargeting)).apply(this, arguments));
  }

  createClass(CatalogBasedTargeting, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        geo_targeting_type: 'geo_targeting_type'
      });
    }
  }]);
  return CatalogBasedTargeting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogItemAppLinks
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogItemAppLinks = function (_AbstractCrudObject) {
  inherits(CatalogItemAppLinks, _AbstractCrudObject);

  function CatalogItemAppLinks() {
    classCallCheck(this, CatalogItemAppLinks);
    return possibleConstructorReturn(this, (CatalogItemAppLinks.__proto__ || Object.getPrototypeOf(CatalogItemAppLinks)).apply(this, arguments));
  }

  createClass(CatalogItemAppLinks, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        android: 'android',
        ios: 'ios',
        ipad: 'ipad',
        iphone: 'iphone',
        web: 'web',
        windows: 'windows',
        windows_phone: 'windows_phone',
        windows_universal: 'windows_universal'
      });
    }
  }]);
  return CatalogItemAppLinks;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogItemOverride
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogItemOverride = function (_AbstractCrudObject) {
  inherits(CatalogItemOverride, _AbstractCrudObject);

  function CatalogItemOverride() {
    classCallCheck(this, CatalogItemOverride);
    return possibleConstructorReturn(this, (CatalogItemOverride.__proto__ || Object.getPrototypeOf(CatalogItemOverride)).apply(this, arguments));
  }

  createClass(CatalogItemOverride, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        local_info: 'local_info',
        override_type: 'override_type',
        override_value: 'override_value'
      });
    }
  }]);
  return CatalogItemOverride;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogItemRejectionReasons
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogItemRejectionReasons = function (_AbstractCrudObject) {
  inherits(CatalogItemRejectionReasons, _AbstractCrudObject);

  function CatalogItemRejectionReasons() {
    classCallCheck(this, CatalogItemRejectionReasons);
    return possibleConstructorReturn(this, (CatalogItemRejectionReasons.__proto__ || Object.getPrototypeOf(CatalogItemRejectionReasons)).apply(this, arguments));
  }

  createClass(CatalogItemRejectionReasons, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        capability: 'capability',
        rejection_information: 'rejection_information'
      });
    }
  }]);
  return CatalogItemRejectionReasons;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogItemValidationErrorList
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogItemValidationErrorList = function (_AbstractCrudObject) {
  inherits(CatalogItemValidationErrorList, _AbstractCrudObject);

  function CatalogItemValidationErrorList() {
    classCallCheck(this, CatalogItemValidationErrorList);
    return possibleConstructorReturn(this, (CatalogItemValidationErrorList.__proto__ || Object.getPrototypeOf(CatalogItemValidationErrorList)).apply(this, arguments));
  }

  createClass(CatalogItemValidationErrorList, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        errors: 'errors'
      });
    }
  }]);
  return CatalogItemValidationErrorList;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogSmartPixelSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogSmartPixelSettings = function (_AbstractCrudObject) {
  inherits(CatalogSmartPixelSettings, _AbstractCrudObject);

  function CatalogSmartPixelSettings() {
    classCallCheck(this, CatalogSmartPixelSettings);
    return possibleConstructorReturn(this, (CatalogSmartPixelSettings.__proto__ || Object.getPrototypeOf(CatalogSmartPixelSettings)).apply(this, arguments));
  }

  createClass(CatalogSmartPixelSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        allowed_domains: 'allowed_domains',
        available_property_filters: 'available_property_filters',
        catalog: 'catalog',
        cbb_custom_override_filters: 'cbb_custom_override_filters',
        cbb_default_filter: 'cbb_default_filter',
        defaults: 'defaults',
        filters: 'filters',
        id: 'id',
        is_cbb_enabled: 'is_cbb_enabled',
        is_create_enabled: 'is_create_enabled',
        is_delete_enabled: 'is_delete_enabled',
        is_update_enabled: 'is_update_enabled',
        microdata_format_precedence: 'microdata_format_precedence',
        pixel: 'pixel',
        property_filter: 'property_filter',
        trusted_domains: 'trusted_domains'
      });
    }
  }]);
  return CatalogSmartPixelSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogSubVerticalList
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogSubVerticalList = function (_AbstractCrudObject) {
  inherits(CatalogSubVerticalList, _AbstractCrudObject);

  function CatalogSubVerticalList() {
    classCallCheck(this, CatalogSubVerticalList);
    return possibleConstructorReturn(this, (CatalogSubVerticalList.__proto__ || Object.getPrototypeOf(CatalogSubVerticalList)).apply(this, arguments));
  }

  createClass(CatalogSubVerticalList, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        appliances: 'appliances',
        baby_feeding: 'baby_feeding',
        baby_transport: 'baby_transport',
        beauty: 'beauty',
        bedding: 'bedding',
        cameras: 'cameras',
        cameras_and_photos: 'cameras_and_photos',
        cell_phones_and_smart_watches: 'cell_phones_and_smart_watches',
        cleaning_supplies: 'cleaning_supplies',
        clo_offer: 'clo_offer',
        clothing: 'clothing',
        clothing_accessories: 'clothing_accessories',
        computer_components: 'computer_components',
        computers_and_tablets: 'computers_and_tablets',
        computers_laptops_and_tablets: 'computers_laptops_and_tablets',
        diapering_and_potty_training: 'diapering_and_potty_training',
        digital_product_offer: 'digital_product_offer',
        electronic_accessories_and_cables: 'electronic_accessories_and_cables',
        electronics_accessories: 'electronics_accessories',
        furniture: 'furniture',
        health: 'health',
        home: 'home',
        home_goods: 'home_goods',
        household_and_cleaning_supplies: 'household_and_cleaning_supplies',
        jewelry: 'jewelry',
        large_appliances: 'large_appliances',
        local_service_business_item: 'local_service_business_item',
        local_service_business_restaurant: 'local_service_business_restaurant',
        loyalty_offer: 'loyalty_offer',
        nursery: 'nursery',
        printers_and_scanners: 'printers_and_scanners',
        printers_scanners_and_fax_machines: 'printers_scanners_and_fax_machines',
        product_discount: 'product_discount',
        projectors: 'projectors',
        shoes: 'shoes',
        shoes_and_footwear: 'shoes_and_footwear',
        software: 'software',
        televisions_and_monitors: 'televisions_and_monitors',
        test_child_sub_vertical: 'test_child_sub_vertical',
        test_grand_child_sub_vertical: 'test_grand_child_sub_vertical',
        test_sub_vertical: 'test_sub_vertical',
        test_sub_vertical_alias: 'test_sub_vertical_alias',
        test_sub_vertical_data_object: 'test_sub_vertical_data_object',
        third_party_electronics: 'third_party_electronics',
        third_party_toys_and_games: 'third_party_toys_and_games',
        toys: 'toys',
        toys_and_games: 'toys_and_games',
        tvs_and_monitors: 'tvs_and_monitors',
        vehicle_manufacturer: 'vehicle_manufacturer',
        video_game_consoles_and_video_games: 'video_game_consoles_and_video_games',
        video_games_and_consoles: 'video_games_and_consoles',
        video_projectors: 'video_projectors',
        watches: 'watches'
      });
    }
  }]);
  return CatalogSubVerticalList;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogWebsiteOnboardingSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogWebsiteOnboardingSettings = function (_AbstractCrudObject) {
  inherits(CatalogWebsiteOnboardingSettings, _AbstractCrudObject);

  function CatalogWebsiteOnboardingSettings() {
    classCallCheck(this, CatalogWebsiteOnboardingSettings);
    return possibleConstructorReturn(this, (CatalogWebsiteOnboardingSettings.__proto__ || Object.getPrototypeOf(CatalogWebsiteOnboardingSettings)).apply(this, arguments));
  }

  createClass(CatalogWebsiteOnboardingSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        status: 'status'
      });
    }
  }]);
  return CatalogWebsiteOnboardingSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CatalogWebsiteSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CatalogWebsiteSettings = function (_AbstractCrudObject) {
  inherits(CatalogWebsiteSettings, _AbstractCrudObject);

  function CatalogWebsiteSettings() {
    classCallCheck(this, CatalogWebsiteSettings);
    return possibleConstructorReturn(this, (CatalogWebsiteSettings.__proto__ || Object.getPrototypeOf(CatalogWebsiteSettings)).apply(this, arguments));
  }

  createClass(CatalogWebsiteSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        is_allowed_to_crawl: 'is_allowed_to_crawl'
      });
    }
  }]);
  return CatalogWebsiteSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ChildEvent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ChildEvent = function (_AbstractCrudObject) {
  inherits(ChildEvent, _AbstractCrudObject);

  function ChildEvent() {
    classCallCheck(this, ChildEvent);
    return possibleConstructorReturn(this, (ChildEvent.__proto__ || Object.getPrototypeOf(ChildEvent)).apply(this, arguments));
  }

  createClass(ChildEvent, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        end_time: 'end_time',
        id: 'id',
        start_time: 'start_time',
        ticket_uri: 'ticket_uri'
      });
    }
  }]);
  return ChildEvent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ChinaBusinessOnboardingVettingRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ChinaBusinessOnboardingVettingRequest = function (_AbstractCrudObject) {
  inherits(ChinaBusinessOnboardingVettingRequest, _AbstractCrudObject);

  function ChinaBusinessOnboardingVettingRequest() {
    classCallCheck(this, ChinaBusinessOnboardingVettingRequest);
    return possibleConstructorReturn(this, (ChinaBusinessOnboardingVettingRequest.__proto__ || Object.getPrototypeOf(ChinaBusinessOnboardingVettingRequest)).apply(this, arguments));
  }

  createClass(ChinaBusinessOnboardingVettingRequest, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_creation_request_status: 'ad_account_creation_request_status',
        ad_account_limit: 'ad_account_limit',
        ad_account_number: 'ad_account_number',
        ad_accounts_info: 'ad_accounts_info',
        business_manager_id: 'business_manager_id',
        business_registration: 'business_registration',
        business_registration_id: 'business_registration_id',
        chinese_address: 'chinese_address',
        chinese_legal_entity_name: 'chinese_legal_entity_name',
        city: 'city',
        contact: 'contact',
        coupon_code: 'coupon_code',
        disapprove_reason: 'disapprove_reason',
        english_business_name: 'english_business_name',
        id: 'id',
        official_website_url: 'official_website_url',
        org_ad_account_count: 'org_ad_account_count',
        payment_type: 'payment_type',
        planning_agency_id: 'planning_agency_id',
        planning_agency_name: 'planning_agency_name',
        promotable_app_ids: 'promotable_app_ids',
        promotable_page_ids: 'promotable_page_ids',
        promotable_pages: 'promotable_pages',
        promotable_urls: 'promotable_urls',
        request_changes_reason: 'request_changes_reason',
        reviewed_user: 'reviewed_user',
        spend_limit: 'spend_limit',
        status: 'status',
        subvertical: 'subvertical',
        subvertical_v2: 'subvertical_v2',
        supporting_document: 'supporting_document',
        time_changes_requested: 'time_changes_requested',
        time_created: 'time_created',
        time_updated: 'time_updated',
        time_zone: 'time_zone',
        used_reseller_link: 'used_reseller_link',
        user_id: 'user_id',
        user_name: 'user_name',
        vertical: 'vertical',
        vertical_v2: 'vertical_v2',
        viewed_by_reseller: 'viewed_by_reseller',
        zip_code: 'zip_code'
      });
    }
  }]);
  return ChinaBusinessOnboardingVettingRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CloudbridgeDatasetStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CloudbridgeDatasetStatus = function (_AbstractCrudObject) {
  inherits(CloudbridgeDatasetStatus, _AbstractCrudObject);

  function CloudbridgeDatasetStatus() {
    classCallCheck(this, CloudbridgeDatasetStatus);
    return possibleConstructorReturn(this, (CloudbridgeDatasetStatus.__proto__ || Object.getPrototypeOf(CloudbridgeDatasetStatus)).apply(this, arguments));
  }

  createClass(CloudbridgeDatasetStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_redacted_event: 'app_redacted_event',
        app_sensitive_params: 'app_sensitive_params',
        app_unverified_event: 'app_unverified_event',
        has_app_associated: 'has_app_associated',
        is_app_prohibited: 'is_app_prohibited',
        is_dataset: 'is_dataset'
      });
    }
  }]);
  return CloudbridgeDatasetStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CollaborativeAdsPartnerBusinesses
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CollaborativeAdsPartnerBusinesses = function (_AbstractCrudObject) {
  inherits(CollaborativeAdsPartnerBusinesses, _AbstractCrudObject);

  function CollaborativeAdsPartnerBusinesses() {
    classCallCheck(this, CollaborativeAdsPartnerBusinesses);
    return possibleConstructorReturn(this, (CollaborativeAdsPartnerBusinesses.__proto__ || Object.getPrototypeOf(CollaborativeAdsPartnerBusinesses)).apply(this, arguments));
  }

  createClass(CollaborativeAdsPartnerBusinesses, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        collaborative_ads_partner_businesses_info: 'collaborative_ads_partner_businesses_info',
        dedicated_partner_business_info: 'dedicated_partner_business_info'
      });
    }
  }]);
  return CollaborativeAdsPartnerBusinesses;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CollaborativeAdsPartnerInfoListItem
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CollaborativeAdsPartnerInfoListItem = function (_AbstractCrudObject) {
  inherits(CollaborativeAdsPartnerInfoListItem, _AbstractCrudObject);

  function CollaborativeAdsPartnerInfoListItem() {
    classCallCheck(this, CollaborativeAdsPartnerInfoListItem);
    return possibleConstructorReturn(this, (CollaborativeAdsPartnerInfoListItem.__proto__ || Object.getPrototypeOf(CollaborativeAdsPartnerInfoListItem)).apply(this, arguments));
  }

  createClass(CollaborativeAdsPartnerInfoListItem, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return CollaborativeAdsPartnerInfoListItem;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ColumnSuggestions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ColumnSuggestions = function (_AbstractCrudObject) {
  inherits(ColumnSuggestions, _AbstractCrudObject);

  function ColumnSuggestions() {
    classCallCheck(this, ColumnSuggestions);
    return possibleConstructorReturn(this, (ColumnSuggestions.__proto__ || Object.getPrototypeOf(ColumnSuggestions)).apply(this, arguments));
  }

  createClass(ColumnSuggestions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        explanations: 'explanations',
        format: 'format',
        objective: 'objective',
        optimization_goals: 'optimization_goals'
      });
    }
  }]);
  return ColumnSuggestions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CommerceSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CommerceSettings = function (_AbstractCrudObject) {
  inherits(CommerceSettings, _AbstractCrudObject);

  function CommerceSettings() {
    classCallCheck(this, CommerceSettings);
    return possibleConstructorReturn(this, (CommerceSettings.__proto__ || Object.getPrototypeOf(CommerceSettings)).apply(this, arguments));
  }

  createClass(CommerceSettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        inventory: 'inventory',
        total_inventory: 'total_inventory'
      });
    }
  }]);
  return CommerceSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ConnectionsTargeting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ConnectionsTargeting = function (_AbstractCrudObject) {
  inherits(ConnectionsTargeting, _AbstractCrudObject);

  function ConnectionsTargeting() {
    classCallCheck(this, ConnectionsTargeting);
    return possibleConstructorReturn(this, (ConnectionsTargeting.__proto__ || Object.getPrototypeOf(ConnectionsTargeting)).apply(this, arguments));
  }

  createClass(ConnectionsTargeting, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return ConnectionsTargeting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ContactsMessengerSyncConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ContactsMessengerSyncConfig = function (_AbstractCrudObject) {
  inherits(ContactsMessengerSyncConfig, _AbstractCrudObject);

  function ContactsMessengerSyncConfig() {
    classCallCheck(this, ContactsMessengerSyncConfig);
    return possibleConstructorReturn(this, (ContactsMessengerSyncConfig.__proto__ || Object.getPrototypeOf(ContactsMessengerSyncConfig)).apply(this, arguments));
  }

  createClass(ContactsMessengerSyncConfig, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        enabled: 'enabled'
      });
    }
  }]);
  return ContactsMessengerSyncConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ContentBlockList
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ContentBlockList = function (_AbstractCrudObject) {
  inherits(ContentBlockList, _AbstractCrudObject);

  function ContentBlockList() {
    classCallCheck(this, ContentBlockList);
    return possibleConstructorReturn(this, (ContentBlockList.__proto__ || Object.getPrototypeOf(ContentBlockList)).apply(this, arguments));
  }

  createClass(ContentBlockList, [{
    key: 'getAppliedAdAccounts',
    value: function getAppliedAdAccounts(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AdAccount, fields, params, fetchFirstPage, '/applied_ad_accounts');
    }
  }, {
    key: 'getFacebookContent',
    value: function getFacebookContent(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/facebook_content');
    }
  }, {
    key: 'getInstagramContent',
    value: function getInstagramContent(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(IGMedia, fields, params, fetchFirstPage, '/instagram_content');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return ContentBlockList;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ContentDeliveryReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ContentDeliveryReport = function (_AbstractCrudObject) {
  inherits(ContentDeliveryReport, _AbstractCrudObject);

  function ContentDeliveryReport() {
    classCallCheck(this, ContentDeliveryReport);
    return possibleConstructorReturn(this, (ContentDeliveryReport.__proto__ || Object.getPrototypeOf(ContentDeliveryReport)).apply(this, arguments));
  }

  createClass(ContentDeliveryReport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        content_name: 'content_name',
        content_url: 'content_url',
        creator_name: 'creator_name',
        creator_url: 'creator_url',
        estimated_impressions: 'estimated_impressions'
      });
    }
  }]);
  return ContentDeliveryReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ContextualBundlingSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ContextualBundlingSpec = function (_AbstractCrudObject) {
  inherits(ContextualBundlingSpec, _AbstractCrudObject);

  function ContextualBundlingSpec() {
    classCallCheck(this, ContextualBundlingSpec);
    return possibleConstructorReturn(this, (ContextualBundlingSpec.__proto__ || Object.getPrototypeOf(ContextualBundlingSpec)).apply(this, arguments));
  }

  createClass(ContextualBundlingSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        status: 'status'
      });
    }
  }]);
  return ContextualBundlingSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ConversionActionQuery
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ConversionActionQuery = function (_AbstractCrudObject) {
  inherits(ConversionActionQuery, _AbstractCrudObject);

  function ConversionActionQuery() {
    classCallCheck(this, ConversionActionQuery);
    return possibleConstructorReturn(this, (ConversionActionQuery.__proto__ || Object.getPrototypeOf(ConversionActionQuery)).apply(this, arguments));
  }

  createClass(ConversionActionQuery, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action_type: 'action.type',
        application: 'application',
        conversion_id: 'conversion_id',
        creative: 'creative',
        dataset: 'dataset',
        event: 'event',
        event_creator: 'event.creator',
        event_type: 'event_type',
        fb_pixel: 'fb_pixel',
        fb_pixel_event: 'fb_pixel_event',
        leadgen: 'leadgen',
        object: 'object',
        object_domain: 'object.domain',
        offer: 'offer',
        offer_creator: 'offer.creator',
        offsite_pixel: 'offsite_pixel',
        page: 'page',
        page_parent: 'page.parent',
        post: 'post',
        post_object: 'post.object',
        post_object_wall: 'post.object.wall',
        post_wall: 'post.wall',
        question: 'question',
        question_creator: 'question.creator',
        response: 'response',
        subtype: 'subtype'
      });
    }
  }]);
  return ConversionActionQuery;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ConversionHealthKPI
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ConversionHealthKPI = function (_AbstractCrudObject) {
  inherits(ConversionHealthKPI, _AbstractCrudObject);

  function ConversionHealthKPI() {
    classCallCheck(this, ConversionHealthKPI);
    return possibleConstructorReturn(this, (ConversionHealthKPI.__proto__ || Object.getPrototypeOf(ConversionHealthKPI)).apply(this, arguments));
  }

  createClass(ConversionHealthKPI, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        health_indicator: 'health_indicator',
        impacted_browsers_match_rate: 'impacted_browsers_match_rate',
        impacted_browsers_match_rate_mom_trend: 'impacted_browsers_match_rate_mom_trend',
        impacted_browsers_traffic_share: 'impacted_browsers_traffic_share',
        impacted_browsers_traffic_share_mom_trend: 'impacted_browsers_traffic_share_mom_trend',
        match_rate: 'match_rate',
        match_rate_mom_trend: 'match_rate_mom_trend',
        match_rate_vertical_benchmark: 'match_rate_vertical_benchmark',
        match_rate_vs_benchmark_mom_trend: 'match_rate_vs_benchmark_mom_trend'
      });
    }
  }]);
  return ConversionHealthKPI;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CopyrightAttributionInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CopyrightAttributionInsights = function (_AbstractCrudObject) {
  inherits(CopyrightAttributionInsights, _AbstractCrudObject);

  function CopyrightAttributionInsights() {
    classCallCheck(this, CopyrightAttributionInsights);
    return possibleConstructorReturn(this, (CopyrightAttributionInsights.__proto__ || Object.getPrototypeOf(CopyrightAttributionInsights)).apply(this, arguments));
  }

  createClass(CopyrightAttributionInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        l7_attribution_page_view: 'l7_attribution_page_view',
        l7_attribution_page_view_delta: 'l7_attribution_page_view_delta',
        l7_attribution_video_view: 'l7_attribution_video_view',
        l7_attribution_video_view_delta: 'l7_attribution_video_view_delta',
        metrics_ending_date: 'metrics_ending_date'
      });
    }
  }]);
  return CopyrightAttributionInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CopyrightAudioAsset
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CopyrightAudioAsset = function (_AbstractCrudObject) {
  inherits(CopyrightAudioAsset, _AbstractCrudObject);

  function CopyrightAudioAsset() {
    classCallCheck(this, CopyrightAudioAsset);
    return possibleConstructorReturn(this, (CopyrightAudioAsset.__proto__ || Object.getPrototypeOf(CopyrightAudioAsset)).apply(this, arguments));
  }

  createClass(CopyrightAudioAsset, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audio_availability_status: 'audio_availability_status',
        audio_library_policy: 'audio_library_policy',
        creation_time: 'creation_time',
        id: 'id',
        reference_files: 'reference_files',
        title: 'title',
        update_time: 'update_time'
      });
    }
  }]);
  return CopyrightAudioAsset;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CopyrightMediaMisuse
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CopyrightMediaMisuse = function (_AbstractCrudObject) {
  inherits(CopyrightMediaMisuse, _AbstractCrudObject);

  function CopyrightMediaMisuse() {
    classCallCheck(this, CopyrightMediaMisuse);
    return possibleConstructorReturn(this, (CopyrightMediaMisuse.__proto__ || Object.getPrototypeOf(CopyrightMediaMisuse)).apply(this, arguments));
  }

  createClass(CopyrightMediaMisuse, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audio_segments: 'audio_segments',
        creation_time: 'creation_time',
        disabled_audio_segments: 'disabled_audio_segments',
        disabled_video_segments: 'disabled_video_segments',
        entire_file_issue: 'entire_file_issue',
        entire_file_issue_reasons: 'entire_file_issue_reasons',
        expiration_time: 'expiration_time',
        id: 'id',
        media_asset_id: 'media_asset_id',
        reasons: 'reasons',
        requested_audio_segments: 'requested_audio_segments',
        requested_video_segments: 'requested_video_segments',
        resolution_type: 'resolution_type',
        status: 'status',
        update_time: 'update_time',
        video_copyright: 'video_copyright',
        video_segments: 'video_segments'
      });
    }
  }]);
  return CopyrightMediaMisuse;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CopyrightReferenceContainer
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CopyrightReferenceContainer = function (_AbstractCrudObject) {
  inherits(CopyrightReferenceContainer, _AbstractCrudObject);

  function CopyrightReferenceContainer() {
    classCallCheck(this, CopyrightReferenceContainer);
    return possibleConstructorReturn(this, (CopyrightReferenceContainer.__proto__ || Object.getPrototypeOf(CopyrightReferenceContainer)).apply(this, arguments));
  }

  createClass(CopyrightReferenceContainer, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        content_type: 'content_type',
        copyright_creation_time: 'copyright_creation_time',
        download_hd_url: 'download_hd_url',
        duration_in_sec: 'duration_in_sec',
        id: 'id',
        iswc: 'iswc',
        metadata: 'metadata',
        published_time: 'published_time',
        thumbnail_url: 'thumbnail_url',
        title: 'title',
        universal_content_id: 'universal_content_id',
        writer_names: 'writer_names'
      });
    }
  }]);
  return CopyrightReferenceContainer;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CoverPhoto
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CoverPhoto = function (_AbstractCrudObject) {
  inherits(CoverPhoto, _AbstractCrudObject);

  function CoverPhoto() {
    classCallCheck(this, CoverPhoto);
    return possibleConstructorReturn(this, (CoverPhoto.__proto__ || Object.getPrototypeOf(CoverPhoto)).apply(this, arguments));
  }

  createClass(CoverPhoto, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        cover_id: 'cover_id',
        id: 'id',
        offset_x: 'offset_x',
        offset_y: 'offset_y',
        source: 'source'
      });
    }
  }]);
  return CoverPhoto;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CreativeAssetTag
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CreativeAssetTag = function (_AbstractCrudObject) {
  inherits(CreativeAssetTag, _AbstractCrudObject);

  function CreativeAssetTag() {
    classCallCheck(this, CreativeAssetTag);
    return possibleConstructorReturn(this, (CreativeAssetTag.__proto__ || Object.getPrototypeOf(CreativeAssetTag)).apply(this, arguments));
  }

  createClass(CreativeAssetTag, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        name: 'name'
      });
    }
  }]);
  return CreativeAssetTag;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CreativeHistory
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CreativeHistory = function (_AbstractCrudObject) {
  inherits(CreativeHistory, _AbstractCrudObject);

  function CreativeHistory() {
    classCallCheck(this, CreativeHistory);
    return possibleConstructorReturn(this, (CreativeHistory.__proto__ || Object.getPrototypeOf(CreativeHistory)).apply(this, arguments));
  }

  createClass(CreativeHistory, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creative_fingerprint: 'creative_fingerprint',
        time_ranges: 'time_ranges'
      });
    }
  }]);
  return CreativeHistory;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CreditPartitionActionOptions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CreditPartitionActionOptions = function (_AbstractCrudObject) {
  inherits(CreditPartitionActionOptions, _AbstractCrudObject);

  function CreditPartitionActionOptions() {
    classCallCheck(this, CreditPartitionActionOptions);
    return possibleConstructorReturn(this, (CreditPartitionActionOptions.__proto__ || Object.getPrototypeOf(CreditPartitionActionOptions)).apply(this, arguments));
  }

  createClass(CreditPartitionActionOptions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        liability_type: 'liability_type',
        partition_type: 'partition_type',
        send_bill_to: 'send_bill_to'
      });
    }
  }]);
  return CreditPartitionActionOptions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Currency
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Currency = function (_AbstractCrudObject) {
  inherits(Currency, _AbstractCrudObject);

  function Currency() {
    classCallCheck(this, Currency);
    return possibleConstructorReturn(this, (Currency.__proto__ || Object.getPrototypeOf(Currency)).apply(this, arguments));
  }

  createClass(Currency, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        currency_offset: 'currency_offset',
        usd_exchange: 'usd_exchange',
        usd_exchange_inverse: 'usd_exchange_inverse',
        user_currency: 'user_currency'
      });
    }
  }]);
  return Currency;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CurrencyAmount
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CurrencyAmount = function (_AbstractCrudObject) {
  inherits(CurrencyAmount, _AbstractCrudObject);

  function CurrencyAmount() {
    classCallCheck(this, CurrencyAmount);
    return possibleConstructorReturn(this, (CurrencyAmount.__proto__ || Object.getPrototypeOf(CurrencyAmount)).apply(this, arguments));
  }

  createClass(CurrencyAmount, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount: 'amount',
        amount_in_hundredths: 'amount_in_hundredths',
        currency: 'currency',
        offsetted_amount: 'offsetted_amount'
      });
    }
  }]);
  return CurrencyAmount;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudienceAdAccount
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudienceAdAccount = function (_AbstractCrudObject) {
  inherits(CustomAudienceAdAccount, _AbstractCrudObject);

  function CustomAudienceAdAccount() {
    classCallCheck(this, CustomAudienceAdAccount);
    return possibleConstructorReturn(this, (CustomAudienceAdAccount.__proto__ || Object.getPrototypeOf(CustomAudienceAdAccount)).apply(this, arguments));
  }

  createClass(CustomAudienceAdAccount, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return CustomAudienceAdAccount;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudienceCapabilities
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudienceCapabilities = function (_AbstractCrudObject) {
  inherits(CustomAudienceCapabilities, _AbstractCrudObject);

  function CustomAudienceCapabilities() {
    classCallCheck(this, CustomAudienceCapabilities);
    return possibleConstructorReturn(this, (CustomAudienceCapabilities.__proto__ || Object.getPrototypeOf(CustomAudienceCapabilities)).apply(this, arguments));
  }

  createClass(CustomAudienceCapabilities, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        capabilities: 'capabilities'
      });
    }
  }]);
  return CustomAudienceCapabilities;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudienceDataSource
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudienceDataSource = function (_AbstractCrudObject) {
  inherits(CustomAudienceDataSource, _AbstractCrudObject);

  function CustomAudienceDataSource() {
    classCallCheck(this, CustomAudienceDataSource);
    return possibleConstructorReturn(this, (CustomAudienceDataSource.__proto__ || Object.getPrototypeOf(CustomAudienceDataSource)).apply(this, arguments));
  }

  createClass(CustomAudienceDataSource, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_params: 'creation_params',
        sub_type: 'sub_type',
        type: 'type'
      });
    }
  }, {
    key: 'SubType',
    get: function get() {
      return Object.freeze({
        ad_campaign: 'AD_CAMPAIGN',
        anything: 'ANYTHING',
        app_users: 'APP_USERS',
        ar_effects_events: 'AR_EFFECTS_EVENTS',
        ar_experience_events: 'AR_EXPERIENCE_EVENTS',
        campaign_conversions: 'CAMPAIGN_CONVERSIONS',
        combination_custom_audience_users: 'COMBINATION_CUSTOM_AUDIENCE_USERS',
        constant_contacts_email_hashes: 'CONSTANT_CONTACTS_EMAIL_HASHES',
        contact_importer: 'CONTACT_IMPORTER',
        conversion_pixel_hits: 'CONVERSION_PIXEL_HITS',
        copy_paste_email_hashes: 'COPY_PASTE_EMAIL_HASHES',
        custom_audience_users: 'CUSTOM_AUDIENCE_USERS',
        custom_data_targeting: 'CUSTOM_DATA_TARGETING',
        data_file: 'DATA_FILE',
        dynamic_rule: 'DYNAMIC_RULE',
        engagement_event_users: 'ENGAGEMENT_EVENT_USERS',
        expanded_audience: 'EXPANDED_AUDIENCE',
        external_ids: 'EXTERNAL_IDS',
        external_ids_mix: 'EXTERNAL_IDS_MIX',
        facebook_wifi_events: 'FACEBOOK_WIFI_EVENTS',
        fb_event_signals: 'FB_EVENT_SIGNALS',
        fb_pixel_hits: 'FB_PIXEL_HITS',
        group_events: 'GROUP_EVENTS',
        hashes: 'HASHES',
        hashes_or_user_ids: 'HASHES_OR_USER_IDS',
        household_expansion: 'HOUSEHOLD_EXPANSION',
        ig_business_events: 'IG_BUSINESS_EVENTS',
        ig_promoted_post: 'IG_PROMOTED_POST',
        instant_article_events: 'INSTANT_ARTICLE_EVENTS',
        lookalike_platform: 'LOOKALIKE_PLATFORM',
        mail_chimp_email_hashes: 'MAIL_CHIMP_EMAIL_HASHES',
        marketplace_listings: 'MARKETPLACE_LISTINGS',
        messenger_onsite_subscription: 'MESSENGER_ONSITE_SUBSCRIPTION',
        mobile_advertiser_ids: 'MOBILE_ADVERTISER_IDS',
        mobile_app_combination_events: 'MOBILE_APP_COMBINATION_EVENTS',
        mobile_app_custom_audience_users: 'MOBILE_APP_CUSTOM_AUDIENCE_USERS',
        mobile_app_events: 'MOBILE_APP_EVENTS',
        multicountry_combination: 'MULTICOUNTRY_COMBINATION',
        multi_data_events: 'MULTI_DATA_EVENTS',
        multi_event_source: 'MULTI_EVENT_SOURCE',
        multi_hashes: 'MULTI_HASHES',
        nothing: 'NOTHING',
        offline_event_users: 'OFFLINE_EVENT_USERS',
        page_fans: 'PAGE_FANS',
        page_smart_audience: 'PAGE_SMART_AUDIENCE',
        partner_category_users: 'PARTNER_CATEGORY_USERS',
        place_visits: 'PLACE_VISITS',
        platform: 'PLATFORM',
        platform_users: 'PLATFORM_USERS',
        seed_list: 'SEED_LIST',
        signal_source: 'SIGNAL_SOURCE',
        smart_audience: 'SMART_AUDIENCE',
        store_visit_events: 'STORE_VISIT_EVENTS',
        subscriber_list: 'SUBSCRIBER_LIST',
        s_expr: 'S_EXPR',
        tokens: 'TOKENS',
        user_ids: 'USER_IDS',
        video_events: 'VIDEO_EVENTS',
        video_event_users: 'VIDEO_EVENT_USERS',
        web_pixel_combination_events: 'WEB_PIXEL_COMBINATION_EVENTS',
        web_pixel_hits: 'WEB_PIXEL_HITS',
        web_pixel_hits_custom_audience_users: 'WEB_PIXEL_HITS_CUSTOM_AUDIENCE_USERS',
        whatsapp_subscriber_pool: 'WHATSAPP_SUBSCRIBER_POOL'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        contact_importer: 'CONTACT_IMPORTER',
        copy_paste: 'COPY_PASTE',
        event_based: 'EVENT_BASED',
        file_imported: 'FILE_IMPORTED',
        household_audience: 'HOUSEHOLD_AUDIENCE',
        seed_based: 'SEED_BASED',
        third_party_imported: 'THIRD_PARTY_IMPORTED',
        unknown: 'UNKNOWN'
      });
    }
  }]);
  return CustomAudienceDataSource;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudienceGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudienceGroup = function (_AbstractCrudObject) {
  inherits(CustomAudienceGroup, _AbstractCrudObject);

  function CustomAudienceGroup() {
    classCallCheck(this, CustomAudienceGroup);
    return possibleConstructorReturn(this, (CustomAudienceGroup.__proto__ || Object.getPrototypeOf(CustomAudienceGroup)).apply(this, arguments));
  }

  createClass(CustomAudienceGroup, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience_type_param_name: 'audience_type_param_name',
        existing_customer_tag: 'existing_customer_tag',
        new_customer_tag: 'new_customer_tag'
      });
    }
  }]);
  return CustomAudienceGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudienceSharedAccountCampaignInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudienceSharedAccountCampaignInfo = function (_AbstractCrudObject) {
  inherits(CustomAudienceSharedAccountCampaignInfo, _AbstractCrudObject);

  function CustomAudienceSharedAccountCampaignInfo() {
    classCallCheck(this, CustomAudienceSharedAccountCampaignInfo);
    return possibleConstructorReturn(this, (CustomAudienceSharedAccountCampaignInfo.__proto__ || Object.getPrototypeOf(CustomAudienceSharedAccountCampaignInfo)).apply(this, arguments));
  }

  createClass(CustomAudienceSharedAccountCampaignInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        account_name: 'account_name',
        adset_excluding_count: 'adset_excluding_count',
        adset_including_count: 'adset_including_count',
        campaign_delivery_status: 'campaign_delivery_status',
        campaign_objective: 'campaign_objective',
        campaign_pages: 'campaign_pages',
        campaign_schedule: 'campaign_schedule'
      });
    }
  }]);
  return CustomAudienceSharedAccountCampaignInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudienceSharingStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudienceSharingStatus = function (_AbstractCrudObject) {
  inherits(CustomAudienceSharingStatus, _AbstractCrudObject);

  function CustomAudienceSharingStatus() {
    classCallCheck(this, CustomAudienceSharingStatus);
    return possibleConstructorReturn(this, (CustomAudienceSharingStatus.__proto__ || Object.getPrototypeOf(CustomAudienceSharingStatus)).apply(this, arguments));
  }

  createClass(CustomAudienceSharingStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        sharing_relationship_id: 'sharing_relationship_id',
        status: 'status'
      });
    }
  }]);
  return CustomAudienceSharingStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomAudienceStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomAudienceStatus = function (_AbstractCrudObject) {
  inherits(CustomAudienceStatus, _AbstractCrudObject);

  function CustomAudienceStatus() {
    classCallCheck(this, CustomAudienceStatus);
    return possibleConstructorReturn(this, (CustomAudienceStatus.__proto__ || Object.getPrototypeOf(CustomAudienceStatus)).apply(this, arguments));
  }

  createClass(CustomAudienceStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        code: 'code',
        description: 'description'
      });
    }
  }]);
  return CustomAudienceStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * CustomConversionActivities
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var CustomConversionActivities = function (_AbstractCrudObject) {
  inherits(CustomConversionActivities, _AbstractCrudObject);

  function CustomConversionActivities() {
    classCallCheck(this, CustomConversionActivities);
    return possibleConstructorReturn(this, (CustomConversionActivities.__proto__ || Object.getPrototypeOf(CustomConversionActivities)).apply(this, arguments));
  }

  createClass(CustomConversionActivities, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        data: 'data',
        event_type: 'event_type',
        timestamp: 'timestamp'
      });
    }
  }]);
  return CustomConversionActivities;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DayPart
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DayPart = function (_AbstractCrudObject) {
  inherits(DayPart, _AbstractCrudObject);

  function DayPart() {
    classCallCheck(this, DayPart);
    return possibleConstructorReturn(this, (DayPart.__proto__ || Object.getPrototypeOf(DayPart)).apply(this, arguments));
  }

  createClass(DayPart, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        days: 'days',
        end_minute: 'end_minute',
        start_minute: 'start_minute',
        timezone_type: 'timezone_type'
      });
    }
  }]);
  return DayPart;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DeliveryCheck
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DeliveryCheck = function (_AbstractCrudObject) {
  inherits(DeliveryCheck, _AbstractCrudObject);

  function DeliveryCheck() {
    classCallCheck(this, DeliveryCheck);
    return possibleConstructorReturn(this, (DeliveryCheck.__proto__ || Object.getPrototypeOf(DeliveryCheck)).apply(this, arguments));
  }

  createClass(DeliveryCheck, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        check_name: 'check_name',
        description: 'description',
        extra_info: 'extra_info',
        summary: 'summary'
      });
    }
  }]);
  return DeliveryCheck;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DeliveryCheckExtraInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DeliveryCheckExtraInfo = function (_AbstractCrudObject) {
  inherits(DeliveryCheckExtraInfo, _AbstractCrudObject);

  function DeliveryCheckExtraInfo() {
    classCallCheck(this, DeliveryCheckExtraInfo);
    return possibleConstructorReturn(this, (DeliveryCheckExtraInfo.__proto__ || Object.getPrototypeOf(DeliveryCheckExtraInfo)).apply(this, arguments));
  }

  createClass(DeliveryCheckExtraInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adgroup_ids: 'adgroup_ids',
        campaign_ids: 'campaign_ids',
        countries: 'countries'
      });
    }
  }]);
  return DeliveryCheckExtraInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DeliveryInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DeliveryInfo = function (_AbstractCrudObject) {
  inherits(DeliveryInfo, _AbstractCrudObject);

  function DeliveryInfo() {
    classCallCheck(this, DeliveryInfo);
    return possibleConstructorReturn(this, (DeliveryInfo.__proto__ || Object.getPrototypeOf(DeliveryInfo)).apply(this, arguments));
  }

  createClass(DeliveryInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        active_accelerated_campaign_count: 'active_accelerated_campaign_count',
        active_day_parted_campaign_count: 'active_day_parted_campaign_count',
        ad_penalty_map: 'ad_penalty_map',
        are_all_daily_budgets_spent: 'are_all_daily_budgets_spent',
        credit_needed_ads_count: 'credit_needed_ads_count',
        eligible_for_delivery_insights: 'eligible_for_delivery_insights',
        end_time: 'end_time',
        has_account_hit_spend_limit: 'has_account_hit_spend_limit',
        has_campaign_group_hit_spend_limit: 'has_campaign_group_hit_spend_limit',
        has_no_active_ads: 'has_no_active_ads',
        has_no_ads: 'has_no_ads',
        inactive_ads_count: 'inactive_ads_count',
        inactive_campaign_count: 'inactive_campaign_count',
        is_account_closed: 'is_account_closed',
        is_account_disabled: 'is_account_disabled',
        is_ad_uneconomical: 'is_ad_uneconomical',
        is_adfarm_penalized: 'is_adfarm_penalized',
        is_adgroup_partially_rejected: 'is_adgroup_partially_rejected',
        is_campaign_accelerated: 'is_campaign_accelerated',
        is_campaign_completed: 'is_campaign_completed',
        is_campaign_day_parted: 'is_campaign_day_parted',
        is_campaign_disabled: 'is_campaign_disabled',
        is_campaign_group_disabled: 'is_campaign_group_disabled',
        is_clickbait_penalized: 'is_clickbait_penalized',
        is_daily_budget_spent: 'is_daily_budget_spent',
        is_engagement_bait_penalized: 'is_engagement_bait_penalized',
        is_lqwe_penalized: 'is_lqwe_penalized',
        is_reach_and_frequency_misconfigured: 'is_reach_and_frequency_misconfigured',
        is_sensationalism_penalized: 'is_sensationalism_penalized',
        is_split_test_active: 'is_split_test_active',
        is_split_test_valid: 'is_split_test_valid',
        lift_study_time_period: 'lift_study_time_period',
        needs_credit: 'needs_credit',
        needs_tax_number: 'needs_tax_number',
        non_deleted_ads_count: 'non_deleted_ads_count',
        not_delivering_campaign_count: 'not_delivering_campaign_count',
        pending_ads_count: 'pending_ads_count',
        reach_frequency_campaign_underdelivery_reason: 'reach_frequency_campaign_underdelivery_reason',
        rejected_ads_count: 'rejected_ads_count',
        start_time: 'start_time',
        status: 'status',
        text_penalty_level: 'text_penalty_level'
      });
    }
  }]);
  return DeliveryInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DeliveryStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DeliveryStatus = function (_AbstractCrudObject) {
  inherits(DeliveryStatus, _AbstractCrudObject);

  function DeliveryStatus() {
    classCallCheck(this, DeliveryStatus);
    return possibleConstructorReturn(this, (DeliveryStatus.__proto__ || Object.getPrototypeOf(DeliveryStatus)).apply(this, arguments));
  }

  createClass(DeliveryStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        status: 'status',
        substatuses: 'substatuses'
      });
    }
  }]);
  return DeliveryStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DeliveryWindow
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DeliveryWindow = function (_AbstractCrudObject) {
  inherits(DeliveryWindow, _AbstractCrudObject);

  function DeliveryWindow() {
    classCallCheck(this, DeliveryWindow);
    return possibleConstructorReturn(this, (DeliveryWindow.__proto__ || Object.getPrototypeOf(DeliveryWindow)).apply(this, arguments));
  }

  createClass(DeliveryWindow, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad: 'ad',
        ae: 'ae',
        af: 'af',
        ag: 'ag',
        ai: 'ai',
        al: 'al',
        all: 'all',
        am: 'am',
        an: 'an',
        ao: 'ao',
        aq: 'aq',
        ar: 'ar',
        as: 'as',
        at: 'at',
        au: 'au',
        aw: 'aw',
        ax: 'ax',
        az: 'az',
        ba: 'ba',
        bb: 'bb',
        bd: 'bd',
        be: 'be',
        bf: 'bf',
        bg: 'bg',
        bh: 'bh',
        bi: 'bi',
        bj: 'bj',
        bl: 'bl',
        bm: 'bm',
        bn: 'bn',
        bo: 'bo',
        bq: 'bq',
        br: 'br',
        bs: 'bs',
        bt: 'bt',
        bv: 'bv',
        bw: 'bw',
        by: 'by',
        bz: 'bz',
        ca: 'ca',
        cc: 'cc',
        cd: 'cd',
        cf: 'cf',
        cg: 'cg',
        ch: 'ch',
        ci: 'ci',
        ck: 'ck',
        cl: 'cl',
        cm: 'cm',
        cn: 'cn',
        co: 'co',
        cr: 'cr',
        cu: 'cu',
        cv: 'cv',
        cw: 'cw',
        cx: 'cx',
        cy: 'cy',
        cz: 'cz',
        de: 'de',
        dj: 'dj',
        dk: 'dk',
        dm: 'dm',
        do: 'do',
        dz: 'dz',
        ec: 'ec',
        ee: 'ee',
        eg: 'eg',
        eh: 'eh',
        er: 'er',
        es: 'es',
        et: 'et',
        fi: 'fi',
        fj: 'fj',
        fk: 'fk',
        fm: 'fm',
        fo: 'fo',
        fr: 'fr',
        ga: 'ga',
        gb: 'gb',
        gd: 'gd',
        ge: 'ge',
        gf: 'gf',
        gg: 'gg',
        gh: 'gh',
        gi: 'gi',
        gl: 'gl',
        gm: 'gm',
        gn: 'gn',
        gp: 'gp',
        gq: 'gq',
        gr: 'gr',
        gs: 'gs',
        gt: 'gt',
        gu: 'gu',
        gw: 'gw',
        gy: 'gy',
        hk: 'hk',
        hm: 'hm',
        hn: 'hn',
        hr: 'hr',
        ht: 'ht',
        hu: 'hu',
        id: 'id',
        ie: 'ie',
        il: 'il',
        im: 'im',
        in: 'in',
        io: 'io',
        iq: 'iq',
        ir: 'ir',
        is: 'is',
        it: 'it',
        je: 'je',
        jm: 'jm',
        jo: 'jo',
        jp: 'jp',
        ke: 'ke',
        kg: 'kg',
        kh: 'kh',
        ki: 'ki',
        km: 'km',
        kn: 'kn',
        kp: 'kp',
        kr: 'kr',
        kw: 'kw',
        ky: 'ky',
        kz: 'kz',
        la: 'la',
        lb: 'lb',
        lc: 'lc',
        li: 'li',
        lk: 'lk',
        lr: 'lr',
        ls: 'ls',
        lt: 'lt',
        lu: 'lu',
        lv: 'lv',
        ly: 'ly',
        ma: 'ma',
        mc: 'mc',
        md: 'md',
        me: 'me',
        mf: 'mf',
        mg: 'mg',
        mh: 'mh',
        mk: 'mk',
        ml: 'ml',
        mm: 'mm',
        mn: 'mn',
        mo: 'mo',
        mp: 'mp',
        mq: 'mq',
        mr: 'mr',
        ms: 'ms',
        mt: 'mt',
        mu: 'mu',
        mv: 'mv',
        mw: 'mw',
        mx: 'mx',
        my: 'my',
        mz: 'mz',
        na: 'na',
        nc: 'nc',
        ne: 'ne',
        nf: 'nf',
        ng: 'ng',
        ni: 'ni',
        nl: 'nl',
        no: 'no',
        np: 'np',
        nr: 'nr',
        nu: 'nu',
        nz: 'nz',
        om: 'om',
        pa: 'pa',
        pe: 'pe',
        pf: 'pf',
        pg: 'pg',
        ph: 'ph',
        pk: 'pk',
        pl: 'pl',
        pm: 'pm',
        pn: 'pn',
        pr: 'pr',
        ps: 'ps',
        pt: 'pt',
        pw: 'pw',
        py: 'py',
        qa: 'qa',
        re: 're',
        ro: 'ro',
        rs: 'rs',
        ru: 'ru',
        rw: 'rw',
        sa: 'sa',
        sb: 'sb',
        sc: 'sc',
        sd: 'sd',
        se: 'se',
        sg: 'sg',
        sh: 'sh',
        si: 'si',
        sj: 'sj',
        sk: 'sk',
        sl: 'sl',
        sm: 'sm',
        sn: 'sn',
        so: 'so',
        sr: 'sr',
        ss: 'ss',
        st: 'st',
        sv: 'sv',
        sx: 'sx',
        sy: 'sy',
        sz: 'sz',
        tc: 'tc',
        td: 'td',
        tf: 'tf',
        tg: 'tg',
        th: 'th',
        tj: 'tj',
        tk: 'tk',
        tl: 'tl',
        tm: 'tm',
        tn: 'tn',
        to: 'to',
        tr: 'tr',
        tt: 'tt',
        tv: 'tv',
        tw: 'tw',
        tz: 'tz',
        ua: 'ua',
        ug: 'ug',
        um: 'um',
        us: 'us',
        uy: 'uy',
        uz: 'uz',
        va: 'va',
        vc: 'vc',
        ve: 've',
        vg: 'vg',
        vi: 'vi',
        vn: 'vn',
        vu: 'vu',
        wf: 'wf',
        ws: 'ws',
        xk: 'xk',
        ye: 'ye',
        yt: 'yt',
        za: 'za',
        zm: 'zm',
        zw: 'zw'
      });
    }
  }]);
  return DeliveryWindow;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DirectDebit
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DirectDebit = function (_AbstractCrudObject) {
  inherits(DirectDebit, _AbstractCrudObject);

  function DirectDebit() {
    classCallCheck(this, DirectDebit);
    return possibleConstructorReturn(this, (DirectDebit.__proto__ || Object.getPrototypeOf(DirectDebit)).apply(this, arguments));
  }

  createClass(DirectDebit, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        bank_account_last_4: 'bank_account_last_4',
        bank_code_last_4: 'bank_code_last_4',
        bank_name: 'bank_name',
        default_receiving_method_products: 'default_receiving_method_products',
        display_string: 'display_string',
        id: 'id',
        last_four_digits: 'last_four_digits',
        onboarding_url: 'onboarding_url',
        owner_name: 'owner_name',
        status: 'status'
      });
    }
  }]);
  return DirectDebit;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Domain
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Domain = function (_AbstractCrudObject) {
  inherits(Domain, _AbstractCrudObject);

  function Domain() {
    classCallCheck(this, Domain);
    return possibleConstructorReturn(this, (Domain.__proto__ || Object.getPrototypeOf(Domain)).apply(this, arguments));
  }

  createClass(Domain, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        url: 'url'
      });
    }
  }]);
  return Domain;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DraftPost
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DraftPost = function (_AbstractCrudObject) {
  inherits(DraftPost, _AbstractCrudObject);

  function DraftPost() {
    classCallCheck(this, DraftPost);
    return possibleConstructorReturn(this, (DraftPost.__proto__ || Object.getPrototypeOf(DraftPost)).apply(this, arguments));
  }

  createClass(DraftPost, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        admin_creator: 'admin_creator',
        creation_time: 'creation_time',
        feed_audience_description: 'feed_audience_description',
        feed_targeting: 'feed_targeting',
        id: 'id',
        is_post_in_good_state: 'is_post_in_good_state',
        message: 'message',
        modified_time: 'modified_time',
        og_action_summary: 'og_action_summary',
        permalink_url: 'permalink_url',
        place: 'place',
        privacy_description: 'privacy_description',
        scheduled_failure_notice: 'scheduled_failure_notice',
        scheduled_publish_time: 'scheduled_publish_time',
        story_token: 'story_token',
        thumbnail: 'thumbnail',
        video_id: 'video_id'
      });
    }
  }]);
  return DraftPost;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DynamicARMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DynamicARMetadata = function (_AbstractCrudObject) {
  inherits(DynamicARMetadata, _AbstractCrudObject);

  function DynamicARMetadata() {
    classCallCheck(this, DynamicARMetadata);
    return possibleConstructorReturn(this, (DynamicARMetadata.__proto__ || Object.getPrototypeOf(DynamicARMetadata)).apply(this, arguments));
  }

  createClass(DynamicARMetadata, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        anchor_point: 'anchor_point',
        container_effect_enum: 'container_effect_enum',
        effect_icon_url: 'effect_icon_url',
        effect_id: 'effect_id',
        id: 'id',
        platforms: 'platforms',
        scale_factor: 'scale_factor',
        shadow_texture_url: 'shadow_texture_url',
        source_url: 'source_url',
        state: 'state',
        tags: 'tags',
        variant_picker_url: 'variant_picker_url'
      });
    }
  }]);
  return DynamicARMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DynamicContentSet
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DynamicContentSet = function (_AbstractCrudObject) {
  inherits(DynamicContentSet, _AbstractCrudObject);

  function DynamicContentSet() {
    classCallCheck(this, DynamicContentSet);
    return possibleConstructorReturn(this, (DynamicContentSet.__proto__ || Object.getPrototypeOf(DynamicContentSet)).apply(this, arguments));
  }

  createClass(DynamicContentSet, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business_id: 'business_id',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return DynamicContentSet;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DynamicItemDisplayBundle
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DynamicItemDisplayBundle = function (_AbstractCrudObject) {
  inherits(DynamicItemDisplayBundle, _AbstractCrudObject);

  function DynamicItemDisplayBundle() {
    classCallCheck(this, DynamicItemDisplayBundle);
    return possibleConstructorReturn(this, (DynamicItemDisplayBundle.__proto__ || Object.getPrototypeOf(DynamicItemDisplayBundle)).apply(this, arguments));
  }

  createClass(DynamicItemDisplayBundle, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        additional_urls: 'additional_urls',
        description: 'description',
        id: 'id',
        name: 'name',
        product_set: 'product_set',
        text_tokens: 'text_tokens',
        url: 'url'
      });
    }
  }]);
  return DynamicItemDisplayBundle;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DynamicItemDisplayBundleFolder
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DynamicItemDisplayBundleFolder = function (_AbstractCrudObject) {
  inherits(DynamicItemDisplayBundleFolder, _AbstractCrudObject);

  function DynamicItemDisplayBundleFolder() {
    classCallCheck(this, DynamicItemDisplayBundleFolder);
    return possibleConstructorReturn(this, (DynamicItemDisplayBundleFolder.__proto__ || Object.getPrototypeOf(DynamicItemDisplayBundleFolder)).apply(this, arguments));
  }

  createClass(DynamicItemDisplayBundleFolder, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        categorization_criteria: 'categorization_criteria',
        id: 'id',
        name: 'name',
        product_catalog: 'product_catalog',
        product_set: 'product_set',
        valid_labels: 'valid_labels'
      });
    }
  }]);
  return DynamicItemDisplayBundleFolder;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * DynamicPostChildAttachment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var DynamicPostChildAttachment = function (_AbstractCrudObject) {
  inherits(DynamicPostChildAttachment, _AbstractCrudObject);

  function DynamicPostChildAttachment() {
    classCallCheck(this, DynamicPostChildAttachment);
    return possibleConstructorReturn(this, (DynamicPostChildAttachment.__proto__ || Object.getPrototypeOf(DynamicPostChildAttachment)).apply(this, arguments));
  }

  createClass(DynamicPostChildAttachment, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        image_url: 'image_url',
        link: 'link',
        place_id: 'place_id',
        product_id: 'product_id',
        title: 'title'
      });
    }
  }]);
  return DynamicPostChildAttachment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EducationExperience
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EducationExperience = function (_AbstractCrudObject) {
  inherits(EducationExperience, _AbstractCrudObject);

  function EducationExperience() {
    classCallCheck(this, EducationExperience);
    return possibleConstructorReturn(this, (EducationExperience.__proto__ || Object.getPrototypeOf(EducationExperience)).apply(this, arguments));
  }

  createClass(EducationExperience, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        classes: 'classes',
        concentration: 'concentration',
        degree: 'degree',
        id: 'id',
        school: 'school',
        type: 'type',
        with: 'with',
        year: 'year'
      });
    }
  }]);
  return EducationExperience;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EmailImport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EmailImport = function (_AbstractCrudObject) {
  inherits(EmailImport, _AbstractCrudObject);

  function EmailImport() {
    classCallCheck(this, EmailImport);
    return possibleConstructorReturn(this, (EmailImport.__proto__ || Object.getPrototypeOf(EmailImport)).apply(this, arguments));
  }

  createClass(EmailImport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        lists: 'lists',
        total: 'total'
      });
    }
  }]);
  return EmailImport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EndStudyCriteria
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EndStudyCriteria = function (_AbstractCrudObject) {
  inherits(EndStudyCriteria, _AbstractCrudObject);

  function EndStudyCriteria() {
    classCallCheck(this, EndStudyCriteria);
    return possibleConstructorReturn(this, (EndStudyCriteria.__proto__ || Object.getPrototypeOf(EndStudyCriteria)).apply(this, arguments));
  }

  createClass(EndStudyCriteria, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return EndStudyCriteria;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Engagement
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Engagement = function (_AbstractCrudObject) {
  inherits(Engagement, _AbstractCrudObject);

  function Engagement() {
    classCallCheck(this, Engagement);
    return possibleConstructorReturn(this, (Engagement.__proto__ || Object.getPrototypeOf(Engagement)).apply(this, arguments));
  }

  createClass(Engagement, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        count: 'count',
        count_string: 'count_string',
        count_string_with_like: 'count_string_with_like',
        count_string_without_like: 'count_string_without_like',
        social_sentence: 'social_sentence',
        social_sentence_with_like: 'social_sentence_with_like',
        social_sentence_without_like: 'social_sentence_without_like'
      });
    }
  }]);
  return Engagement;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EntWithSponsor
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EntWithSponsor = function (_AbstractCrudObject) {
  inherits(EntWithSponsor, _AbstractCrudObject);

  function EntWithSponsor() {
    classCallCheck(this, EntWithSponsor);
    return possibleConstructorReturn(this, (EntWithSponsor.__proto__ || Object.getPrototypeOf(EntWithSponsor)).apply(this, arguments));
  }

  createClass(EntWithSponsor, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        owner_linked_instagram_user_v1_id: 'owner_linked_instagram_user_v1_id',
        owner_picture: 'owner_picture',
        post_id: 'post_id',
        post_info: 'post_info'
      });
    }
  }]);
  return EntWithSponsor;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EntityAtTextRange
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EntityAtTextRange = function (_AbstractCrudObject) {
  inherits(EntityAtTextRange, _AbstractCrudObject);

  function EntityAtTextRange() {
    classCallCheck(this, EntityAtTextRange);
    return possibleConstructorReturn(this, (EntityAtTextRange.__proto__ || Object.getPrototypeOf(EntityAtTextRange)).apply(this, arguments));
  }

  createClass(EntityAtTextRange, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        length: 'length',
        name: 'name',
        object: 'object',
        offset: 'offset',
        type: 'type'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        application: 'application',
        event: 'event',
        group: 'group',
        page: 'page',
        user: 'user'
      });
    }
  }]);
  return EntityAtTextRange;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EventExternalTicketInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EventExternalTicketInfo = function (_AbstractCrudObject) {
  inherits(EventExternalTicketInfo, _AbstractCrudObject);

  function EventExternalTicketInfo() {
    classCallCheck(this, EventExternalTicketInfo);
    return possibleConstructorReturn(this, (EventExternalTicketInfo.__proto__ || Object.getPrototypeOf(EventExternalTicketInfo)).apply(this, arguments));
  }

  createClass(EventExternalTicketInfo, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        max_sales_price: 'max_sales_price',
        min_sales_price: 'min_sales_price',
        sales_status: 'sales_status'
      });
    }
  }]);
  return EventExternalTicketInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EventRegistrationSetting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EventRegistrationSetting = function (_AbstractCrudObject) {
  inherits(EventRegistrationSetting, _AbstractCrudObject);

  function EventRegistrationSetting() {
    classCallCheck(this, EventRegistrationSetting);
    return possibleConstructorReturn(this, (EventRegistrationSetting.__proto__ || Object.getPrototypeOf(EventRegistrationSetting)).apply(this, arguments));
  }

  createClass(EventRegistrationSetting, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        questions: 'questions',
        target_type: 'target_type',
        ticket_tier_ids: 'ticket_tier_ids'
      });
    }
  }]);
  return EventRegistrationSetting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EventTicketSetting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EventTicketSetting = function (_AbstractCrudObject) {
  inherits(EventTicketSetting, _AbstractCrudObject);

  function EventTicketSetting() {
    classCallCheck(this, EventTicketSetting);
    return possibleConstructorReturn(this, (EventTicketSetting.__proto__ || Object.getPrototypeOf(EventTicketSetting)).apply(this, arguments));
  }

  createClass(EventTicketSetting, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        ticket_delivery_type: 'ticket_delivery_type'
      });
    }
  }]);
  return EventTicketSetting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * EventTour
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var EventTour = function (_AbstractCrudObject) {
  inherits(EventTour, _AbstractCrudObject);

  function EventTour() {
    classCallCheck(this, EventTour);
    return possibleConstructorReturn(this, (EventTour.__proto__ || Object.getPrototypeOf(EventTour)).apply(this, arguments));
  }

  createClass(EventTour, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        dominant_color: 'dominant_color',
        end_time: 'end_time',
        id: 'id',
        is_past: 'is_past',
        last_event_timestamp: 'last_event_timestamp',
        name: 'name',
        num_events: 'num_events',
        photo: 'photo',
        scheduled_publish_timestamp: 'scheduled_publish_timestamp',
        start_time: 'start_time',
        ticketing_uri: 'ticketing_uri',
        video: 'video'
      });
    }
  }]);
  return EventTour;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Experience
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Experience = function (_AbstractCrudObject) {
  inherits(Experience, _AbstractCrudObject);

  function Experience() {
    classCallCheck(this, Experience);
    return possibleConstructorReturn(this, (Experience.__proto__ || Object.getPrototypeOf(Experience)).apply(this, arguments));
  }

  createClass(Experience, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        from: 'from',
        id: 'id',
        name: 'name',
        with: 'with'
      });
    }
  }]);
  return Experience;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExtendedCreditEmail
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExtendedCreditEmail = function (_AbstractCrudObject) {
  inherits(ExtendedCreditEmail, _AbstractCrudObject);

  function ExtendedCreditEmail() {
    classCallCheck(this, ExtendedCreditEmail);
    return possibleConstructorReturn(this, (ExtendedCreditEmail.__proto__ || Object.getPrototypeOf(ExtendedCreditEmail)).apply(this, arguments));
  }

  createClass(ExtendedCreditEmail, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        email: 'email',
        id: 'id'
      });
    }
  }]);
  return ExtendedCreditEmail;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExtendedCreditInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExtendedCreditInfo = function (_AbstractCrudObject) {
  inherits(ExtendedCreditInfo, _AbstractCrudObject);

  function ExtendedCreditInfo() {
    classCallCheck(this, ExtendedCreditInfo);
    return possibleConstructorReturn(this, (ExtendedCreditInfo.__proto__ || Object.getPrototypeOf(ExtendedCreditInfo)).apply(this, arguments));
  }

  createClass(ExtendedCreditInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        credit_left: 'credit_left',
        credit_revoked: 'credit_revoked',
        credit_used: 'credit_used',
        using_biz_ec: 'using_biz_ec'
      });
    }
  }]);
  return ExtendedCreditInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExternalEventSourceCPASEventsDebugging
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExternalEventSourceCPASEventsDebugging = function (_AbstractCrudObject) {
  inherits(ExternalEventSourceCPASEventsDebugging, _AbstractCrudObject);

  function ExternalEventSourceCPASEventsDebugging() {
    classCallCheck(this, ExternalEventSourceCPASEventsDebugging);
    return possibleConstructorReturn(this, (ExternalEventSourceCPASEventsDebugging.__proto__ || Object.getPrototypeOf(ExternalEventSourceCPASEventsDebugging)).apply(this, arguments));
  }

  createClass(ExternalEventSourceCPASEventsDebugging, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actual_event_time: 'actual_event_time',
        app_version: 'app_version',
        content_url: 'content_url',
        device_os: 'device_os',
        diagnostic: 'diagnostic',
        event_name: 'event_name',
        event_time: 'event_time',
        missing_ids: 'missing_ids',
        severity: 'severity'
      });
    }
  }]);
  return ExternalEventSourceCPASEventsDebugging;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExternalEventSourceCPASEventsDebuggingInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExternalEventSourceCPASEventsDebuggingInfo = function (_AbstractCrudObject) {
  inherits(ExternalEventSourceCPASEventsDebuggingInfo, _AbstractCrudObject);

  function ExternalEventSourceCPASEventsDebuggingInfo() {
    classCallCheck(this, ExternalEventSourceCPASEventsDebuggingInfo);
    return possibleConstructorReturn(this, (ExternalEventSourceCPASEventsDebuggingInfo.__proto__ || Object.getPrototypeOf(ExternalEventSourceCPASEventsDebuggingInfo)).apply(this, arguments));
  }

  createClass(ExternalEventSourceCPASEventsDebuggingInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        counts: 'counts',
        diagnostic: 'diagnostic',
        event_name: 'event_name'
      });
    }
  }]);
  return ExternalEventSourceCPASEventsDebuggingInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ExternalMerchantSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ExternalMerchantSettings = function (_AbstractCrudObject) {
  inherits(ExternalMerchantSettings, _AbstractCrudObject);

  function ExternalMerchantSettings() {
    classCallCheck(this, ExternalMerchantSettings);
    return possibleConstructorReturn(this, (ExternalMerchantSettings.__proto__ || Object.getPrototypeOf(ExternalMerchantSettings)).apply(this, arguments));
  }

  createClass(ExternalMerchantSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        connect_woo: 'connect_woo',
        external_platform: 'external_platform',
        id: 'id'
      });
    }
  }]);
  return ExternalMerchantSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FAMEKumo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FAMEKumo = function (_AbstractCrudObject) {
  inherits(FAMEKumo, _AbstractCrudObject);

  function FAMEKumo() {
    classCallCheck(this, FAMEKumo);
    return possibleConstructorReturn(this, (FAMEKumo.__proto__ || Object.getPrototypeOf(FAMEKumo)).apply(this, arguments));
  }

  createClass(FAMEKumo, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return FAMEKumo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FBImageCopyrightMatch
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FBImageCopyrightMatch = function (_AbstractCrudObject) {
  inherits(FBImageCopyrightMatch, _AbstractCrudObject);

  function FBImageCopyrightMatch() {
    classCallCheck(this, FBImageCopyrightMatch);
    return possibleConstructorReturn(this, (FBImageCopyrightMatch.__proto__ || Object.getPrototypeOf(FBImageCopyrightMatch)).apply(this, arguments));
  }

  createClass(FBImageCopyrightMatch, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        added_to_dashboard_time: 'added_to_dashboard_time',
        applied_actions: 'applied_actions',
        audit_log: 'audit_log',
        available_ui_actions: 'available_ui_actions',
        expiration_days: 'expiration_days',
        id: 'id',
        is_business_page_match: 'is_business_page_match',
        last_modified_time: 'last_modified_time',
        match_data: 'match_data',
        match_status: 'match_status',
        ownership_countries: 'ownership_countries',
        reference_owner: 'reference_owner',
        time_to_appeal: 'time_to_appeal'
      });
    }
  }]);
  return FBImageCopyrightMatch;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FBLiteToNTTransitions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FBLiteToNTTransitions = function (_AbstractCrudObject) {
  inherits(FBLiteToNTTransitions, _AbstractCrudObject);

  function FBLiteToNTTransitions() {
    classCallCheck(this, FBLiteToNTTransitions);
    return possibleConstructorReturn(this, (FBLiteToNTTransitions.__proto__ || Object.getPrototypeOf(FBLiteToNTTransitions)).apply(this, arguments));
  }

  createClass(FBLiteToNTTransitions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        transition: 'transition'
      });
    }
  }]);
  return FBLiteToNTTransitions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FBPageAndInstagramAccount
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FBPageAndInstagramAccount = function (_AbstractCrudObject) {
  inherits(FBPageAndInstagramAccount, _AbstractCrudObject);

  function FBPageAndInstagramAccount() {
    classCallCheck(this, FBPageAndInstagramAccount);
    return possibleConstructorReturn(this, (FBPageAndInstagramAccount.__proto__ || Object.getPrototypeOf(FBPageAndInstagramAccount)).apply(this, arguments));
  }

  createClass(FBPageAndInstagramAccount, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_permissions: 'ad_permissions',
        bc_permission_status: 'bc_permission_status',
        bc_permissions: 'bc_permissions',
        is_managed: 'is_managed',
        matched_by: 'matched_by'
      });
    }
  }]);
  return FBPageAndInstagramAccount;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FBPayButtonLogin
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FBPayButtonLogin = function (_AbstractCrudObject) {
  inherits(FBPayButtonLogin, _AbstractCrudObject);

  function FBPayButtonLogin() {
    classCallCheck(this, FBPayButtonLogin);
    return possibleConstructorReturn(this, (FBPayButtonLogin.__proto__ || Object.getPrototypeOf(FBPayButtonLogin)).apply(this, arguments));
  }

  createClass(FBPayButtonLogin, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return FBPayButtonLogin;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FavoriteCatalog
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FavoriteCatalog = function (_AbstractCrudObject) {
  inherits(FavoriteCatalog, _AbstractCrudObject);

  function FavoriteCatalog() {
    classCallCheck(this, FavoriteCatalog);
    return possibleConstructorReturn(this, (FavoriteCatalog.__proto__ || Object.getPrototypeOf(FavoriteCatalog)).apply(this, arguments));
  }

  createClass(FavoriteCatalog, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        catalog: 'catalog',
        id: 'id'
      });
    }
  }]);
  return FavoriteCatalog;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FinanceObject
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FinanceObject = function (_AbstractCrudObject) {
  inherits(FinanceObject, _AbstractCrudObject);

  function FinanceObject() {
    classCallCheck(this, FinanceObject);
    return possibleConstructorReturn(this, (FinanceObject.__proto__ || Object.getPrototypeOf(FinanceObject)).apply(this, arguments));
  }

  createClass(FinanceObject, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        finance_permission: 'finance_permission',
        user: 'user'
      });
    }
  }]);
  return FinanceObject;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FlexibleTargeting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FlexibleTargeting = function (_AbstractCrudObject) {
  inherits(FlexibleTargeting, _AbstractCrudObject);

  function FlexibleTargeting() {
    classCallCheck(this, FlexibleTargeting);
    return possibleConstructorReturn(this, (FlexibleTargeting.__proto__ || Object.getPrototypeOf(FlexibleTargeting)).apply(this, arguments));
  }

  createClass(FlexibleTargeting, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        behaviors: 'behaviors',
        college_years: 'college_years',
        connections: 'connections',
        custom_audiences: 'custom_audiences',
        education_majors: 'education_majors',
        education_schools: 'education_schools',
        education_statuses: 'education_statuses',
        ethnic_affinity: 'ethnic_affinity',
        family_statuses: 'family_statuses',
        friends_of_connections: 'friends_of_connections',
        generation: 'generation',
        home_ownership: 'home_ownership',
        home_type: 'home_type',
        home_value: 'home_value',
        household_composition: 'household_composition',
        income: 'income',
        industries: 'industries',
        interested_in: 'interested_in',
        interests: 'interests',
        life_events: 'life_events',
        moms: 'moms',
        net_worth: 'net_worth',
        office_type: 'office_type',
        politics: 'politics',
        relationship_statuses: 'relationship_statuses',
        user_adclusters: 'user_adclusters',
        work_employers: 'work_employers',
        work_positions: 'work_positions'
      });
    }
  }]);
  return FlexibleTargeting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FranchiseProgram
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FranchiseProgram = function (_AbstractCrudObject) {
  inherits(FranchiseProgram, _AbstractCrudObject);

  function FranchiseProgram() {
    classCallCheck(this, FranchiseProgram);
    return possibleConstructorReturn(this, (FranchiseProgram.__proto__ || Object.getPrototypeOf(FranchiseProgram)).apply(this, arguments));
  }

  createClass(FranchiseProgram, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business_asset_group: 'business_asset_group',
        creator_business: 'creator_business',
        description: 'description',
        end_date: 'end_date',
        id: 'id',
        name: 'name',
        program_access_type: 'program_access_type',
        program_approval_type: 'program_approval_type',
        program_image_link: 'program_image_link',
        program_url: 'program_url',
        shared_custom_audience: 'shared_custom_audience',
        start_date: 'start_date'
      });
    }
  }]);
  return FranchiseProgram;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FranchiseProgramMember
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FranchiseProgramMember = function (_AbstractCrudObject) {
  inherits(FranchiseProgramMember, _AbstractCrudObject);

  function FranchiseProgramMember() {
    classCallCheck(this, FranchiseProgramMember);
    return possibleConstructorReturn(this, (FranchiseProgramMember.__proto__ || Object.getPrototypeOf(FranchiseProgramMember)).apply(this, arguments));
  }

  createClass(FranchiseProgramMember, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        end_date: 'end_date',
        id: 'id',
        join_date: 'join_date',
        member_ad_account: 'member_ad_account',
        member_user: 'member_user',
        membership_status: 'membership_status',
        page: 'page'
      });
    }
  }]);
  return FranchiseProgramMember;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FundingSourceDetails
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FundingSourceDetails = function (_AbstractCrudObject) {
  inherits(FundingSourceDetails, _AbstractCrudObject);

  function FundingSourceDetails() {
    classCallCheck(this, FundingSourceDetails);
    return possibleConstructorReturn(this, (FundingSourceDetails.__proto__ || Object.getPrototypeOf(FundingSourceDetails)).apply(this, arguments));
  }

  createClass(FundingSourceDetails, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        coupon: 'coupon',
        coupons: 'coupons',
        display_string: 'display_string',
        id: 'id',
        type: 'type'
      });
    }
  }]);
  return FundingSourceDetails;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * FundingSourceDetailsCoupon
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var FundingSourceDetailsCoupon = function (_AbstractCrudObject) {
  inherits(FundingSourceDetailsCoupon, _AbstractCrudObject);

  function FundingSourceDetailsCoupon() {
    classCallCheck(this, FundingSourceDetailsCoupon);
    return possibleConstructorReturn(this, (FundingSourceDetailsCoupon.__proto__ || Object.getPrototypeOf(FundingSourceDetailsCoupon)).apply(this, arguments));
  }

  createClass(FundingSourceDetailsCoupon, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount: 'amount',
        campaign_ids: 'campaign_ids',
        coupon_id: 'coupon_id',
        currency: 'currency',
        display_amount: 'display_amount',
        expiration: 'expiration',
        original_amount: 'original_amount',
        original_display_amount: 'original_display_amount'
      });
    }
  }]);
  return FundingSourceDetailsCoupon;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * GeoGatingPolicy
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var GeoGatingPolicy = function (_AbstractCrudObject) {
  inherits(GeoGatingPolicy, _AbstractCrudObject);

  function GeoGatingPolicy() {
    classCallCheck(this, GeoGatingPolicy);
    return possibleConstructorReturn(this, (GeoGatingPolicy.__proto__ || Object.getPrototypeOf(GeoGatingPolicy)).apply(this, arguments));
  }

  createClass(GeoGatingPolicy, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        after_schedule: 'after_schedule',
        exclude_country: 'exclude_country',
        id: 'id',
        include_country: 'include_country',
        name: 'name',
        valid_from: 'valid_from',
        valid_until: 'valid_until'
      });
    }
  }]);
  return GeoGatingPolicy;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * HasLeadAccess
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var HasLeadAccess = function (_AbstractCrudObject) {
  inherits(HasLeadAccess, _AbstractCrudObject);

  function HasLeadAccess() {
    classCallCheck(this, HasLeadAccess);
    return possibleConstructorReturn(this, (HasLeadAccess.__proto__ || Object.getPrototypeOf(HasLeadAccess)).apply(this, arguments));
  }

  createClass(HasLeadAccess, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_has_leads_permission: 'app_has_leads_permission',
        can_access_lead: 'can_access_lead',
        enabled_lead_access_manager: 'enabled_lead_access_manager',
        failure_reason: 'failure_reason',
        failure_resolution: 'failure_resolution',
        is_page_admin: 'is_page_admin',
        page_id: 'page_id',
        user_has_leads_permission: 'user_has_leads_permission',
        user_id: 'user_id'
      });
    }
  }]);
  return HasLeadAccess;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * HighDemandPeriodTimeSuggestionWeeklySegment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var HighDemandPeriodTimeSuggestionWeeklySegment = function (_AbstractCrudObject) {
  inherits(HighDemandPeriodTimeSuggestionWeeklySegment, _AbstractCrudObject);

  function HighDemandPeriodTimeSuggestionWeeklySegment() {
    classCallCheck(this, HighDemandPeriodTimeSuggestionWeeklySegment);
    return possibleConstructorReturn(this, (HighDemandPeriodTimeSuggestionWeeklySegment.__proto__ || Object.getPrototypeOf(HighDemandPeriodTimeSuggestionWeeklySegment)).apply(this, arguments));
  }

  createClass(HighDemandPeriodTimeSuggestionWeeklySegment, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        days: 'days',
        end_minute: 'end_minute',
        start_minute: 'start_minute',
        timezone_type: 'timezone_type'
      });
    }
  }]);
  return HighDemandPeriodTimeSuggestionWeeklySegment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Hours
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Hours = function (_AbstractCrudObject) {
  inherits(Hours, _AbstractCrudObject);

  function Hours() {
    classCallCheck(this, Hours);
    return possibleConstructorReturn(this, (Hours.__proto__ || Object.getPrototypeOf(Hours)).apply(this, arguments));
  }

  createClass(Hours, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        permanent_status: 'permanent_status'
      });
    }
  }]);
  return Hours;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IDName
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IDName = function (_AbstractCrudObject) {
  inherits(IDName, _AbstractCrudObject);

  function IDName() {
    classCallCheck(this, IDName);
    return possibleConstructorReturn(this, (IDName.__proto__ || Object.getPrototypeOf(IDName)).apply(this, arguments));
  }

  createClass(IDName, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return IDName;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGAccessTokenForIGOnlyAPI
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGAccessTokenForIGOnlyAPI = function (_AbstractCrudObject) {
  inherits(IGAccessTokenForIGOnlyAPI, _AbstractCrudObject);

  function IGAccessTokenForIGOnlyAPI() {
    classCallCheck(this, IGAccessTokenForIGOnlyAPI);
    return possibleConstructorReturn(this, (IGAccessTokenForIGOnlyAPI.__proto__ || Object.getPrototypeOf(IGAccessTokenForIGOnlyAPI)).apply(this, arguments));
  }

  createClass(IGAccessTokenForIGOnlyAPI, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        access_token: 'access_token',
        expires_in: 'expires_in',
        token_type: 'token_type',
        id: 'id'
      });
    }
  }]);
  return IGAccessTokenForIGOnlyAPI;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGCommentFromUser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGCommentFromUser = function (_AbstractCrudObject) {
  inherits(IGCommentFromUser, _AbstractCrudObject);

  function IGCommentFromUser() {
    classCallCheck(this, IGCommentFromUser);
    return possibleConstructorReturn(this, (IGCommentFromUser.__proto__ || Object.getPrototypeOf(IGCommentFromUser)).apply(this, arguments));
  }

  createClass(IGCommentFromUser, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        username: 'username'
      });
    }
  }]);
  return IGCommentFromUser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGMediaBoostEligibilityInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGMediaBoostEligibilityInfo = function (_AbstractCrudObject) {
  inherits(IGMediaBoostEligibilityInfo, _AbstractCrudObject);

  function IGMediaBoostEligibilityInfo() {
    classCallCheck(this, IGMediaBoostEligibilityInfo);
    return possibleConstructorReturn(this, (IGMediaBoostEligibilityInfo.__proto__ || Object.getPrototypeOf(IGMediaBoostEligibilityInfo)).apply(this, arguments));
  }

  createClass(IGMediaBoostEligibilityInfo, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        boost_ineligible_reason: 'boost_ineligible_reason',
        eligible_to_boost: 'eligible_to_boost',
        id: 'id'
      });
    }
  }]);
  return IGMediaBoostEligibilityInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGMediaForIGOnlyAPI
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGMediaForIGOnlyAPI = function (_AbstractCrudObject) {
  inherits(IGMediaForIGOnlyAPI, _AbstractCrudObject);

  function IGMediaForIGOnlyAPI() {
    classCallCheck(this, IGMediaForIGOnlyAPI);
    return possibleConstructorReturn(this, (IGMediaForIGOnlyAPI.__proto__ || Object.getPrototypeOf(IGMediaForIGOnlyAPI)).apply(this, arguments));
  }

  createClass(IGMediaForIGOnlyAPI, [{
    key: 'getChildren',
    value: function getChildren(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/children');
    }
  }, {
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Comment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, null, pathOverride);
    }
  }, {
    key: 'getInsights',
    value: function getInsights(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InsightsResult, fields, params, fetchFirstPage, '/insights');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(IGMediaForIGOnlyAPI.prototype.__proto__ || Object.getPrototypeOf(IGMediaForIGOnlyAPI.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        caption: 'caption',
        comments_count: 'comments_count',
        id: 'id',
        is_comment_enabled: 'is_comment_enabled',
        is_shared_to_feed: 'is_shared_to_feed',
        like_count: 'like_count',
        media_product_type: 'media_product_type',
        media_type: 'media_type',
        media_url: 'media_url',
        owner: 'owner',
        permalink: 'permalink',
        shortcode: 'shortcode',
        thumbnail_url: 'thumbnail_url',
        timestamp: 'timestamp',
        username: 'username'
      });
    }
  }]);
  return IGMediaForIGOnlyAPI;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGProductTaggingInvalidationError
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGProductTaggingInvalidationError = function (_AbstractCrudObject) {
  inherits(IGProductTaggingInvalidationError, _AbstractCrudObject);

  function IGProductTaggingInvalidationError() {
    classCallCheck(this, IGProductTaggingInvalidationError);
    return possibleConstructorReturn(this, (IGProductTaggingInvalidationError.__proto__ || Object.getPrototypeOf(IGProductTaggingInvalidationError)).apply(this, arguments));
  }

  createClass(IGProductTaggingInvalidationError, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        taggability_state: 'taggability_state',
        title: 'title'
      });
    }
  }]);
  return IGProductTaggingInvalidationError;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGRefreshAccessTokenForIGOnlyAPI
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGRefreshAccessTokenForIGOnlyAPI = function (_AbstractCrudObject) {
  inherits(IGRefreshAccessTokenForIGOnlyAPI, _AbstractCrudObject);

  function IGRefreshAccessTokenForIGOnlyAPI() {
    classCallCheck(this, IGRefreshAccessTokenForIGOnlyAPI);
    return possibleConstructorReturn(this, (IGRefreshAccessTokenForIGOnlyAPI.__proto__ || Object.getPrototypeOf(IGRefreshAccessTokenForIGOnlyAPI)).apply(this, arguments));
  }

  createClass(IGRefreshAccessTokenForIGOnlyAPI, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        access_token: 'access_token',
        expires_in: 'expires_in',
        permissions: 'permissions',
        token_type: 'token_type',
        id: 'id'
      });
    }
  }]);
  return IGRefreshAccessTokenForIGOnlyAPI;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGResumableVideoUploadStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGResumableVideoUploadStatus = function (_AbstractCrudObject) {
  inherits(IGResumableVideoUploadStatus, _AbstractCrudObject);

  function IGResumableVideoUploadStatus() {
    classCallCheck(this, IGResumableVideoUploadStatus);
    return possibleConstructorReturn(this, (IGResumableVideoUploadStatus.__proto__ || Object.getPrototypeOf(IGResumableVideoUploadStatus)).apply(this, arguments));
  }

  createClass(IGResumableVideoUploadStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        processing_phase: 'processing_phase',
        uploading_phase: 'uploading_phase'
      });
    }
  }]);
  return IGResumableVideoUploadStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGShoppingReviewStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGShoppingReviewStatus = function (_AbstractCrudObject) {
  inherits(IGShoppingReviewStatus, _AbstractCrudObject);

  function IGShoppingReviewStatus() {
    classCallCheck(this, IGShoppingReviewStatus);
    return possibleConstructorReturn(this, (IGShoppingReviewStatus.__proto__ || Object.getPrototypeOf(IGShoppingReviewStatus)).apply(this, arguments));
  }

  createClass(IGShoppingReviewStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        onsite_eligibility: 'onsite_eligibility',
        reasons: 'reasons',
        status: 'status'
      });
    }
  }]);
  return IGShoppingReviewStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGShoppingReviewStatusOnsiteEligibility
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGShoppingReviewStatusOnsiteEligibility = function (_AbstractCrudObject) {
  inherits(IGShoppingReviewStatusOnsiteEligibility, _AbstractCrudObject);

  function IGShoppingReviewStatusOnsiteEligibility() {
    classCallCheck(this, IGShoppingReviewStatusOnsiteEligibility);
    return possibleConstructorReturn(this, (IGShoppingReviewStatusOnsiteEligibility.__proto__ || Object.getPrototypeOf(IGShoppingReviewStatusOnsiteEligibility)).apply(this, arguments));
  }

  createClass(IGShoppingReviewStatusOnsiteEligibility, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_eligible: 'is_eligible',
        reasons: 'reasons'
      });
    }
  }]);
  return IGShoppingReviewStatusOnsiteEligibility;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGShoppingReviewStatusReasonWithHelpMessage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGShoppingReviewStatusReasonWithHelpMessage = function (_AbstractCrudObject) {
  inherits(IGShoppingReviewStatusReasonWithHelpMessage, _AbstractCrudObject);

  function IGShoppingReviewStatusReasonWithHelpMessage() {
    classCallCheck(this, IGShoppingReviewStatusReasonWithHelpMessage);
    return possibleConstructorReturn(this, (IGShoppingReviewStatusReasonWithHelpMessage.__proto__ || Object.getPrototypeOf(IGShoppingReviewStatusReasonWithHelpMessage)).apply(this, arguments));
  }

  createClass(IGShoppingReviewStatusReasonWithHelpMessage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        code: 'code',
        help_url: 'help_url',
        message: 'message'
      });
    }
  }]);
  return IGShoppingReviewStatusReasonWithHelpMessage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGUserExportForCAM
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGUserExportForCAM = function (_AbstractCrudObject) {
  inherits(IGUserExportForCAM, _AbstractCrudObject);

  function IGUserExportForCAM() {
    classCallCheck(this, IGUserExportForCAM);
    return possibleConstructorReturn(this, (IGUserExportForCAM.__proto__ || Object.getPrototypeOf(IGUserExportForCAM)).apply(this, arguments));
  }

  createClass(IGUserExportForCAM, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        email: 'email',
        id: 'id',
        is_paid_partnership_messages_enabled: 'is_paid_partnership_messages_enabled',
        messaging_id: 'messaging_id',
        portfolio_url: 'portfolio_url',
        username: 'username'
      });
    }
  }]);
  return IGUserExportForCAM;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGUserForIGOnlyAPI
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGUserForIGOnlyAPI = function (_AbstractCrudObject) {
  inherits(IGUserForIGOnlyAPI, _AbstractCrudObject);

  function IGUserForIGOnlyAPI() {
    classCallCheck(this, IGUserForIGOnlyAPI);
    return possibleConstructorReturn(this, (IGUserForIGOnlyAPI.__proto__ || Object.getPrototypeOf(IGUserForIGOnlyAPI)).apply(this, arguments));
  }

  createClass(IGUserForIGOnlyAPI, [{
    key: 'getContentPublishingLimit',
    value: function getContentPublishingLimit(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(ContentPublishingLimitResponse, fields, params, fetchFirstPage, '/content_publishing_limit');
    }
  }, {
    key: 'getConversations',
    value: function getConversations(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(UnifiedThread, fields, params, fetchFirstPage, '/conversations');
    }
  }, {
    key: 'getLiveMedia',
    value: function getLiveMedia(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/live_media');
    }
  }, {
    key: 'getMedia',
    value: function getMedia(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/media');
    }
  }, {
    key: 'createMedia',
    value: function createMedia(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/media', fields, params, null, pathOverride);
    }
  }, {
    key: 'createMediaPublish',
    value: function createMediaPublish(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/mediapublish', fields, params, null, pathOverride);
    }
  }, {
    key: 'createMention',
    value: function createMention(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/mentions', fields, params, null, pathOverride);
    }
  }, {
    key: 'createMessageAttachment',
    value: function createMessageAttachment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/messageattachments', fields, params, null, pathOverride);
    }
  }, {
    key: 'createMessage',
    value: function createMessage(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/messages', fields, params, null, pathOverride);
    }
  }, {
    key: 'deleteMessengerProfile',
    value: function deleteMessengerProfile() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(IGUserForIGOnlyAPI.prototype.__proto__ || Object.getPrototypeOf(IGUserForIGOnlyAPI.prototype), 'deleteEdge', this).call(this, '/messenger_profile', params);
    }
  }, {
    key: 'getMessengerProfile',
    value: function getMessengerProfile(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/messenger_profile');
    }
  }, {
    key: 'createMessengerProfile',
    value: function createMessengerProfile(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/messenger_profile', fields, params, null, pathOverride);
    }
  }, {
    key: 'getStories',
    value: function getStories(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/stories');
    }
  }, {
    key: 'deleteSubscribedApps',
    value: function deleteSubscribedApps() {
      var params = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      return get$1(IGUserForIGOnlyAPI.prototype.__proto__ || Object.getPrototypeOf(IGUserForIGOnlyAPI.prototype), 'deleteEdge', this).call(this, '/subscribed_apps', params);
    }
  }, {
    key: 'getSubscribedApps',
    value: function getSubscribedApps(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/subscribed_apps');
    }
  }, {
    key: 'createSubscribedApp',
    value: function createSubscribedApp(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/subscribed_apps', fields, params, null, pathOverride);
    }
  }, {
    key: 'getTags',
    value: function getTags(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(AbstractObject, fields, params, fetchFirstPage, '/tags');
    }
  }, {
    key: 'getWelcomeMessageFlows',
    value: function getWelcomeMessageFlows(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CTXPartnerAppWelcomeMessageFlow, fields, params, fetchFirstPage, '/welcome_message_flows');
    }
  }, {
    key: 'createWelcomeMessageFlow',
    value: function createWelcomeMessageFlow(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/welcome_message_flows', fields, params, null, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_type: 'account_type',
        biography: 'biography',
        followers_count: 'followers_count',
        follows_count: 'follows_count',
        id: 'id',
        media_count: 'media_count',
        name: 'name',
        profile_picture_url: 'profile_picture_url',
        user_id: 'user_id',
        username: 'username',
        website: 'website'
      });
    }
  }]);
  return IGUserForIGOnlyAPI;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGVideoCopyrightCheckMatchesInformation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGVideoCopyrightCheckMatchesInformation = function (_AbstractCrudObject) {
  inherits(IGVideoCopyrightCheckMatchesInformation, _AbstractCrudObject);

  function IGVideoCopyrightCheckMatchesInformation() {
    classCallCheck(this, IGVideoCopyrightCheckMatchesInformation);
    return possibleConstructorReturn(this, (IGVideoCopyrightCheckMatchesInformation.__proto__ || Object.getPrototypeOf(IGVideoCopyrightCheckMatchesInformation)).apply(this, arguments));
  }

  createClass(IGVideoCopyrightCheckMatchesInformation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        copyright_matches: 'copyright_matches',
        status: 'status'
      });
    }
  }]);
  return IGVideoCopyrightCheckMatchesInformation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IGVideoCopyrightCheckStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IGVideoCopyrightCheckStatus = function (_AbstractCrudObject) {
  inherits(IGVideoCopyrightCheckStatus, _AbstractCrudObject);

  function IGVideoCopyrightCheckStatus() {
    classCallCheck(this, IGVideoCopyrightCheckStatus);
    return possibleConstructorReturn(this, (IGVideoCopyrightCheckStatus.__proto__ || Object.getPrototypeOf(IGVideoCopyrightCheckStatus)).apply(this, arguments));
  }

  createClass(IGVideoCopyrightCheckStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        matches_found: 'matches_found',
        status: 'status'
      });
    }
  }]);
  return IGVideoCopyrightCheckStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IPObject
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IPObject = function (_AbstractCrudObject) {
  inherits(IPObject, _AbstractCrudObject);

  function IPObject() {
    classCallCheck(this, IPObject);
    return possibleConstructorReturn(this, (IPObject.__proto__ || Object.getPrototypeOf(IPObject)).apply(this, arguments));
  }

  createClass(IPObject, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ip_permission: 'ip_permission',
        user: 'user'
      });
    }
  }]);
  return IPObject;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ImageCopyrightDispute
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ImageCopyrightDispute = function (_AbstractCrudObject) {
  inherits(ImageCopyrightDispute, _AbstractCrudObject);

  function ImageCopyrightDispute() {
    classCallCheck(this, ImageCopyrightDispute);
    return possibleConstructorReturn(this, (ImageCopyrightDispute.__proto__ || Object.getPrototypeOf(ImageCopyrightDispute)).apply(this, arguments));
  }

  createClass(ImageCopyrightDispute, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        appeal_form_data: 'appeal_form_data',
        dispute_form_data: 'dispute_form_data',
        expiration_time: 'expiration_time',
        id: 'id',
        match_id: 'match_id',
        status: 'status',
        time_appealed: 'time_appealed',
        time_created: 'time_created',
        time_updated: 'time_updated'
      });
    }
  }]);
  return ImageCopyrightDispute;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ImageReferenceMatch
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ImageReferenceMatch = function (_AbstractCrudObject) {
  inherits(ImageReferenceMatch, _AbstractCrudObject);

  function ImageReferenceMatch() {
    classCallCheck(this, ImageReferenceMatch);
    return possibleConstructorReturn(this, (ImageReferenceMatch.__proto__ || Object.getPrototypeOf(ImageReferenceMatch)).apply(this, arguments));
  }

  createClass(ImageReferenceMatch, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        conflicting_countries: 'conflicting_countries',
        country_resolution_history: 'country_resolution_history',
        creation_time: 'creation_time',
        current_conflict_resolved_countries: 'current_conflict_resolved_countries',
        displayed_match_state: 'displayed_match_state',
        dispute_form_data_entries_with_translations: 'dispute_form_data_entries_with_translations',
        expiration_time: 'expiration_time',
        id: 'id',
        match_state: 'match_state',
        matched_reference_copyright: 'matched_reference_copyright',
        matched_reference_owner: 'matched_reference_owner',
        modification_history: 'modification_history',
        reference_copyright: 'reference_copyright',
        reference_owner: 'reference_owner',
        rejection_form_data_entries_with_translations: 'rejection_form_data_entries_with_translations',
        resolution_reason: 'resolution_reason',
        update_time: 'update_time'
      });
    }
  }]);
  return ImageReferenceMatch;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InsightsValue
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InsightsValue = function (_AbstractCrudObject) {
  inherits(InsightsValue, _AbstractCrudObject);

  function InsightsValue() {
    classCallCheck(this, InsightsValue);
    return possibleConstructorReturn(this, (InsightsValue.__proto__ || Object.getPrototypeOf(InsightsValue)).apply(this, arguments));
  }

  createClass(InsightsValue, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        campaign_id: 'campaign_id',
        end_time: 'end_time',
        engagement_source: 'engagement_source',
        message_type: 'message_type',
        messaging_channel: 'messaging_channel',
        recurring_notifications_entry_point: 'recurring_notifications_entry_point',
        recurring_notifications_frequency: 'recurring_notifications_frequency',
        recurring_notifications_topic: 'recurring_notifications_topic',
        start_time: 'start_time',
        value: 'value'
      });
    }
  }]);
  return InsightsValue;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramBoostableMediaForAccessToken
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramBoostableMediaForAccessToken = function (_AbstractCrudObject) {
  inherits(InstagramBoostableMediaForAccessToken, _AbstractCrudObject);

  function InstagramBoostableMediaForAccessToken() {
    classCallCheck(this, InstagramBoostableMediaForAccessToken);
    return possibleConstructorReturn(this, (InstagramBoostableMediaForAccessToken.__proto__ || Object.getPrototypeOf(InstagramBoostableMediaForAccessToken)).apply(this, arguments));
  }

  createClass(InstagramBoostableMediaForAccessToken, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        has_product_tags: 'has_product_tags',
        media: 'media'
      });
    }
  }]);
  return InstagramBoostableMediaForAccessToken;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramComment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramComment = function (_AbstractCrudObject) {
  inherits(InstagramComment, _AbstractCrudObject);

  function InstagramComment() {
    classCallCheck(this, InstagramComment);
    return possibleConstructorReturn(this, (InstagramComment.__proto__ || Object.getPrototypeOf(InstagramComment)).apply(this, arguments));
  }

  createClass(InstagramComment, [{
    key: 'getReplies',
    value: function getReplies(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramComment, fields, params, fetchFirstPage, '/replies');
    }
  }, {
    key: 'createReply',
    value: function createReply(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/replies', fields, params, InstagramComment, pathOverride);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'delete',
    value: function _delete(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(InstagramComment.prototype.__proto__ || Object.getPrototypeOf(InstagramComment.prototype), 'delete', this).call(this, params);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(InstagramComment.prototype.__proto__ || Object.getPrototypeOf(InstagramComment.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        comment_type: 'comment_type',
        created_at: 'created_at',
        id: 'id',
        instagram_comment_id: 'instagram_comment_id',
        instagram_user: 'instagram_user',
        mentioned_instagram_users: 'mentioned_instagram_users',
        message: 'message',
        username: 'username'
      });
    }
  }]);
  return InstagramComment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramCarousel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramCarousel = function (_AbstractCrudObject) {
  inherits(InstagramCarousel, _AbstractCrudObject);

  function InstagramCarousel() {
    classCallCheck(this, InstagramCarousel);
    return possibleConstructorReturn(this, (InstagramCarousel.__proto__ || Object.getPrototypeOf(InstagramCarousel)).apply(this, arguments));
  }

  createClass(InstagramCarousel, [{
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramComment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, InstagramComment, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        caption_text: 'caption_text',
        comment_count: 'comment_count',
        content_type: 'content_type',
        display_url: 'display_url',
        id: 'id',
        like_count: 'like_count',
        owner_instagram_user: 'owner_instagram_user',
        permalink: 'permalink',
        taken_at: 'taken_at',
        video_url: 'video_url'
      });
    }
  }]);
  return InstagramCarousel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramInsightsValue
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramInsightsValue = function (_AbstractCrudObject) {
  inherits(InstagramInsightsValue, _AbstractCrudObject);

  function InstagramInsightsValue() {
    classCallCheck(this, InstagramInsightsValue);
    return possibleConstructorReturn(this, (InstagramInsightsValue.__proto__ || Object.getPrototypeOf(InstagramInsightsValue)).apply(this, arguments));
  }

  createClass(InstagramInsightsValue, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        end_time: 'end_time',
        value: 'value'
      });
    }
  }]);
  return InstagramInsightsValue;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramMedia
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramMedia = function (_AbstractCrudObject) {
  inherits(InstagramMedia, _AbstractCrudObject);

  function InstagramMedia() {
    classCallCheck(this, InstagramMedia);
    return possibleConstructorReturn(this, (InstagramMedia.__proto__ || Object.getPrototypeOf(InstagramMedia)).apply(this, arguments));
  }

  createClass(InstagramMedia, [{
    key: 'getComments',
    value: function getComments(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(InstagramComment, fields, params, fetchFirstPage, '/comments');
    }
  }, {
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, InstagramComment, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        caption_text: 'caption_text',
        comment_count: 'comment_count',
        content_type: 'content_type',
        display_url: 'display_url',
        filter_name: 'filter_name',
        id: 'id',
        latitude: 'latitude',
        like_count: 'like_count',
        location: 'location',
        location_name: 'location_name',
        longitude: 'longitude',
        owner_instagram_user: 'owner_instagram_user',
        permalink: 'permalink',
        taken_at: 'taken_at',
        video_url: 'video_url'
      });
    }
  }]);
  return InstagramMedia;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramRelatedProductTags
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramRelatedProductTags = function (_AbstractCrudObject) {
  inherits(InstagramRelatedProductTags, _AbstractCrudObject);

  function InstagramRelatedProductTags() {
    classCallCheck(this, InstagramRelatedProductTags);
    return possibleConstructorReturn(this, (InstagramRelatedProductTags.__proto__ || Object.getPrototypeOf(InstagramRelatedProductTags)).apply(this, arguments));
  }

  createClass(InstagramRelatedProductTags, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        checkout_setting: 'checkout_setting',
        id: 'id',
        image_uri: 'image_uri',
        name: 'name',
        price_label: 'price_label',
        sale_price_label: 'sale_price_label'
      });
    }
  }]);
  return InstagramRelatedProductTags;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramShoppingMerchantReviewMessage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramShoppingMerchantReviewMessage = function (_AbstractCrudObject) {
  inherits(InstagramShoppingMerchantReviewMessage, _AbstractCrudObject);

  function InstagramShoppingMerchantReviewMessage() {
    classCallCheck(this, InstagramShoppingMerchantReviewMessage);
    return possibleConstructorReturn(this, (InstagramShoppingMerchantReviewMessage.__proto__ || Object.getPrototypeOf(InstagramShoppingMerchantReviewMessage)).apply(this, arguments));
  }

  createClass(InstagramShoppingMerchantReviewMessage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        help_url: 'help_url',
        message: 'message'
      });
    }
  }]);
  return InstagramShoppingMerchantReviewMessage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstagramVideoMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstagramVideoMetadata = function (_AbstractCrudObject) {
  inherits(InstagramVideoMetadata, _AbstractCrudObject);

  function InstagramVideoMetadata() {
    classCallCheck(this, InstagramVideoMetadata);
    return possibleConstructorReturn(this, (InstagramVideoMetadata.__proto__ || Object.getPrototypeOf(InstagramVideoMetadata)).apply(this, arguments));
  }

  createClass(InstagramVideoMetadata, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        duration: 'duration',
        height: 'height',
        width: 'width'
      });
    }
  }]);
  return InstagramVideoMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * InstantArticleInsightsQueryResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var InstantArticleInsightsQueryResult = function (_AbstractCrudObject) {
  inherits(InstantArticleInsightsQueryResult, _AbstractCrudObject);

  function InstantArticleInsightsQueryResult() {
    classCallCheck(this, InstantArticleInsightsQueryResult);
    return possibleConstructorReturn(this, (InstantArticleInsightsQueryResult.__proto__ || Object.getPrototypeOf(InstantArticleInsightsQueryResult)).apply(this, arguments));
  }

  createClass(InstantArticleInsightsQueryResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        breakdowns: 'breakdowns',
        name: 'name',
        time: 'time',
        value: 'value'
      });
    }
  }]);
  return InstantArticleInsightsQueryResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * IosAppLink
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var IosAppLink = function (_AbstractCrudObject) {
  inherits(IosAppLink, _AbstractCrudObject);

  function IosAppLink() {
    classCallCheck(this, IosAppLink);
    return possibleConstructorReturn(this, (IosAppLink.__proto__ || Object.getPrototypeOf(IosAppLink)).apply(this, arguments));
  }

  createClass(IosAppLink, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_name: 'app_name',
        app_store_id: 'app_store_id',
        url: 'url'
      });
    }
  }]);
  return IosAppLink;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * JobOpening
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var JobOpening = function (_AbstractCrudObject) {
  inherits(JobOpening, _AbstractCrudObject);

  function JobOpening() {
    classCallCheck(this, JobOpening);
    return possibleConstructorReturn(this, (JobOpening.__proto__ || Object.getPrototypeOf(JobOpening)).apply(this, arguments));
  }

  createClass(JobOpening, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        address: 'address',
        application_callback_url: 'application_callback_url',
        created_time: 'created_time',
        description: 'description',
        errors: 'errors',
        external_company_facebook_url: 'external_company_facebook_url',
        external_company_full_address: 'external_company_full_address',
        external_company_id: 'external_company_id',
        external_company_name: 'external_company_name',
        external_id: 'external_id',
        id: 'id',
        job_status: 'job_status',
        latitude: 'latitude',
        longitude: 'longitude',
        offsite_application_url: 'offsite_application_url',
        page: 'page',
        photo: 'photo',
        platform_review_status: 'platform_review_status',
        post: 'post',
        remote_type: 'remote_type',
        review_rejection_reasons: 'review_rejection_reasons',
        title: 'title',
        type: 'type'
      });
    }
  }, {
    key: 'JobStatus',
    get: function get() {
      return Object.freeze({
        closed: 'CLOSED',
        draft: 'DRAFT',
        open: 'OPEN',
        provisional: 'PROVISIONAL'
      });
    }
  }, {
    key: 'PlatformReviewStatus',
    get: function get() {
      return Object.freeze({
        approved: 'APPROVED',
        pending: 'PENDING',
        rejected: 'REJECTED'
      });
    }
  }, {
    key: 'ReviewRejectionReasons',
    get: function get() {
      return Object.freeze({
        adult_content: 'ADULT_CONTENT',
        discrimination: 'DISCRIMINATION',
        drugs: 'DRUGS',
        generic_default: 'GENERIC_DEFAULT',
        illegal: 'ILLEGAL',
        impersonation: 'IMPERSONATION',
        misleading: 'MISLEADING',
        multilevel_marketing: 'MULTILEVEL_MARKETING',
        personal_info: 'PERSONAL_INFO',
        sexual: 'SEXUAL'
      });
    }
  }, {
    key: 'Type',
    get: function get() {
      return Object.freeze({
        contract: 'CONTRACT',
        full_time: 'FULL_TIME',
        internship: 'INTERNSHIP',
        part_time: 'PART_TIME',
        volunteer: 'VOLUNTEER'
      });
    }
  }]);
  return JobOpening;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * KeyValue
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var KeyValue = function (_AbstractCrudObject) {
  inherits(KeyValue, _AbstractCrudObject);

  function KeyValue() {
    classCallCheck(this, KeyValue);
    return possibleConstructorReturn(this, (KeyValue.__proto__ || Object.getPrototypeOf(KeyValue)).apply(this, arguments));
  }

  createClass(KeyValue, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        key: 'key',
        value: 'value'
      });
    }
  }]);
  return KeyValue;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * KeywordDeliveryReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var KeywordDeliveryReport = function (_AbstractCrudObject) {
  inherits(KeywordDeliveryReport, _AbstractCrudObject);

  function KeywordDeliveryReport() {
    classCallCheck(this, KeywordDeliveryReport);
    return possibleConstructorReturn(this, (KeywordDeliveryReport.__proto__ || Object.getPrototypeOf(KeywordDeliveryReport)).apply(this, arguments));
  }

  createClass(KeywordDeliveryReport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        estimated_clicks: 'estimated_clicks',
        estimated_conversions: 'estimated_conversions',
        estimated_cost: 'estimated_cost',
        estimated_cpc: 'estimated_cpc',
        estimated_ctr: 'estimated_ctr',
        estimated_cvr: 'estimated_cvr',
        estimated_impressions: 'estimated_impressions',
        estimated_returns: 'estimated_returns',
        keyword: 'keyword'
      });
    }
  }]);
  return KeywordDeliveryReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenAppointmentBookingInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenAppointmentBookingInfo = function (_AbstractCrudObject) {
  inherits(LeadGenAppointmentBookingInfo, _AbstractCrudObject);

  function LeadGenAppointmentBookingInfo() {
    classCallCheck(this, LeadGenAppointmentBookingInfo);
    return possibleConstructorReturn(this, (LeadGenAppointmentBookingInfo.__proto__ || Object.getPrototypeOf(LeadGenAppointmentBookingInfo)).apply(this, arguments));
  }

  createClass(LeadGenAppointmentBookingInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        advertiser_timezone_offset: 'advertiser_timezone_offset',
        appointment_durations: 'appointment_durations',
        appointment_slots_by_day: 'appointment_slots_by_day'
      });
    }
  }]);
  return LeadGenAppointmentBookingInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenAppointmentSlotsByDay
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenAppointmentSlotsByDay = function (_AbstractCrudObject) {
  inherits(LeadGenAppointmentSlotsByDay, _AbstractCrudObject);

  function LeadGenAppointmentSlotsByDay() {
    classCallCheck(this, LeadGenAppointmentSlotsByDay);
    return possibleConstructorReturn(this, (LeadGenAppointmentSlotsByDay.__proto__ || Object.getPrototypeOf(LeadGenAppointmentSlotsByDay)).apply(this, arguments));
  }

  createClass(LeadGenAppointmentSlotsByDay, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        appointment_slots: 'appointment_slots',
        day: 'day'
      });
    }
  }]);
  return LeadGenAppointmentSlotsByDay;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenAppointmentTimeSlot
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenAppointmentTimeSlot = function (_AbstractCrudObject) {
  inherits(LeadGenAppointmentTimeSlot, _AbstractCrudObject);

  function LeadGenAppointmentTimeSlot() {
    classCallCheck(this, LeadGenAppointmentTimeSlot);
    return possibleConstructorReturn(this, (LeadGenAppointmentTimeSlot.__proto__ || Object.getPrototypeOf(LeadGenAppointmentTimeSlot)).apply(this, arguments));
  }

  createClass(LeadGenAppointmentTimeSlot, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        end_time: 'end_time',
        start_time: 'start_time'
      });
    }
  }]);
  return LeadGenAppointmentTimeSlot;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenConditionalQuestionsGroupChoices
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenConditionalQuestionsGroupChoices = function (_AbstractCrudObject) {
  inherits(LeadGenConditionalQuestionsGroupChoices, _AbstractCrudObject);

  function LeadGenConditionalQuestionsGroupChoices() {
    classCallCheck(this, LeadGenConditionalQuestionsGroupChoices);
    return possibleConstructorReturn(this, (LeadGenConditionalQuestionsGroupChoices.__proto__ || Object.getPrototypeOf(LeadGenConditionalQuestionsGroupChoices)).apply(this, arguments));
  }

  createClass(LeadGenConditionalQuestionsGroupChoices, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        customized_token: 'customized_token',
        next_question_choices: 'next_question_choices',
        value: 'value'
      });
    }
  }]);
  return LeadGenConditionalQuestionsGroupChoices;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenConditionalQuestionsGroupQuestions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenConditionalQuestionsGroupQuestions = function (_AbstractCrudObject) {
  inherits(LeadGenConditionalQuestionsGroupQuestions, _AbstractCrudObject);

  function LeadGenConditionalQuestionsGroupQuestions() {
    classCallCheck(this, LeadGenConditionalQuestionsGroupQuestions);
    return possibleConstructorReturn(this, (LeadGenConditionalQuestionsGroupQuestions.__proto__ || Object.getPrototypeOf(LeadGenConditionalQuestionsGroupQuestions)).apply(this, arguments));
  }

  createClass(LeadGenConditionalQuestionsGroupQuestions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        field_key: 'field_key',
        input_type: 'input_type',
        name: 'name'
      });
    }
  }]);
  return LeadGenConditionalQuestionsGroupQuestions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenContextCard
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenContextCard = function (_AbstractCrudObject) {
  inherits(LeadGenContextCard, _AbstractCrudObject);

  function LeadGenContextCard() {
    classCallCheck(this, LeadGenContextCard);
    return possibleConstructorReturn(this, (LeadGenContextCard.__proto__ || Object.getPrototypeOf(LeadGenContextCard)).apply(this, arguments));
  }

  createClass(LeadGenContextCard, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        button_text: 'button_text',
        content: 'content',
        cover_photo: 'cover_photo',
        id: 'id',
        style: 'style',
        title: 'title'
      });
    }
  }]);
  return LeadGenContextCard;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenCustomDisclaimer
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenCustomDisclaimer = function (_AbstractCrudObject) {
  inherits(LeadGenCustomDisclaimer, _AbstractCrudObject);

  function LeadGenCustomDisclaimer() {
    classCallCheck(this, LeadGenCustomDisclaimer);
    return possibleConstructorReturn(this, (LeadGenCustomDisclaimer.__proto__ || Object.getPrototypeOf(LeadGenCustomDisclaimer)).apply(this, arguments));
  }

  createClass(LeadGenCustomDisclaimer, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        body: 'body',
        checkboxes: 'checkboxes',
        title: 'title'
      });
    }
  }]);
  return LeadGenCustomDisclaimer;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenCustomDisclaimerBody
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenCustomDisclaimerBody = function (_AbstractCrudObject) {
  inherits(LeadGenCustomDisclaimerBody, _AbstractCrudObject);

  function LeadGenCustomDisclaimerBody() {
    classCallCheck(this, LeadGenCustomDisclaimerBody);
    return possibleConstructorReturn(this, (LeadGenCustomDisclaimerBody.__proto__ || Object.getPrototypeOf(LeadGenCustomDisclaimerBody)).apply(this, arguments));
  }

  createClass(LeadGenCustomDisclaimerBody, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        text: 'text',
        url_entities: 'url_entities'
      });
    }
  }]);
  return LeadGenCustomDisclaimerBody;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenDataDraft
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenDataDraft = function (_AbstractCrudObject) {
  inherits(LeadGenDataDraft, _AbstractCrudObject);

  function LeadGenDataDraft() {
    classCallCheck(this, LeadGenDataDraft);
    return possibleConstructorReturn(this, (LeadGenDataDraft.__proto__ || Object.getPrototypeOf(LeadGenDataDraft)).apply(this, arguments));
  }

  createClass(LeadGenDataDraft, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        block_display_for_non_targeted_viewer: 'block_display_for_non_targeted_viewer',
        created_time: 'created_time',
        disqualified_end_component: 'disqualified_end_component',
        follow_up_action_url: 'follow_up_action_url',
        id: 'id',
        is_optimized_for_quality: 'is_optimized_for_quality',
        legal_content: 'legal_content',
        locale: 'locale',
        name: 'name',
        page: 'page',
        question_page_custom_headline: 'question_page_custom_headline',
        questions: 'questions',
        status: 'status',
        thank_you_page: 'thank_you_page',
        tracking_parameters: 'tracking_parameters'
      });
    }
  }]);
  return LeadGenDataDraft;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenDirectCRMIntegrationConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenDirectCRMIntegrationConfig = function (_AbstractCrudObject) {
  inherits(LeadGenDirectCRMIntegrationConfig, _AbstractCrudObject);

  function LeadGenDirectCRMIntegrationConfig() {
    classCallCheck(this, LeadGenDirectCRMIntegrationConfig);
    return possibleConstructorReturn(this, (LeadGenDirectCRMIntegrationConfig.__proto__ || Object.getPrototypeOf(LeadGenDirectCRMIntegrationConfig)).apply(this, arguments));
  }

  createClass(LeadGenDirectCRMIntegrationConfig, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        auth_id: 'auth_id',
        creation_time: 'creation_time',
        id: 'id',
        lead_gen_data: 'lead_gen_data',
        matched_fields: 'matched_fields',
        matched_fields_labels: 'matched_fields_labels',
        resources: 'resources',
        third_party_app_id: 'third_party_app_id'
      });
    }
  }]);
  return LeadGenDirectCRMIntegrationConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenDraftQuestion
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenDraftQuestion = function (_AbstractCrudObject) {
  inherits(LeadGenDraftQuestion, _AbstractCrudObject);

  function LeadGenDraftQuestion() {
    classCallCheck(this, LeadGenDraftQuestion);
    return possibleConstructorReturn(this, (LeadGenDraftQuestion.__proto__ || Object.getPrototypeOf(LeadGenDraftQuestion)).apply(this, arguments));
  }

  createClass(LeadGenDraftQuestion, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        conditional_questions_choices: 'conditional_questions_choices',
        conditional_questions_group_id: 'conditional_questions_group_id',
        dependent_conditional_questions: 'dependent_conditional_questions',
        inline_context: 'inline_context',
        key: 'key',
        label: 'label',
        options: 'options',
        type: 'type'
      });
    }
  }]);
  return LeadGenDraftQuestion;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenFormPreviewDetails
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenFormPreviewDetails = function (_AbstractCrudObject) {
  inherits(LeadGenFormPreviewDetails, _AbstractCrudObject);

  function LeadGenFormPreviewDetails() {
    classCallCheck(this, LeadGenFormPreviewDetails);
    return possibleConstructorReturn(this, (LeadGenFormPreviewDetails.__proto__ || Object.getPrototypeOf(LeadGenFormPreviewDetails)).apply(this, arguments));
  }

  createClass(LeadGenFormPreviewDetails, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        call_business_text: 'call_business_text',
        call_to_action_title: 'call_to_action_title',
        contact_information_text: 'contact_information_text',
        creatives_overview_default_text: 'creatives_overview_default_text',
        data_privacy_policy_setting_description: 'data_privacy_policy_setting_description',
        default_appointment_scheduling_inline_context: 'default_appointment_scheduling_inline_context',
        default_disqualified_end_component: 'default_disqualified_end_component',
        default_thank_you_page: 'default_thank_you_page',
        disqualified_thank_you_card_transparency_info_text: 'disqualified_thank_you_card_transparency_info_text',
        edit_text: 'edit_text',
        email_inline_context_text: 'email_inline_context_text',
        email_messenger_push_opt_in_disclaimer: 'email_messenger_push_opt_in_disclaimer',
        email_messenger_push_opt_in_transparency_text: 'email_messenger_push_opt_in_transparency_text',
        form_clarity_description_content: 'form_clarity_description_content',
        form_clarity_description_title: 'form_clarity_description_title',
        form_clarity_headline: 'form_clarity_headline',
        gated_content_locked_description: 'gated_content_locked_description',
        gated_content_locked_headline: 'gated_content_locked_headline',
        gated_content_unlocked_description: 'gated_content_unlocked_description',
        gated_content_unlocked_headline: 'gated_content_unlocked_headline',
        how_it_works_section_headers: 'how_it_works_section_headers',
        next_button_text: 'next_button_text',
        optional_question_text: 'optional_question_text',
        personal_info_text: 'personal_info_text',
        phone_number_inline_context_text: 'phone_number_inline_context_text',
        privacy_policy_link_text: 'privacy_policy_link_text',
        privacy_policy_title_section_title_text: 'privacy_policy_title_section_title_text',
        privacy_setting_description: 'privacy_setting_description',
        products_section_headers: 'products_section_headers',
        qualified_thank_you_card_transparency_info_text: 'qualified_thank_you_card_transparency_info_text',
        redeem_promo_code_text: 'redeem_promo_code_text',
        review_your_info_text: 'review_your_info_text',
        secure_sharing_text: 'secure_sharing_text',
        slide_to_submit_text: 'slide_to_submit_text',
        social_proof_section_headers: 'social_proof_section_headers',
        submit_button_text: 'submit_button_text',
        view_file_text: 'view_file_text'
      });
    }
  }]);
  return LeadGenFormPreviewDetails;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenLegalContent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenLegalContent = function (_AbstractCrudObject) {
  inherits(LeadGenLegalContent, _AbstractCrudObject);

  function LeadGenLegalContent() {
    classCallCheck(this, LeadGenLegalContent);
    return possibleConstructorReturn(this, (LeadGenLegalContent.__proto__ || Object.getPrototypeOf(LeadGenLegalContent)).apply(this, arguments));
  }

  createClass(LeadGenLegalContent, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        custom_disclaimer: 'custom_disclaimer',
        id: 'id',
        privacy_policy: 'privacy_policy'
      });
    }
  }]);
  return LeadGenLegalContent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenLegalContentCheckbox
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenLegalContentCheckbox = function (_AbstractCrudObject) {
  inherits(LeadGenLegalContentCheckbox, _AbstractCrudObject);

  function LeadGenLegalContentCheckbox() {
    classCallCheck(this, LeadGenLegalContentCheckbox);
    return possibleConstructorReturn(this, (LeadGenLegalContentCheckbox.__proto__ || Object.getPrototypeOf(LeadGenLegalContentCheckbox)).apply(this, arguments));
  }

  createClass(LeadGenLegalContentCheckbox, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        is_checked_by_default: 'is_checked_by_default',
        is_required: 'is_required',
        key: 'key',
        text: 'text'
      });
    }
  }]);
  return LeadGenLegalContentCheckbox;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenPostSubmissionCheckResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenPostSubmissionCheckResult = function (_AbstractCrudObject) {
  inherits(LeadGenPostSubmissionCheckResult, _AbstractCrudObject);

  function LeadGenPostSubmissionCheckResult() {
    classCallCheck(this, LeadGenPostSubmissionCheckResult);
    return possibleConstructorReturn(this, (LeadGenPostSubmissionCheckResult.__proto__ || Object.getPrototypeOf(LeadGenPostSubmissionCheckResult)).apply(this, arguments));
  }

  createClass(LeadGenPostSubmissionCheckResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        api_call_result: 'api_call_result',
        api_error_message: 'api_error_message',
        shown_thank_you_page: 'shown_thank_you_page'
      });
    }
  }]);
  return LeadGenPostSubmissionCheckResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenPrivacyPolicy
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenPrivacyPolicy = function (_AbstractCrudObject) {
  inherits(LeadGenPrivacyPolicy, _AbstractCrudObject);

  function LeadGenPrivacyPolicy() {
    classCallCheck(this, LeadGenPrivacyPolicy);
    return possibleConstructorReturn(this, (LeadGenPrivacyPolicy.__proto__ || Object.getPrototypeOf(LeadGenPrivacyPolicy)).apply(this, arguments));
  }

  createClass(LeadGenPrivacyPolicy, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        link_text: 'link_text',
        url: 'url'
      });
    }
  }]);
  return LeadGenPrivacyPolicy;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenQuestion
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenQuestion = function (_AbstractCrudObject) {
  inherits(LeadGenQuestion, _AbstractCrudObject);

  function LeadGenQuestion() {
    classCallCheck(this, LeadGenQuestion);
    return possibleConstructorReturn(this, (LeadGenQuestion.__proto__ || Object.getPrototypeOf(LeadGenQuestion)).apply(this, arguments));
  }

  createClass(LeadGenQuestion, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        conditional_questions_choices: 'conditional_questions_choices',
        conditional_questions_group_id: 'conditional_questions_group_id',
        dependent_conditional_questions: 'dependent_conditional_questions',
        id: 'id',
        inline_context: 'inline_context',
        key: 'key',
        label: 'label',
        options: 'options',
        type: 'type'
      });
    }
  }]);
  return LeadGenQuestion;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenQuestionOption
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenQuestionOption = function (_AbstractCrudObject) {
  inherits(LeadGenQuestionOption, _AbstractCrudObject);

  function LeadGenQuestionOption() {
    classCallCheck(this, LeadGenQuestionOption);
    return possibleConstructorReturn(this, (LeadGenQuestionOption.__proto__ || Object.getPrototypeOf(LeadGenQuestionOption)).apply(this, arguments));
  }

  createClass(LeadGenQuestionOption, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        key: 'key',
        value: 'value'
      });
    }
  }]);
  return LeadGenQuestionOption;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenThankYouPage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenThankYouPage = function (_AbstractCrudObject) {
  inherits(LeadGenThankYouPage, _AbstractCrudObject);

  function LeadGenThankYouPage() {
    classCallCheck(this, LeadGenThankYouPage);
    return possibleConstructorReturn(this, (LeadGenThankYouPage.__proto__ || Object.getPrototypeOf(LeadGenThankYouPage)).apply(this, arguments));
  }

  createClass(LeadGenThankYouPage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        body: 'body',
        business_phone_number: 'business_phone_number',
        button_text: 'button_text',
        button_type: 'button_type',
        country_code: 'country_code',
        enable_messenger: 'enable_messenger',
        id: 'id',
        lead_gen_use_case: 'lead_gen_use_case',
        status: 'status',
        title: 'title',
        website_url: 'website_url'
      });
    }
  }]);
  return LeadGenThankYouPage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenThankYouPageGatedFile
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenThankYouPageGatedFile = function (_AbstractCrudObject) {
  inherits(LeadGenThankYouPageGatedFile, _AbstractCrudObject);

  function LeadGenThankYouPageGatedFile() {
    classCallCheck(this, LeadGenThankYouPageGatedFile);
    return possibleConstructorReturn(this, (LeadGenThankYouPageGatedFile.__proto__ || Object.getPrototypeOf(LeadGenThankYouPageGatedFile)).apply(this, arguments));
  }

  createClass(LeadGenThankYouPageGatedFile, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        file_cdn_url: 'file_cdn_url',
        file_name: 'file_name',
        file_size_bytes: 'file_size_bytes',
        id: 'id'
      });
    }
  }]);
  return LeadGenThankYouPageGatedFile;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenThankYouPageGatedPromo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenThankYouPageGatedPromo = function (_AbstractCrudObject) {
  inherits(LeadGenThankYouPageGatedPromo, _AbstractCrudObject);

  function LeadGenThankYouPageGatedPromo() {
    classCallCheck(this, LeadGenThankYouPageGatedPromo);
    return possibleConstructorReturn(this, (LeadGenThankYouPageGatedPromo.__proto__ || Object.getPrototypeOf(LeadGenThankYouPageGatedPromo)).apply(this, arguments));
  }

  createClass(LeadGenThankYouPageGatedPromo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        online_offer_url: 'online_offer_url',
        online_promo_code: 'online_promo_code'
      });
    }
  }]);
  return LeadGenThankYouPageGatedPromo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LeadGenURLEntityAtRanges
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LeadGenURLEntityAtRanges = function (_AbstractCrudObject) {
  inherits(LeadGenURLEntityAtRanges, _AbstractCrudObject);

  function LeadGenURLEntityAtRanges() {
    classCallCheck(this, LeadGenURLEntityAtRanges);
    return possibleConstructorReturn(this, (LeadGenURLEntityAtRanges.__proto__ || Object.getPrototypeOf(LeadGenURLEntityAtRanges)).apply(this, arguments));
  }

  createClass(LeadGenURLEntityAtRanges, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        length: 'length',
        offset: 'offset',
        url: 'url'
      });
    }
  }]);
  return LeadGenURLEntityAtRanges;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LifeEvent
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LifeEvent = function (_AbstractCrudObject) {
  inherits(LifeEvent, _AbstractCrudObject);

  function LifeEvent() {
    classCallCheck(this, LifeEvent);
    return possibleConstructorReturn(this, (LifeEvent.__proto__ || Object.getPrototypeOf(LifeEvent)).apply(this, arguments));
  }

  createClass(LifeEvent, [{
    key: 'getLikes',
    value: function getLikes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/likes');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        end_time: 'end_time',
        from: 'from',
        id: 'id',
        is_hidden: 'is_hidden',
        start_time: 'start_time',
        title: 'title',
        updated_time: 'updated_time'
      });
    }
  }]);
  return LifeEvent;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Link
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Link = function (_AbstractCrudObject) {
  inherits(Link, _AbstractCrudObject);

  function Link() {
    classCallCheck(this, Link);
    return possibleConstructorReturn(this, (Link.__proto__ || Object.getPrototypeOf(Link)).apply(this, arguments));
  }

  createClass(Link, [{
    key: 'createComment',
    value: function createComment(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/comments', fields, params, Comment, pathOverride);
    }
  }, {
    key: 'getLikes',
    value: function getLikes(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(Profile, fields, params, fetchFirstPage, '/likes');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        caption: 'caption',
        created_time: 'created_time',
        description: 'description',
        from: 'from',
        icon: 'icon',
        id: 'id',
        link: 'link',
        message: 'message',
        multi_share_optimized: 'multi_share_optimized',
        name: 'name',
        privacy: 'privacy',
        via: 'via'
      });
    }
  }]);
  return Link;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LinkedInstagramAccountData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LinkedInstagramAccountData = function (_AbstractCrudObject) {
  inherits(LinkedInstagramAccountData, _AbstractCrudObject);

  function LinkedInstagramAccountData() {
    classCallCheck(this, LinkedInstagramAccountData);
    return possibleConstructorReturn(this, (LinkedInstagramAccountData.__proto__ || Object.getPrototypeOf(LinkedInstagramAccountData)).apply(this, arguments));
  }

  createClass(LinkedInstagramAccountData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        access_token: 'access_token',
        analytics_claim: 'analytics_claim',
        full_name: 'full_name',
        profile_picture_url: 'profile_picture_url',
        user_id: 'user_id',
        user_name: 'user_name'
      });
    }
  }]);
  return LinkedInstagramAccountData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LiveVideoAdBreakConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LiveVideoAdBreakConfig = function (_AbstractCrudObject) {
  inherits(LiveVideoAdBreakConfig, _AbstractCrudObject);

  function LiveVideoAdBreakConfig() {
    classCallCheck(this, LiveVideoAdBreakConfig);
    return possibleConstructorReturn(this, (LiveVideoAdBreakConfig.__proto__ || Object.getPrototypeOf(LiveVideoAdBreakConfig)).apply(this, arguments));
  }

  createClass(LiveVideoAdBreakConfig, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        default_ad_break_duration: 'default_ad_break_duration',
        failure_reason_polling_interval: 'failure_reason_polling_interval',
        first_break_eligible_secs: 'first_break_eligible_secs',
        guide_url: 'guide_url',
        is_eligible_to_onboard: 'is_eligible_to_onboard',
        is_enabled: 'is_enabled',
        onboarding_url: 'onboarding_url',
        preparing_duration: 'preparing_duration',
        time_between_ad_breaks_secs: 'time_between_ad_breaks_secs',
        viewer_count_threshold: 'viewer_count_threshold'
      });
    }
  }]);
  return LiveVideoAdBreakConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LiveVideoRecommendedEncoderSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LiveVideoRecommendedEncoderSettings = function (_AbstractCrudObject) {
  inherits(LiveVideoRecommendedEncoderSettings, _AbstractCrudObject);

  function LiveVideoRecommendedEncoderSettings() {
    classCallCheck(this, LiveVideoRecommendedEncoderSettings);
    return possibleConstructorReturn(this, (LiveVideoRecommendedEncoderSettings.__proto__ || Object.getPrototypeOf(LiveVideoRecommendedEncoderSettings)).apply(this, arguments));
  }

  createClass(LiveVideoRecommendedEncoderSettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audio_codec_settings: 'audio_codec_settings',
        streaming_protocol: 'streaming_protocol',
        video_codec_settings: 'video_codec_settings'
      });
    }
  }]);
  return LiveVideoRecommendedEncoderSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LiveVideoTargeting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LiveVideoTargeting = function (_AbstractCrudObject) {
  inherits(LiveVideoTargeting, _AbstractCrudObject);

  function LiveVideoTargeting() {
    classCallCheck(this, LiveVideoTargeting);
    return possibleConstructorReturn(this, (LiveVideoTargeting.__proto__ || Object.getPrototypeOf(LiveVideoTargeting)).apply(this, arguments));
  }

  createClass(LiveVideoTargeting, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        age_max: 'age_max',
        age_min: 'age_min',
        excluded_countries: 'excluded_countries',
        geo_locations: 'geo_locations'
      });
    }
  }]);
  return LiveVideoTargeting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LocalServiceBusiness
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LocalServiceBusiness = function (_AbstractCrudObject) {
  inherits(LocalServiceBusiness, _AbstractCrudObject);

  function LocalServiceBusiness() {
    classCallCheck(this, LocalServiceBusiness);
    return possibleConstructorReturn(this, (LocalServiceBusiness.__proto__ || Object.getPrototypeOf(LocalServiceBusiness)).apply(this, arguments));
  }

  createClass(LocalServiceBusiness, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        address: 'address',
        applinks: 'applinks',
        availability: 'availability',
        brand: 'brand',
        category: 'category',
        category_specific_fields: 'category_specific_fields',
        condition: 'condition',
        cuisine_type: 'cuisine_type',
        currency: 'currency',
        custom_label_0: 'custom_label_0',
        custom_label_1: 'custom_label_1',
        custom_label_2: 'custom_label_2',
        custom_label_3: 'custom_label_3',
        custom_label_4: 'custom_label_4',
        custom_number_0: 'custom_number_0',
        custom_number_1: 'custom_number_1',
        custom_number_2: 'custom_number_2',
        custom_number_3: 'custom_number_3',
        custom_number_4: 'custom_number_4',
        description: 'description',
        expiration_date: 'expiration_date',
        gtin: 'gtin',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        local_info: 'local_info',
        local_service_business_id: 'local_service_business_id',
        main_local_info: 'main_local_info',
        phone: 'phone',
        price: 'price',
        price_range: 'price_range',
        retailer_category: 'retailer_category',
        sanitized_images: 'sanitized_images',
        size: 'size',
        tags: 'tags',
        title: 'title',
        unit_price: 'unit_price',
        url: 'url',
        vendor_id: 'vendor_id',
        visibility: 'visibility'
      });
    }
  }, {
    key: 'Availability',
    get: function get() {
      return Object.freeze({
        available_for_order: 'AVAILABLE_FOR_ORDER',
        discontinued: 'DISCONTINUED',
        in_stock: 'IN_STOCK',
        mark_as_sold: 'MARK_AS_SOLD',
        out_of_stock: 'OUT_OF_STOCK',
        pending: 'PENDING',
        preorder: 'PREORDER'
      });
    }
  }, {
    key: 'Condition',
    get: function get() {
      return Object.freeze({
        pc_cpo: 'PC_CPO',
        pc_new: 'PC_NEW',
        pc_open_box_new: 'PC_OPEN_BOX_NEW',
        pc_refurbished: 'PC_REFURBISHED',
        pc_used: 'PC_USED',
        pc_used_fair: 'PC_USED_FAIR',
        pc_used_good: 'PC_USED_GOOD',
        pc_used_like_new: 'PC_USED_LIKE_NEW'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }]);
  return LocalServiceBusiness;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Location
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Location = function (_AbstractCrudObject) {
  inherits(Location, _AbstractCrudObject);

  function Location() {
    classCallCheck(this, Location);
    return possibleConstructorReturn(this, (Location.__proto__ || Object.getPrototypeOf(Location)).apply(this, arguments));
  }

  createClass(Location, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        city: 'city',
        city_id: 'city_id',
        country: 'country',
        country_code: 'country_code',
        latitude: 'latitude',
        located_in: 'located_in',
        longitude: 'longitude',
        name: 'name',
        region: 'region',
        region_id: 'region_id',
        state: 'state',
        street: 'street',
        zip: 'zip'
      });
    }
  }]);
  return Location;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LookalikeSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LookalikeSpec = function (_AbstractCrudObject) {
  inherits(LookalikeSpec, _AbstractCrudObject);

  function LookalikeSpec() {
    classCallCheck(this, LookalikeSpec);
    return possibleConstructorReturn(this, (LookalikeSpec.__proto__ || Object.getPrototypeOf(LookalikeSpec)).apply(this, arguments));
  }

  createClass(LookalikeSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        is_financial_service: 'is_financial_service',
        origin: 'origin',
        origin_event_name: 'origin_event_name',
        origin_event_source_name: 'origin_event_source_name',
        origin_event_source_type: 'origin_event_source_type',
        product_set_name: 'product_set_name',
        ratio: 'ratio',
        starting_ratio: 'starting_ratio',
        target_countries: 'target_countries',
        target_country_names: 'target_country_names',
        type: 'type'
      });
    }
  }]);
  return LookalikeSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * LoomConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var LoomConfig = function (_AbstractCrudObject) {
  inherits(LoomConfig, _AbstractCrudObject);

  function LoomConfig() {
    classCallCheck(this, LoomConfig);
    return possibleConstructorReturn(this, (LoomConfig.__proto__ || Object.getPrototypeOf(LoomConfig)).apply(this, arguments));
  }

  createClass(LoomConfig, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return LoomConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MCExperienceConfigForApi
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MCExperienceConfigForApi = function (_AbstractCrudObject) {
  inherits(MCExperienceConfigForApi, _AbstractCrudObject);

  function MCExperienceConfigForApi() {
    classCallCheck(this, MCExperienceConfigForApi);
    return possibleConstructorReturn(this, (MCExperienceConfigForApi.__proto__ || Object.getPrototypeOf(MCExperienceConfigForApi)).apply(this, arguments));
  }

  createClass(MCExperienceConfigForApi, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_campaign_enabled: 'is_campaign_enabled',
        is_terms_signed: 'is_terms_signed',
        merchant_type: 'merchant_type'
      });
    }
  }]);
  return MCExperienceConfigForApi;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MIXInsightsResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MIXInsightsResult = function (_AbstractCrudObject) {
  inherits(MIXInsightsResult, _AbstractCrudObject);

  function MIXInsightsResult() {
    classCallCheck(this, MIXInsightsResult);
    return possibleConstructorReturn(this, (MIXInsightsResult.__proto__ || Object.getPrototypeOf(MIXInsightsResult)).apply(this, arguments));
  }

  createClass(MIXInsightsResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        daily_age_gender_breakdown: 'daily_age_gender_breakdown',
        daily_audio_library_values: 'daily_audio_library_values',
        daily_ugc_values: 'daily_ugc_values',
        daily_values: 'daily_values',
        metric: 'metric',
        monthly_audio_library_values: 'monthly_audio_library_values',
        monthly_ugc_values: 'monthly_ugc_values',
        monthly_values: 'monthly_values',
        percent_growth: 'percent_growth',
        shielded_fields: 'shielded_fields',
        total_age_gender_breakdown: 'total_age_gender_breakdown',
        total_audio_library_value: 'total_audio_library_value',
        total_country_breakdown: 'total_country_breakdown',
        total_locale_breakdown: 'total_locale_breakdown',
        total_product_breakdown: 'total_product_breakdown',
        total_ugc_value: 'total_ugc_value',
        total_value: 'total_value',
        trending_age: 'trending_age',
        trending_gender: 'trending_gender',
        trending_interest: 'trending_interest',
        trending_territory: 'trending_territory'
      });
    }
  }]);
  return MIXInsightsResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MailingAddress
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MailingAddress = function (_AbstractCrudObject) {
  inherits(MailingAddress, _AbstractCrudObject);

  function MailingAddress() {
    classCallCheck(this, MailingAddress);
    return possibleConstructorReturn(this, (MailingAddress.__proto__ || Object.getPrototypeOf(MailingAddress)).apply(this, arguments));
  }

  createClass(MailingAddress, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        city: 'city',
        city_page: 'city_page',
        country: 'country',
        id: 'id',
        postal_code: 'postal_code',
        region: 'region',
        street1: 'street1',
        street2: 'street2'
      });
    }
  }]);
  return MailingAddress;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ManagedPartnerBusiness
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ManagedPartnerBusiness = function (_AbstractCrudObject) {
  inherits(ManagedPartnerBusiness, _AbstractCrudObject);

  function ManagedPartnerBusiness() {
    classCallCheck(this, ManagedPartnerBusiness);
    return possibleConstructorReturn(this, (ManagedPartnerBusiness.__proto__ || Object.getPrototypeOf(ManagedPartnerBusiness)).apply(this, arguments));
  }

  createClass(ManagedPartnerBusiness, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account: 'ad_account',
        catalog_segment: 'catalog_segment',
        extended_credit: 'extended_credit',
        page: 'page',
        seller_business_info: 'seller_business_info',
        seller_business_status: 'seller_business_status',
        template: 'template'
      });
    }
  }]);
  return ManagedPartnerBusiness;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ManagedPartnerExtendedCredit
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ManagedPartnerExtendedCredit = function (_AbstractCrudObject) {
  inherits(ManagedPartnerExtendedCredit, _AbstractCrudObject);

  function ManagedPartnerExtendedCredit() {
    classCallCheck(this, ManagedPartnerExtendedCredit);
    return possibleConstructorReturn(this, (ManagedPartnerExtendedCredit.__proto__ || Object.getPrototypeOf(ManagedPartnerExtendedCredit)).apply(this, arguments));
  }

  createClass(ManagedPartnerExtendedCredit, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        max_balance: 'max_balance',
        receiving_credit_allocation_config: 'receiving_credit_allocation_config'
      });
    }
  }]);
  return ManagedPartnerExtendedCredit;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MarketingMessageTargeting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MarketingMessageTargeting = function (_AbstractCrudObject) {
  inherits(MarketingMessageTargeting, _AbstractCrudObject);

  function MarketingMessageTargeting() {
    classCallCheck(this, MarketingMessageTargeting);
    return possibleConstructorReturn(this, (MarketingMessageTargeting.__proto__ || Object.getPrototypeOf(MarketingMessageTargeting)).apply(this, arguments));
  }

  createClass(MarketingMessageTargeting, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        automation_type: 'automation_type',
        delay_send_time_second: 'delay_send_time_second',
        delay_send_time_unit: 'delay_send_time_unit',
        subscriber_lists: 'subscriber_lists',
        targeting_rules: 'targeting_rules'
      });
    }
  }]);
  return MarketingMessageTargeting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * McomInvoiceBankAccount
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var McomInvoiceBankAccount = function (_AbstractCrudObject) {
  inherits(McomInvoiceBankAccount, _AbstractCrudObject);

  function McomInvoiceBankAccount() {
    classCallCheck(this, McomInvoiceBankAccount);
    return possibleConstructorReturn(this, (McomInvoiceBankAccount.__proto__ || Object.getPrototypeOf(McomInvoiceBankAccount)).apply(this, arguments));
  }

  createClass(McomInvoiceBankAccount, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        num_pending_verification_accounts: 'num_pending_verification_accounts',
        num_verified_accounts: 'num_verified_accounts',
        pending_verification_accounts: 'pending_verification_accounts',
        verified_accounts: 'verified_accounts'
      });
    }
  }]);
  return McomInvoiceBankAccount;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * McomInvoiceDetails
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var McomInvoiceDetails = function (_AbstractCrudObject) {
  inherits(McomInvoiceDetails, _AbstractCrudObject);

  function McomInvoiceDetails() {
    classCallCheck(this, McomInvoiceDetails);
    return possibleConstructorReturn(this, (McomInvoiceDetails.__proto__ || Object.getPrototypeOf(McomInvoiceDetails)).apply(this, arguments));
  }

  createClass(McomInvoiceDetails, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        additional_amounts: 'additional_amounts',
        buyer_notes: 'buyer_notes',
        currency_amount: 'currency_amount',
        external_invoice_id: 'external_invoice_id',
        features: 'features',
        invoice_created: 'invoice_created',
        invoice_id: 'invoice_id',
        invoice_instructions: 'invoice_instructions',
        invoice_instructions_image_url: 'invoice_instructions_image_url',
        invoice_updated: 'invoice_updated',
        outstanding_amount: 'outstanding_amount',
        paid_amount: 'paid_amount',
        payments: 'payments',
        platform_logo_url: 'platform_logo_url',
        platform_name: 'platform_name',
        product_items: 'product_items',
        shipping_address: 'shipping_address',
        status: 'status',
        tracking_info: 'tracking_info'
      });
    }
  }]);
  return McomInvoiceDetails;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * McomInvoiceLists
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var McomInvoiceLists = function (_AbstractCrudObject) {
  inherits(McomInvoiceLists, _AbstractCrudObject);

  function McomInvoiceLists() {
    classCallCheck(this, McomInvoiceLists);
    return possibleConstructorReturn(this, (McomInvoiceLists.__proto__ || Object.getPrototypeOf(McomInvoiceLists)).apply(this, arguments));
  }

  createClass(McomInvoiceLists, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        invoice_details: 'invoice_details',
        invoice_ids: 'invoice_ids',
        page_id: 'page_id'
      });
    }
  }]);
  return McomInvoiceLists;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * McomInvoiceStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var McomInvoiceStatus = function (_AbstractCrudObject) {
  inherits(McomInvoiceStatus, _AbstractCrudObject);

  function McomInvoiceStatus() {
    classCallCheck(this, McomInvoiceStatus);
    return possibleConstructorReturn(this, (McomInvoiceStatus.__proto__ || Object.getPrototypeOf(McomInvoiceStatus)).apply(this, arguments));
  }

  createClass(McomInvoiceStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        bank_account_number: 'bank_account_number',
        bank_code: 'bank_code',
        invoice_id: 'invoice_id',
        invoice_status: 'invoice_status',
        page_id: 'page_id',
        payment_method: 'payment_method',
        payment_type: 'payment_type',
        payout_amount: 'payout_amount',
        slip_verification_error: 'slip_verification_error',
        slip_verification_status: 'slip_verification_status',
        transaction_fee: 'transaction_fee',
        transfer_slip: 'transfer_slip'
      });
    }
  }]);
  return McomInvoiceStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * McomOnboardingStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var McomOnboardingStatus = function (_AbstractCrudObject) {
  inherits(McomOnboardingStatus, _AbstractCrudObject);

  function McomOnboardingStatus() {
    classCallCheck(this, McomOnboardingStatus);
    return possibleConstructorReturn(this, (McomOnboardingStatus.__proto__ || Object.getPrototypeOf(McomOnboardingStatus)).apply(this, arguments));
  }

  createClass(McomOnboardingStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        onboarding_status: 'onboarding_status',
        page_id: 'page_id'
      });
    }
  }]);
  return McomOnboardingStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * McomPayouts
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var McomPayouts = function (_AbstractCrudObject) {
  inherits(McomPayouts, _AbstractCrudObject);

  function McomPayouts() {
    classCallCheck(this, McomPayouts);
    return possibleConstructorReturn(this, (McomPayouts.__proto__ || Object.getPrototypeOf(McomPayouts)).apply(this, arguments));
  }

  createClass(McomPayouts, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        number_of_orders: 'number_of_orders',
        order_ids: 'order_ids',
        payout_amount: 'payout_amount',
        payout_provider_reference_id: 'payout_provider_reference_id',
        payout_status: 'payout_status',
        payout_time: 'payout_time',
        provider: 'provider'
      });
    }
  }]);
  return McomPayouts;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MeasurementReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MeasurementReport = function (_AbstractCrudObject) {
  inherits(MeasurementReport, _AbstractCrudObject);

  function MeasurementReport() {
    classCallCheck(this, MeasurementReport);
    return possibleConstructorReturn(this, (MeasurementReport.__proto__ || Object.getPrototypeOf(MeasurementReport)).apply(this, arguments));
  }

  createClass(MeasurementReport, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        download_urls: 'download_urls',
        id: 'id',
        metadata: 'metadata',
        report_type: 'report_type',
        status: 'status'
      });
    }
  }]);
  return MeasurementReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MediaCopyrightAttribution
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MediaCopyrightAttribution = function (_AbstractCrudObject) {
  inherits(MediaCopyrightAttribution, _AbstractCrudObject);

  function MediaCopyrightAttribution() {
    classCallCheck(this, MediaCopyrightAttribution);
    return possibleConstructorReturn(this, (MediaCopyrightAttribution.__proto__ || Object.getPrototypeOf(MediaCopyrightAttribution)).apply(this, arguments));
  }

  createClass(MediaCopyrightAttribution, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        attribution_ig_target_id: 'attribution_ig_target_id',
        attribution_target_email_address: 'attribution_target_email_address',
        attribution_target_id: 'attribution_target_id',
        attribution_target_name: 'attribution_target_name',
        attribution_type: 'attribution_type',
        attribution_uri: 'attribution_uri',
        copyright_count: 'copyright_count',
        creation_time: 'creation_time',
        creator: 'creator',
        id: 'id',
        is_enabled: 'is_enabled',
        link_title: 'link_title',
        match_count: 'match_count',
        owner: 'owner',
        status: 'status',
        title: 'title'
      });
    }
  }]);
  return MediaCopyrightAttribution;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MerchantCompliance
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MerchantCompliance = function (_AbstractCrudObject) {
  inherits(MerchantCompliance, _AbstractCrudObject);

  function MerchantCompliance() {
    classCallCheck(this, MerchantCompliance);
    return possibleConstructorReturn(this, (MerchantCompliance.__proto__ || Object.getPrototypeOf(MerchantCompliance)).apply(this, arguments));
  }

  createClass(MerchantCompliance, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        active_campaigns: 'active_campaigns',
        compliance_status: 'compliance_status',
        count_down_start_time: 'count_down_start_time',
        purchase: 'purchase',
        purchase_conversion_value: 'purchase_conversion_value'
      });
    }
  }]);
  return MerchantCompliance;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MerchantReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MerchantReport = function (_AbstractCrudObject) {
  inherits(MerchantReport, _AbstractCrudObject);

  function MerchantReport() {
    classCallCheck(this, MerchantReport);
    return possibleConstructorReturn(this, (MerchantReport.__proto__ || Object.getPrototypeOf(MerchantReport)).apply(this, arguments));
  }

  createClass(MerchantReport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        add_to_cart: 'add_to_cart',
        brand: 'brand',
        catalog_segment_id: 'catalog_segment_id',
        catalog_segment_purchase_value: 'catalog_segment_purchase_value',
        category: 'category',
        date: 'date',
        latest_date: 'latest_date',
        link_clicks: 'link_clicks',
        merchant_currency: 'merchant_currency',
        page_id: 'page_id',
        product_id: 'product_id',
        product_quantity: 'product_quantity',
        product_total_value: 'product_total_value',
        purchase: 'purchase',
        purchase_value: 'purchase_value'
      });
    }
  }]);
  return MerchantReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MessagingAppsInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MessagingAppsInfo = function (_AbstractCrudObject) {
  inherits(MessagingAppsInfo, _AbstractCrudObject);

  function MessagingAppsInfo() {
    classCallCheck(this, MessagingAppsInfo);
    return possibleConstructorReturn(this, (MessagingAppsInfo.__proto__ || Object.getPrototypeOf(MessagingAppsInfo)).apply(this, arguments));
  }

  createClass(MessagingAppsInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ctd_support_only_for_ig_app: 'ctd_support_only_for_ig_app',
        has_instagram_messaging_permission: 'has_instagram_messaging_permission',
        has_messenger_messaging_permission: 'has_messenger_messaging_permission',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return MessagingAppsInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MessagingFeatureStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MessagingFeatureStatus = function (_AbstractCrudObject) {
  inherits(MessagingFeatureStatus, _AbstractCrudObject);

  function MessagingFeatureStatus() {
    classCallCheck(this, MessagingFeatureStatus);
    return possibleConstructorReturn(this, (MessagingFeatureStatus.__proto__ || Object.getPrototypeOf(MessagingFeatureStatus)).apply(this, arguments));
  }

  createClass(MessagingFeatureStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        hop_v2: 'hop_v2',
        ig_multi_app: 'ig_multi_app',
        msgr_multi_app: 'msgr_multi_app'
      });
    }
  }]);
  return MessagingFeatureStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MessengerBusinessTemplate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MessengerBusinessTemplate = function (_AbstractCrudObject) {
  inherits(MessengerBusinessTemplate, _AbstractCrudObject);

  function MessengerBusinessTemplate() {
    classCallCheck(this, MessengerBusinessTemplate);
    return possibleConstructorReturn(this, (MessengerBusinessTemplate.__proto__ || Object.getPrototypeOf(MessengerBusinessTemplate)).apply(this, arguments));
  }

  createClass(MessengerBusinessTemplate, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        category: 'category',
        components: 'components',
        creation_time: 'creation_time',
        id: 'id',
        language: 'language',
        language_count: 'language_count',
        last_updated_time: 'last_updated_time',
        library_template_name: 'library_template_name',
        name: 'name',
        rejected_reason: 'rejected_reason',
        status: 'status'
      });
    }
  }]);
  return MessengerBusinessTemplate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MessengerDestinationPageWelcomeMessage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MessengerDestinationPageWelcomeMessage = function (_AbstractCrudObject) {
  inherits(MessengerDestinationPageWelcomeMessage, _AbstractCrudObject);

  function MessengerDestinationPageWelcomeMessage() {
    classCallCheck(this, MessengerDestinationPageWelcomeMessage);
    return possibleConstructorReturn(this, (MessengerDestinationPageWelcomeMessage.__proto__ || Object.getPrototypeOf(MessengerDestinationPageWelcomeMessage)).apply(this, arguments));
  }

  createClass(MessengerDestinationPageWelcomeMessage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        page_welcome_message_body: 'page_welcome_message_body',
        page_welcome_message_type: 'page_welcome_message_type',
        template_name: 'template_name',
        time_created: 'time_created',
        time_last_used: 'time_last_used'
      });
    }
  }]);
  return MessengerDestinationPageWelcomeMessage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MusicVideoCopyright
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MusicVideoCopyright = function (_AbstractCrudObject) {
  inherits(MusicVideoCopyright, _AbstractCrudObject);

  function MusicVideoCopyright() {
    classCallCheck(this, MusicVideoCopyright);
    return possibleConstructorReturn(this, (MusicVideoCopyright.__proto__ || Object.getPrototypeOf(MusicVideoCopyright)).apply(this, arguments));
  }

  createClass(MusicVideoCopyright, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        displayed_matches_count: 'displayed_matches_count',
        id: 'id',
        in_conflict: 'in_conflict',
        isrc: 'isrc',
        match_rule: 'match_rule',
        ownership_countries: 'ownership_countries',
        reference_file_status: 'reference_file_status',
        ridge_monitoring_status: 'ridge_monitoring_status',
        tags: 'tags',
        update_time: 'update_time',
        video_asset: 'video_asset',
        whitelisted_fb_users: 'whitelisted_fb_users',
        whitelisted_ig_users: 'whitelisted_ig_users'
      });
    }
  }]);
  return MusicVideoCopyright;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * MusicWorkCopyright
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var MusicWorkCopyright = function (_AbstractCrudObject) {
  inherits(MusicWorkCopyright, _AbstractCrudObject);

  function MusicWorkCopyright() {
    classCallCheck(this, MusicWorkCopyright);
    return possibleConstructorReturn(this, (MusicWorkCopyright.__proto__ || Object.getPrototypeOf(MusicWorkCopyright)).apply(this, arguments));
  }

  createClass(MusicWorkCopyright, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        available_ui_actions: 'available_ui_actions',
        claim_status: 'claim_status',
        creation_time: 'creation_time',
        displayed_fb_matches_count: 'displayed_fb_matches_count',
        displayed_ig_matches_count: 'displayed_ig_matches_count',
        displayed_matches_count: 'displayed_matches_count',
        id: 'id',
        match_rule: 'match_rule',
        status: 'status',
        tags: 'tags',
        update_time: 'update_time'
      });
    }
  }]);
  return MusicWorkCopyright;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OfflineConversionDataSetActivities
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OfflineConversionDataSetActivities = function (_AbstractCrudObject) {
  inherits(OfflineConversionDataSetActivities, _AbstractCrudObject);

  function OfflineConversionDataSetActivities() {
    classCallCheck(this, OfflineConversionDataSetActivities);
    return possibleConstructorReturn(this, (OfflineConversionDataSetActivities.__proto__ || Object.getPrototypeOf(OfflineConversionDataSetActivities)).apply(this, arguments));
  }

  createClass(OfflineConversionDataSetActivities, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actor_id: 'actor_id',
        actor_name: 'actor_name',
        adaccount_id: 'adaccount_id',
        adaccount_name: 'adaccount_name',
        event_time: 'event_time',
        event_type: 'event_type',
        extra_data: 'extra_data',
        object_id: 'object_id',
        object_name: 'object_name'
      });
    }
  }]);
  return OfflineConversionDataSetActivities;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OfflineConversionDataSetOptimizationStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OfflineConversionDataSetOptimizationStatus = function (_AbstractCrudObject) {
  inherits(OfflineConversionDataSetOptimizationStatus, _AbstractCrudObject);

  function OfflineConversionDataSetOptimizationStatus() {
    classCallCheck(this, OfflineConversionDataSetOptimizationStatus);
    return possibleConstructorReturn(this, (OfflineConversionDataSetOptimizationStatus.__proto__ || Object.getPrototypeOf(OfflineConversionDataSetOptimizationStatus)).apply(this, arguments));
  }

  createClass(OfflineConversionDataSetOptimizationStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        event: 'event',
        last_changed_time: 'last_changed_time',
        last_detected_time: 'last_detected_time',
        status: 'status'
      });
    }
  }]);
  return OfflineConversionDataSetOptimizationStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OfflineConversionDataSetPermissions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OfflineConversionDataSetPermissions = function (_AbstractCrudObject) {
  inherits(OfflineConversionDataSetPermissions, _AbstractCrudObject);

  function OfflineConversionDataSetPermissions() {
    classCallCheck(this, OfflineConversionDataSetPermissions);
    return possibleConstructorReturn(this, (OfflineConversionDataSetPermissions.__proto__ || Object.getPrototypeOf(OfflineConversionDataSetPermissions)).apply(this, arguments));
  }

  createClass(OfflineConversionDataSetPermissions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_edit: 'can_edit',
        can_edit_or_upload: 'can_edit_or_upload',
        can_upload: 'can_upload',
        should_block_vanilla_business_employee_access: 'should_block_vanilla_business_employee_access'
      });
    }
  }]);
  return OfflineConversionDataSetPermissions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OfflineConversionDataSetUsage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OfflineConversionDataSetUsage = function (_AbstractCrudObject) {
  inherits(OfflineConversionDataSetUsage, _AbstractCrudObject);

  function OfflineConversionDataSetUsage() {
    classCallCheck(this, OfflineConversionDataSetUsage);
    return possibleConstructorReturn(this, (OfflineConversionDataSetUsage.__proto__ || Object.getPrototypeOf(OfflineConversionDataSetUsage)).apply(this, arguments));
  }

  createClass(OfflineConversionDataSetUsage, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        num_lift_studies: 'num_lift_studies'
      });
    }
  }]);
  return OfflineConversionDataSetUsage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OfflineProductItem
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OfflineProductItem = function (_AbstractCrudObject) {
  inherits(OfflineProductItem, _AbstractCrudObject);

  function OfflineProductItem() {
    classCallCheck(this, OfflineProductItem);
    return possibleConstructorReturn(this, (OfflineProductItem.__proto__ || Object.getPrototypeOf(OfflineProductItem)).apply(this, arguments));
  }

  createClass(OfflineProductItem, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        applinks: 'applinks',
        brand: 'brand',
        category: 'category',
        category_specific_fields: 'category_specific_fields',
        currency: 'currency',
        description: 'description',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        image_url: 'image_url',
        images: 'images',
        name: 'name',
        offline_product_item_id: 'offline_product_item_id',
        price: 'price',
        sanitized_images: 'sanitized_images',
        url: 'url',
        visibility: 'visibility'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }]);
  return OfflineProductItem;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OfflineTermsOfService
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OfflineTermsOfService = function (_AbstractCrudObject) {
  inherits(OfflineTermsOfService, _AbstractCrudObject);

  function OfflineTermsOfService() {
    classCallCheck(this, OfflineTermsOfService);
    return possibleConstructorReturn(this, (OfflineTermsOfService.__proto__ || Object.getPrototypeOf(OfflineTermsOfService)).apply(this, arguments));
  }

  createClass(OfflineTermsOfService, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        accept_time: 'accept_time',
        id: 'id',
        signed_by_user: 'signed_by_user'
      });
    }
  }]);
  return OfflineTermsOfService;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OffsitePixel
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OffsitePixel = function (_AbstractCrudObject) {
  inherits(OffsitePixel, _AbstractCrudObject);

  function OffsitePixel() {
    classCallCheck(this, OffsitePixel);
    return possibleConstructorReturn(this, (OffsitePixel.__proto__ || Object.getPrototypeOf(OffsitePixel)).apply(this, arguments));
  }

  createClass(OffsitePixel, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creator: 'creator',
        id: 'id',
        js_pixel: 'js_pixel',
        last_firing_time: 'last_firing_time',
        name: 'name',
        tag: 'tag'
      });
    }
  }]);
  return OffsitePixel;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OpenGraphContext
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OpenGraphContext = function (_AbstractCrudObject) {
  inherits(OpenGraphContext, _AbstractCrudObject);

  function OpenGraphContext() {
    classCallCheck(this, OpenGraphContext);
    return possibleConstructorReturn(this, (OpenGraphContext.__proto__ || Object.getPrototypeOf(OpenGraphContext)).apply(this, arguments));
  }

  createClass(OpenGraphContext, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return OpenGraphContext;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OrderIDAttributions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OrderIDAttributions = function (_AbstractCrudObject) {
  inherits(OrderIDAttributions, _AbstractCrudObject);

  function OrderIDAttributions() {
    classCallCheck(this, OrderIDAttributions);
    return possibleConstructorReturn(this, (OrderIDAttributions.__proto__ || Object.getPrototypeOf(OrderIDAttributions)).apply(this, arguments));
  }

  createClass(OrderIDAttributions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        attribution_type: 'attribution_type',
        attributions: 'attributions',
        conversion_device: 'conversion_device',
        dataset_id: 'dataset_id',
        holdout_status: 'holdout_status',
        order_id: 'order_id',
        order_timestamp: 'order_timestamp',
        pixel_id: 'pixel_id'
      });
    }
  }]);
  return OrderIDAttributions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Organization
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Organization = function (_AbstractCrudObject) {
  inherits(Organization, _AbstractCrudObject);

  function Organization() {
    classCallCheck(this, Organization);
    return possibleConstructorReturn(this, (Organization.__proto__ || Object.getPrototypeOf(Organization)).apply(this, arguments));
  }

  createClass(Organization, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        hq_country: 'hq_country',
        id: 'id',
        legal_entity_name: 'legal_entity_name',
        master_bm_id: 'master_bm_id',
        owner_business: 'owner_business'
      });
    }
  }]);
  return Organization;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OutcomePredictionPoint
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OutcomePredictionPoint = function (_AbstractCrudObject) {
  inherits(OutcomePredictionPoint, _AbstractCrudObject);

  function OutcomePredictionPoint() {
    classCallCheck(this, OutcomePredictionPoint);
    return possibleConstructorReturn(this, (OutcomePredictionPoint.__proto__ || Object.getPrototypeOf(OutcomePredictionPoint)).apply(this, arguments));
  }

  createClass(OutcomePredictionPoint, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actions: 'actions',
        impressions: 'impressions',
        reach: 'reach',
        spend: 'spend'
      });
    }
  }]);
  return OutcomePredictionPoint;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * OwnedDomain
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var OwnedDomain = function (_AbstractCrudObject) {
  inherits(OwnedDomain, _AbstractCrudObject);

  function OwnedDomain() {
    classCallCheck(this, OwnedDomain);
    return possibleConstructorReturn(this, (OwnedDomain.__proto__ || Object.getPrototypeOf(OwnedDomain)).apply(this, arguments));
  }

  createClass(OwnedDomain, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        domain_name: 'domain_name',
        id: 'id',
        owner_business: 'owner_business',
        status: 'status',
        verification_code: 'verification_code'
      });
    }
  }]);
  return OwnedDomain;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * P2MInvoicePayments
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var P2MInvoicePayments = function (_AbstractCrudObject) {
  inherits(P2MInvoicePayments, _AbstractCrudObject);

  function P2MInvoicePayments() {
    classCallCheck(this, P2MInvoicePayments);
    return possibleConstructorReturn(this, (P2MInvoicePayments.__proto__ || Object.getPrototypeOf(P2MInvoicePayments)).apply(this, arguments));
  }

  createClass(P2MInvoicePayments, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        page_id: 'page_id',
        payments: 'payments'
      });
    }
  }]);
  return P2MInvoicePayments;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageAboutStoryComposedBlock
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageAboutStoryComposedBlock = function (_AbstractCrudObject) {
  inherits(PageAboutStoryComposedBlock, _AbstractCrudObject);

  function PageAboutStoryComposedBlock() {
    classCallCheck(this, PageAboutStoryComposedBlock);
    return possibleConstructorReturn(this, (PageAboutStoryComposedBlock.__proto__ || Object.getPrototypeOf(PageAboutStoryComposedBlock)).apply(this, arguments));
  }

  createClass(PageAboutStoryComposedBlock, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        depth: 'depth',
        entity_ranges: 'entity_ranges',
        inline_style_ranges: 'inline_style_ranges',
        text: 'text',
        type: 'type'
      });
    }
  }]);
  return PageAboutStoryComposedBlock;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageAboutStoryComposedBlockEntityRanges
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageAboutStoryComposedBlockEntityRanges = function (_AbstractCrudObject) {
  inherits(PageAboutStoryComposedBlockEntityRanges, _AbstractCrudObject);

  function PageAboutStoryComposedBlockEntityRanges() {
    classCallCheck(this, PageAboutStoryComposedBlockEntityRanges);
    return possibleConstructorReturn(this, (PageAboutStoryComposedBlockEntityRanges.__proto__ || Object.getPrototypeOf(PageAboutStoryComposedBlockEntityRanges)).apply(this, arguments));
  }

  createClass(PageAboutStoryComposedBlockEntityRanges, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        key: 'key',
        length: 'length',
        offset: 'offset'
      });
    }
  }]);
  return PageAboutStoryComposedBlockEntityRanges;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageAboutStoryComposedBlockInlineStyle
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageAboutStoryComposedBlockInlineStyle = function (_AbstractCrudObject) {
  inherits(PageAboutStoryComposedBlockInlineStyle, _AbstractCrudObject);

  function PageAboutStoryComposedBlockInlineStyle() {
    classCallCheck(this, PageAboutStoryComposedBlockInlineStyle);
    return possibleConstructorReturn(this, (PageAboutStoryComposedBlockInlineStyle.__proto__ || Object.getPrototypeOf(PageAboutStoryComposedBlockInlineStyle)).apply(this, arguments));
  }

  createClass(PageAboutStoryComposedBlockInlineStyle, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        length: 'length',
        offset: 'offset',
        style: 'style'
      });
    }
  }]);
  return PageAboutStoryComposedBlockInlineStyle;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageAppWithLeadsAccess
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageAppWithLeadsAccess = function (_AbstractCrudObject) {
  inherits(PageAppWithLeadsAccess, _AbstractCrudObject);

  function PageAppWithLeadsAccess() {
    classCallCheck(this, PageAppWithLeadsAccess);
    return possibleConstructorReturn(this, (PageAppWithLeadsAccess.__proto__ || Object.getPrototypeOf(PageAppWithLeadsAccess)).apply(this, arguments));
  }

  createClass(PageAppWithLeadsAccess, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_access_leads: 'can_access_leads',
        type: 'type'
      });
    }
  }]);
  return PageAppWithLeadsAccess;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageBroadcast
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageBroadcast = function (_AbstractCrudObject) {
  inherits(PageBroadcast, _AbstractCrudObject);

  function PageBroadcast() {
    classCallCheck(this, PageBroadcast);
    return possibleConstructorReturn(this, (PageBroadcast.__proto__ || Object.getPrototypeOf(PageBroadcast)).apply(this, arguments));
  }

  createClass(PageBroadcast, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        scheduled_time: 'scheduled_time',
        status: 'status'
      });
    }
  }]);
  return PageBroadcast;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageCTSTopic
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageCTSTopic = function (_AbstractCrudObject) {
  inherits(PageCTSTopic, _AbstractCrudObject);

  function PageCTSTopic() {
    classCallCheck(this, PageCTSTopic);
    return possibleConstructorReturn(this, (PageCTSTopic.__proto__ || Object.getPrototypeOf(PageCTSTopic)).apply(this, arguments));
  }

  createClass(PageCTSTopic, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        frequency: 'frequency',
        image_hash: 'image_hash',
        image_url: 'image_url',
        subscriber: 'subscriber',
        title: 'title'
      });
    }
  }]);
  return PageCTSTopic;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageCTXBudgetSimilarAdvertiserBudgetRecommendation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageCTXBudgetSimilarAdvertiserBudgetRecommendation = function (_AbstractCrudObject) {
  inherits(PageCTXBudgetSimilarAdvertiserBudgetRecommendation, _AbstractCrudObject);

  function PageCTXBudgetSimilarAdvertiserBudgetRecommendation() {
    classCallCheck(this, PageCTXBudgetSimilarAdvertiserBudgetRecommendation);
    return possibleConstructorReturn(this, (PageCTXBudgetSimilarAdvertiserBudgetRecommendation.__proto__ || Object.getPrototypeOf(PageCTXBudgetSimilarAdvertiserBudgetRecommendation)).apply(this, arguments));
  }

  createClass(PageCTXBudgetSimilarAdvertiserBudgetRecommendation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        budget: 'budget',
        reported_conversion: 'reported_conversion'
      });
    }
  }]);
  return PageCTXBudgetSimilarAdvertiserBudgetRecommendation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageCTXDefaultGreetingText
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageCTXDefaultGreetingText = function (_AbstractCrudObject) {
  inherits(PageCTXDefaultGreetingText, _AbstractCrudObject);

  function PageCTXDefaultGreetingText() {
    classCallCheck(this, PageCTXDefaultGreetingText);
    return possibleConstructorReturn(this, (PageCTXDefaultGreetingText.__proto__ || Object.getPrototypeOf(PageCTXDefaultGreetingText)).apply(this, arguments));
  }

  createClass(PageCTXDefaultGreetingText, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ctd: 'ctd',
        ctm: 'ctm',
        ctwa: 'ctwa'
      });
    }
  }]);
  return PageCTXDefaultGreetingText;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageCTXMessagingFeatureLimit
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageCTXMessagingFeatureLimit = function (_AbstractCrudObject) {
  inherits(PageCTXMessagingFeatureLimit, _AbstractCrudObject);

  function PageCTXMessagingFeatureLimit() {
    classCallCheck(this, PageCTXMessagingFeatureLimit);
    return possibleConstructorReturn(this, (PageCTXMessagingFeatureLimit.__proto__ || Object.getPrototypeOf(PageCTXMessagingFeatureLimit)).apply(this, arguments));
  }

  createClass(PageCTXMessagingFeatureLimit, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        messaging_feature_limit_duration: 'messaging_feature_limit_duration',
        messaging_feature_limit_type: 'messaging_feature_limit_type',
        messaging_violation_type: 'messaging_violation_type'
      });
    }
  }]);
  return PageCTXMessagingFeatureLimit;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageCategory
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageCategory = function (_AbstractCrudObject) {
  inherits(PageCategory, _AbstractCrudObject);

  function PageCategory() {
    classCallCheck(this, PageCategory);
    return possibleConstructorReturn(this, (PageCategory.__proto__ || Object.getPrototypeOf(PageCategory)).apply(this, arguments));
  }

  createClass(PageCategory, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        api_enum: 'api_enum',
        fb_page_categories: 'fb_page_categories',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return PageCategory;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageChangeProposal
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageChangeProposal = function (_AbstractCrudObject) {
  inherits(PageChangeProposal, _AbstractCrudObject);

  function PageChangeProposal() {
    classCallCheck(this, PageChangeProposal);
    return possibleConstructorReturn(this, (PageChangeProposal.__proto__ || Object.getPrototypeOf(PageChangeProposal)).apply(this, arguments));
  }

  createClass(PageChangeProposal, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        acceptance_status: 'acceptance_status',
        category: 'category',
        current_value: 'current_value',
        id: 'id',
        proposed_value: 'proposed_value',
        upcoming_change_info: 'upcoming_change_info'
      });
    }
  }]);
  return PageChangeProposal;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageCrmsWithLeadsAccess
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageCrmsWithLeadsAccess = function (_AbstractCrudObject) {
  inherits(PageCrmsWithLeadsAccess, _AbstractCrudObject);

  function PageCrmsWithLeadsAccess() {
    classCallCheck(this, PageCrmsWithLeadsAccess);
    return possibleConstructorReturn(this, (PageCrmsWithLeadsAccess.__proto__ || Object.getPrototypeOf(PageCrmsWithLeadsAccess)).apply(this, arguments));
  }

  createClass(PageCrmsWithLeadsAccess, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_access_leads: 'can_access_leads',
        id: 'id',
        integration_type: 'integration_type',
        name: 'name'
      });
    }
  }]);
  return PageCrmsWithLeadsAccess;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageDirectIntegrationCrmWithLeadsAccess
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageDirectIntegrationCrmWithLeadsAccess = function (_AbstractCrudObject) {
  inherits(PageDirectIntegrationCrmWithLeadsAccess, _AbstractCrudObject);

  function PageDirectIntegrationCrmWithLeadsAccess() {
    classCallCheck(this, PageDirectIntegrationCrmWithLeadsAccess);
    return possibleConstructorReturn(this, (PageDirectIntegrationCrmWithLeadsAccess.__proto__ || Object.getPrototypeOf(PageDirectIntegrationCrmWithLeadsAccess)).apply(this, arguments));
  }

  createClass(PageDirectIntegrationCrmWithLeadsAccess, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_access_leads: 'can_access_leads',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return PageDirectIntegrationCrmWithLeadsAccess;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageGameBotQuotaInformation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageGameBotQuotaInformation = function (_AbstractCrudObject) {
  inherits(PageGameBotQuotaInformation, _AbstractCrudObject);

  function PageGameBotQuotaInformation() {
    classCallCheck(this, PageGameBotQuotaInformation);
    return possibleConstructorReturn(this, (PageGameBotQuotaInformation.__proto__ || Object.getPrototypeOf(PageGameBotQuotaInformation)).apply(this, arguments));
  }

  createClass(PageGameBotQuotaInformation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        count: 'count',
        time_window: 'time_window'
      });
    }
  }]);
  return PageGameBotQuotaInformation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageGetStartedNullstate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageGetStartedNullstate = function (_AbstractCrudObject) {
  inherits(PageGetStartedNullstate, _AbstractCrudObject);

  function PageGetStartedNullstate() {
    classCallCheck(this, PageGetStartedNullstate);
    return possibleConstructorReturn(this, (PageGetStartedNullstate.__proto__ || Object.getPrototypeOf(PageGetStartedNullstate)).apply(this, arguments));
  }

  createClass(PageGetStartedNullstate, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        cta_title: 'cta_title',
        processed_greeting: 'processed_greeting',
        responsiveness: 'responsiveness'
      });
    }
  }]);
  return PageGetStartedNullstate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageInsightsAsyncExportRun
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageInsightsAsyncExportRun = function (_AbstractCrudObject) {
  inherits(PageInsightsAsyncExportRun, _AbstractCrudObject);

  function PageInsightsAsyncExportRun() {
    classCallCheck(this, PageInsightsAsyncExportRun);
    return possibleConstructorReturn(this, (PageInsightsAsyncExportRun.__proto__ || Object.getPrototypeOf(PageInsightsAsyncExportRun)).apply(this, arguments));
  }

  createClass(PageInsightsAsyncExportRun, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        data_level: 'data_level',
        filters: 'filters',
        format: 'format',
        gen_report_date: 'gen_report_date',
        id: 'id',
        report_end_date: 'report_end_date',
        report_start_date: 'report_start_date',
        sorters: 'sorters',
        status: 'status'
      });
    }
  }]);
  return PageInsightsAsyncExportRun;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageLeadsAccessConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageLeadsAccessConfig = function (_AbstractCrudObject) {
  inherits(PageLeadsAccessConfig, _AbstractCrudObject);

  function PageLeadsAccessConfig() {
    classCallCheck(this, PageLeadsAccessConfig);
    return possibleConstructorReturn(this, (PageLeadsAccessConfig.__proto__ || Object.getPrototypeOf(PageLeadsAccessConfig)).apply(this, arguments));
  }

  createClass(PageLeadsAccessConfig, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        page: 'page'
      });
    }
  }]);
  return PageLeadsAccessConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageLocationsBreakdown
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageLocationsBreakdown = function (_AbstractCrudObject) {
  inherits(PageLocationsBreakdown, _AbstractCrudObject);

  function PageLocationsBreakdown() {
    classCallCheck(this, PageLocationsBreakdown);
    return possibleConstructorReturn(this, (PageLocationsBreakdown.__proto__ || Object.getPrototypeOf(PageLocationsBreakdown)).apply(this, arguments));
  }

  createClass(PageLocationsBreakdown, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        location_id: 'location_id',
        location_name: 'location_name',
        location_type: 'location_type',
        num_pages: 'num_pages',
        num_pages_eligible_for_store_visit_reporting: 'num_pages_eligible_for_store_visit_reporting',
        num_unpublished_or_closed_pages: 'num_unpublished_or_closed_pages',
        parent_country_code: 'parent_country_code',
        parent_region_id: 'parent_region_id',
        parent_region_name: 'parent_region_name'
      });
    }
  }]);
  return PageLocationsBreakdown;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageMessageResponsivenessMetrics
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageMessageResponsivenessMetrics = function (_AbstractCrudObject) {
  inherits(PageMessageResponsivenessMetrics, _AbstractCrudObject);

  function PageMessageResponsivenessMetrics() {
    classCallCheck(this, PageMessageResponsivenessMetrics);
    return possibleConstructorReturn(this, (PageMessageResponsivenessMetrics.__proto__ || Object.getPrototypeOf(PageMessageResponsivenessMetrics)).apply(this, arguments));
  }

  createClass(PageMessageResponsivenessMetrics, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_very_responsive: 'is_very_responsive',
        response_rate: 'response_rate',
        response_time: 'response_time'
      });
    }
  }]);
  return PageMessageResponsivenessMetrics;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageParking
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageParking = function (_AbstractCrudObject) {
  inherits(PageParking, _AbstractCrudObject);

  function PageParking() {
    classCallCheck(this, PageParking);
    return possibleConstructorReturn(this, (PageParking.__proto__ || Object.getPrototypeOf(PageParking)).apply(this, arguments));
  }

  createClass(PageParking, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        lot: 'lot',
        street: 'street',
        valet: 'valet'
      });
    }
  }]);
  return PageParking;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PagePartnerWithLeadsAccess
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PagePartnerWithLeadsAccess = function (_AbstractCrudObject) {
  inherits(PagePartnerWithLeadsAccess, _AbstractCrudObject);

  function PagePartnerWithLeadsAccess() {
    classCallCheck(this, PagePartnerWithLeadsAccess);
    return possibleConstructorReturn(this, (PagePartnerWithLeadsAccess.__proto__ || Object.getPrototypeOf(PagePartnerWithLeadsAccess)).apply(this, arguments));
  }

  createClass(PagePartnerWithLeadsAccess, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_access_leads: 'can_access_leads',
        partner_business: 'partner_business',
        permitted_tasks: 'permitted_tasks'
      });
    }
  }]);
  return PagePartnerWithLeadsAccess;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PagePaymentOptions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PagePaymentOptions = function (_AbstractCrudObject) {
  inherits(PagePaymentOptions, _AbstractCrudObject);

  function PagePaymentOptions() {
    classCallCheck(this, PagePaymentOptions);
    return possibleConstructorReturn(this, (PagePaymentOptions.__proto__ || Object.getPrototypeOf(PagePaymentOptions)).apply(this, arguments));
  }

  createClass(PagePaymentOptions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amex: 'amex',
        cash_only: 'cash_only',
        discover: 'discover',
        mastercard: 'mastercard',
        visa: 'visa'
      });
    }
  }]);
  return PagePaymentOptions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PagePublisher
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PagePublisher = function (_AbstractCrudObject) {
  inherits(PagePublisher, _AbstractCrudObject);

  function PagePublisher() {
    classCallCheck(this, PagePublisher);
    return possibleConstructorReturn(this, (PagePublisher.__proto__ || Object.getPrototypeOf(PagePublisher)).apply(this, arguments));
  }

  createClass(PagePublisher, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        global_parent_id: 'global_parent_id',
        icon: 'icon',
        id: 'id',
        name: 'name',
        url: 'url'
      });
    }
  }]);
  return PagePublisher;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageRestaurantServices
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageRestaurantServices = function (_AbstractCrudObject) {
  inherits(PageRestaurantServices, _AbstractCrudObject);

  function PageRestaurantServices() {
    classCallCheck(this, PageRestaurantServices);
    return possibleConstructorReturn(this, (PageRestaurantServices.__proto__ || Object.getPrototypeOf(PageRestaurantServices)).apply(this, arguments));
  }

  createClass(PageRestaurantServices, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        catering: 'catering',
        delivery: 'delivery',
        groups: 'groups',
        kids: 'kids',
        outdoor: 'outdoor',
        pickup: 'pickup',
        reserve: 'reserve',
        takeout: 'takeout',
        waiter: 'waiter',
        walkins: 'walkins'
      });
    }
  }]);
  return PageRestaurantServices;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageRestaurantSpecialties
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageRestaurantSpecialties = function (_AbstractCrudObject) {
  inherits(PageRestaurantSpecialties, _AbstractCrudObject);

  function PageRestaurantSpecialties() {
    classCallCheck(this, PageRestaurantSpecialties);
    return possibleConstructorReturn(this, (PageRestaurantSpecialties.__proto__ || Object.getPrototypeOf(PageRestaurantSpecialties)).apply(this, arguments));
  }

  createClass(PageRestaurantSpecialties, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        breakfast: 'breakfast',
        coffee: 'coffee',
        dinner: 'dinner',
        drinks: 'drinks',
        lunch: 'lunch'
      });
    }
  }]);
  return PageRestaurantSpecialties;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageStartInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageStartInfo = function (_AbstractCrudObject) {
  inherits(PageStartInfo, _AbstractCrudObject);

  function PageStartInfo() {
    classCallCheck(this, PageStartInfo);
    return possibleConstructorReturn(this, (PageStartInfo.__proto__ || Object.getPrototypeOf(PageStartInfo)).apply(this, arguments));
  }

  createClass(PageStartInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        date: 'date',
        type: 'type'
      });
    }
  }]);
  return PageStartInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageUpcomingChange
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageUpcomingChange = function (_AbstractCrudObject) {
  inherits(PageUpcomingChange, _AbstractCrudObject);

  function PageUpcomingChange() {
    classCallCheck(this, PageUpcomingChange);
    return possibleConstructorReturn(this, (PageUpcomingChange.__proto__ || Object.getPrototypeOf(PageUpcomingChange)).apply(this, arguments));
  }

  createClass(PageUpcomingChange, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        change_type: 'change_type',
        effective_time: 'effective_time',
        id: 'id',
        page: 'page',
        proposal: 'proposal',
        timer_status: 'timer_status'
      });
    }
  }]);
  return PageUpcomingChange;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageUserPermissions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageUserPermissions = function (_AbstractCrudObject) {
  inherits(PageUserPermissions, _AbstractCrudObject);

  function PageUserPermissions() {
    classCallCheck(this, PageUserPermissions);
    return possibleConstructorReturn(this, (PageUserPermissions.__proto__ || Object.getPrototypeOf(PageUserPermissions)).apply(this, arguments));
  }

  createClass(PageUserPermissions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        business_persona: 'business_persona',
        created_by: 'created_by',
        created_time: 'created_time',
        email: 'email',
        status: 'status',
        tasks: 'tasks',
        updated_by: 'updated_by',
        updated_time: 'updated_time',
        user: 'user'
      });
    }
  }]);
  return PageUserPermissions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PageUserWithLeadsAccess
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PageUserWithLeadsAccess = function (_AbstractCrudObject) {
  inherits(PageUserWithLeadsAccess, _AbstractCrudObject);

  function PageUserWithLeadsAccess() {
    classCallCheck(this, PageUserWithLeadsAccess);
    return possibleConstructorReturn(this, (PageUserWithLeadsAccess.__proto__ || Object.getPrototypeOf(PageUserWithLeadsAccess)).apply(this, arguments));
  }

  createClass(PageUserWithLeadsAccess, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        active_on_business: 'active_on_business',
        business_role: 'business_role',
        can_access_leads: 'can_access_leads',
        page_role: 'page_role'
      });
    }
  }]);
  return PageUserWithLeadsAccess;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ParentCatalogReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ParentCatalogReport = function (_AbstractCrudObject) {
  inherits(ParentCatalogReport, _AbstractCrudObject);

  function ParentCatalogReport() {
    classCallCheck(this, ParentCatalogReport);
    return possibleConstructorReturn(this, (ParentCatalogReport.__proto__ || Object.getPrototypeOf(ParentCatalogReport)).apply(this, arguments));
  }

  createClass(ParentCatalogReport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        purchase_conversion_value: 'purchase_conversion_value',
        purchases: 'purchases'
      });
    }
  }]);
  return ParentCatalogReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PartnerCategory
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PartnerCategory = function (_AbstractCrudObject) {
  inherits(PartnerCategory, _AbstractCrudObject);

  function PartnerCategory() {
    classCallCheck(this, PartnerCategory);
    return possibleConstructorReturn(this, (PartnerCategory.__proto__ || Object.getPrototypeOf(PartnerCategory)).apply(this, arguments));
  }

  createClass(PartnerCategory, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        approximate_count: 'approximate_count',
        country: 'country',
        description: 'description',
        details: 'details',
        id: 'id',
        is_private: 'is_private',
        name: 'name',
        parent_category: 'parent_category',
        source: 'source',
        status: 'status',
        targeting_type: 'targeting_type'
      });
    }
  }]);
  return PartnerCategory;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PartnerIntegrationLinked
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PartnerIntegrationLinked = function (_AbstractCrudObject) {
  inherits(PartnerIntegrationLinked, _AbstractCrudObject);

  function PartnerIntegrationLinked() {
    classCallCheck(this, PartnerIntegrationLinked);
    return possibleConstructorReturn(this, (PartnerIntegrationLinked.__proto__ || Object.getPrototypeOf(PartnerIntegrationLinked)).apply(this, arguments));
  }

  createClass(PartnerIntegrationLinked, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ads_pixel: 'ads_pixel',
        application: 'application',
        completed_integration_types: 'completed_integration_types',
        external_business_connection_id: 'external_business_connection_id',
        external_id: 'external_id',
        has_oauth_token: 'has_oauth_token',
        id: 'id',
        mbe_app_id: 'mbe_app_id',
        mbe_asset_id: 'mbe_asset_id',
        mbe_external_business_id: 'mbe_external_business_id',
        name: 'name',
        offline_conversion_data_set: 'offline_conversion_data_set',
        page: 'page',
        partner: 'partner',
        product_catalog: 'product_catalog',
        setup_status: 'setup_status'
      });
    }
  }]);
  return PartnerIntegrationLinked;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PartnershipAdContentSearchMedia
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PartnershipAdContentSearchMedia = function (_AbstractCrudObject) {
  inherits(PartnershipAdContentSearchMedia, _AbstractCrudObject);

  function PartnershipAdContentSearchMedia() {
    classCallCheck(this, PartnershipAdContentSearchMedia);
    return possibleConstructorReturn(this, (PartnershipAdContentSearchMedia.__proto__ || Object.getPrototypeOf(PartnershipAdContentSearchMedia)).apply(this, arguments));
  }

  createClass(PartnershipAdContentSearchMedia, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ig_ad_code_sponsor_count: 'ig_ad_code_sponsor_count',
        ig_ad_code_sponsors: 'ig_ad_code_sponsors',
        ig_media: 'ig_media',
        ig_media_has_product_tags: 'ig_media_has_product_tags',
        is_ad_code_eligible_for_boosting_by_two_sponsors: 'is_ad_code_eligible_for_boosting_by_two_sponsors',
        is_ad_code_entry: 'is_ad_code_entry'
      });
    }
  }]);
  return PartnershipAdContentSearchMedia;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PartnershipAdsIdentity
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PartnershipAdsIdentity = function (_AbstractCrudObject) {
  inherits(PartnershipAdsIdentity, _AbstractCrudObject);

  function PartnershipAdsIdentity() {
    classCallCheck(this, PartnershipAdsIdentity);
    return possibleConstructorReturn(this, (PartnershipAdsIdentity.__proto__ || Object.getPrototypeOf(PartnershipAdsIdentity)).apply(this, arguments));
  }

  createClass(PartnershipAdsIdentity, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        post_types: 'post_types',
        secondary_identities: 'secondary_identities'
      });
    }
  }]);
  return PartnershipAdsIdentity;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PaymentPricepoints
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PaymentPricepoints = function (_AbstractCrudObject) {
  inherits(PaymentPricepoints, _AbstractCrudObject);

  function PaymentPricepoints() {
    classCallCheck(this, PaymentPricepoints);
    return possibleConstructorReturn(this, (PaymentPricepoints.__proto__ || Object.getPrototypeOf(PaymentPricepoints)).apply(this, arguments));
  }

  createClass(PaymentPricepoints, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        mobile: 'mobile'
      });
    }
  }]);
  return PaymentPricepoints;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PaymentRequestDetails
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PaymentRequestDetails = function (_AbstractCrudObject) {
  inherits(PaymentRequestDetails, _AbstractCrudObject);

  function PaymentRequestDetails() {
    classCallCheck(this, PaymentRequestDetails);
    return possibleConstructorReturn(this, (PaymentRequestDetails.__proto__ || Object.getPrototypeOf(PaymentRequestDetails)).apply(this, arguments));
  }

  createClass(PaymentRequestDetails, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount: 'amount',
        creation_time: 'creation_time',
        note: 'note',
        payment_request_id: 'payment_request_id',
        receiver_id: 'receiver_id',
        reference_number: 'reference_number',
        sender_id: 'sender_id',
        status: 'status',
        transaction_time: 'transaction_time'
      });
    }
  }]);
  return PaymentRequestDetails;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PaymentSubscription
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PaymentSubscription = function (_AbstractCrudObject) {
  inherits(PaymentSubscription, _AbstractCrudObject);

  function PaymentSubscription() {
    classCallCheck(this, PaymentSubscription);
    return possibleConstructorReturn(this, (PaymentSubscription.__proto__ || Object.getPrototypeOf(PaymentSubscription)).apply(this, arguments));
  }

  createClass(PaymentSubscription, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        amount: 'amount',
        app_param_data: 'app_param_data',
        application: 'application',
        billing_period: 'billing_period',
        canceled_reason: 'canceled_reason',
        created_time: 'created_time',
        currency: 'currency',
        id: 'id',
        last_payment: 'last_payment',
        next_bill_time: 'next_bill_time',
        next_period_amount: 'next_period_amount',
        next_period_currency: 'next_period_currency',
        next_period_product: 'next_period_product',
        payment_status: 'payment_status',
        pending_cancel: 'pending_cancel',
        period_start_time: 'period_start_time',
        product: 'product',
        status: 'status',
        test: 'test',
        trial_amount: 'trial_amount',
        trial_currency: 'trial_currency',
        trial_expiry_time: 'trial_expiry_time',
        updated_time: 'updated_time',
        user: 'user'
      });
    }
  }]);
  return PaymentSubscription;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PersonalAdsPersona
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PersonalAdsPersona = function (_AbstractCrudObject) {
  inherits(PersonalAdsPersona, _AbstractCrudObject);

  function PersonalAdsPersona() {
    classCallCheck(this, PersonalAdsPersona);
    return possibleConstructorReturn(this, (PersonalAdsPersona.__proto__ || Object.getPrototypeOf(PersonalAdsPersona)).apply(this, arguments));
  }

  createClass(PersonalAdsPersona, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        email: 'email',
        first_name: 'first_name',
        id: 'id',
        last_name: 'last_name',
        pending_email: 'pending_email'
      });
    }
  }]);
  return PersonalAdsPersona;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PhotoMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PhotoMetadata = function (_AbstractCrudObject) {
  inherits(PhotoMetadata, _AbstractCrudObject);

  function PhotoMetadata() {
    classCallCheck(this, PhotoMetadata);
    return possibleConstructorReturn(this, (PhotoMetadata.__proto__ || Object.getPrototypeOf(PhotoMetadata)).apply(this, arguments));
  }

  createClass(PhotoMetadata, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        camera_make: 'camera_make',
        camera_model: 'camera_model',
        datetime_modified: 'datetime_modified',
        datetime_taken: 'datetime_taken',
        exposure: 'exposure',
        focal_length: 'focal_length',
        fstop: 'fstop',
        iso_speed: 'iso_speed',
        offline_id: 'offline_id',
        orientation: 'orientation',
        original_height: 'original_height',
        original_width: 'original_width'
      });
    }
  }]);
  return PhotoMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Place
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Place = function (_AbstractCrudObject) {
  inherits(Place, _AbstractCrudObject);

  function Place() {
    classCallCheck(this, Place);
    return possibleConstructorReturn(this, (Place.__proto__ || Object.getPrototypeOf(Place)).apply(this, arguments));
  }

  createClass(Place, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        location: 'location',
        name: 'name',
        overall_rating: 'overall_rating'
      });
    }
  }]);
  return Place;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PlaceTag
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PlaceTag = function (_AbstractCrudObject) {
  inherits(PlaceTag, _AbstractCrudObject);

  function PlaceTag() {
    classCallCheck(this, PlaceTag);
    return possibleConstructorReturn(this, (PlaceTag.__proto__ || Object.getPrototypeOf(PlaceTag)).apply(this, arguments));
  }

  createClass(PlaceTag, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        created_time: 'created_time',
        id: 'id',
        place: 'place'
      });
    }
  }]);
  return PlaceTag;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PlaceTopic
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PlaceTopic = function (_AbstractCrudObject) {
  inherits(PlaceTopic, _AbstractCrudObject);

  function PlaceTopic() {
    classCallCheck(this, PlaceTopic);
    return possibleConstructorReturn(this, (PlaceTopic.__proto__ || Object.getPrototypeOf(PlaceTopic)).apply(this, arguments));
  }

  createClass(PlaceTopic, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        count: 'count',
        has_children: 'has_children',
        icon_url: 'icon_url',
        id: 'id',
        name: 'name',
        parent_ids: 'parent_ids',
        plural_name: 'plural_name',
        top_subtopic_names: 'top_subtopic_names'
      });
    }
  }]);
  return PlaceTopic;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Placement
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Placement = function (_AbstractCrudObject) {
  inherits(Placement, _AbstractCrudObject);

  function Placement() {
    classCallCheck(this, Placement);
    return possibleConstructorReturn(this, (Placement.__proto__ || Object.getPrototypeOf(Placement)).apply(this, arguments));
  }

  createClass(Placement, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        audience_network_positions: 'audience_network_positions',
        device_platforms: 'device_platforms',
        effective_audience_network_positions: 'effective_audience_network_positions',
        effective_device_platforms: 'effective_device_platforms',
        effective_facebook_positions: 'effective_facebook_positions',
        effective_instagram_positions: 'effective_instagram_positions',
        effective_messenger_positions: 'effective_messenger_positions',
        effective_oculus_positions: 'effective_oculus_positions',
        effective_publisher_platforms: 'effective_publisher_platforms',
        effective_threads_positions: 'effective_threads_positions',
        effective_whatsapp_positions: 'effective_whatsapp_positions',
        facebook_positions: 'facebook_positions',
        instagram_positions: 'instagram_positions',
        messenger_positions: 'messenger_positions',
        oculus_positions: 'oculus_positions',
        publisher_platforms: 'publisher_platforms',
        threads_positions: 'threads_positions',
        whatsapp_positions: 'whatsapp_positions'
      });
    }
  }, {
    key: 'DevicePlatforms',
    get: function get() {
      return Object.freeze({
        desktop: 'desktop',
        mobile: 'mobile'
      });
    }
  }, {
    key: 'EffectiveDevicePlatforms',
    get: function get() {
      return Object.freeze({
        desktop: 'desktop',
        mobile: 'mobile'
      });
    }
  }]);
  return Placement;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PlatformImageSource
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PlatformImageSource = function (_AbstractCrudObject) {
  inherits(PlatformImageSource, _AbstractCrudObject);

  function PlatformImageSource() {
    classCallCheck(this, PlatformImageSource);
    return possibleConstructorReturn(this, (PlatformImageSource.__proto__ || Object.getPrototypeOf(PlatformImageSource)).apply(this, arguments));
  }

  createClass(PlatformImageSource, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        height: 'height',
        source: 'source',
        width: 'width'
      });
    }
  }]);
  return PlatformImageSource;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PlatformSessionKey
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PlatformSessionKey = function (_AbstractCrudObject) {
  inherits(PlatformSessionKey, _AbstractCrudObject);

  function PlatformSessionKey() {
    classCallCheck(this, PlatformSessionKey);
    return possibleConstructorReturn(this, (PlatformSessionKey.__proto__ || Object.getPrototypeOf(PlatformSessionKey)).apply(this, arguments));
  }

  createClass(PlatformSessionKey, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return PlatformSessionKey;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PreapprovalReview
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PreapprovalReview = function (_AbstractCrudObject) {
  inherits(PreapprovalReview, _AbstractCrudObject);

  function PreapprovalReview() {
    classCallCheck(this, PreapprovalReview);
    return possibleConstructorReturn(this, (PreapprovalReview.__proto__ || Object.getPrototypeOf(PreapprovalReview)).apply(this, arguments));
  }

  createClass(PreapprovalReview, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        comp_type: 'comp_type',
        crow_component_id: 'crow_component_id',
        is_human_reviewed: 'is_human_reviewed',
        is_reviewed: 'is_reviewed',
        policy_info: 'policy_info'
      });
    }
  }]);
  return PreapprovalReview;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PremiumMusicVideo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PremiumMusicVideo = function (_AbstractCrudObject) {
  inherits(PremiumMusicVideo, _AbstractCrudObject);

  function PremiumMusicVideo() {
    classCallCheck(this, PremiumMusicVideo);
    return possibleConstructorReturn(this, (PremiumMusicVideo.__proto__ || Object.getPrototypeOf(PremiumMusicVideo)).apply(this, arguments));
  }

  createClass(PremiumMusicVideo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        cross_post_videos: 'cross_post_videos',
        eligible_cross_post_pages: 'eligible_cross_post_pages',
        id: 'id',
        preferred_video_thumbnail_image_uri: 'preferred_video_thumbnail_image_uri',
        premium_music_video_metadata: 'premium_music_video_metadata',
        scheduled_publish_time: 'scheduled_publish_time',
        title: 'title'
      });
    }
  }]);
  return PremiumMusicVideo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Privacy
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Privacy = function (_AbstractCrudObject) {
  inherits(Privacy, _AbstractCrudObject);

  function Privacy() {
    classCallCheck(this, Privacy);
    return possibleConstructorReturn(this, (Privacy.__proto__ || Object.getPrototypeOf(Privacy)).apply(this, arguments));
  }

  createClass(Privacy, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        allow: 'allow',
        deny: 'deny',
        description: 'description',
        friends: 'friends',
        networks: 'networks',
        value: 'value'
      });
    }
  }]);
  return Privacy;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PrivacyOption
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PrivacyOption = function (_AbstractCrudObject) {
  inherits(PrivacyOption, _AbstractCrudObject);

  function PrivacyOption() {
    classCallCheck(this, PrivacyOption);
    return possibleConstructorReturn(this, (PrivacyOption.__proto__ || Object.getPrototypeOf(PrivacyOption)).apply(this, arguments));
  }

  createClass(PrivacyOption, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        icon_src: 'icon_src',
        id: 'id',
        is_currently_selected: 'is_currently_selected',
        type: 'type',
        user_id: 'user_id'
      });
    }
  }]);
  return PrivacyOption;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PrivateComputationEnvironment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PrivateComputationEnvironment = function (_AbstractCrudObject) {
  inherits(PrivateComputationEnvironment, _AbstractCrudObject);

  function PrivateComputationEnvironment() {
    classCallCheck(this, PrivateComputationEnvironment);
    return possibleConstructorReturn(this, (PrivateComputationEnvironment.__proto__ || Object.getPrototypeOf(PrivateComputationEnvironment)).apply(this, arguments));
  }

  createClass(PrivateComputationEnvironment, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        publisher_account_id: 'publisher_account_id',
        publisher_pce_deployment_status: 'publisher_pce_deployment_status',
        publisher_pce_id: 'publisher_pce_id',
        publisher_region: 'publisher_region',
        publisher_vpc_id: 'publisher_vpc_id',
        id: 'id'
      });
    }
  }]);
  return PrivateComputationEnvironment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogFacets
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogFacets = function (_AbstractCrudObject) {
  inherits(ProductCatalogFacets, _AbstractCrudObject);

  function ProductCatalogFacets() {
    classCallCheck(this, ProductCatalogFacets);
    return possibleConstructorReturn(this, (ProductCatalogFacets.__proto__ || Object.getPrototypeOf(ProductCatalogFacets)).apply(this, arguments));
  }

  createClass(ProductCatalogFacets, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        facets: 'facets',
        item_count: 'item_count'
      });
    }
  }]);
  return ProductCatalogFacets;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogImageSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogImageSettings = function (_AbstractCrudObject) {
  inherits(ProductCatalogImageSettings, _AbstractCrudObject);

  function ProductCatalogImageSettings() {
    classCallCheck(this, ProductCatalogImageSettings);
    return possibleConstructorReturn(this, (ProductCatalogImageSettings.__proto__ || Object.getPrototypeOf(ProductCatalogImageSettings)).apply(this, arguments));
  }

  createClass(ProductCatalogImageSettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        carousel_ad: 'carousel_ad',
        single_ad: 'single_ad'
      });
    }
  }]);
  return ProductCatalogImageSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogImageSettingsInternal
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogImageSettingsInternal = function (_AbstractCrudObject) {
  inherits(ProductCatalogImageSettingsInternal, _AbstractCrudObject);

  function ProductCatalogImageSettingsInternal() {
    classCallCheck(this, ProductCatalogImageSettingsInternal);
    return possibleConstructorReturn(this, (ProductCatalogImageSettingsInternal.__proto__ || Object.getPrototypeOf(ProductCatalogImageSettingsInternal)).apply(this, arguments));
  }

  createClass(ProductCatalogImageSettingsInternal, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        carousel_ad: 'carousel_ad',
        shops_pdp: 'shops_pdp',
        single_ad: 'single_ad'
      });
    }
  }]);
  return ProductCatalogImageSettingsInternal;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogImageSettingsOperation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogImageSettingsOperation = function (_AbstractCrudObject) {
  inherits(ProductCatalogImageSettingsOperation, _AbstractCrudObject);

  function ProductCatalogImageSettingsOperation() {
    classCallCheck(this, ProductCatalogImageSettingsOperation);
    return possibleConstructorReturn(this, (ProductCatalogImageSettingsOperation.__proto__ || Object.getPrototypeOf(ProductCatalogImageSettingsOperation)).apply(this, arguments));
  }

  createClass(ProductCatalogImageSettingsOperation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        transformation_type: 'transformation_type'
      });
    }
  }]);
  return ProductCatalogImageSettingsOperation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogLocalizationSettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogLocalizationSettings = function (_AbstractCrudObject) {
  inherits(ProductCatalogLocalizationSettings, _AbstractCrudObject);

  function ProductCatalogLocalizationSettings() {
    classCallCheck(this, ProductCatalogLocalizationSettings);
    return possibleConstructorReturn(this, (ProductCatalogLocalizationSettings.__proto__ || Object.getPrototypeOf(ProductCatalogLocalizationSettings)).apply(this, arguments));
  }

  createClass(ProductCatalogLocalizationSettings, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        default_country: 'default_country',
        default_language: 'default_language',
        id: 'id'
      });
    }
  }]);
  return ProductCatalogLocalizationSettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogUserActions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogUserActions = function (_AbstractCrudObject) {
  inherits(ProductCatalogUserActions, _AbstractCrudObject);

  function ProductCatalogUserActions() {
    classCallCheck(this, ProductCatalogUserActions);
    return possibleConstructorReturn(this, (ProductCatalogUserActions.__proto__ || Object.getPrototypeOf(ProductCatalogUserActions)).apply(this, arguments));
  }

  createClass(ProductCatalogUserActions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        actions: 'actions'
      });
    }
  }]);
  return ProductCatalogUserActions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogUserPermissions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogUserPermissions = function (_AbstractCrudObject) {
  inherits(ProductCatalogUserPermissions, _AbstractCrudObject);

  function ProductCatalogUserPermissions() {
    classCallCheck(this, ProductCatalogUserPermissions);
    return possibleConstructorReturn(this, (ProductCatalogUserPermissions.__proto__ || Object.getPrototypeOf(ProductCatalogUserPermissions)).apply(this, arguments));
  }

  createClass(ProductCatalogUserPermissions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        business_persona: 'business_persona',
        created_by: 'created_by',
        created_time: 'created_time',
        email: 'email',
        role: 'role',
        status: 'status',
        updated_by: 'updated_by',
        updated_time: 'updated_time',
        user: 'user'
      });
    }
  }]);
  return ProductCatalogUserPermissions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductCatalogUserTasks
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductCatalogUserTasks = function (_AbstractCrudObject) {
  inherits(ProductCatalogUserTasks, _AbstractCrudObject);

  function ProductCatalogUserTasks() {
    classCallCheck(this, ProductCatalogUserTasks);
    return possibleConstructorReturn(this, (ProductCatalogUserTasks.__proto__ || Object.getPrototypeOf(ProductCatalogUserTasks)).apply(this, arguments));
  }

  createClass(ProductCatalogUserTasks, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business: 'business',
        tasks: 'tasks'
      });
    }
  }]);
  return ProductCatalogUserTasks;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductDaEventSamplesBatch
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductDaEventSamplesBatch = function (_AbstractCrudObject) {
  inherits(ProductDaEventSamplesBatch, _AbstractCrudObject);

  function ProductDaEventSamplesBatch() {
    classCallCheck(this, ProductDaEventSamplesBatch);
    return possibleConstructorReturn(this, (ProductDaEventSamplesBatch.__proto__ || Object.getPrototypeOf(ProductDaEventSamplesBatch)).apply(this, arguments));
  }

  createClass(ProductDaEventSamplesBatch, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        samples: 'samples',
        time_start: 'time_start',
        time_stop: 'time_stop'
      });
    }
  }]);
  return ProductDaEventSamplesBatch;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductDeliveryPreference
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductDeliveryPreference = function (_AbstractCrudObject) {
  inherits(ProductDeliveryPreference, _AbstractCrudObject);

  function ProductDeliveryPreference() {
    classCallCheck(this, ProductDeliveryPreference);
    return possibleConstructorReturn(this, (ProductDeliveryPreference.__proto__ || Object.getPrototypeOf(ProductDeliveryPreference)).apply(this, arguments));
  }

  createClass(ProductDeliveryPreference, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_object_id: 'ad_object_id',
        id: 'id',
        product_priority: 'product_priority',
        product_priority_category: 'product_priority_category'
      });
    }
  }]);
  return ProductDeliveryPreference;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeedRulePreviewSample
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeedRulePreviewSample = function (_AbstractCrudObject) {
  inherits(ProductFeedRulePreviewSample, _AbstractCrudObject);

  function ProductFeedRulePreviewSample() {
    classCallCheck(this, ProductFeedRulePreviewSample);
    return possibleConstructorReturn(this, (ProductFeedRulePreviewSample.__proto__ || Object.getPrototypeOf(ProductFeedRulePreviewSample)).apply(this, arguments));
  }

  createClass(ProductFeedRulePreviewSample, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        properties_after: 'properties_after',
        properties_before: 'properties_before'
      });
    }
  }]);
  return ProductFeedRulePreviewSample;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeedUploadErrorReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeedUploadErrorReport = function (_AbstractCrudObject) {
  inherits(ProductFeedUploadErrorReport, _AbstractCrudObject);

  function ProductFeedUploadErrorReport() {
    classCallCheck(this, ProductFeedUploadErrorReport);
    return possibleConstructorReturn(this, (ProductFeedUploadErrorReport.__proto__ || Object.getPrototypeOf(ProductFeedUploadErrorReport)).apply(this, arguments));
  }

  createClass(ProductFeedUploadErrorReport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        file_handle: 'file_handle',
        report_status: 'report_status'
      });
    }
  }]);
  return ProductFeedUploadErrorReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductFeedUploadProgress
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductFeedUploadProgress = function (_AbstractCrudObject) {
  inherits(ProductFeedUploadProgress, _AbstractCrudObject);

  function ProductFeedUploadProgress() {
    classCallCheck(this, ProductFeedUploadProgress);
    return possibleConstructorReturn(this, (ProductFeedUploadProgress.__proto__ || Object.getPrototypeOf(ProductFeedUploadProgress)).apply(this, arguments));
  }

  createClass(ProductFeedUploadProgress, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        pos: 'pos',
        size: 'size',
        step: 'step',
        unit: 'unit',
        updated_time: 'updated_time'
      });
    }
  }]);
  return ProductFeedUploadProgress;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemCommerceInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemCommerceInsights = function (_AbstractCrudObject) {
  inherits(ProductItemCommerceInsights, _AbstractCrudObject);

  function ProductItemCommerceInsights() {
    classCallCheck(this, ProductItemCommerceInsights);
    return possibleConstructorReturn(this, (ProductItemCommerceInsights.__proto__ || Object.getPrototypeOf(ProductItemCommerceInsights)).apply(this, arguments));
  }

  createClass(ProductItemCommerceInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        message_sends: 'message_sends',
        organic_impressions: 'organic_impressions',
        paid_impressions: 'paid_impressions'
      });
    }
  }]);
  return ProductItemCommerceInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemError
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemError = function (_AbstractCrudObject) {
  inherits(ProductItemError, _AbstractCrudObject);

  function ProductItemError() {
    classCallCheck(this, ProductItemError);
    return possibleConstructorReturn(this, (ProductItemError.__proto__ || Object.getPrototypeOf(ProductItemError)).apply(this, arguments));
  }

  createClass(ProductItemError, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        error_priority: 'error_priority',
        error_type: 'error_type',
        title: 'title'
      });
    }
  }]);
  return ProductItemError;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemImporterAddress
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemImporterAddress = function (_AbstractCrudObject) {
  inherits(ProductItemImporterAddress, _AbstractCrudObject);

  function ProductItemImporterAddress() {
    classCallCheck(this, ProductItemImporterAddress);
    return possibleConstructorReturn(this, (ProductItemImporterAddress.__proto__ || Object.getPrototypeOf(ProductItemImporterAddress)).apply(this, arguments));
  }

  createClass(ProductItemImporterAddress, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        city: 'city',
        country: 'country',
        postal_code: 'postal_code',
        region: 'region',
        street1: 'street1',
        street2: 'street2'
      });
    }
  }]);
  return ProductItemImporterAddress;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemInsights = function (_AbstractCrudObject) {
  inherits(ProductItemInsights, _AbstractCrudObject);

  function ProductItemInsights() {
    classCallCheck(this, ProductItemInsights);
    return possibleConstructorReturn(this, (ProductItemInsights.__proto__ || Object.getPrototypeOf(ProductItemInsights)).apply(this, arguments));
  }

  createClass(ProductItemInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_click_count: 'ad_click_count',
        ad_impression_count: 'ad_impression_count',
        add_to_cart_count: 'add_to_cart_count',
        purchase_count: 'purchase_count',
        view_content_count: 'view_content_count'
      });
    }
  }]);
  return ProductItemInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemInvalidationError
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemInvalidationError = function (_AbstractCrudObject) {
  inherits(ProductItemInvalidationError, _AbstractCrudObject);

  function ProductItemInvalidationError() {
    classCallCheck(this, ProductItemInvalidationError);
    return possibleConstructorReturn(this, (ProductItemInvalidationError.__proto__ || Object.getPrototypeOf(ProductItemInvalidationError)).apply(this, arguments));
  }

  createClass(ProductItemInvalidationError, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return ProductItemInvalidationError;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemLandingPageData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemLandingPageData = function (_AbstractCrudObject) {
  inherits(ProductItemLandingPageData, _AbstractCrudObject);

  function ProductItemLandingPageData() {
    classCallCheck(this, ProductItemLandingPageData);
    return possibleConstructorReturn(this, (ProductItemLandingPageData.__proto__ || Object.getPrototypeOf(ProductItemLandingPageData)).apply(this, arguments));
  }

  createClass(ProductItemLandingPageData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        availability: 'availability'
      });
    }
  }, {
    key: 'Availability',
    get: function get() {
      return Object.freeze({
        available_for_order: 'available for order',
        discontinued: 'discontinued',
        in_stock: 'in stock',
        mark_as_sold: 'mark_as_sold',
        out_of_stock: 'out of stock',
        pending: 'pending',
        preorder: 'preorder'
      });
    }
  }]);
  return ProductItemLandingPageData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemLocalInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemLocalInfo = function (_AbstractCrudObject) {
  inherits(ProductItemLocalInfo, _AbstractCrudObject);

  function ProductItemLocalInfo() {
    classCallCheck(this, ProductItemLocalInfo);
    return possibleConstructorReturn(this, (ProductItemLocalInfo.__proto__ || Object.getPrototypeOf(ProductItemLocalInfo)).apply(this, arguments));
  }

  createClass(ProductItemLocalInfo, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        availability_circle_origin: 'availability_circle_origin',
        availability_circle_radius: 'availability_circle_radius',
        availability_circle_radius_unit: 'availability_circle_radius_unit',
        availability_polygon_coordinates: 'availability_polygon_coordinates',
        availability_postal_codes: 'availability_postal_codes',
        availability_source: 'availability_source',
        id: 'id',
        inferred_circle_origin: 'inferred_circle_origin',
        inferred_circle_radius: 'inferred_circle_radius'
      });
    }
  }]);
  return ProductItemLocalInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemLocalInfoLatLongShape
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemLocalInfoLatLongShape = function (_AbstractCrudObject) {
  inherits(ProductItemLocalInfoLatLongShape, _AbstractCrudObject);

  function ProductItemLocalInfoLatLongShape() {
    classCallCheck(this, ProductItemLocalInfoLatLongShape);
    return possibleConstructorReturn(this, (ProductItemLocalInfoLatLongShape.__proto__ || Object.getPrototypeOf(ProductItemLocalInfoLatLongShape)).apply(this, arguments));
  }

  createClass(ProductItemLocalInfoLatLongShape, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        latitude: 'latitude',
        longitude: 'longitude'
      });
    }
  }]);
  return ProductItemLocalInfoLatLongShape;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemOffer
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemOffer = function (_AbstractCrudObject) {
  inherits(ProductItemOffer, _AbstractCrudObject);

  function ProductItemOffer() {
    classCallCheck(this, ProductItemOffer);
    return possibleConstructorReturn(this, (ProductItemOffer.__proto__ || Object.getPrototypeOf(ProductItemOffer)).apply(this, arguments));
  }

  createClass(ProductItemOffer, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        availability_area: 'availability_area',
        availability_radius: 'availability_radius',
        id: 'id'
      });
    }
  }]);
  return ProductItemOffer;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemShipping
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemShipping = function (_AbstractCrudObject) {
  inherits(ProductItemShipping, _AbstractCrudObject);

  function ProductItemShipping() {
    classCallCheck(this, ProductItemShipping);
    return possibleConstructorReturn(this, (ProductItemShipping.__proto__ || Object.getPrototypeOf(ProductItemShipping)).apply(this, arguments));
  }

  createClass(ProductItemShipping, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        shipping_country: 'shipping_country',
        shipping_price_currency: 'shipping_price_currency',
        shipping_price_value: 'shipping_price_value',
        shipping_region: 'shipping_region',
        shipping_service: 'shipping_service'
      });
    }
  }]);
  return ProductItemShipping;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemSubscriptionInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemSubscriptionInfo = function (_AbstractCrudObject) {
  inherits(ProductItemSubscriptionInfo, _AbstractCrudObject);

  function ProductItemSubscriptionInfo() {
    classCallCheck(this, ProductItemSubscriptionInfo);
    return possibleConstructorReturn(this, (ProductItemSubscriptionInfo.__proto__ || Object.getPrototypeOf(ProductItemSubscriptionInfo)).apply(this, arguments));
  }

  createClass(ProductItemSubscriptionInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_subscribable: 'is_subscribable',
        subscription_billing_period: 'subscription_billing_period',
        subscription_billing_type: 'subscription_billing_type'
      });
    }
  }]);
  return ProductItemSubscriptionInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductItemUnitPrice
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductItemUnitPrice = function (_AbstractCrudObject) {
  inherits(ProductItemUnitPrice, _AbstractCrudObject);

  function ProductItemUnitPrice() {
    classCallCheck(this, ProductItemUnitPrice);
    return possibleConstructorReturn(this, (ProductItemUnitPrice.__proto__ || Object.getPrototypeOf(ProductItemUnitPrice)).apply(this, arguments));
  }

  createClass(ProductItemUnitPrice, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return ProductItemUnitPrice;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductSetMetadata
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductSetMetadata = function (_AbstractCrudObject) {
  inherits(ProductSetMetadata, _AbstractCrudObject);

  function ProductSetMetadata() {
    classCallCheck(this, ProductSetMetadata);
    return possibleConstructorReturn(this, (ProductSetMetadata.__proto__ || Object.getPrototypeOf(ProductSetMetadata)).apply(this, arguments));
  }

  createClass(ProductSetMetadata, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        cover_image_url: 'cover_image_url',
        description: 'description',
        external_url: 'external_url',
        integrity_review_status: 'integrity_review_status'
      });
    }
  }]);
  return ProductSetMetadata;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductSetTaxonCategory
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductSetTaxonCategory = function (_AbstractCrudObject) {
  inherits(ProductSetTaxonCategory, _AbstractCrudObject);

  function ProductSetTaxonCategory() {
    classCallCheck(this, ProductSetTaxonCategory);
    return possibleConstructorReturn(this, (ProductSetTaxonCategory.__proto__ || Object.getPrototypeOf(ProductSetTaxonCategory)).apply(this, arguments));
  }

  createClass(ProductSetTaxonCategory, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        category_id: 'category_id',
        category_name: 'category_name',
        image_url: 'image_url'
      });
    }
  }]);
  return ProductSetTaxonCategory;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductSetUsage
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductSetUsage = function (_AbstractCrudObject) {
  inherits(ProductSetUsage, _AbstractCrudObject);

  function ProductSetUsage() {
    classCallCheck(this, ProductSetUsage);
    return possibleConstructorReturn(this, (ProductSetUsage.__proto__ || Object.getPrototypeOf(ProductSetUsage)).apply(this, arguments));
  }

  createClass(ProductSetUsage, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        product_set: 'product_set',
        usage_type: 'usage_type'
      });
    }
  }]);
  return ProductSetUsage;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductVariant
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductVariant = function (_AbstractCrudObject) {
  inherits(ProductVariant, _AbstractCrudObject);

  function ProductVariant() {
    classCallCheck(this, ProductVariant);
    return possibleConstructorReturn(this, (ProductVariant.__proto__ || Object.getPrototypeOf(ProductVariant)).apply(this, arguments));
  }

  createClass(ProductVariant, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        label: 'label',
        options: 'options',
        product_field: 'product_field'
      });
    }
  }]);
  return ProductVariant;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ProductVisualVariant
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ProductVisualVariant = function (_AbstractCrudObject) {
  inherits(ProductVisualVariant, _AbstractCrudObject);

  function ProductVisualVariant() {
    classCallCheck(this, ProductVisualVariant);
    return possibleConstructorReturn(this, (ProductVisualVariant.__proto__ || Object.getPrototypeOf(ProductVisualVariant)).apply(this, arguments));
  }

  createClass(ProductVisualVariant, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        items: 'items',
        unique_key: 'unique_key'
      });
    }
  }]);
  return ProductVisualVariant;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PublisherDeliveryReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PublisherDeliveryReport = function (_AbstractCrudObject) {
  inherits(PublisherDeliveryReport, _AbstractCrudObject);

  function PublisherDeliveryReport() {
    classCallCheck(this, PublisherDeliveryReport);
    return possibleConstructorReturn(this, (PublisherDeliveryReport.__proto__ || Object.getPrototypeOf(PublisherDeliveryReport)).apply(this, arguments));
  }

  createClass(PublisherDeliveryReport, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        content_types: 'content_types',
        estimated_impressions: 'estimated_impressions',
        name: 'name',
        status: 'status',
        url: 'url'
      });
    }
  }]);
  return PublisherDeliveryReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * PublisherWhiteList
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var PublisherWhiteList = function (_AbstractCrudObject) {
  inherits(PublisherWhiteList, _AbstractCrudObject);

  function PublisherWhiteList() {
    classCallCheck(this, PublisherWhiteList);
    return possibleConstructorReturn(this, (PublisherWhiteList.__proto__ || Object.getPrototypeOf(PublisherWhiteList)).apply(this, arguments));
  }

  createClass(PublisherWhiteList, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        business_owner_id: 'business_owner_id',
        id: 'id',
        last_updated_time: 'last_updated_time',
        last_updated_user: 'last_updated_user',
        name: 'name',
        placement_type: 'placement_type'
      });
    }
  }]);
  return PublisherWhiteList;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * RawCustomAudience
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var RawCustomAudience = function (_AbstractCrudObject) {
  inherits(RawCustomAudience, _AbstractCrudObject);

  function RawCustomAudience() {
    classCallCheck(this, RawCustomAudience);
    return possibleConstructorReturn(this, (RawCustomAudience.__proto__ || Object.getPrototypeOf(RawCustomAudience)).apply(this, arguments));
  }

  createClass(RawCustomAudience, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return RawCustomAudience;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReachFrequencyActivity
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReachFrequencyActivity = function (_AbstractCrudObject) {
  inherits(ReachFrequencyActivity, _AbstractCrudObject);

  function ReachFrequencyActivity() {
    classCallCheck(this, ReachFrequencyActivity);
    return possibleConstructorReturn(this, (ReachFrequencyActivity.__proto__ || Object.getPrototypeOf(ReachFrequencyActivity)).apply(this, arguments));
  }

  createClass(ReachFrequencyActivity, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        campaign_active: 'campaign_active',
        campaign_started: 'campaign_started',
        creative_uploaded: 'creative_uploaded',
        io_approved: 'io_approved',
        sf_link: 'sf_link'
      });
    }
  }]);
  return ReachFrequencyActivity;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReachFrequencyAdFormat
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReachFrequencyAdFormat = function (_AbstractCrudObject) {
  inherits(ReachFrequencyAdFormat, _AbstractCrudObject);

  function ReachFrequencyAdFormat() {
    classCallCheck(this, ReachFrequencyAdFormat);
    return possibleConstructorReturn(this, (ReachFrequencyAdFormat.__proto__ || Object.getPrototypeOf(ReachFrequencyAdFormat)).apply(this, arguments));
  }

  createClass(ReachFrequencyAdFormat, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        details: 'details',
        type: 'type'
      });
    }
  }]);
  return ReachFrequencyAdFormat;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReachFrequencyCurveLowerConfidenceRange
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReachFrequencyCurveLowerConfidenceRange = function (_AbstractCrudObject) {
  inherits(ReachFrequencyCurveLowerConfidenceRange, _AbstractCrudObject);

  function ReachFrequencyCurveLowerConfidenceRange() {
    classCallCheck(this, ReachFrequencyCurveLowerConfidenceRange);
    return possibleConstructorReturn(this, (ReachFrequencyCurveLowerConfidenceRange.__proto__ || Object.getPrototypeOf(ReachFrequencyCurveLowerConfidenceRange)).apply(this, arguments));
  }

  createClass(ReachFrequencyCurveLowerConfidenceRange, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        impression_lower: 'impression_lower',
        num_points: 'num_points',
        reach: 'reach',
        reach_lower: 'reach_lower',
        uniq_video_views_2s_lower: 'uniq_video_views_2s_lower',
        video_views_2s_lower: 'video_views_2s_lower'
      });
    }
  }]);
  return ReachFrequencyCurveLowerConfidenceRange;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReachFrequencyCurveUpperConfidenceRange
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReachFrequencyCurveUpperConfidenceRange = function (_AbstractCrudObject) {
  inherits(ReachFrequencyCurveUpperConfidenceRange, _AbstractCrudObject);

  function ReachFrequencyCurveUpperConfidenceRange() {
    classCallCheck(this, ReachFrequencyCurveUpperConfidenceRange);
    return possibleConstructorReturn(this, (ReachFrequencyCurveUpperConfidenceRange.__proto__ || Object.getPrototypeOf(ReachFrequencyCurveUpperConfidenceRange)).apply(this, arguments));
  }

  createClass(ReachFrequencyCurveUpperConfidenceRange, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        impression_upper: 'impression_upper',
        num_points: 'num_points',
        reach: 'reach',
        reach_upper: 'reach_upper',
        uniq_video_views_2s_upper: 'uniq_video_views_2s_upper',
        video_views_2s_upper: 'video_views_2s_upper'
      });
    }
  }]);
  return ReachFrequencyCurveUpperConfidenceRange;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReachFrequencyDayPart
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReachFrequencyDayPart = function (_AbstractCrudObject) {
  inherits(ReachFrequencyDayPart, _AbstractCrudObject);

  function ReachFrequencyDayPart() {
    classCallCheck(this, ReachFrequencyDayPart);
    return possibleConstructorReturn(this, (ReachFrequencyDayPart.__proto__ || Object.getPrototypeOf(ReachFrequencyDayPart)).apply(this, arguments));
  }

  createClass(ReachFrequencyDayPart, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        days: 'days',
        end_minute: 'end_minute',
        start_minute: 'start_minute'
      });
    }
  }]);
  return ReachFrequencyDayPart;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReachFrequencyEstimatesCurve
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReachFrequencyEstimatesCurve = function (_AbstractCrudObject) {
  inherits(ReachFrequencyEstimatesCurve, _AbstractCrudObject);

  function ReachFrequencyEstimatesCurve() {
    classCallCheck(this, ReachFrequencyEstimatesCurve);
    return possibleConstructorReturn(this, (ReachFrequencyEstimatesCurve.__proto__ || Object.getPrototypeOf(ReachFrequencyEstimatesCurve)).apply(this, arguments));
  }

  createClass(ReachFrequencyEstimatesCurve, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        budget: 'budget',
        conversion: 'conversion',
        impression: 'impression',
        interpolated_reach: 'interpolated_reach',
        num_points: 'num_points',
        raw_impression: 'raw_impression',
        raw_reach: 'raw_reach',
        reach: 'reach'
      });
    }
  }]);
  return ReachFrequencyEstimatesCurve;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReachFrequencyEstimatesPlacementBreakdown
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReachFrequencyEstimatesPlacementBreakdown = function (_AbstractCrudObject) {
  inherits(ReachFrequencyEstimatesPlacementBreakdown, _AbstractCrudObject);

  function ReachFrequencyEstimatesPlacementBreakdown() {
    classCallCheck(this, ReachFrequencyEstimatesPlacementBreakdown);
    return possibleConstructorReturn(this, (ReachFrequencyEstimatesPlacementBreakdown.__proto__ || Object.getPrototypeOf(ReachFrequencyEstimatesPlacementBreakdown)).apply(this, arguments));
  }

  createClass(ReachFrequencyEstimatesPlacementBreakdown, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        android: 'android',
        audience_network: 'audience_network',
        desktop: 'desktop',
        facebook_search: 'facebook_search',
        fb_reels: 'fb_reels',
        fb_reels_overlay: 'fb_reels_overlay',
        ig_android: 'ig_android',
        ig_ios: 'ig_ios',
        ig_other: 'ig_other',
        ig_reels: 'ig_reels',
        ig_story: 'ig_story',
        instant_articles: 'instant_articles',
        instream_videos: 'instream_videos',
        ios: 'ios',
        msite: 'msite',
        suggested_videos: 'suggested_videos'
      });
    }
  }]);
  return ReachFrequencyEstimatesPlacementBreakdown;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReachFrequencySpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReachFrequencySpec = function (_AbstractCrudObject) {
  inherits(ReachFrequencySpec, _AbstractCrudObject);

  function ReachFrequencySpec() {
    classCallCheck(this, ReachFrequencySpec);
    return possibleConstructorReturn(this, (ReachFrequencySpec.__proto__ || Object.getPrototypeOf(ReachFrequencySpec)).apply(this, arguments));
  }

  createClass(ReachFrequencySpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        countries: 'countries',
        default_creation_data: 'default_creation_data',
        global_io_max_campaign_duration: 'global_io_max_campaign_duration',
        max_campaign_duration: 'max_campaign_duration',
        max_days_to_finish: 'max_days_to_finish',
        max_pause_without_prediction_rerun: 'max_pause_without_prediction_rerun',
        min_campaign_duration: 'min_campaign_duration',
        min_reach_limits: 'min_reach_limits'
      });
    }
  }]);
  return ReachFrequencySpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * RecommendedIGMedia
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var RecommendedIGMedia = function (_AbstractCrudObject) {
  inherits(RecommendedIGMedia, _AbstractCrudObject);

  function RecommendedIGMedia() {
    classCallCheck(this, RecommendedIGMedia);
    return possibleConstructorReturn(this, (RecommendedIGMedia.__proto__ || Object.getPrototypeOf(RecommendedIGMedia)).apply(this, arguments));
  }

  createClass(RecommendedIGMedia, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        intent_score: 'intent_score',
        media: 'media'
      });
    }
  }]);
  return RecommendedIGMedia;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * RecommendedPagePost
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var RecommendedPagePost = function (_AbstractCrudObject) {
  inherits(RecommendedPagePost, _AbstractCrudObject);

  function RecommendedPagePost() {
    classCallCheck(this, RecommendedPagePost);
    return possibleConstructorReturn(this, (RecommendedPagePost.__proto__ || Object.getPrototypeOf(RecommendedPagePost)).apply(this, arguments));
  }

  createClass(RecommendedPagePost, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        intent_score: 'intent_score',
        is_ig_media: 'is_ig_media',
        post_id: 'post_id'
      });
    }
  }]);
  return RecommendedPagePost;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * RegionalRegulationIdentities
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var RegionalRegulationIdentities = function (_AbstractCrudObject) {
  inherits(RegionalRegulationIdentities, _AbstractCrudObject);

  function RegionalRegulationIdentities() {
    classCallCheck(this, RegionalRegulationIdentities);
    return possibleConstructorReturn(this, (RegionalRegulationIdentities.__proto__ || Object.getPrototypeOf(RegionalRegulationIdentities)).apply(this, arguments));
  }

  createClass(RegionalRegulationIdentities, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        taiwan_finserv_beneficiary: 'taiwan_finserv_beneficiary',
        taiwan_finserv_payer: 'taiwan_finserv_payer'
      });
    }
  }]);
  return RegionalRegulationIdentities;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ReportingAudience
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ReportingAudience = function (_AbstractCrudObject) {
  inherits(ReportingAudience, _AbstractCrudObject);

  function ReportingAudience() {
    classCallCheck(this, ReportingAudience);
    return possibleConstructorReturn(this, (ReportingAudience.__proto__ || Object.getPrototypeOf(ReportingAudience)).apply(this, arguments));
  }

  createClass(ReportingAudience, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        custom_audiences: 'custom_audiences',
        custom_audiences_url_param_name: 'custom_audiences_url_param_name',
        custom_audiences_url_param_type: 'custom_audiences_url_param_type'
      });
    }
  }]);
  return ReportingAudience;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ResearchPollStudy
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ResearchPollStudy = function (_AbstractCrudObject) {
  inherits(ResearchPollStudy, _AbstractCrudObject);

  function ResearchPollStudy() {
    classCallCheck(this, ResearchPollStudy);
    return possibleConstructorReturn(this, (ResearchPollStudy.__proto__ || Object.getPrototypeOf(ResearchPollStudy)).apply(this, arguments));
  }

  createClass(ResearchPollStudy, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account: 'account',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return ResearchPollStudy;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * RevSharePolicy
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var RevSharePolicy = function (_AbstractCrudObject) {
  inherits(RevSharePolicy, _AbstractCrudObject);

  function RevSharePolicy() {
    classCallCheck(this, RevSharePolicy);
    return possibleConstructorReturn(this, (RevSharePolicy.__proto__ || Object.getPrototypeOf(RevSharePolicy)).apply(this, arguments));
  }

  createClass(RevSharePolicy, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        policy_id: 'policy_id',
        policy_name: 'policy_name'
      });
    }
  }]);
  return RevSharePolicy;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * RichMediaElement
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var RichMediaElement = function (_AbstractCrudObject) {
  inherits(RichMediaElement, _AbstractCrudObject);

  function RichMediaElement() {
    classCallCheck(this, RichMediaElement);
    return possibleConstructorReturn(this, (RichMediaElement.__proto__ || Object.getPrototypeOf(RichMediaElement)).apply(this, arguments));
  }

  createClass(RichMediaElement, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        element: 'element',
        element_type: 'element_type',
        name: 'name'
      });
    }
  }]);
  return RichMediaElement;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * RightsManagerDataExport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var RightsManagerDataExport = function (_AbstractCrudObject) {
  inherits(RightsManagerDataExport, _AbstractCrudObject);

  function RightsManagerDataExport() {
    classCallCheck(this, RightsManagerDataExport);
    return possibleConstructorReturn(this, (RightsManagerDataExport.__proto__ || Object.getPrototypeOf(RightsManagerDataExport)).apply(this, arguments));
  }

  createClass(RightsManagerDataExport, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        download_uri: 'download_uri',
        export_scope: 'export_scope',
        id: 'id',
        name: 'name',
        record_type: 'record_type',
        time_range_end: 'time_range_end',
        time_range_start: 'time_range_start'
      });
    }
  }]);
  return RightsManagerDataExport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * RightsManagerInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var RightsManagerInsights = function (_AbstractCrudObject) {
  inherits(RightsManagerInsights, _AbstractCrudObject);

  function RightsManagerInsights() {
    classCallCheck(this, RightsManagerInsights);
    return possibleConstructorReturn(this, (RightsManagerInsights.__proto__ || Object.getPrototypeOf(RightsManagerInsights)).apply(this, arguments));
  }

  createClass(RightsManagerInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        error: 'error',
        error_message: 'error_message',
        metadata: 'metadata',
        totals: 'totals',
        x_axis_breakdown: 'x_axis_breakdown'
      });
    }
  }]);
  return RightsManagerInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Robot
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Robot = function (_AbstractCrudObject) {
  inherits(Robot, _AbstractCrudObject);

  function Robot() {
    classCallCheck(this, Robot);
    return possibleConstructorReturn(this, (Robot.__proto__ || Object.getPrototypeOf(Robot)).apply(this, arguments));
  }

  createClass(Robot, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        bringup_vars: 'bringup_vars',
        configurations: 'configurations',
        data_center: 'data_center',
        id: 'id',
        init_pos: 'init_pos',
        last_pos: 'last_pos',
        meetup_link_hash: 'meetup_link_hash',
        suite: 'suite',
        target_map_image_uri: 'target_map_image_uri',
        target_os_image_uri: 'target_os_image_uri',
        target_sw_image_uri: 'target_sw_image_uri',
        user: 'user'
      });
    }
  }]);
  return Robot;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SalesRightsInventoryManagement
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SalesRightsInventoryManagement = function (_AbstractCrudObject) {
  inherits(SalesRightsInventoryManagement, _AbstractCrudObject);

  function SalesRightsInventoryManagement() {
    classCallCheck(this, SalesRightsInventoryManagement);
    return possibleConstructorReturn(this, (SalesRightsInventoryManagement.__proto__ || Object.getPrototypeOf(SalesRightsInventoryManagement)).apply(this, arguments));
  }

  createClass(SalesRightsInventoryManagement, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        available_impressions: 'available_impressions',
        booked_impressions: 'booked_impressions',
        overbooked_impressions: 'overbooked_impressions',
        supported_countries: 'supported_countries',
        total_impressions: 'total_impressions',
        unavailable_impressions: 'unavailable_impressions',
        warning_messages: 'warning_messages'
      });
    }
  }]);
  return SalesRightsInventoryManagement;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SavedMessageResponse
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SavedMessageResponse = function (_AbstractCrudObject) {
  inherits(SavedMessageResponse, _AbstractCrudObject);

  function SavedMessageResponse() {
    classCallCheck(this, SavedMessageResponse);
    return possibleConstructorReturn(this, (SavedMessageResponse.__proto__ || Object.getPrototypeOf(SavedMessageResponse)).apply(this, arguments));
  }

  createClass(SavedMessageResponse, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        image: 'image',
        is_enabled: 'is_enabled',
        message: 'message',
        title: 'title'
      });
    }
  }]);
  return SavedMessageResponse;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ScheduledPost
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ScheduledPost = function (_AbstractCrudObject) {
  inherits(ScheduledPost, _AbstractCrudObject);

  function ScheduledPost() {
    classCallCheck(this, ScheduledPost);
    return possibleConstructorReturn(this, (ScheduledPost.__proto__ || Object.getPrototypeOf(ScheduledPost)).apply(this, arguments));
  }

  createClass(ScheduledPost, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        admin_creator: 'admin_creator',
        creation_time: 'creation_time',
        feed_audience_description: 'feed_audience_description',
        feed_targeting: 'feed_targeting',
        id: 'id',
        is_post_in_good_state: 'is_post_in_good_state',
        message: 'message',
        modified_time: 'modified_time',
        og_action_summary: 'og_action_summary',
        permalink_url: 'permalink_url',
        place: 'place',
        privacy_description: 'privacy_description',
        scheduled_failure_notice: 'scheduled_failure_notice',
        scheduled_publish_time: 'scheduled_publish_time',
        story_token: 'story_token',
        thumbnail: 'thumbnail',
        video_id: 'video_id'
      });
    }
  }]);
  return ScheduledPost;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ScimCompanyUserPhoneNumber
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ScimCompanyUserPhoneNumber = function (_AbstractCrudObject) {
  inherits(ScimCompanyUserPhoneNumber, _AbstractCrudObject);

  function ScimCompanyUserPhoneNumber() {
    classCallCheck(this, ScimCompanyUserPhoneNumber);
    return possibleConstructorReturn(this, (ScimCompanyUserPhoneNumber.__proto__ || Object.getPrototypeOf(ScimCompanyUserPhoneNumber)).apply(this, arguments));
  }

  createClass(ScimCompanyUserPhoneNumber, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        number: 'number',
        primary: 'primary',
        type: 'type'
      });
    }
  }]);
  return ScimCompanyUserPhoneNumber;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SecuritySettings
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SecuritySettings = function (_AbstractCrudObject) {
  inherits(SecuritySettings, _AbstractCrudObject);

  function SecuritySettings() {
    classCallCheck(this, SecuritySettings);
    return possibleConstructorReturn(this, (SecuritySettings.__proto__ || Object.getPrototypeOf(SecuritySettings)).apply(this, arguments));
  }

  createClass(SecuritySettings, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({});
    }
  }]);
  return SecuritySettings;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ShadowIGMediaBoostedInsightsResult
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ShadowIGMediaBoostedInsightsResult = function (_AbstractCrudObject) {
  inherits(ShadowIGMediaBoostedInsightsResult, _AbstractCrudObject);

  function ShadowIGMediaBoostedInsightsResult() {
    classCallCheck(this, ShadowIGMediaBoostedInsightsResult);
    return possibleConstructorReturn(this, (ShadowIGMediaBoostedInsightsResult.__proto__ || Object.getPrototypeOf(ShadowIGMediaBoostedInsightsResult)).apply(this, arguments));
  }

  createClass(ShadowIGMediaBoostedInsightsResult, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        name: 'name',
        organic_media_id: 'organic_media_id',
        source_type: 'source_type',
        title: 'title',
        values: 'values'
      });
    }
  }]);
  return ShadowIGMediaBoostedInsightsResult;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ShadowIGMediaBuilder
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ShadowIGMediaBuilder = function (_AbstractCrudObject) {
  inherits(ShadowIGMediaBuilder, _AbstractCrudObject);

  function ShadowIGMediaBuilder() {
    classCallCheck(this, ShadowIGMediaBuilder);
    return possibleConstructorReturn(this, (ShadowIGMediaBuilder.__proto__ || Object.getPrototypeOf(ShadowIGMediaBuilder)).apply(this, arguments));
  }

  createClass(ShadowIGMediaBuilder, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        copyright_check_status: 'copyright_check_status',
        id: 'id',
        status: 'status',
        status_code: 'status_code',
        video_status: 'video_status'
      });
    }
  }]);
  return ShadowIGMediaBuilder;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ShadowIGUserCatalogProductVariant
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ShadowIGUserCatalogProductVariant = function (_AbstractCrudObject) {
  inherits(ShadowIGUserCatalogProductVariant, _AbstractCrudObject);

  function ShadowIGUserCatalogProductVariant() {
    classCallCheck(this, ShadowIGUserCatalogProductVariant);
    return possibleConstructorReturn(this, (ShadowIGUserCatalogProductVariant.__proto__ || Object.getPrototypeOf(ShadowIGUserCatalogProductVariant)).apply(this, arguments));
  }

  createClass(ShadowIGUserCatalogProductVariant, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        product_id: 'product_id',
        variant_name: 'variant_name'
      });
    }
  }]);
  return ShadowIGUserCatalogProductVariant;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ShadowIGUserPartnershipAdsMediaErrors
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ShadowIGUserPartnershipAdsMediaErrors = function (_AbstractCrudObject) {
  inherits(ShadowIGUserPartnershipAdsMediaErrors, _AbstractCrudObject);

  function ShadowIGUserPartnershipAdsMediaErrors() {
    classCallCheck(this, ShadowIGUserPartnershipAdsMediaErrors);
    return possibleConstructorReturn(this, (ShadowIGUserPartnershipAdsMediaErrors.__proto__ || Object.getPrototypeOf(ShadowIGUserPartnershipAdsMediaErrors)).apply(this, arguments));
  }

  createClass(ShadowIGUserPartnershipAdsMediaErrors, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_code: 'ad_code',
        error_codes: 'error_codes',
        errors: 'errors',
        permalink: 'permalink'
      });
    }
  }]);
  return ShadowIGUserPartnershipAdsMediaErrors;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SignalsIWLExtractor
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SignalsIWLExtractor = function (_AbstractCrudObject) {
  inherits(SignalsIWLExtractor, _AbstractCrudObject);

  function SignalsIWLExtractor() {
    classCallCheck(this, SignalsIWLExtractor);
    return possibleConstructorReturn(this, (SignalsIWLExtractor.__proto__ || Object.getPrototypeOf(SignalsIWLExtractor)).apply(this, arguments));
  }

  createClass(SignalsIWLExtractor, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        domain_uri: 'domain_uri',
        event_type: 'event_type',
        extractor_type: 'extractor_type',
        id: 'id'
      });
    }
  }]);
  return SignalsIWLExtractor;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SingleOwnerAdditionalProfile
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SingleOwnerAdditionalProfile = function (_AbstractCrudObject) {
  inherits(SingleOwnerAdditionalProfile, _AbstractCrudObject);

  function SingleOwnerAdditionalProfile() {
    classCallCheck(this, SingleOwnerAdditionalProfile);
    return possibleConstructorReturn(this, (SingleOwnerAdditionalProfile.__proto__ || Object.getPrototypeOf(SingleOwnerAdditionalProfile)).apply(this, arguments));
  }

  createClass(SingleOwnerAdditionalProfile, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        user_name: 'user_name'
      });
    }
  }]);
  return SingleOwnerAdditionalProfile;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SiteLink
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SiteLink = function (_AbstractCrudObject) {
  inherits(SiteLink, _AbstractCrudObject);

  function SiteLink() {
    classCallCheck(this, SiteLink);
    return possibleConstructorReturn(this, (SiteLink.__proto__ || Object.getPrototypeOf(SiteLink)).apply(this, arguments));
  }

  createClass(SiteLink, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        link_image_hash: 'link_image_hash',
        link_title: 'link_title',
        link_type: 'link_type',
        link_url: 'link_url'
      });
    }
  }]);
  return SiteLink;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SlicedEventSourceGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SlicedEventSourceGroup = function (_AbstractCrudObject) {
  inherits(SlicedEventSourceGroup, _AbstractCrudObject);

  function SlicedEventSourceGroup() {
    classCallCheck(this, SlicedEventSourceGroup);
    return possibleConstructorReturn(this, (SlicedEventSourceGroup.__proto__ || Object.getPrototypeOf(SlicedEventSourceGroup)).apply(this, arguments));
  }

  createClass(SlicedEventSourceGroup, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        event_source_group: 'event_source_group',
        filter: 'filter',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return SlicedEventSourceGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SmartPixelInsights
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SmartPixelInsights = function (_AbstractCrudObject) {
  inherits(SmartPixelInsights, _AbstractCrudObject);

  function SmartPixelInsights() {
    classCallCheck(this, SmartPixelInsights);
    return possibleConstructorReturn(this, (SmartPixelInsights.__proto__ || Object.getPrototypeOf(SmartPixelInsights)).apply(this, arguments));
  }

  createClass(SmartPixelInsights, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        source: 'source',
        stats: 'stats'
      });
    }
  }]);
  return SmartPixelInsights;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SocialWifiSite
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SocialWifiSite = function (_AbstractCrudObject) {
  inherits(SocialWifiSite, _AbstractCrudObject);

  function SocialWifiSite() {
    classCallCheck(this, SocialWifiSite);
    return possibleConstructorReturn(this, (SocialWifiSite.__proto__ || Object.getPrototypeOf(SocialWifiSite)).apply(this, arguments));
  }

  createClass(SocialWifiSite, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return SocialWifiSite;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SplitTestConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SplitTestConfig = function (_AbstractCrudObject) {
  inherits(SplitTestConfig, _AbstractCrudObject);

  function SplitTestConfig() {
    classCallCheck(this, SplitTestConfig);
    return possibleConstructorReturn(this, (SplitTestConfig.__proto__ || Object.getPrototypeOf(SplitTestConfig)).apply(this, arguments));
  }

  createClass(SplitTestConfig, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        budget: 'budget',
        early_winner_declaration_enabled: 'early_winner_declaration_enabled',
        end_time: 'end_time',
        splits: 'splits',
        start_time: 'start_time',
        test_variable: 'test_variable',
        id: 'id'
      });
    }
  }]);
  return SplitTestConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * SplitTestWinner
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var SplitTestWinner = function (_AbstractCrudObject) {
  inherits(SplitTestWinner, _AbstractCrudObject);

  function SplitTestWinner() {
    classCallCheck(this, SplitTestWinner);
    return possibleConstructorReturn(this, (SplitTestWinner.__proto__ || Object.getPrototypeOf(SplitTestWinner)).apply(this, arguments));
  }

  createClass(SplitTestWinner, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_object_level: 'ad_object_level',
        confidences: 'confidences',
        winner_ad_object_id: 'winner_ad_object_id'
      });
    }
  }]);
  return SplitTestWinner;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Status
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Status = function (_AbstractCrudObject) {
  inherits(Status, _AbstractCrudObject);

  function Status() {
    classCallCheck(this, Status);
    return possibleConstructorReturn(this, (Status.__proto__ || Object.getPrototypeOf(Status)).apply(this, arguments));
  }

  createClass(Status, [{
    key: 'createLike',
    value: function createLike(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var pathOverride = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      return this.createEdge('/likes', fields, params, Status, pathOverride);
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        event: 'event',
        from: 'from',
        id: 'id',
        message: 'message',
        place: 'place',
        updated_time: 'updated_time'
      });
    }
  }]);
  return Status;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * StreamFilter
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var StreamFilter = function (_AbstractCrudObject) {
  inherits(StreamFilter, _AbstractCrudObject);

  function StreamFilter() {
    classCallCheck(this, StreamFilter);
    return possibleConstructorReturn(this, (StreamFilter.__proto__ || Object.getPrototypeOf(StreamFilter)).apply(this, arguments));
  }

  createClass(StreamFilter, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        filter_key: 'filter_key',
        name: 'name',
        type: 'type'
      });
    }
  }]);
  return StreamFilter;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TaggableSubject
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TaggableSubject = function (_AbstractCrudObject) {
  inherits(TaggableSubject, _AbstractCrudObject);

  function TaggableSubject() {
    classCallCheck(this, TaggableSubject);
    return possibleConstructorReturn(this, (TaggableSubject.__proto__ || Object.getPrototypeOf(TaggableSubject)).apply(this, arguments));
  }

  createClass(TaggableSubject, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return TaggableSubject;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Targeting
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Targeting = function (_AbstractCrudObject) {
  inherits(Targeting, _AbstractCrudObject);

  function Targeting() {
    classCallCheck(this, Targeting);
    return possibleConstructorReturn(this, (Targeting.__proto__ || Object.getPrototypeOf(Targeting)).apply(this, arguments));
  }

  createClass(Targeting, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adgroup_id: 'adgroup_id',
        age_max: 'age_max',
        age_min: 'age_min',
        age_range: 'age_range',
        alternate_auto_targeting_option: 'alternate_auto_targeting_option',
        app_install_state: 'app_install_state',
        audience_network_positions: 'audience_network_positions',
        behaviors: 'behaviors',
        brand_safety_content_filter_levels: 'brand_safety_content_filter_levels',
        catalog_based_targeting: 'catalog_based_targeting',
        cities: 'cities',
        college_years: 'college_years',
        connections: 'connections',
        contextual_targeting_categories: 'contextual_targeting_categories',
        countries: 'countries',
        country: 'country',
        country_groups: 'country_groups',
        custom_audiences: 'custom_audiences',
        device_platforms: 'device_platforms',
        direct_install_devices: 'direct_install_devices',
        dynamic_audience_ids: 'dynamic_audience_ids',
        education_majors: 'education_majors',
        education_schools: 'education_schools',
        education_statuses: 'education_statuses',
        effective_audience_network_positions: 'effective_audience_network_positions',
        effective_device_platforms: 'effective_device_platforms',
        effective_facebook_positions: 'effective_facebook_positions',
        effective_instagram_positions: 'effective_instagram_positions',
        effective_messenger_positions: 'effective_messenger_positions',
        effective_publisher_platforms: 'effective_publisher_platforms',
        engagement_specs: 'engagement_specs',
        ethnic_affinity: 'ethnic_affinity',
        exclude_reached_since: 'exclude_reached_since',
        excluded_brand_safety_content_types: 'excluded_brand_safety_content_types',
        excluded_connections: 'excluded_connections',
        excluded_custom_audiences: 'excluded_custom_audiences',
        excluded_dynamic_audience_ids: 'excluded_dynamic_audience_ids',
        excluded_engagement_specs: 'excluded_engagement_specs',
        excluded_geo_locations: 'excluded_geo_locations',
        excluded_mobile_device_model: 'excluded_mobile_device_model',
        excluded_product_audience_specs: 'excluded_product_audience_specs',
        excluded_publisher_categories: 'excluded_publisher_categories',
        excluded_publisher_list_ids: 'excluded_publisher_list_ids',
        excluded_user_device: 'excluded_user_device',
        exclusions: 'exclusions',
        facebook_positions: 'facebook_positions',
        family_statuses: 'family_statuses',
        fb_deal_id: 'fb_deal_id',
        flexible_spec: 'flexible_spec',
        friends_of_connections: 'friends_of_connections',
        genders: 'genders',
        generation: 'generation',
        geo_locations: 'geo_locations',
        home_ownership: 'home_ownership',
        home_type: 'home_type',
        home_value: 'home_value',
        household_composition: 'household_composition',
        income: 'income',
        industries: 'industries',
        instagram_positions: 'instagram_positions',
        instream_video_skippable_excluded: 'instream_video_skippable_excluded',
        interested_in: 'interested_in',
        interests: 'interests',
        is_whatsapp_destination_ad: 'is_whatsapp_destination_ad',
        keywords: 'keywords',
        life_events: 'life_events',
        locales: 'locales',
        messenger_positions: 'messenger_positions',
        moms: 'moms',
        net_worth: 'net_worth',
        office_type: 'office_type',
        place_page_set_ids: 'place_page_set_ids',
        political_views: 'political_views',
        politics: 'politics',
        product_audience_specs: 'product_audience_specs',
        prospecting_audience: 'prospecting_audience',
        publisher_platforms: 'publisher_platforms',
        radius: 'radius',
        regions: 'regions',
        relationship_statuses: 'relationship_statuses',
        site_category: 'site_category',
        targeting_automation: 'targeting_automation',
        targeting_optimization: 'targeting_optimization',
        targeting_relaxation_types: 'targeting_relaxation_types',
        user_adclusters: 'user_adclusters',
        user_device: 'user_device',
        user_event: 'user_event',
        user_os: 'user_os',
        wireless_carrier: 'wireless_carrier',
        work_employers: 'work_employers',
        work_positions: 'work_positions',
        zips: 'zips'
      });
    }
  }, {
    key: 'DevicePlatforms',
    get: function get() {
      return Object.freeze({
        desktop: 'desktop',
        mobile: 'mobile'
      });
    }
  }, {
    key: 'EffectiveDevicePlatforms',
    get: function get() {
      return Object.freeze({
        desktop: 'desktop',
        mobile: 'mobile'
      });
    }
  }]);
  return Targeting;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingAutomation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingAutomation = function (_AbstractCrudObject) {
  inherits(TargetingAutomation, _AbstractCrudObject);

  function TargetingAutomation() {
    classCallCheck(this, TargetingAutomation);
    return possibleConstructorReturn(this, (TargetingAutomation.__proto__ || Object.getPrototypeOf(TargetingAutomation)).apply(this, arguments));
  }

  createClass(TargetingAutomation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        advantage_audience: 'advantage_audience',
        individual_setting: 'individual_setting',
        shared_audiences: 'shared_audiences',
        value_expression: 'value_expression'
      });
    }
  }]);
  return TargetingAutomation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingDynamicRule
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingDynamicRule = function (_AbstractCrudObject) {
  inherits(TargetingDynamicRule, _AbstractCrudObject);

  function TargetingDynamicRule() {
    classCallCheck(this, TargetingDynamicRule);
    return possibleConstructorReturn(this, (TargetingDynamicRule.__proto__ || Object.getPrototypeOf(TargetingDynamicRule)).apply(this, arguments));
  }

  createClass(TargetingDynamicRule, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action_type: 'action.type',
        ad_group_id: 'ad_group_id',
        campaign_group_id: 'campaign_group_id',
        campaign_id: 'campaign_id',
        impression_count: 'impression_count',
        page_id: 'page_id',
        post: 'post',
        retention_seconds: 'retention_seconds'
      });
    }
  }]);
  return TargetingDynamicRule;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocation = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocation, _AbstractCrudObject);

  function TargetingGeoLocation() {
    classCallCheck(this, TargetingGeoLocation);
    return possibleConstructorReturn(this, (TargetingGeoLocation.__proto__ || Object.getPrototypeOf(TargetingGeoLocation)).apply(this, arguments));
  }

  createClass(TargetingGeoLocation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        cities: 'cities',
        countries: 'countries',
        country_groups: 'country_groups',
        custom_locations: 'custom_locations',
        electoral_districts: 'electoral_districts',
        geo_markets: 'geo_markets',
        large_geo_areas: 'large_geo_areas',
        location_cluster_ids: 'location_cluster_ids',
        location_types: 'location_types',
        medium_geo_areas: 'medium_geo_areas',
        metro_areas: 'metro_areas',
        neighborhoods: 'neighborhoods',
        places: 'places',
        political_districts: 'political_districts',
        regions: 'regions',
        small_geo_areas: 'small_geo_areas',
        subcities: 'subcities',
        subneighborhoods: 'subneighborhoods',
        zips: 'zips'
      });
    }
  }]);
  return TargetingGeoLocation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationCity
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationCity = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationCity, _AbstractCrudObject);

  function TargetingGeoLocationCity() {
    classCallCheck(this, TargetingGeoLocationCity);
    return possibleConstructorReturn(this, (TargetingGeoLocationCity.__proto__ || Object.getPrototypeOf(TargetingGeoLocationCity)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationCity, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        distance_unit: 'distance_unit',
        key: 'key',
        name: 'name',
        radius: 'radius',
        region: 'region',
        region_id: 'region_id'
      });
    }
  }]);
  return TargetingGeoLocationCity;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationCustomLocation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationCustomLocation = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationCustomLocation, _AbstractCrudObject);

  function TargetingGeoLocationCustomLocation() {
    classCallCheck(this, TargetingGeoLocationCustomLocation);
    return possibleConstructorReturn(this, (TargetingGeoLocationCustomLocation.__proto__ || Object.getPrototypeOf(TargetingGeoLocationCustomLocation)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationCustomLocation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        address_string: 'address_string',
        country: 'country',
        country_group: 'country_group',
        custom_type: 'custom_type',
        distance_unit: 'distance_unit',
        key: 'key',
        latitude: 'latitude',
        longitude: 'longitude',
        max_population: 'max_population',
        min_population: 'min_population',
        name: 'name',
        primary_city_id: 'primary_city_id',
        radius: 'radius',
        region_id: 'region_id'
      });
    }
  }]);
  return TargetingGeoLocationCustomLocation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationElectoralDistrict
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationElectoralDistrict = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationElectoralDistrict, _AbstractCrudObject);

  function TargetingGeoLocationElectoralDistrict() {
    classCallCheck(this, TargetingGeoLocationElectoralDistrict);
    return possibleConstructorReturn(this, (TargetingGeoLocationElectoralDistrict.__proto__ || Object.getPrototypeOf(TargetingGeoLocationElectoralDistrict)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationElectoralDistrict, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        deprecation_code: 'deprecation_code',
        electoral_district: 'electoral_district',
        key: 'key',
        name: 'name'
      });
    }
  }]);
  return TargetingGeoLocationElectoralDistrict;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationGeoEntities
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationGeoEntities = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationGeoEntities, _AbstractCrudObject);

  function TargetingGeoLocationGeoEntities() {
    classCallCheck(this, TargetingGeoLocationGeoEntities);
    return possibleConstructorReturn(this, (TargetingGeoLocationGeoEntities.__proto__ || Object.getPrototypeOf(TargetingGeoLocationGeoEntities)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationGeoEntities, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        key: 'key',
        name: 'name',
        region: 'region',
        region_id: 'region_id'
      });
    }
  }]);
  return TargetingGeoLocationGeoEntities;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationLocationCluster
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationLocationCluster = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationLocationCluster, _AbstractCrudObject);

  function TargetingGeoLocationLocationCluster() {
    classCallCheck(this, TargetingGeoLocationLocationCluster);
    return possibleConstructorReturn(this, (TargetingGeoLocationLocationCluster.__proto__ || Object.getPrototypeOf(TargetingGeoLocationLocationCluster)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationLocationCluster, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        key: 'key'
      });
    }
  }]);
  return TargetingGeoLocationLocationCluster;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationLocationExpansion
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationLocationExpansion = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationLocationExpansion, _AbstractCrudObject);

  function TargetingGeoLocationLocationExpansion() {
    classCallCheck(this, TargetingGeoLocationLocationExpansion);
    return possibleConstructorReturn(this, (TargetingGeoLocationLocationExpansion.__proto__ || Object.getPrototypeOf(TargetingGeoLocationLocationExpansion)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationLocationExpansion, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        allowed: 'allowed',
        intent: 'intent'
      });
    }
  }]);
  return TargetingGeoLocationLocationExpansion;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationMarket
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationMarket = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationMarket, _AbstractCrudObject);

  function TargetingGeoLocationMarket() {
    classCallCheck(this, TargetingGeoLocationMarket);
    return possibleConstructorReturn(this, (TargetingGeoLocationMarket.__proto__ || Object.getPrototypeOf(TargetingGeoLocationMarket)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationMarket, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        key: 'key',
        market_type: 'market_type',
        name: 'name'
      });
    }
  }]);
  return TargetingGeoLocationMarket;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationPlace
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationPlace = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationPlace, _AbstractCrudObject);

  function TargetingGeoLocationPlace() {
    classCallCheck(this, TargetingGeoLocationPlace);
    return possibleConstructorReturn(this, (TargetingGeoLocationPlace.__proto__ || Object.getPrototypeOf(TargetingGeoLocationPlace)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationPlace, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        distance_unit: 'distance_unit',
        key: 'key',
        latitude: 'latitude',
        longitude: 'longitude',
        name: 'name',
        primary_city_id: 'primary_city_id',
        radius: 'radius',
        region_id: 'region_id'
      });
    }
  }]);
  return TargetingGeoLocationPlace;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationPoliticalDistrict
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationPoliticalDistrict = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationPoliticalDistrict, _AbstractCrudObject);

  function TargetingGeoLocationPoliticalDistrict() {
    classCallCheck(this, TargetingGeoLocationPoliticalDistrict);
    return possibleConstructorReturn(this, (TargetingGeoLocationPoliticalDistrict.__proto__ || Object.getPrototypeOf(TargetingGeoLocationPoliticalDistrict)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationPoliticalDistrict, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        key: 'key',
        name: 'name',
        political_district: 'political_district'
      });
    }
  }]);
  return TargetingGeoLocationPoliticalDistrict;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationRegion
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationRegion = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationRegion, _AbstractCrudObject);

  function TargetingGeoLocationRegion() {
    classCallCheck(this, TargetingGeoLocationRegion);
    return possibleConstructorReturn(this, (TargetingGeoLocationRegion.__proto__ || Object.getPrototypeOf(TargetingGeoLocationRegion)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationRegion, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        key: 'key',
        name: 'name'
      });
    }
  }]);
  return TargetingGeoLocationRegion;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingGeoLocationZip
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingGeoLocationZip = function (_AbstractCrudObject) {
  inherits(TargetingGeoLocationZip, _AbstractCrudObject);

  function TargetingGeoLocationZip() {
    classCallCheck(this, TargetingGeoLocationZip);
    return possibleConstructorReturn(this, (TargetingGeoLocationZip.__proto__ || Object.getPrototypeOf(TargetingGeoLocationZip)).apply(this, arguments));
  }

  createClass(TargetingGeoLocationZip, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        country: 'country',
        key: 'key',
        name: 'name',
        primary_city_id: 'primary_city_id',
        region_id: 'region_id'
      });
    }
  }]);
  return TargetingGeoLocationZip;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingMarketingMessageChannels
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingMarketingMessageChannels = function (_AbstractCrudObject) {
  inherits(TargetingMarketingMessageChannels, _AbstractCrudObject);

  function TargetingMarketingMessageChannels() {
    classCallCheck(this, TargetingMarketingMessageChannels);
    return possibleConstructorReturn(this, (TargetingMarketingMessageChannels.__proto__ || Object.getPrototypeOf(TargetingMarketingMessageChannels)).apply(this, arguments));
  }

  createClass(TargetingMarketingMessageChannels, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        whatsapp: 'whatsapp'
      });
    }
  }]);
  return TargetingMarketingMessageChannels;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingProductAudienceSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingProductAudienceSpec = function (_AbstractCrudObject) {
  inherits(TargetingProductAudienceSpec, _AbstractCrudObject);

  function TargetingProductAudienceSpec() {
    classCallCheck(this, TargetingProductAudienceSpec);
    return possibleConstructorReturn(this, (TargetingProductAudienceSpec.__proto__ || Object.getPrototypeOf(TargetingProductAudienceSpec)).apply(this, arguments));
  }

  createClass(TargetingProductAudienceSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        exclusions: 'exclusions',
        inclusions: 'inclusions',
        product_set_id: 'product_set_id'
      });
    }
  }]);
  return TargetingProductAudienceSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingProductAudienceSubSpec
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingProductAudienceSubSpec = function (_AbstractCrudObject) {
  inherits(TargetingProductAudienceSubSpec, _AbstractCrudObject);

  function TargetingProductAudienceSubSpec() {
    classCallCheck(this, TargetingProductAudienceSubSpec);
    return possibleConstructorReturn(this, (TargetingProductAudienceSubSpec.__proto__ || Object.getPrototypeOf(TargetingProductAudienceSubSpec)).apply(this, arguments));
  }

  createClass(TargetingProductAudienceSubSpec, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        retention_seconds: 'retention_seconds',
        rule: 'rule'
      });
    }
  }]);
  return TargetingProductAudienceSubSpec;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingProspectingAudience
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingProspectingAudience = function (_AbstractCrudObject) {
  inherits(TargetingProspectingAudience, _AbstractCrudObject);

  function TargetingProspectingAudience() {
    classCallCheck(this, TargetingProspectingAudience);
    return possibleConstructorReturn(this, (TargetingProspectingAudience.__proto__ || Object.getPrototypeOf(TargetingProspectingAudience)).apply(this, arguments));
  }

  createClass(TargetingProspectingAudience, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        sources: 'sources'
      });
    }
  }]);
  return TargetingProspectingAudience;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TargetingRelaxation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TargetingRelaxation = function (_AbstractCrudObject) {
  inherits(TargetingRelaxation, _AbstractCrudObject);

  function TargetingRelaxation() {
    classCallCheck(this, TargetingRelaxation);
    return possibleConstructorReturn(this, (TargetingRelaxation.__proto__ || Object.getPrototypeOf(TargetingRelaxation)).apply(this, arguments));
  }

  createClass(TargetingRelaxation, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        custom_audience: 'custom_audience',
        lookalike: 'lookalike'
      });
    }
  }]);
  return TargetingRelaxation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ThirdPartyPartnerLiftRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ThirdPartyPartnerLiftRequest = function (_AbstractCrudObject) {
  inherits(ThirdPartyPartnerLiftRequest, _AbstractCrudObject);

  function ThirdPartyPartnerLiftRequest() {
    classCallCheck(this, ThirdPartyPartnerLiftRequest);
    return possibleConstructorReturn(this, (ThirdPartyPartnerLiftRequest.__proto__ || Object.getPrototypeOf(ThirdPartyPartnerLiftRequest)).apply(this, arguments));
  }

  createClass(ThirdPartyPartnerLiftRequest, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_entities: 'ad_entities',
        country: 'country',
        created_time: 'created_time',
        description: 'description',
        holdout_size: 'holdout_size',
        id: 'id',
        modified_time: 'modified_time',
        owner_instance_id: 'owner_instance_id',
        region: 'region',
        status: 'status',
        study_cells: 'study_cells',
        study_end_time: 'study_end_time',
        study_start_time: 'study_start_time'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        created: 'CREATED',
        failure: 'FAILURE',
        in_progress: 'IN_PROGRESS',
        scheduled: 'SCHEDULED',
        success: 'SUCCESS'
      });
    }
  }]);
  return ThirdPartyPartnerLiftRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ThirdPartyPartnerPanelRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ThirdPartyPartnerPanelRequest = function (_AbstractCrudObject) {
  inherits(ThirdPartyPartnerPanelRequest, _AbstractCrudObject);

  function ThirdPartyPartnerPanelRequest() {
    classCallCheck(this, ThirdPartyPartnerPanelRequest);
    return possibleConstructorReturn(this, (ThirdPartyPartnerPanelRequest.__proto__ || Object.getPrototypeOf(ThirdPartyPartnerPanelRequest)).apply(this, arguments));
  }

  createClass(ThirdPartyPartnerPanelRequest, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adentities_ids: 'adentities_ids',
        country: 'country',
        created_time: 'created_time',
        description: 'description',
        id: 'id',
        modified_time: 'modified_time',
        owner_instance_id: 'owner_instance_id',
        owner_panel_id: 'owner_panel_id',
        owner_panel_name: 'owner_panel_name',
        status: 'status',
        study_end_time: 'study_end_time',
        study_start_time: 'study_start_time',
        study_type: 'study_type'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        created: 'CREATED',
        failure: 'FAILURE',
        in_progress: 'IN_PROGRESS',
        scheduled: 'SCHEDULED',
        success: 'SUCCESS'
      });
    }
  }, {
    key: 'StudyType',
    get: function get() {
      return Object.freeze({
        brand_lift: 'BRAND_LIFT',
        panel_sales_attribution: 'PANEL_SALES_ATTRIBUTION',
        reach: 'REACH'
      });
    }
  }]);
  return ThirdPartyPartnerPanelRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ThirdPartyPartnerPanelScheduled
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ThirdPartyPartnerPanelScheduled = function (_AbstractCrudObject) {
  inherits(ThirdPartyPartnerPanelScheduled, _AbstractCrudObject);

  function ThirdPartyPartnerPanelScheduled() {
    classCallCheck(this, ThirdPartyPartnerPanelScheduled);
    return possibleConstructorReturn(this, (ThirdPartyPartnerPanelScheduled.__proto__ || Object.getPrototypeOf(ThirdPartyPartnerPanelScheduled)).apply(this, arguments));
  }

  createClass(ThirdPartyPartnerPanelScheduled, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        adentities_ids: 'adentities_ids',
        cadence: 'cadence',
        country: 'country',
        created_time: 'created_time',
        description: 'description',
        end_time: 'end_time',
        id: 'id',
        modified_time: 'modified_time',
        owner_instance_id: 'owner_instance_id',
        owner_panel_id: 'owner_panel_id',
        owner_panel_name: 'owner_panel_name',
        start_time: 'start_time',
        status: 'status',
        study_type: 'study_type'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        cancelled: 'CANCELLED',
        created: 'CREATED',
        finished: 'FINISHED',
        ongoing: 'ONGOING'
      });
    }
  }, {
    key: 'StudyType',
    get: function get() {
      return Object.freeze({
        brand_lift: 'BRAND_LIFT',
        panel_sales_attribution: 'PANEL_SALES_ATTRIBUTION',
        reach: 'REACH'
      });
    }
  }]);
  return ThirdPartyPartnerPanelScheduled;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ThirdPartyPartnerViewabilityRequest
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ThirdPartyPartnerViewabilityRequest = function (_AbstractCrudObject) {
  inherits(ThirdPartyPartnerViewabilityRequest, _AbstractCrudObject);

  function ThirdPartyPartnerViewabilityRequest() {
    classCallCheck(this, ThirdPartyPartnerViewabilityRequest);
    return possibleConstructorReturn(this, (ThirdPartyPartnerViewabilityRequest.__proto__ || Object.getPrototypeOf(ThirdPartyPartnerViewabilityRequest)).apply(this, arguments));
  }

  createClass(ThirdPartyPartnerViewabilityRequest, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        created_time: 'created_time',
        description: 'description',
        hour: 'hour',
        id: 'id',
        metric: 'metric',
        modified_time: 'modified_time',
        owner_instance_id: 'owner_instance_id',
        platform: 'platform',
        status: 'status',
        total_file_count: 'total_file_count'
      });
    }
  }, {
    key: 'Metric',
    get: function get() {
      return Object.freeze({
        display_event: 'DISPLAY_EVENT',
        impression: 'IMPRESSION',
        video_event: 'VIDEO_EVENT'
      });
    }
  }, {
    key: 'Platform',
    get: function get() {
      return Object.freeze({
        audience_network: 'AUDIENCE_NETWORK',
        facebook: 'FACEBOOK',
        instagram: 'INSTAGRAM'
      });
    }
  }, {
    key: 'Status',
    get: function get() {
      return Object.freeze({
        created: 'CREATED',
        failure: 'FAILURE',
        in_progress: 'IN_PROGRESS',
        scheduled: 'SCHEDULED',
        success: 'SUCCESS'
      });
    }
  }]);
  return ThirdPartyPartnerViewabilityRequest;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TimeSuggestion
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TimeSuggestion = function (_AbstractCrudObject) {
  inherits(TimeSuggestion, _AbstractCrudObject);

  function TimeSuggestion() {
    classCallCheck(this, TimeSuggestion);
    return possibleConstructorReturn(this, (TimeSuggestion.__proto__ || Object.getPrototypeOf(TimeSuggestion)).apply(this, arguments));
  }

  createClass(TimeSuggestion, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        high_demand_periods: 'high_demand_periods',
        is_enabled: 'is_enabled'
      });
    }
  }]);
  return TimeSuggestion;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TimezoneOffset
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TimezoneOffset = function (_AbstractCrudObject) {
  inherits(TimezoneOffset, _AbstractCrudObject);

  function TimezoneOffset() {
    classCallCheck(this, TimezoneOffset);
    return possibleConstructorReturn(this, (TimezoneOffset.__proto__ || Object.getPrototypeOf(TimezoneOffset)).apply(this, arguments));
  }

  createClass(TimezoneOffset, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        abbr: 'abbr',
        isdst: 'isdst',
        offset: 'offset',
        time: 'time',
        ts: 'ts'
      });
    }
  }]);
  return TimezoneOffset;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TrackingAndConversionWithDefaults
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TrackingAndConversionWithDefaults = function (_AbstractCrudObject) {
  inherits(TrackingAndConversionWithDefaults, _AbstractCrudObject);

  function TrackingAndConversionWithDefaults() {
    classCallCheck(this, TrackingAndConversionWithDefaults);
    return possibleConstructorReturn(this, (TrackingAndConversionWithDefaults.__proto__ || Object.getPrototypeOf(TrackingAndConversionWithDefaults)).apply(this, arguments));
  }

  createClass(TrackingAndConversionWithDefaults, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        custom_conversion: 'custom_conversion',
        custom_tracking: 'custom_tracking',
        default_conversion: 'default_conversion',
        default_tracking: 'default_tracking'
      });
    }
  }]);
  return TrackingAndConversionWithDefaults;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * TransactableItem
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var TransactableItem = function (_AbstractCrudObject) {
  inherits(TransactableItem, _AbstractCrudObject);

  function TransactableItem() {
    classCallCheck(this, TransactableItem);
    return possibleConstructorReturn(this, (TransactableItem.__proto__ || Object.getPrototypeOf(TransactableItem)).apply(this, arguments));
  }

  createClass(TransactableItem, [{
    key: 'getChannelsToIntegrityStatus',
    value: function getChannelsToIntegrityStatus(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(CatalogItemChannelsToIntegrityStatus, fields, params, fetchFirstPage, '/channels_to_integrity_status');
    }
  }, {
    key: 'getOverrideDetails',
    value: function getOverrideDetails(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(OverrideDetails, fields, params, fetchFirstPage, '/override_details');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action_title: 'action_title',
        applinks: 'applinks',
        category_specific_fields: 'category_specific_fields',
        currency: 'currency',
        description: 'description',
        duration_time: 'duration_time',
        duration_type: 'duration_type',
        id: 'id',
        image_fetch_status: 'image_fetch_status',
        images: 'images',
        order_index: 'order_index',
        price: 'price',
        price_type: 'price_type',
        sanitized_images: 'sanitized_images',
        session_type: 'session_type',
        time_padding_after_end: 'time_padding_after_end',
        title: 'title',
        transactable_item_id: 'transactable_item_id',
        url: 'url',
        visibility: 'visibility'
      });
    }
  }, {
    key: 'ImageFetchStatus',
    get: function get() {
      return Object.freeze({
        direct_upload: 'DIRECT_UPLOAD',
        fetched: 'FETCHED',
        fetch_failed: 'FETCH_FAILED',
        no_status: 'NO_STATUS',
        outdated: 'OUTDATED',
        partial_fetch: 'PARTIAL_FETCH'
      });
    }
  }, {
    key: 'Visibility',
    get: function get() {
      return Object.freeze({
        published: 'PUBLISHED',
        staging: 'STAGING'
      });
    }
  }]);
  return TransactableItem;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * Transaction
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var Transaction = function (_AbstractCrudObject) {
  inherits(Transaction, _AbstractCrudObject);

  function Transaction() {
    classCallCheck(this, Transaction);
    return possibleConstructorReturn(this, (Transaction.__proto__ || Object.getPrototypeOf(Transaction)).apply(this, arguments));
  }

  createClass(Transaction, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        app_amount: 'app_amount',
        billing_end_time: 'billing_end_time',
        billing_reason: 'billing_reason',
        billing_start_time: 'billing_start_time',
        card_charge_mode: 'card_charge_mode',
        charge_type: 'charge_type',
        checkout_campaign_group_id: 'checkout_campaign_group_id',
        credential_id: 'credential_id',
        fatura_id: 'fatura_id',
        id: 'id',
        is_business_ec_charge: 'is_business_ec_charge',
        is_funding_event: 'is_funding_event',
        payment_option: 'payment_option',
        product_type: 'product_type',
        provider_amount: 'provider_amount',
        status: 'status',
        time: 'time',
        tracking_id: 'tracking_id',
        transaction_type: 'transaction_type',
        tx_type: 'tx_type',
        vat_invoice_id: 'vat_invoice_id'
      });
    }
  }, {
    key: 'ProductType',
    get: function get() {
      return Object.freeze({
        cp_return_label: 'cp_return_label',
        facebook_ad: 'facebook_ad',
        ig_ad: 'ig_ad',
        whatsapp: 'whatsapp',
        workplace: 'workplace'
      });
    }
  }]);
  return Transaction;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * URL
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var URL = function (_AbstractCrudObject) {
  inherits(URL, _AbstractCrudObject);

  function URL() {
    classCallCheck(this, URL);
    return possibleConstructorReturn(this, (URL.__proto__ || Object.getPrototypeOf(URL)).apply(this, arguments));
  }

  createClass(URL, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(URL.prototype.__proto__ || Object.getPrototypeOf(URL.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        engagement: 'engagement',
        id: 'id',
        og_object: 'og_object',
        ownership_permissions: 'ownership_permissions',
        scopes: 'scopes'
      });
    }
  }, {
    key: 'Scopes',
    get: function get() {
      return Object.freeze({
        news_tab: 'NEWS_TAB',
        news_tab_dev_env: 'NEWS_TAB_DEV_ENV'
      });
    }
  }]);
  return URL;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UniqueAdCreative
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UniqueAdCreative = function (_AbstractCrudObject) {
  inherits(UniqueAdCreative, _AbstractCrudObject);

  function UniqueAdCreative() {
    classCallCheck(this, UniqueAdCreative);
    return possibleConstructorReturn(this, (UniqueAdCreative.__proto__ || Object.getPrototypeOf(UniqueAdCreative)).apply(this, arguments));
  }

  createClass(UniqueAdCreative, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        sample_creative: 'sample_creative',
        visual_hash: 'visual_hash'
      });
    }
  }]);
  return UniqueAdCreative;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserContext
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserContext = function (_AbstractCrudObject) {
  inherits(UserContext, _AbstractCrudObject);

  function UserContext() {
    classCallCheck(this, UserContext);
    return possibleConstructorReturn(this, (UserContext.__proto__ || Object.getPrototypeOf(UserContext)).apply(this, arguments));
  }

  createClass(UserContext, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return UserContext;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserCoverPhoto
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserCoverPhoto = function (_AbstractCrudObject) {
  inherits(UserCoverPhoto, _AbstractCrudObject);

  function UserCoverPhoto() {
    classCallCheck(this, UserCoverPhoto);
    return possibleConstructorReturn(this, (UserCoverPhoto.__proto__ || Object.getPrototypeOf(UserCoverPhoto)).apply(this, arguments));
  }

  createClass(UserCoverPhoto, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        offset_x: 'offset_x',
        offset_y: 'offset_y',
        source: 'source'
      });
    }
  }]);
  return UserCoverPhoto;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserDevice
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserDevice = function (_AbstractCrudObject) {
  inherits(UserDevice, _AbstractCrudObject);

  function UserDevice() {
    classCallCheck(this, UserDevice);
    return possibleConstructorReturn(this, (UserDevice.__proto__ || Object.getPrototypeOf(UserDevice)).apply(this, arguments));
  }

  createClass(UserDevice, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        hardware: 'hardware',
        os: 'os'
      });
    }
  }]);
  return UserDevice;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserLeadGenDisclaimerResponse
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserLeadGenDisclaimerResponse = function (_AbstractCrudObject) {
  inherits(UserLeadGenDisclaimerResponse, _AbstractCrudObject);

  function UserLeadGenDisclaimerResponse() {
    classCallCheck(this, UserLeadGenDisclaimerResponse);
    return possibleConstructorReturn(this, (UserLeadGenDisclaimerResponse.__proto__ || Object.getPrototypeOf(UserLeadGenDisclaimerResponse)).apply(this, arguments));
  }

  createClass(UserLeadGenDisclaimerResponse, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        checkbox_key: 'checkbox_key',
        is_checked: 'is_checked'
      });
    }
  }]);
  return UserLeadGenDisclaimerResponse;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserLeadGenFieldData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserLeadGenFieldData = function (_AbstractCrudObject) {
  inherits(UserLeadGenFieldData, _AbstractCrudObject);

  function UserLeadGenFieldData() {
    classCallCheck(this, UserLeadGenFieldData);
    return possibleConstructorReturn(this, (UserLeadGenFieldData.__proto__ || Object.getPrototypeOf(UserLeadGenFieldData)).apply(this, arguments));
  }

  createClass(UserLeadGenFieldData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        name: 'name',
        values: 'values'
      });
    }
  }]);
  return UserLeadGenFieldData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserMobileConfig
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserMobileConfig = function (_AbstractCrudObject) {
  inherits(UserMobileConfig, _AbstractCrudObject);

  function UserMobileConfig() {
    classCallCheck(this, UserMobileConfig);
    return possibleConstructorReturn(this, (UserMobileConfig.__proto__ || Object.getPrototypeOf(UserMobileConfig)).apply(this, arguments));
  }

  createClass(UserMobileConfig, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        section_name: 'section_name',
        value: 'value'
      });
    }
  }]);
  return UserMobileConfig;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserNotificationSeenStateData
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserNotificationSeenStateData = function (_AbstractCrudObject) {
  inherits(UserNotificationSeenStateData, _AbstractCrudObject);

  function UserNotificationSeenStateData() {
    classCallCheck(this, UserNotificationSeenStateData);
    return possibleConstructorReturn(this, (UserNotificationSeenStateData.__proto__ || Object.getPrototypeOf(UserNotificationSeenStateData)).apply(this, arguments));
  }

  createClass(UserNotificationSeenStateData, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        seen_state: 'seen_state'
      });
    }
  }]);
  return UserNotificationSeenStateData;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserPaymentMethodsInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserPaymentMethodsInfo = function (_AbstractCrudObject) {
  inherits(UserPaymentMethodsInfo, _AbstractCrudObject);

  function UserPaymentMethodsInfo() {
    classCallCheck(this, UserPaymentMethodsInfo);
    return possibleConstructorReturn(this, (UserPaymentMethodsInfo.__proto__ || Object.getPrototypeOf(UserPaymentMethodsInfo)).apply(this, arguments));
  }

  createClass(UserPaymentMethodsInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        available_card_types: 'available_card_types',
        available_payment_methods: 'available_payment_methods',
        available_payment_methods_details: 'available_payment_methods_details',
        country: 'country',
        currency: 'currency',
        existing_payment_methods: 'existing_payment_methods'
      });
    }
  }]);
  return UserPaymentMethodsInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserPaymentMobilePricepoints
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserPaymentMobilePricepoints = function (_AbstractCrudObject) {
  inherits(UserPaymentMobilePricepoints, _AbstractCrudObject);

  function UserPaymentMobilePricepoints() {
    classCallCheck(this, UserPaymentMobilePricepoints);
    return possibleConstructorReturn(this, (UserPaymentMobilePricepoints.__proto__ || Object.getPrototypeOf(UserPaymentMobilePricepoints)).apply(this, arguments));
  }

  createClass(UserPaymentMobilePricepoints, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        mobile_country: 'mobile_country',
        phone_number_last4: 'phone_number_last4',
        pricepoints: 'pricepoints',
        user_currency: 'user_currency'
      });
    }
  }]);
  return UserPaymentMobilePricepoints;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * UserPaymentModulesOptions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var UserPaymentModulesOptions = function (_AbstractCrudObject) {
  inherits(UserPaymentModulesOptions, _AbstractCrudObject);

  function UserPaymentModulesOptions() {
    classCallCheck(this, UserPaymentModulesOptions);
    return possibleConstructorReturn(this, (UserPaymentModulesOptions.__proto__ || Object.getPrototypeOf(UserPaymentModulesOptions)).apply(this, arguments));
  }

  createClass(UserPaymentModulesOptions, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        account_id: 'account_id',
        available_payment_options: 'available_payment_options',
        country: 'country',
        currency: 'currency'
      });
    }
  }]);
  return UserPaymentModulesOptions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * ValueBasedEligibleSource
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var ValueBasedEligibleSource = function (_AbstractCrudObject) {
  inherits(ValueBasedEligibleSource, _AbstractCrudObject);

  function ValueBasedEligibleSource() {
    classCallCheck(this, ValueBasedEligibleSource);
    return possibleConstructorReturn(this, (ValueBasedEligibleSource.__proto__ || Object.getPrototypeOf(ValueBasedEligibleSource)).apply(this, arguments));
  }

  createClass(ValueBasedEligibleSource, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        title: 'title',
        type: 'type'
      });
    }
  }]);
  return ValueBasedEligibleSource;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoCopyrightCheckStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoCopyrightCheckStatus = function (_AbstractCrudObject) {
  inherits(VideoCopyrightCheckStatus, _AbstractCrudObject);

  function VideoCopyrightCheckStatus() {
    classCallCheck(this, VideoCopyrightCheckStatus);
    return possibleConstructorReturn(this, (VideoCopyrightCheckStatus.__proto__ || Object.getPrototypeOf(VideoCopyrightCheckStatus)).apply(this, arguments));
  }

  createClass(VideoCopyrightCheckStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        matches_found: 'matches_found',
        status: 'status'
      });
    }
  }]);
  return VideoCopyrightCheckStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoCopyrightConditionGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoCopyrightConditionGroup = function (_AbstractCrudObject) {
  inherits(VideoCopyrightConditionGroup, _AbstractCrudObject);

  function VideoCopyrightConditionGroup() {
    classCallCheck(this, VideoCopyrightConditionGroup);
    return possibleConstructorReturn(this, (VideoCopyrightConditionGroup.__proto__ || Object.getPrototypeOf(VideoCopyrightConditionGroup)).apply(this, arguments));
  }

  createClass(VideoCopyrightConditionGroup, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        action: 'action',
        conditions: 'conditions',
        validity_status: 'validity_status'
      });
    }
  }]);
  return VideoCopyrightConditionGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoCopyrightGeoGate
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoCopyrightGeoGate = function (_AbstractCrudObject) {
  inherits(VideoCopyrightGeoGate, _AbstractCrudObject);

  function VideoCopyrightGeoGate() {
    classCallCheck(this, VideoCopyrightGeoGate);
    return possibleConstructorReturn(this, (VideoCopyrightGeoGate.__proto__ || Object.getPrototypeOf(VideoCopyrightGeoGate)).apply(this, arguments));
  }

  createClass(VideoCopyrightGeoGate, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        excluded_countries: 'excluded_countries',
        included_countries: 'included_countries'
      });
    }
  }]);
  return VideoCopyrightGeoGate;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoCopyrightSegment
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoCopyrightSegment = function (_AbstractCrudObject) {
  inherits(VideoCopyrightSegment, _AbstractCrudObject);

  function VideoCopyrightSegment() {
    classCallCheck(this, VideoCopyrightSegment);
    return possibleConstructorReturn(this, (VideoCopyrightSegment.__proto__ || Object.getPrototypeOf(VideoCopyrightSegment)).apply(this, arguments));
  }

  createClass(VideoCopyrightSegment, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        duration_in_sec: 'duration_in_sec',
        media_type: 'media_type',
        start_time_in_sec: 'start_time_in_sec'
      });
    }
  }]);
  return VideoCopyrightSegment;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoGroup
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoGroup = function (_AbstractCrudObject) {
  inherits(VideoGroup, _AbstractCrudObject);

  function VideoGroup() {
    classCallCheck(this, VideoGroup);
    return possibleConstructorReturn(this, (VideoGroup.__proto__ || Object.getPrototypeOf(VideoGroup)).apply(this, arguments));
  }

  createClass(VideoGroup, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        created_time: 'created_time',
        description: 'description',
        disable_reason: 'disable_reason',
        id: 'id',
        ig_profile_ids: 'ig_profile_ids',
        is_disabled: 'is_disabled',
        is_fb_video_group: 'is_fb_video_group',
        last_used_time: 'last_used_time',
        length: 'length',
        name: 'name',
        page_id: 'page_id',
        page_ids: 'page_ids',
        picture: 'picture',
        placements: 'placements',
        video_group_types: 'video_group_types',
        videos: 'videos',
        views: 'views'
      });
    }
  }]);
  return VideoGroup;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoMetricsReport
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoMetricsReport = function (_AbstractCrudObject) {
  inherits(VideoMetricsReport, _AbstractCrudObject);

  function VideoMetricsReport() {
    classCallCheck(this, VideoMetricsReport);
    return possibleConstructorReturn(this, (VideoMetricsReport.__proto__ || Object.getPrototypeOf(VideoMetricsReport)).apply(this, arguments));
  }

  createClass(VideoMetricsReport, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        checksum: 'checksum',
        chunks: 'chunks',
        end_date: 'end_date',
        id: 'id',
        index: 'index',
        name: 'name',
        platform: 'platform',
        start_date: 'start_date',
        type: 'type',
        upload_date: 'upload_date',
        url: 'url'
      });
    }
  }]);
  return VideoMetricsReport;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoStats
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoStats = function (_AbstractCrudObject) {
  inherits(VideoStats, _AbstractCrudObject);

  function VideoStats() {
    classCallCheck(this, VideoStats);
    return possibleConstructorReturn(this, (VideoStats.__proto__ || Object.getPrototypeOf(VideoStats)).apply(this, arguments));
  }

  createClass(VideoStats, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        aggregate: 'aggregate',
        error: 'error',
        metadata: 'metadata',
        time_series: 'time_series',
        totals: 'totals',
        x_axis_breakdown: 'x_axis_breakdown'
      });
    }
  }]);
  return VideoStats;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoStatus = function (_AbstractCrudObject) {
  inherits(VideoStatus, _AbstractCrudObject);

  function VideoStatus() {
    classCallCheck(this, VideoStatus);
    return possibleConstructorReturn(this, (VideoStatus.__proto__ || Object.getPrototypeOf(VideoStatus)).apply(this, arguments));
  }

  createClass(VideoStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        copyright_check_status: 'copyright_check_status',
        processing_phase: 'processing_phase',
        processing_progress: 'processing_progress',
        publishing_phase: 'publishing_phase',
        uploading_phase: 'uploading_phase',
        video_status: 'video_status'
      });
    }
  }]);
  return VideoStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoStatusError
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoStatusError = function (_AbstractCrudObject) {
  inherits(VideoStatusError, _AbstractCrudObject);

  function VideoStatusError() {
    classCallCheck(this, VideoStatusError);
    return possibleConstructorReturn(this, (VideoStatusError.__proto__ || Object.getPrototypeOf(VideoStatusError)).apply(this, arguments));
  }

  createClass(VideoStatusError, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        code: 'code',
        message: 'message'
      });
    }
  }]);
  return VideoStatusError;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoStatusProcessingPhase
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoStatusProcessingPhase = function (_AbstractCrudObject) {
  inherits(VideoStatusProcessingPhase, _AbstractCrudObject);

  function VideoStatusProcessingPhase() {
    classCallCheck(this, VideoStatusProcessingPhase);
    return possibleConstructorReturn(this, (VideoStatusProcessingPhase.__proto__ || Object.getPrototypeOf(VideoStatusProcessingPhase)).apply(this, arguments));
  }

  createClass(VideoStatusProcessingPhase, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        errors: 'errors',
        status: 'status'
      });
    }
  }]);
  return VideoStatusProcessingPhase;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoStatusPublishingPhase
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoStatusPublishingPhase = function (_AbstractCrudObject) {
  inherits(VideoStatusPublishingPhase, _AbstractCrudObject);

  function VideoStatusPublishingPhase() {
    classCallCheck(this, VideoStatusPublishingPhase);
    return possibleConstructorReturn(this, (VideoStatusPublishingPhase.__proto__ || Object.getPrototypeOf(VideoStatusPublishingPhase)).apply(this, arguments));
  }

  createClass(VideoStatusPublishingPhase, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        errors: 'errors',
        publish_status: 'publish_status',
        publish_time: 'publish_time',
        status: 'status'
      });
    }
  }]);
  return VideoStatusPublishingPhase;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoStatusUploadingPhase
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoStatusUploadingPhase = function (_AbstractCrudObject) {
  inherits(VideoStatusUploadingPhase, _AbstractCrudObject);

  function VideoStatusUploadingPhase() {
    classCallCheck(this, VideoStatusUploadingPhase);
    return possibleConstructorReturn(this, (VideoStatusUploadingPhase.__proto__ || Object.getPrototypeOf(VideoStatusUploadingPhase)).apply(this, arguments));
  }

  createClass(VideoStatusUploadingPhase, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        bytes_transferred: 'bytes_transferred',
        errors: 'errors',
        source_file_size: 'source_file_size',
        status: 'status'
      });
    }
  }]);
  return VideoStatusUploadingPhase;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoTextQuestion
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoTextQuestion = function (_AbstractCrudObject) {
  inherits(VideoTextQuestion, _AbstractCrudObject);

  function VideoTextQuestion() {
    classCallCheck(this, VideoTextQuestion);
    return possibleConstructorReturn(this, (VideoTextQuestion.__proto__ || Object.getPrototypeOf(VideoTextQuestion)).apply(this, arguments));
  }

  createClass(VideoTextQuestion, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        question_target_id: 'question_target_id',
        question_text: 'question_text',
        status: 'status'
      });
    }
  }]);
  return VideoTextQuestion;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VideoUploadLimits
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VideoUploadLimits = function (_AbstractCrudObject) {
  inherits(VideoUploadLimits, _AbstractCrudObject);

  function VideoUploadLimits() {
    classCallCheck(this, VideoUploadLimits);
    return possibleConstructorReturn(this, (VideoUploadLimits.__proto__ || Object.getPrototypeOf(VideoUploadLimits)).apply(this, arguments));
  }

  createClass(VideoUploadLimits, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        length: 'length',
        size: 'size'
      });
    }
  }]);
  return VideoUploadLimits;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * VoipInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var VoipInfo = function (_AbstractCrudObject) {
  inherits(VoipInfo, _AbstractCrudObject);

  function VoipInfo() {
    classCallCheck(this, VoipInfo);
    return possibleConstructorReturn(this, (VoipInfo.__proto__ || Object.getPrototypeOf(VoipInfo)).apply(this, arguments));
  }

  createClass(VoipInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        has_mobile_app: 'has_mobile_app',
        has_permission: 'has_permission',
        is_callable: 'is_callable',
        is_callable_webrtc: 'is_callable_webrtc',
        is_pushable: 'is_pushable',
        reason_code: 'reason_code',
        reason_description: 'reason_description'
      });
    }
  }]);
  return VoipInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WITUser
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WITUser = function (_AbstractCrudObject) {
  inherits(WITUser, _AbstractCrudObject);

  function WITUser() {
    classCallCheck(this, WITUser);
    return possibleConstructorReturn(this, (WITUser.__proto__ || Object.getPrototypeOf(WITUser)).apply(this, arguments));
  }

  createClass(WITUser, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        access_token: 'access_token',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return WITUser;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WearableDevicePublicKey
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WearableDevicePublicKey = function (_AbstractCrudObject) {
  inherits(WearableDevicePublicKey, _AbstractCrudObject);

  function WearableDevicePublicKey() {
    classCallCheck(this, WearableDevicePublicKey);
    return possibleConstructorReturn(this, (WearableDevicePublicKey.__proto__ || Object.getPrototypeOf(WearableDevicePublicKey)).apply(this, arguments));
  }

  createClass(WearableDevicePublicKey, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        base64_encoded_public_key: 'base64_encoded_public_key',
        creation_time_on_device: 'creation_time_on_device',
        device_uuid: 'device_uuid',
        id: 'id',
        key_type: 'key_type',
        owner_id: 'owner_id',
        product_use_case: 'product_use_case',
        version: 'version'
      });
    }
  }]);
  return WearableDevicePublicKey;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WebAppLink
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WebAppLink = function (_AbstractCrudObject) {
  inherits(WebAppLink, _AbstractCrudObject);

  function WebAppLink() {
    classCallCheck(this, WebAppLink);
    return possibleConstructorReturn(this, (WebAppLink.__proto__ || Object.getPrototypeOf(WebAppLink)).apply(this, arguments));
  }

  createClass(WebAppLink, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        should_fallback: 'should_fallback',
        url: 'url'
      });
    }
  }]);
  return WebAppLink;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WebsiteCreativeAssetSource
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WebsiteCreativeAssetSource = function (_AbstractCrudObject) {
  inherits(WebsiteCreativeAssetSource, _AbstractCrudObject);

  function WebsiteCreativeAssetSource() {
    classCallCheck(this, WebsiteCreativeAssetSource);
    return possibleConstructorReturn(this, (WebsiteCreativeAssetSource.__proto__ || Object.getPrototypeOf(WebsiteCreativeAssetSource)).apply(this, arguments));
  }

  createClass(WebsiteCreativeAssetSource, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        source_url: 'source_url'
      });
    }
  }]);
  return WebsiteCreativeAssetSource;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WebsiteCreativeAssetSuggestions
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WebsiteCreativeAssetSuggestions = function (_AbstractCrudObject) {
  inherits(WebsiteCreativeAssetSuggestions, _AbstractCrudObject);

  function WebsiteCreativeAssetSuggestions() {
    classCallCheck(this, WebsiteCreativeAssetSuggestions);
    return possibleConstructorReturn(this, (WebsiteCreativeAssetSuggestions.__proto__ || Object.getPrototypeOf(WebsiteCreativeAssetSuggestions)).apply(this, arguments));
  }

  createClass(WebsiteCreativeAssetSuggestions, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        ad_account_id: 'ad_account_id',
        extraction_status: 'extraction_status',
        id: 'id',
        link_url: 'link_url'
      });
    }
  }]);
  return WebsiteCreativeAssetSuggestions;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WhatsAppBusinessHealthStatus
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WhatsAppBusinessHealthStatus = function (_AbstractCrudObject) {
  inherits(WhatsAppBusinessHealthStatus, _AbstractCrudObject);

  function WhatsAppBusinessHealthStatus() {
    classCallCheck(this, WhatsAppBusinessHealthStatus);
    return possibleConstructorReturn(this, (WhatsAppBusinessHealthStatus.__proto__ || Object.getPrototypeOf(WhatsAppBusinessHealthStatus)).apply(this, arguments));
  }

  createClass(WhatsAppBusinessHealthStatus, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        additional_info: 'additional_info',
        can_send_message: 'can_send_message',
        entity_type: 'entity_type',
        errors: 'errors',
        id: 'id'
      });
    }
  }]);
  return WhatsAppBusinessHealthStatus;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WhatsAppBusinessHealthStatusForMessageSend
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WhatsAppBusinessHealthStatusForMessageSend = function (_AbstractCrudObject) {
  inherits(WhatsAppBusinessHealthStatusForMessageSend, _AbstractCrudObject);

  function WhatsAppBusinessHealthStatusForMessageSend() {
    classCallCheck(this, WhatsAppBusinessHealthStatusForMessageSend);
    return possibleConstructorReturn(this, (WhatsAppBusinessHealthStatusForMessageSend.__proto__ || Object.getPrototypeOf(WhatsAppBusinessHealthStatusForMessageSend)).apply(this, arguments));
  }

  createClass(WhatsAppBusinessHealthStatusForMessageSend, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        can_send_message: 'can_send_message',
        entities: 'entities'
      });
    }
  }]);
  return WhatsAppBusinessHealthStatusForMessageSend;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WhatsAppBusinessProfile
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WhatsAppBusinessProfile = function (_AbstractCrudObject) {
  inherits(WhatsAppBusinessProfile, _AbstractCrudObject);

  function WhatsAppBusinessProfile() {
    classCallCheck(this, WhatsAppBusinessProfile);
    return possibleConstructorReturn(this, (WhatsAppBusinessProfile.__proto__ || Object.getPrototypeOf(WhatsAppBusinessProfile)).apply(this, arguments));
  }

  createClass(WhatsAppBusinessProfile, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }

    // $FlowFixMe : Support Generic Types

  }, {
    key: 'update',
    value: function update(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return get$1(WhatsAppBusinessProfile.prototype.__proto__ || Object.getPrototypeOf(WhatsAppBusinessProfile.prototype), 'update', this).call(this, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name_verification: 'name_verification',
        whatsapp_business_api_data: 'whatsapp_business_api_data'
      });
    }
  }]);
  return WhatsAppBusinessProfile;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WhatsAppPaymentCapabilities
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WhatsAppPaymentCapabilities = function (_AbstractCrudObject) {
  inherits(WhatsAppPaymentCapabilities, _AbstractCrudObject);

  function WhatsAppPaymentCapabilities() {
    classCallCheck(this, WhatsAppPaymentCapabilities);
    return possibleConstructorReturn(this, (WhatsAppPaymentCapabilities.__proto__ || Object.getPrototypeOf(WhatsAppPaymentCapabilities)).apply(this, arguments));
  }

  createClass(WhatsAppPaymentCapabilities, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        is_enabled: 'is_enabled',
        payment_capability_details: 'payment_capability_details'
      });
    }
  }]);
  return WhatsAppPaymentCapabilities;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WhatsappSubscribedAppsInfo
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WhatsappSubscribedAppsInfo = function (_AbstractCrudObject) {
  inherits(WhatsappSubscribedAppsInfo, _AbstractCrudObject);

  function WhatsappSubscribedAppsInfo() {
    classCallCheck(this, WhatsappSubscribedAppsInfo);
    return possibleConstructorReturn(this, (WhatsappSubscribedAppsInfo.__proto__ || Object.getPrototypeOf(WhatsappSubscribedAppsInfo)).apply(this, arguments));
  }

  createClass(WhatsappSubscribedAppsInfo, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        page_whatsapp_number: 'page_whatsapp_number',
        subscribed_apps: 'subscribed_apps'
      });
    }
  }]);
  return WhatsappSubscribedAppsInfo;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WhitehatFBDLRun
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WhitehatFBDLRun = function (_AbstractCrudObject) {
  inherits(WhitehatFBDLRun, _AbstractCrudObject);

  function WhitehatFBDLRun() {
    classCallCheck(this, WhitehatFBDLRun);
    return possibleConstructorReturn(this, (WhitehatFBDLRun.__proto__ || Object.getPrototypeOf(WhitehatFBDLRun)).apply(this, arguments));
  }

  createClass(WhitehatFBDLRun, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        id: 'id',
        is_pinned: 'is_pinned',
        note: 'note',
        result: 'result',
        run_code: 'run_code',
        status: 'status',
        user_type: 'user_type'
      });
    }
  }]);
  return WhitehatFBDLRun;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WifiInformation
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WifiInformation = function (_AbstractCrudObject) {
  inherits(WifiInformation, _AbstractCrudObject);

  function WifiInformation() {
    classCallCheck(this, WifiInformation);
    return possibleConstructorReturn(this, (WifiInformation.__proto__ || Object.getPrototypeOf(WifiInformation)).apply(this, arguments));
  }

  createClass(WifiInformation, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name',
        network_access_type: 'network_access_type'
      });
    }
  }]);
  return WifiInformation;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WindowsAppLink
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WindowsAppLink = function (_AbstractCrudObject) {
  inherits(WindowsAppLink, _AbstractCrudObject);

  function WindowsAppLink() {
    classCallCheck(this, WindowsAppLink);
    return possibleConstructorReturn(this, (WindowsAppLink.__proto__ || Object.getPrototypeOf(WindowsAppLink)).apply(this, arguments));
  }

  createClass(WindowsAppLink, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        app_name: 'app_name',
        package_family_name: 'package_family_name',
        url: 'url'
      });
    }
  }]);
  return WindowsAppLink;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WindowsPhoneAppLink
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WindowsPhoneAppLink = function (_AbstractCrudObject) {
  inherits(WindowsPhoneAppLink, _AbstractCrudObject);

  function WindowsPhoneAppLink() {
    classCallCheck(this, WindowsPhoneAppLink);
    return possibleConstructorReturn(this, (WindowsPhoneAppLink.__proto__ || Object.getPrototypeOf(WindowsPhoneAppLink)).apply(this, arguments));
  }

  createClass(WindowsPhoneAppLink, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        app_id: 'app_id',
        app_name: 'app_name',
        url: 'url'
      });
    }
  }]);
  return WindowsPhoneAppLink;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WithAsset3D
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WithAsset3D = function (_AbstractCrudObject) {
  inherits(WithAsset3D, _AbstractCrudObject);

  function WithAsset3D() {
    classCallCheck(this, WithAsset3D);
    return possibleConstructorReturn(this, (WithAsset3D.__proto__ || Object.getPrototypeOf(WithAsset3D)).apply(this, arguments));
  }

  createClass(WithAsset3D, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id'
      });
    }
  }]);
  return WithAsset3D;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WoodhengePurchasedPAYGReceipt
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WoodhengePurchasedPAYGReceipt = function (_AbstractCrudObject) {
  inherits(WoodhengePurchasedPAYGReceipt, _AbstractCrudObject);

  function WoodhengePurchasedPAYGReceipt() {
    classCallCheck(this, WoodhengePurchasedPAYGReceipt);
    return possibleConstructorReturn(this, (WoodhengePurchasedPAYGReceipt.__proto__ || Object.getPrototypeOf(WoodhengePurchasedPAYGReceipt)).apply(this, arguments));
  }

  createClass(WoodhengePurchasedPAYGReceipt, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        number_of_subscriptions_purchased: 'number_of_subscriptions_purchased',
        purchase_time: 'purchase_time',
        user: 'user'
      });
    }
  }]);
  return WoodhengePurchasedPAYGReceipt;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WoodhengeSupporter
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WoodhengeSupporter = function (_AbstractCrudObject) {
  inherits(WoodhengeSupporter, _AbstractCrudObject);

  function WoodhengeSupporter() {
    classCallCheck(this, WoodhengeSupporter);
    return possibleConstructorReturn(this, (WoodhengeSupporter.__proto__ || Object.getPrototypeOf(WoodhengeSupporter)).apply(this, arguments));
  }

  createClass(WoodhengeSupporter, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        creation_time: 'creation_time',
        id: 'id',
        is_gifted_subscription: 'is_gifted_subscription',
        most_recent_subscription_time: 'most_recent_subscription_time',
        number_of_months_subscribed: 'number_of_months_subscribed',
        user: 'user'
      });
    }
  }]);
  return WoodhengeSupporter;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WorkAccessCode
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WorkAccessCode = function (_AbstractCrudObject) {
  inherits(WorkAccessCode, _AbstractCrudObject);

  function WorkAccessCode() {
    classCallCheck(this, WorkAccessCode);
    return possibleConstructorReturn(this, (WorkAccessCode.__proto__ || Object.getPrototypeOf(WorkAccessCode)).apply(this, arguments));
  }

  createClass(WorkAccessCode, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        code: 'code',
        expiration_time: 'expiration_time'
      });
    }
  }]);
  return WorkAccessCode;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WorkExperience
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WorkExperience = function (_AbstractCrudObject) {
  inherits(WorkExperience, _AbstractCrudObject);

  function WorkExperience() {
    classCallCheck(this, WorkExperience);
    return possibleConstructorReturn(this, (WorkExperience.__proto__ || Object.getPrototypeOf(WorkExperience)).apply(this, arguments));
  }

  createClass(WorkExperience, [{
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        description: 'description',
        employer: 'employer',
        end_date: 'end_date',
        from: 'from',
        id: 'id',
        location: 'location',
        position: 'position',
        projects: 'projects',
        start_date: 'start_date',
        with: 'with'
      });
    }
  }]);
  return WorkExperience;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WorkSkill
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WorkSkill = function (_AbstractCrudObject) {
  inherits(WorkSkill, _AbstractCrudObject);

  function WorkSkill() {
    classCallCheck(this, WorkSkill);
    return possibleConstructorReturn(this, (WorkSkill.__proto__ || Object.getPrototypeOf(WorkSkill)).apply(this, arguments));
  }

  createClass(WorkSkill, [{
    key: 'getUsers',
    value: function getUsers(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      var fetchFirstPage = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;

      return this.getEdge(User, fields, params, fetchFirstPage, '/users');
    }
  }, {
    key: 'get',
    value: function get(fields) {
      var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

      // $FlowFixMe : Support Generic Types
      return this.read(fields, params);
    }
  }], [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return WorkSkill;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WorkUserBadges
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WorkUserBadges = function (_AbstractCrudObject) {
  inherits(WorkUserBadges, _AbstractCrudObject);

  function WorkUserBadges() {
    classCallCheck(this, WorkUserBadges);
    return possibleConstructorReturn(this, (WorkUserBadges.__proto__ || Object.getPrototypeOf(WorkUserBadges)).apply(this, arguments));
  }

  createClass(WorkUserBadges, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        category: 'category',
        description: 'description',
        icon: 'icon',
        id: 'id',
        name: 'name'
      });
    }
  }]);
  return WorkUserBadges;
}(AbstractCrudObject);

/*
* Copyright (c) Meta Platforms, Inc. and affiliates.
* All rights reserved.
*
* This source code is licensed under the license found in the
* LICENSE file in the root directory of this source tree.
*
* 
*/

/**
 * WorkUserFrontline
 * @extends AbstractCrudObject
 * @see {@link https://developers.facebook.com/docs/marketing-api/}
 */

var WorkUserFrontline = function (_AbstractCrudObject) {
  inherits(WorkUserFrontline, _AbstractCrudObject);

  function WorkUserFrontline() {
    classCallCheck(this, WorkUserFrontline);
    return possibleConstructorReturn(this, (WorkUserFrontline.__proto__ || Object.getPrototypeOf(WorkUserFrontline)).apply(this, arguments));
  }

  createClass(WorkUserFrontline, null, [{
    key: 'Fields',
    get: function get() {
      return Object.freeze({
        has_access: 'has_access',
        is_frontline: 'is_frontline'
      });
    }
  }]);
  return WorkUserFrontline;
}(AbstractCrudObject);

/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 */

//# sourceMappingURL=globals.js.map
